/*
 * MODIFIED to always load synchronously
 */

/**
 * @license almond 0.3.3 Copyright jQuery Foundation and other contributors.
 * Released under MIT license, http://github.com/requirejs/almond/LICENSE
 */
//Going sloppy to avoid 'use strict' string cost, but strict practices should
//be followed.
/*global setTimeout: false */

var requirejs, require, define;
(function (undef) {
    var main, req, makeMap, handlers,
        defined = {},
        waiting = {},
        config = {},
        defining = {},
        hasOwn = Object.prototype.hasOwnProperty,
        aps = [].slice,
        jsSuffixRegExp = /\.js$/;

    function hasProp(obj, prop) {
        return hasOwn.call(obj, prop);
    }

    /**
     * Given a relative module name, like ./something, normalize it to
     * a real name that can be mapped to a path.
     * @param {String} name the relative name
     * @param {String} baseName a real name that the name arg is relative
     * to.
     * @returns {String} normalized name
     */
    function normalize(name, baseName) {
        var nameParts, nameSegment, mapValue, foundMap, lastIndex,
            foundI, foundStarMap, starI, i, j, part, normalizedBaseParts,
            baseParts = baseName && baseName.split("/"),
            map = config.map,
            starMap = (map && map['*']) || {};

        //Adjust any relative paths.
        if (name) {
            name = name.split('/');
            lastIndex = name.length - 1;

            // If wanting node ID compatibility, strip .js from end
            // of IDs. Have to do this here, and not in nameToUrl
            // because node allows either .js or non .js to map
            // to same file.
            if (config.nodeIdCompat && jsSuffixRegExp.test(name[lastIndex])) {
                name[lastIndex] = name[lastIndex].replace(jsSuffixRegExp, '');
            }

            // Starts with a '.' so need the baseName
            if (name[0].charAt(0) === '.' && baseParts) {
                //Convert baseName to array, and lop off the last part,
                //so that . matches that 'directory' and not name of the baseName's
                //module. For instance, baseName of 'one/two/three', maps to
                //'one/two/three.js', but we want the directory, 'one/two' for
                //this normalization.
                normalizedBaseParts = baseParts.slice(0, baseParts.length - 1);
                name = normalizedBaseParts.concat(name);
            }

            //start trimDots
            for (i = 0; i < name.length; i++) {
                part = name[i];
                if (part === '.') {
                    name.splice(i, 1);
                    i -= 1;
                } else if (part === '..') {
                    // If at the start, or previous value is still ..,
                    // keep them so that when converted to a path it may
                    // still work when converted to a path, even though
                    // as an ID it is less than ideal. In larger point
                    // releases, may be better to just kick out an error.
                    if (i === 0 || (i === 1 && name[2] === '..') || name[i - 1] === '..') {
                        continue;
                    } else if (i > 0) {
                        name.splice(i - 1, 2);
                        i -= 2;
                    }
                }
            }
            //end trimDots

            name = name.join('/');
        }

        //Apply map config if available.
        if ((baseParts || starMap) && map) {
            nameParts = name.split('/');

            for (i = nameParts.length; i > 0; i -= 1) {
                nameSegment = nameParts.slice(0, i).join("/");

                if (baseParts) {
                    //Find the longest baseName segment match in the config.
                    //So, do joins on the biggest to smallest lengths of baseParts.
                    for (j = baseParts.length; j > 0; j -= 1) {
                        mapValue = map[baseParts.slice(0, j).join('/')];

                        //baseName segment has  config, find if it has one for
                        //this name.
                        if (mapValue) {
                            mapValue = mapValue[nameSegment];
                            if (mapValue) {
                                //Match, update name to the new value.
                                foundMap = mapValue;
                                foundI = i;
                                break;
                            }
                        }
                    }
                }

                if (foundMap) {
                    break;
                }

                //Check for a star map match, but just hold on to it,
                //if there is a shorter segment match later in a matching
                //config, then favor over this star map.
                if (!foundStarMap && starMap && starMap[nameSegment]) {
                    foundStarMap = starMap[nameSegment];
                    starI = i;
                }
            }

            if (!foundMap && foundStarMap) {
                foundMap = foundStarMap;
                foundI = starI;
            }

            if (foundMap) {
                nameParts.splice(0, foundI, foundMap);
                name = nameParts.join('/');
            }
        }

        return name;
    }

    function makeRequire(relName, forceSync) {
        return function () {
            //A version of a require function that passes a moduleName
            //value for items that may need to
            //look up paths relative to the moduleName
            var args = aps.call(arguments, 0);

            //If first arg is not require('string'), and there is only
            //one arg, it is the array form without a callback. Insert
            //a null so that the following concat is correct.
            if (typeof args[0] !== 'string' && args.length === 1) {
                args.push(null);
            }
            return req.apply(undef, args.concat([relName, forceSync]));
        };
    }

    function makeNormalize(relName) {
        return function (name) {
            return normalize(name, relName);
        };
    }

    function makeLoad(depName) {
        return function (value) {
            defined[depName] = value;
        };
    }

    function callDep(name) {
        if (hasProp(waiting, name)) {
            var args = waiting[name];
            delete waiting[name];
            defining[name] = true;
            main.apply(undef, args);
        }

        if (!hasProp(defined, name) && !hasProp(defining, name)) {
            throw new Error('No ' + name);
        }
        return defined[name];
    }

    //Turns a plugin!resource to [plugin, resource]
    //with the plugin being undefined if the name
    //did not have a plugin prefix.
    function splitPrefix(name) {
        var prefix,
            index = name ? name.indexOf('!') : -1;
        if (index > -1) {
            prefix = name.substring(0, index);
            name = name.substring(index + 1, name.length);
        }
        return [prefix, name];
    }

    //Creates a parts array for a relName where first part is plugin ID,
    //second part is resource ID. Assumes relName has already been normalized.
    function makeRelParts(relName) {
        return relName ? splitPrefix(relName) : [];
    }

    /**
     * Makes a name map, normalizing the name, and using a plugin
     * for normalization if necessary. Grabs a ref to plugin
     * too, as an optimization.
     */
    makeMap = function (name, relParts) {
        var plugin,
            parts = splitPrefix(name),
            prefix = parts[0],
            relResourceName = relParts[1];

        name = parts[1];

        if (prefix) {
            prefix = normalize(prefix, relResourceName);
            plugin = callDep(prefix);
        }

        //Normalize according
        if (prefix) {
            if (plugin && plugin.normalize) {
                name = plugin.normalize(name, makeNormalize(relResourceName));
            } else {
                name = normalize(name, relResourceName);
            }
        } else {
            name = normalize(name, relResourceName);
            parts = splitPrefix(name);
            prefix = parts[0];
            name = parts[1];
            if (prefix) {
                plugin = callDep(prefix);
            }
        }

        //Using ridiculous property names for space reasons
        return {
            f: prefix ? prefix + '!' + name : name, //fullName
            n: name,
            pr: prefix,
            p: plugin
        };
    };

    function makeConfig(name) {
        return function () {
            return (config && config.config && config.config[name]) || {};
        };
    }

    handlers = {
        require: function (name) {
            return makeRequire(name);
        },
        exports: function (name) {
            var e = defined[name];
            if (typeof e !== 'undefined') {
                return e;
            } else {
                return (defined[name] = {});
            }
        },
        module: function (name) {
            return {
                id: name,
                uri: '',
                exports: defined[name],
                config: makeConfig(name)
            };
        }
    };

    main = function (name, deps, callback, relName) {
        var cjsModule, depName, ret, map, i, relParts,
            args = [],
            callbackType = typeof callback,
            usingExports;

        //Use name if no relName
        relName = relName || name;
        relParts = makeRelParts(relName);

        //Call the callback to define the module, if necessary.
        if (callbackType === 'undefined' || callbackType === 'function') {
            //Pull out the defined dependencies and pass the ordered
            //values to the callback.
            //Default to [require, exports, module] if no deps
            deps = !deps.length && callback.length ? ['require', 'exports', 'module'] : deps;
            for (i = 0; i < deps.length; i += 1) {
                map = makeMap(deps[i], relParts);
                depName = map.f;

                //Fast path CommonJS standard dependencies.
                if (depName === "require") {
                    args[i] = handlers.require(name);
                } else if (depName === "exports") {
                    //CommonJS module spec 1.1
                    args[i] = handlers.exports(name);
                    usingExports = true;
                } else if (depName === "module") {
                    //CommonJS module spec 1.1
                    cjsModule = args[i] = handlers.module(name);
                } else if (hasProp(defined, depName) ||
                           hasProp(waiting, depName) ||
                           hasProp(defining, depName)) {
                    args[i] = callDep(depName);
                } else if (map.p) {
                    map.p.load(map.n, makeRequire(relName, true), makeLoad(depName), {});
                    args[i] = defined[depName];
                } else {
                    throw new Error(name + ' missing ' + depName);
                }
            }

            ret = callback ? callback.apply(defined[name], args) : undefined;

            if (name) {
                //If setting exports via "module" is in play,
                //favor that over return value and exports. After that,
                //favor a non-undefined return value over exports use.
                if (cjsModule && cjsModule.exports !== undef &&
                        cjsModule.exports !== defined[name]) {
                    defined[name] = cjsModule.exports;
                } else if (ret !== undef || !usingExports) {
                    //Use the return value from the function.
                    defined[name] = ret;
                }
            }
        } else if (name) {
            //May just be an object definition for the module. Only
            //worry about defining if have a module name.
            defined[name] = callback;
        }
    };

    requirejs = require = req = function (deps, callback, relName, forceSync, alt) {
        if (typeof deps === "string") {
            if (handlers[deps]) {
                //callback in this case is really relName
                return handlers[deps](callback);
            }
            //Just return the module wanted. In this scenario, the
            //deps arg is the module name, and second arg (if passed)
            //is just the relName.
            //Normalize module name, if it contains . or ..
            return callDep(makeMap(deps, makeRelParts(callback)).f);
        } else if (!deps.splice) {
            //deps is a config object, not an array.
            config = deps;
            if (config.deps) {
                req(config.deps, config.callback);
            }
            if (!callback) {
                return;
            }

            if (callback.splice) {
                //callback is an array, which means it is a dependency list.
                //Adjust args if there are dependencies
                deps = callback;
                callback = relName;
                relName = null;
            } else {
                deps = undef;
            }
        }

        //Support require(['a'])
        callback = callback || function () {};

        //If relName is a function, it is an errback handler,
        //so remove it.
        if (typeof relName === 'function') {
            relName = forceSync;
            forceSync = alt;
        }

        main(undef, deps, callback, relName);

        return req;
    };

    /**
     * Just drops the config on the floor, but returns req in case
     * the config return value is used.
     */
    req.config = function (cfg) {
        return req(cfg);
    };

    /**
     * Expose module registry for debugging and tooling
     */
    requirejs._defined = defined;

    define = function (name, deps, callback) {
        if (typeof name !== 'string') {
            throw new Error('See almond README: incorrect module build, no module name');
        }

        //This module may not have dependencies
        if (!deps.splice) {
            //deps is not an array, so probably means
            //an object literal or factory function for
            //the value. Adjust args.
            callback = deps;
            deps = [];
        }

        if (!hasProp(defined, name) && !hasProp(waiting, name)) {
            waiting[name] = [name, deps, callback];
        }
    };

    define.amd = {
        jQuery: true
    };
}());
define("lib/almond", function(){});

/*!
 * jQuery JavaScript Library v2.1.1
 * http://jquery.com/
 *
 * Includes Sizzle.js
 * http://sizzlejs.com/
 *
 * Copyright 2005, 2014 jQuery Foundation, Inc. and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 *
 * Date: 2014-05-01T17:11Z
 */

(function( global, factory ) {

	if ( typeof module === "object" && typeof module.exports === "object" ) {
		// For CommonJS and CommonJS-like environments where a proper window is present,
		// execute the factory and get jQuery
		// For environments that do not inherently posses a window with a document
		// (such as Node.js), expose a jQuery-making factory as module.exports
		// This accentuates the need for the creation of a real window
		// e.g. var jQuery = require("jquery")(window);
		// See ticket #14549 for more info
		module.exports = global.document ?
			factory( global, true ) :
			function( w ) {
				if ( !w.document ) {
					throw new Error( "jQuery requires a window with a document" );
				}
				return factory( w );
			};
	} else {
		factory( global );
	}

// Pass this if window is not defined yet
}(typeof window !== "undefined" ? window : this, function( window, noGlobal ) {

// Can't do this because several apps including ASP.NET trace
// the stack via arguments.caller.callee and Firefox dies if
// you try to trace through "use strict" call chains. (#13335)
// Support: Firefox 18+
//

var arr = [];

var slice = arr.slice;

var concat = arr.concat;

var push = arr.push;

var indexOf = arr.indexOf;

var class2type = {};

var toString = class2type.toString;

var hasOwn = class2type.hasOwnProperty;

var support = {};



var
	// Use the correct document accordingly with window argument (sandbox)
	document = window.document,

	version = "2.1.1",

	// Define a local copy of jQuery
	jQuery = function( selector, context ) {
		// The jQuery object is actually just the init constructor 'enhanced'
		// Need init if jQuery is called (just allow error to be thrown if not included)
		return new jQuery.fn.init( selector, context );
	},

	// Support: Android<4.1
	// Make sure we trim BOM and NBSP
	rtrim = /^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,

	// Matches dashed string for camelizing
	rmsPrefix = /^-ms-/,
	rdashAlpha = /-([\da-z])/gi,

	// Used by jQuery.camelCase as callback to replace()
	fcamelCase = function( all, letter ) {
		return letter.toUpperCase();
	};

jQuery.fn = jQuery.prototype = {
	// The current version of jQuery being used
	jquery: version,

	constructor: jQuery,

	// Start with an empty selector
	selector: "",

	// The default length of a jQuery object is 0
	length: 0,

	toArray: function() {
		return slice.call( this );
	},

	// Get the Nth element in the matched element set OR
	// Get the whole matched element set as a clean array
	get: function( num ) {
		return num != null ?

			// Return just the one element from the set
			( num < 0 ? this[ num + this.length ] : this[ num ] ) :

			// Return all the elements in a clean array
			slice.call( this );
	},

	// Take an array of elements and push it onto the stack
	// (returning the new matched element set)
	pushStack: function( elems ) {

		// Build a new jQuery matched element set
		var ret = jQuery.merge( this.constructor(), elems );

		// Add the old object onto the stack (as a reference)
		ret.prevObject = this;
		ret.context = this.context;

		// Return the newly-formed element set
		return ret;
	},

	// Execute a callback for every element in the matched set.
	// (You can seed the arguments with an array of args, but this is
	// only used internally.)
	each: function( callback, args ) {
		return jQuery.each( this, callback, args );
	},

	map: function( callback ) {
		return this.pushStack( jQuery.map(this, function( elem, i ) {
			return callback.call( elem, i, elem );
		}));
	},

	slice: function() {
		return this.pushStack( slice.apply( this, arguments ) );
	},

	first: function() {
		return this.eq( 0 );
	},

	last: function() {
		return this.eq( -1 );
	},

	eq: function( i ) {
		var len = this.length,
			j = +i + ( i < 0 ? len : 0 );
		return this.pushStack( j >= 0 && j < len ? [ this[j] ] : [] );
	},

	end: function() {
		return this.prevObject || this.constructor(null);
	},

	// For internal use only.
	// Behaves like an Array's method, not like a jQuery method.
	push: push,
	sort: arr.sort,
	splice: arr.splice
};

jQuery.extend = jQuery.fn.extend = function() {
	var options, name, src, copy, copyIsArray, clone,
		target = arguments[0] || {},
		i = 1,
		length = arguments.length,
		deep = false;

	// Handle a deep copy situation
	if ( typeof target === "boolean" ) {
		deep = target;

		// skip the boolean and the target
		target = arguments[ i ] || {};
		i++;
	}

	// Handle case when target is a string or something (possible in deep copy)
	if ( typeof target !== "object" && !jQuery.isFunction(target) ) {
		target = {};
	}

	// extend jQuery itself if only one argument is passed
	if ( i === length ) {
		target = this;
		i--;
	}

	for ( ; i < length; i++ ) {
		// Only deal with non-null/undefined values
		if ( (options = arguments[ i ]) != null ) {
			// Extend the base object
			for ( name in options ) {
				src = target[ name ];
				copy = options[ name ];

				// Prevent never-ending loop
				if ( target === copy ) {
					continue;
				}

				// Recurse if we're merging plain objects or arrays
				if ( deep && copy && ( jQuery.isPlainObject(copy) || (copyIsArray = jQuery.isArray(copy)) ) ) {
					if ( copyIsArray ) {
						copyIsArray = false;
						clone = src && jQuery.isArray(src) ? src : [];

					} else {
						clone = src && jQuery.isPlainObject(src) ? src : {};
					}

					// Never move original objects, clone them
					target[ name ] = jQuery.extend( deep, clone, copy );

				// Don't bring in undefined values
				} else if ( copy !== undefined ) {
					target[ name ] = copy;
				}
			}
		}
	}

	// Return the modified object
	return target;
};

jQuery.extend({
	// Unique for each copy of jQuery on the page
	expando: "jQuery" + ( version + Math.random() ).replace( /\D/g, "" ),

	// Assume jQuery is ready without the ready module
	isReady: true,

	error: function( msg ) {
		throw new Error( msg );
	},

	noop: function() {},

	// See test/unit/core.js for details concerning isFunction.
	// Since version 1.3, DOM methods and functions like alert
	// aren't supported. They return false on IE (#2968).
	isFunction: function( obj ) {
		return jQuery.type(obj) === "function";
	},

	isArray: Array.isArray,

	isWindow: function( obj ) {
		return obj != null && obj === obj.window;
	},

	isNumeric: function( obj ) {
		// parseFloat NaNs numeric-cast false positives (null|true|false|"")
		// ...but misinterprets leading-number strings, particularly hex literals ("0x...")
		// subtraction forces infinities to NaN
		return !jQuery.isArray( obj ) && obj - parseFloat( obj ) >= 0;
	},

	isPlainObject: function( obj ) {
		// Not plain objects:
		// - Any object or value whose internal [[Class]] property is not "[object Object]"
		// - DOM nodes
		// - window
		if ( jQuery.type( obj ) !== "object" || obj.nodeType || jQuery.isWindow( obj ) ) {
			return false;
		}

		if ( obj.constructor &&
				!hasOwn.call( obj.constructor.prototype, "isPrototypeOf" ) ) {
			return false;
		}

		// If the function hasn't returned already, we're confident that
		// |obj| is a plain object, created by {} or constructed with new Object
		return true;
	},

	isEmptyObject: function( obj ) {
		var name;
		for ( name in obj ) {
			return false;
		}
		return true;
	},

	type: function( obj ) {
		if ( obj == null ) {
			return obj + "";
		}
		// Support: Android < 4.0, iOS < 6 (functionish RegExp)
		return typeof obj === "object" || typeof obj === "function" ?
			class2type[ toString.call(obj) ] || "object" :
			typeof obj;
	},

	// Evaluates a script in a global context
	globalEval: function( code ) {
		var script,
			indirect = eval;

		code = jQuery.trim( code );

		if ( code ) {
			// If the code includes a valid, prologue position
			// strict mode pragma, execute code by injecting a
			// script tag into the document.
			if ( code.indexOf("use strict") === 1 ) {
				script = document.createElement("script");
				script.text = code;
				document.head.appendChild( script ).parentNode.removeChild( script );
			} else {
			// Otherwise, avoid the DOM node creation, insertion
			// and removal by using an indirect global eval
				indirect( code );
			}
		}
	},

	// Convert dashed to camelCase; used by the css and data modules
	// Microsoft forgot to hump their vendor prefix (#9572)
	camelCase: function( string ) {
		return string.replace( rmsPrefix, "ms-" ).replace( rdashAlpha, fcamelCase );
	},

	nodeName: function( elem, name ) {
		return elem.nodeName && elem.nodeName.toLowerCase() === name.toLowerCase();
	},

	// args is for internal usage only
	each: function( obj, callback, args ) {
		var value,
			i = 0,
			length = obj.length,
			isArray = isArraylike( obj );

		if ( args ) {
			if ( isArray ) {
				for ( ; i < length; i++ ) {
					value = callback.apply( obj[ i ], args );

					if ( value === false ) {
						break;
					}
				}
			} else {
				for ( i in obj ) {
					value = callback.apply( obj[ i ], args );

					if ( value === false ) {
						break;
					}
				}
			}

		// A special, fast, case for the most common use of each
		} else {
			if ( isArray ) {
				for ( ; i < length; i++ ) {
					value = callback.call( obj[ i ], i, obj[ i ] );

					if ( value === false ) {
						break;
					}
				}
			} else {
				for ( i in obj ) {
					value = callback.call( obj[ i ], i, obj[ i ] );

					if ( value === false ) {
						break;
					}
				}
			}
		}

		return obj;
	},

	// Support: Android<4.1
	trim: function( text ) {
		return text == null ?
			"" :
			( text + "" ).replace( rtrim, "" );
	},

	// results is for internal usage only
	makeArray: function( arr, results ) {
		var ret = results || [];

		if ( arr != null ) {
			if ( isArraylike( Object(arr) ) ) {
				jQuery.merge( ret,
					typeof arr === "string" ?
					[ arr ] : arr
				);
			} else {
				push.call( ret, arr );
			}
		}

		return ret;
	},

	inArray: function( elem, arr, i ) {
		return arr == null ? -1 : indexOf.call( arr, elem, i );
	},

	merge: function( first, second ) {
		var len = +second.length,
			j = 0,
			i = first.length;

		for ( ; j < len; j++ ) {
			first[ i++ ] = second[ j ];
		}

		first.length = i;

		return first;
	},

	grep: function( elems, callback, invert ) {
		var callbackInverse,
			matches = [],
			i = 0,
			length = elems.length,
			callbackExpect = !invert;

		// Go through the array, only saving the items
		// that pass the validator function
		for ( ; i < length; i++ ) {
			callbackInverse = !callback( elems[ i ], i );
			if ( callbackInverse !== callbackExpect ) {
				matches.push( elems[ i ] );
			}
		}

		return matches;
	},

	// arg is for internal usage only
	map: function( elems, callback, arg ) {
		var value,
			i = 0,
			length = elems.length,
			isArray = isArraylike( elems ),
			ret = [];

		// Go through the array, translating each of the items to their new values
		if ( isArray ) {
			for ( ; i < length; i++ ) {
				value = callback( elems[ i ], i, arg );

				if ( value != null ) {
					ret.push( value );
				}
			}

		// Go through every key on the object,
		} else {
			for ( i in elems ) {
				value = callback( elems[ i ], i, arg );

				if ( value != null ) {
					ret.push( value );
				}
			}
		}

		// Flatten any nested arrays
		return concat.apply( [], ret );
	},

	// A global GUID counter for objects
	guid: 1,

	// Bind a function to a context, optionally partially applying any
	// arguments.
	proxy: function( fn, context ) {
		var tmp, args, proxy;

		if ( typeof context === "string" ) {
			tmp = fn[ context ];
			context = fn;
			fn = tmp;
		}

		// Quick check to determine if target is callable, in the spec
		// this throws a TypeError, but we will just return undefined.
		if ( !jQuery.isFunction( fn ) ) {
			return undefined;
		}

		// Simulated bind
		args = slice.call( arguments, 2 );
		proxy = function() {
			return fn.apply( context || this, args.concat( slice.call( arguments ) ) );
		};

		// Set the guid of unique handler to the same of original handler, so it can be removed
		proxy.guid = fn.guid = fn.guid || jQuery.guid++;

		return proxy;
	},

	now: Date.now,

	// jQuery.support is not used in Core but other projects attach their
	// properties to it so it needs to exist.
	support: support
});

// Populate the class2type map
jQuery.each("Boolean Number String Function Array Date RegExp Object Error".split(" "), function(i, name) {
	class2type[ "[object " + name + "]" ] = name.toLowerCase();
});

function isArraylike( obj ) {
	var length = obj.length,
		type = jQuery.type( obj );

	if ( type === "function" || jQuery.isWindow( obj ) ) {
		return false;
	}

	if ( obj.nodeType === 1 && length ) {
		return true;
	}

	return type === "array" || length === 0 ||
		typeof length === "number" && length > 0 && ( length - 1 ) in obj;
}
var Sizzle =
/*!
 * Sizzle CSS Selector Engine v1.10.19
 * http://sizzlejs.com/
 *
 * Copyright 2013 jQuery Foundation, Inc. and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 *
 * Date: 2014-04-18
 */
(function( window ) {

var i,
	support,
	Expr,
	getText,
	isXML,
	tokenize,
	compile,
	select,
	outermostContext,
	sortInput,
	hasDuplicate,

	// Local document vars
	setDocument,
	document,
	docElem,
	documentIsHTML,
	rbuggyQSA,
	rbuggyMatches,
	matches,
	contains,

	// Instance-specific data
	expando = "sizzle" + -(new Date()),
	preferredDoc = window.document,
	dirruns = 0,
	done = 0,
	classCache = createCache(),
	tokenCache = createCache(),
	compilerCache = createCache(),
	sortOrder = function( a, b ) {
		if ( a === b ) {
			hasDuplicate = true;
		}
		return 0;
	},

	// General-purpose constants
	strundefined = typeof undefined,
	MAX_NEGATIVE = 1 << 31,

	// Instance methods
	hasOwn = ({}).hasOwnProperty,
	arr = [],
	pop = arr.pop,
	push_native = arr.push,
	push = arr.push,
	slice = arr.slice,
	// Use a stripped-down indexOf if we can't use a native one
	indexOf = arr.indexOf || function( elem ) {
		var i = 0,
			len = this.length;
		for ( ; i < len; i++ ) {
			if ( this[i] === elem ) {
				return i;
			}
		}
		return -1;
	},

	booleans = "checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",

	// Regular expressions

	// Whitespace characters http://www.w3.org/TR/css3-selectors/#whitespace
	whitespace = "[\\x20\\t\\r\\n\\f]",
	// http://www.w3.org/TR/css3-syntax/#characters
	characterEncoding = "(?:\\\\.|[\\w-]|[^\\x00-\\xa0])+",

	// Loosely modeled on CSS identifier characters
	// An unquoted value should be a CSS identifier http://www.w3.org/TR/css3-selectors/#attribute-selectors
	// Proper syntax: http://www.w3.org/TR/CSS21/syndata.html#value-def-identifier
	identifier = characterEncoding.replace( "w", "w#" ),

	// Attribute selectors: http://www.w3.org/TR/selectors/#attribute-selectors
	attributes = "\\[" + whitespace + "*(" + characterEncoding + ")(?:" + whitespace +
		// Operator (capture 2)
		"*([*^$|!~]?=)" + whitespace +
		// "Attribute values must be CSS identifiers [capture 5] or strings [capture 3 or capture 4]"
		"*(?:'((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\"|(" + identifier + "))|)" + whitespace +
		"*\\]",

	pseudos = ":(" + characterEncoding + ")(?:\\((" +
		// To reduce the number of selectors needing tokenize in the preFilter, prefer arguments:
		// 1. quoted (capture 3; capture 4 or capture 5)
		"('((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\")|" +
		// 2. simple (capture 6)
		"((?:\\\\.|[^\\\\()[\\]]|" + attributes + ")*)|" +
		// 3. anything else (capture 2)
		".*" +
		")\\)|)",

	// Leading and non-escaped trailing whitespace, capturing some non-whitespace characters preceding the latter
	rtrim = new RegExp( "^" + whitespace + "+|((?:^|[^\\\\])(?:\\\\.)*)" + whitespace + "+$", "g" ),

	rcomma = new RegExp( "^" + whitespace + "*," + whitespace + "*" ),
	rcombinators = new RegExp( "^" + whitespace + "*([>+~]|" + whitespace + ")" + whitespace + "*" ),

	rattributeQuotes = new RegExp( "=" + whitespace + "*([^\\]'\"]*?)" + whitespace + "*\\]", "g" ),

	rpseudo = new RegExp( pseudos ),
	ridentifier = new RegExp( "^" + identifier + "$" ),

	matchExpr = {
		"ID": new RegExp( "^#(" + characterEncoding + ")" ),
		"CLASS": new RegExp( "^\\.(" + characterEncoding + ")" ),
		"TAG": new RegExp( "^(" + characterEncoding.replace( "w", "w*" ) + ")" ),
		"ATTR": new RegExp( "^" + attributes ),
		"PSEUDO": new RegExp( "^" + pseudos ),
		"CHILD": new RegExp( "^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\(" + whitespace +
			"*(even|odd|(([+-]|)(\\d*)n|)" + whitespace + "*(?:([+-]|)" + whitespace +
			"*(\\d+)|))" + whitespace + "*\\)|)", "i" ),
		"bool": new RegExp( "^(?:" + booleans + ")$", "i" ),
		// For use in libraries implementing .is()
		// We use this for POS matching in `select`
		"needsContext": new RegExp( "^" + whitespace + "*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\(" +
			whitespace + "*((?:-\\d)?\\d*)" + whitespace + "*\\)|)(?=[^-]|$)", "i" )
	},

	rinputs = /^(?:input|select|textarea|button)$/i,
	rheader = /^h\d$/i,

	rnative = /^[^{]+\{\s*\[native \w/,

	// Easily-parseable/retrievable ID or TAG or CLASS selectors
	rquickExpr = /^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,

	rsibling = /[+~]/,
	rescape = /'|\\/g,

	// CSS escapes http://www.w3.org/TR/CSS21/syndata.html#escaped-characters
	runescape = new RegExp( "\\\\([\\da-f]{1,6}" + whitespace + "?|(" + whitespace + ")|.)", "ig" ),
	funescape = function( _, escaped, escapedWhitespace ) {
		var high = "0x" + escaped - 0x10000;
		// NaN means non-codepoint
		// Support: Firefox<24
		// Workaround erroneous numeric interpretation of +"0x"
		return high !== high || escapedWhitespace ?
			escaped :
			high < 0 ?
				// BMP codepoint
				String.fromCharCode( high + 0x10000 ) :
				// Supplemental Plane codepoint (surrogate pair)
				String.fromCharCode( high >> 10 | 0xD800, high & 0x3FF | 0xDC00 );
	};

// Optimize for push.apply( _, NodeList )
try {
	push.apply(
		(arr = slice.call( preferredDoc.childNodes )),
		preferredDoc.childNodes
	);
	// Support: Android<4.0
	// Detect silently failing push.apply
	arr[ preferredDoc.childNodes.length ].nodeType;
} catch ( e ) {
	push = { apply: arr.length ?

		// Leverage slice if possible
		function( target, els ) {
			push_native.apply( target, slice.call(els) );
		} :

		// Support: IE<9
		// Otherwise append directly
		function( target, els ) {
			var j = target.length,
				i = 0;
			// Can't trust NodeList.length
			while ( (target[j++] = els[i++]) ) {}
			target.length = j - 1;
		}
	};
}

function Sizzle( selector, context, results, seed ) {
	var match, elem, m, nodeType,
		// QSA vars
		i, groups, old, nid, newContext, newSelector;

	if ( ( context ? context.ownerDocument || context : preferredDoc ) !== document ) {
		setDocument( context );
	}

	context = context || document;
	results = results || [];

	if ( !selector || typeof selector !== "string" ) {
		return results;
	}

	if ( (nodeType = context.nodeType) !== 1 && nodeType !== 9 ) {
		return [];
	}

	if ( documentIsHTML && !seed ) {

		// Shortcuts
		if ( (match = rquickExpr.exec( selector )) ) {
			// Speed-up: Sizzle("#ID")
			if ( (m = match[1]) ) {
				if ( nodeType === 9 ) {
					elem = context.getElementById( m );
					// Check parentNode to catch when Blackberry 4.6 returns
					// nodes that are no longer in the document (jQuery #6963)
					if ( elem && elem.parentNode ) {
						// Handle the case where IE, Opera, and Webkit return items
						// by name instead of ID
						if ( elem.id === m ) {
							results.push( elem );
							return results;
						}
					} else {
						return results;
					}
				} else {
					// Context is not a document
					if ( context.ownerDocument && (elem = context.ownerDocument.getElementById( m )) &&
						contains( context, elem ) && elem.id === m ) {
						results.push( elem );
						return results;
					}
				}

			// Speed-up: Sizzle("TAG")
			} else if ( match[2] ) {
				push.apply( results, context.getElementsByTagName( selector ) );
				return results;

			// Speed-up: Sizzle(".CLASS")
			} else if ( (m = match[3]) && support.getElementsByClassName && context.getElementsByClassName ) {
				push.apply( results, context.getElementsByClassName( m ) );
				return results;
			}
		}

		// QSA path
		if ( support.qsa && (!rbuggyQSA || !rbuggyQSA.test( selector )) ) {
			nid = old = expando;
			newContext = context;
			newSelector = nodeType === 9 && selector;

			// qSA works strangely on Element-rooted queries
			// We can work around this by specifying an extra ID on the root
			// and working up from there (Thanks to Andrew Dupont for the technique)
			// IE 8 doesn't work on object elements
			if ( nodeType === 1 && context.nodeName.toLowerCase() !== "object" ) {
				groups = tokenize( selector );

				if ( (old = context.getAttribute("id")) ) {
					nid = old.replace( rescape, "\\$&" );
				} else {
					context.setAttribute( "id", nid );
				}
				nid = "[id='" + nid + "'] ";

				i = groups.length;
				while ( i-- ) {
					groups[i] = nid + toSelector( groups[i] );
				}
				newContext = rsibling.test( selector ) && testContext( context.parentNode ) || context;
				newSelector = groups.join(",");
			}

			if ( newSelector ) {
				try {
					push.apply( results,
						newContext.querySelectorAll( newSelector )
					);
					return results;
				} catch(qsaError) {
				} finally {
					if ( !old ) {
						context.removeAttribute("id");
					}
				}
			}
		}
	}

	// All others
	return select( selector.replace( rtrim, "$1" ), context, results, seed );
}

/**
 * Create key-value caches of limited size
 * @returns {Function(string, Object)} Returns the Object data after storing it on itself with
 *	property name the (space-suffixed) string and (if the cache is larger than Expr.cacheLength)
 *	deleting the oldest entry
 */
function createCache() {
	var keys = [];

	function cache( key, value ) {
		// Use (key + " ") to avoid collision with native prototype properties (see Issue #157)
		if ( keys.push( key + " " ) > Expr.cacheLength ) {
			// Only keep the most recent entries
			delete cache[ keys.shift() ];
		}
		return (cache[ key + " " ] = value);
	}
	return cache;
}

/**
 * Mark a function for special use by Sizzle
 * @param {Function} fn The function to mark
 */
function markFunction( fn ) {
	fn[ expando ] = true;
	return fn;
}

/**
 * Support testing using an element
 * @param {Function} fn Passed the created div and expects a boolean result
 */
function assert( fn ) {
	var div = document.createElement("div");

	try {
		return !!fn( div );
	} catch (e) {
		return false;
	} finally {
		// Remove from its parent by default
		if ( div.parentNode ) {
			div.parentNode.removeChild( div );
		}
		// release memory in IE
		div = null;
	}
}

/**
 * Adds the same handler for all of the specified attrs
 * @param {String} attrs Pipe-separated list of attributes
 * @param {Function} handler The method that will be applied
 */
function addHandle( attrs, handler ) {
	var arr = attrs.split("|"),
		i = attrs.length;

	while ( i-- ) {
		Expr.attrHandle[ arr[i] ] = handler;
	}
}

/**
 * Checks document order of two siblings
 * @param {Element} a
 * @param {Element} b
 * @returns {Number} Returns less than 0 if a precedes b, greater than 0 if a follows b
 */
function siblingCheck( a, b ) {
	var cur = b && a,
		diff = cur && a.nodeType === 1 && b.nodeType === 1 &&
			( ~b.sourceIndex || MAX_NEGATIVE ) -
			( ~a.sourceIndex || MAX_NEGATIVE );

	// Use IE sourceIndex if available on both nodes
	if ( diff ) {
		return diff;
	}

	// Check if b follows a
	if ( cur ) {
		while ( (cur = cur.nextSibling) ) {
			if ( cur === b ) {
				return -1;
			}
		}
	}

	return a ? 1 : -1;
}

/**
 * Returns a function to use in pseudos for input types
 * @param {String} type
 */
function createInputPseudo( type ) {
	return function( elem ) {
		var name = elem.nodeName.toLowerCase();
		return name === "input" && elem.type === type;
	};
}

/**
 * Returns a function to use in pseudos for buttons
 * @param {String} type
 */
function createButtonPseudo( type ) {
	return function( elem ) {
		var name = elem.nodeName.toLowerCase();
		return (name === "input" || name === "button") && elem.type === type;
	};
}

/**
 * Returns a function to use in pseudos for positionals
 * @param {Function} fn
 */
function createPositionalPseudo( fn ) {
	return markFunction(function( argument ) {
		argument = +argument;
		return markFunction(function( seed, matches ) {
			var j,
				matchIndexes = fn( [], seed.length, argument ),
				i = matchIndexes.length;

			// Match elements found at the specified indexes
			while ( i-- ) {
				if ( seed[ (j = matchIndexes[i]) ] ) {
					seed[j] = !(matches[j] = seed[j]);
				}
			}
		});
	});
}

/**
 * Checks a node for validity as a Sizzle context
 * @param {Element|Object=} context
 * @returns {Element|Object|Boolean} The input node if acceptable, otherwise a falsy value
 */
function testContext( context ) {
	return context && typeof context.getElementsByTagName !== strundefined && context;
}

// Expose support vars for convenience
support = Sizzle.support = {};

/**
 * Detects XML nodes
 * @param {Element|Object} elem An element or a document
 * @returns {Boolean} True iff elem is a non-HTML XML node
 */
isXML = Sizzle.isXML = function( elem ) {
	// documentElement is verified for cases where it doesn't yet exist
	// (such as loading iframes in IE - #4833)
	var documentElement = elem && (elem.ownerDocument || elem).documentElement;
	return documentElement ? documentElement.nodeName !== "HTML" : false;
};

/**
 * Sets document-related variables once based on the current document
 * @param {Element|Object} [doc] An element or document object to use to set the document
 * @returns {Object} Returns the current document
 */
setDocument = Sizzle.setDocument = function( node ) {
	var hasCompare,
		doc = node ? node.ownerDocument || node : preferredDoc,
		parent = doc.defaultView;

	// If no document and documentElement is available, return
	if ( doc === document || doc.nodeType !== 9 || !doc.documentElement ) {
		return document;
	}

	// Set our document
	document = doc;
	docElem = doc.documentElement;

	// Support tests
	documentIsHTML = !isXML( doc );

	// Support: IE>8
	// If iframe document is assigned to "document" variable and if iframe has been reloaded,
	// IE will throw "permission denied" error when accessing "document" variable, see jQuery #13936
	// IE6-8 do not support the defaultView property so parent will be undefined
	if ( parent && parent !== parent.top ) {
		// IE11 does not have attachEvent, so all must suffer
		if ( parent.addEventListener ) {
			parent.addEventListener( "unload", function() {
				setDocument();
			}, false );
		} else if ( parent.attachEvent ) {
			parent.attachEvent( "onunload", function() {
				setDocument();
			});
		}
	}

	/* Attributes
	---------------------------------------------------------------------- */

	// Support: IE<8
	// Verify that getAttribute really returns attributes and not properties (excepting IE8 booleans)
	support.attributes = assert(function( div ) {
		div.className = "i";
		return !div.getAttribute("className");
	});

	/* getElement(s)By*
	---------------------------------------------------------------------- */

	// Check if getElementsByTagName("*") returns only elements
	support.getElementsByTagName = assert(function( div ) {
		div.appendChild( doc.createComment("") );
		return !div.getElementsByTagName("*").length;
	});

	// Check if getElementsByClassName can be trusted
	support.getElementsByClassName = rnative.test( doc.getElementsByClassName ) && assert(function( div ) {
		div.innerHTML = "<div class='a'></div><div class='a i'></div>";

		// Support: Safari<4
		// Catch class over-caching
		div.firstChild.className = "i";
		// Support: Opera<10
		// Catch gEBCN failure to find non-leading classes
		return div.getElementsByClassName("i").length === 2;
	});

	// Support: IE<10
	// Check if getElementById returns elements by name
	// The broken getElementById methods don't pick up programatically-set names,
	// so use a roundabout getElementsByName test
	support.getById = assert(function( div ) {
		docElem.appendChild( div ).id = expando;
		return !doc.getElementsByName || !doc.getElementsByName( expando ).length;
	});

	// ID find and filter
	if ( support.getById ) {
		Expr.find["ID"] = function( id, context ) {
			if ( typeof context.getElementById !== strundefined && documentIsHTML ) {
				var m = context.getElementById( id );
				// Check parentNode to catch when Blackberry 4.6 returns
				// nodes that are no longer in the document #6963
				return m && m.parentNode ? [ m ] : [];
			}
		};
		Expr.filter["ID"] = function( id ) {
			var attrId = id.replace( runescape, funescape );
			return function( elem ) {
				return elem.getAttribute("id") === attrId;
			};
		};
	} else {
		// Support: IE6/7
		// getElementById is not reliable as a find shortcut
		delete Expr.find["ID"];

		Expr.filter["ID"] =  function( id ) {
			var attrId = id.replace( runescape, funescape );
			return function( elem ) {
				var node = typeof elem.getAttributeNode !== strundefined && elem.getAttributeNode("id");
				return node && node.value === attrId;
			};
		};
	}

	// Tag
	Expr.find["TAG"] = support.getElementsByTagName ?
		function( tag, context ) {
			if ( typeof context.getElementsByTagName !== strundefined ) {
				return context.getElementsByTagName( tag );
			}
		} :
		function( tag, context ) {
			var elem,
				tmp = [],
				i = 0,
				results = context.getElementsByTagName( tag );

			// Filter out possible comments
			if ( tag === "*" ) {
				while ( (elem = results[i++]) ) {
					if ( elem.nodeType === 1 ) {
						tmp.push( elem );
					}
				}

				return tmp;
			}
			return results;
		};

	// Class
	Expr.find["CLASS"] = support.getElementsByClassName && function( className, context ) {
		if ( typeof context.getElementsByClassName !== strundefined && documentIsHTML ) {
			return context.getElementsByClassName( className );
		}
	};

	/* QSA/matchesSelector
	---------------------------------------------------------------------- */

	// QSA and matchesSelector support

	// matchesSelector(:active) reports false when true (IE9/Opera 11.5)
	rbuggyMatches = [];

	// qSa(:focus) reports false when true (Chrome 21)
	// We allow this because of a bug in IE8/9 that throws an error
	// whenever `document.activeElement` is accessed on an iframe
	// So, we allow :focus to pass through QSA all the time to avoid the IE error
	// See http://bugs.jquery.com/ticket/13378
	rbuggyQSA = [];

	if ( (support.qsa = rnative.test( doc.querySelectorAll )) ) {
		// Build QSA regex
		// Regex strategy adopted from Diego Perini
		assert(function( div ) {
			// Select is set to empty string on purpose
			// This is to test IE's treatment of not explicitly
			// setting a boolean content attribute,
			// since its presence should be enough
			// http://bugs.jquery.com/ticket/12359
			div.innerHTML = "<select msallowclip=''><option selected=''></option></select>";

			// Support: IE8, Opera 11-12.16
			// Nothing should be selected when empty strings follow ^= or $= or *=
			// The test attribute must be unknown in Opera but "safe" for WinRT
			// http://msdn.microsoft.com/en-us/library/ie/hh465388.aspx#attribute_section
			if ( div.querySelectorAll("[msallowclip^='']").length ) {
				rbuggyQSA.push( "[*^$]=" + whitespace + "*(?:''|\"\")" );
			}

			// Support: IE8
			// Boolean attributes and "value" are not treated correctly
			if ( !div.querySelectorAll("[selected]").length ) {
				rbuggyQSA.push( "\\[" + whitespace + "*(?:value|" + booleans + ")" );
			}

			// Webkit/Opera - :checked should return selected option elements
			// http://www.w3.org/TR/2011/REC-css3-selectors-20110929/#checked
			// IE8 throws error here and will not see later tests
			if ( !div.querySelectorAll(":checked").length ) {
				rbuggyQSA.push(":checked");
			}
		});

		assert(function( div ) {
			// Support: Windows 8 Native Apps
			// The type and name attributes are restricted during .innerHTML assignment
			var input = doc.createElement("input");
			input.setAttribute( "type", "hidden" );
			div.appendChild( input ).setAttribute( "name", "D" );

			// Support: IE8
			// Enforce case-sensitivity of name attribute
			if ( div.querySelectorAll("[name=d]").length ) {
				rbuggyQSA.push( "name" + whitespace + "*[*^$|!~]?=" );
			}

			// FF 3.5 - :enabled/:disabled and hidden elements (hidden elements are still enabled)
			// IE8 throws error here and will not see later tests
			if ( !div.querySelectorAll(":enabled").length ) {
				rbuggyQSA.push( ":enabled", ":disabled" );
			}

			// Opera 10-11 does not throw on post-comma invalid pseudos
			div.querySelectorAll("*,:x");
			rbuggyQSA.push(",.*:");
		});
	}

	if ( (support.matchesSelector = rnative.test( (matches = docElem.matches ||
		docElem.webkitMatchesSelector ||
		docElem.mozMatchesSelector ||
		docElem.oMatchesSelector ||
		docElem.msMatchesSelector) )) ) {

		assert(function( div ) {
			// Check to see if it's possible to do matchesSelector
			// on a disconnected node (IE 9)
			support.disconnectedMatch = matches.call( div, "div" );

			// This should fail with an exception
			// Gecko does not error, returns false instead
			matches.call( div, "[s!='']:x" );
			rbuggyMatches.push( "!=", pseudos );
		});
	}

	rbuggyQSA = rbuggyQSA.length && new RegExp( rbuggyQSA.join("|") );
	rbuggyMatches = rbuggyMatches.length && new RegExp( rbuggyMatches.join("|") );

	/* Contains
	---------------------------------------------------------------------- */
	hasCompare = rnative.test( docElem.compareDocumentPosition );

	// Element contains another
	// Purposefully does not implement inclusive descendent
	// As in, an element does not contain itself
	contains = hasCompare || rnative.test( docElem.contains ) ?
		function( a, b ) {
			var adown = a.nodeType === 9 ? a.documentElement : a,
				bup = b && b.parentNode;
			return a === bup || !!( bup && bup.nodeType === 1 && (
				adown.contains ?
					adown.contains( bup ) :
					a.compareDocumentPosition && a.compareDocumentPosition( bup ) & 16
			));
		} :
		function( a, b ) {
			if ( b ) {
				while ( (b = b.parentNode) ) {
					if ( b === a ) {
						return true;
					}
				}
			}
			return false;
		};

	/* Sorting
	---------------------------------------------------------------------- */

	// Document order sorting
	sortOrder = hasCompare ?
	function( a, b ) {

		// Flag for duplicate removal
		if ( a === b ) {
			hasDuplicate = true;
			return 0;
		}

		// Sort on method existence if only one input has compareDocumentPosition
		var compare = !a.compareDocumentPosition - !b.compareDocumentPosition;
		if ( compare ) {
			return compare;
		}

		// Calculate position if both inputs belong to the same document
		compare = ( a.ownerDocument || a ) === ( b.ownerDocument || b ) ?
			a.compareDocumentPosition( b ) :

			// Otherwise we know they are disconnected
			1;

		// Disconnected nodes
		if ( compare & 1 ||
			(!support.sortDetached && b.compareDocumentPosition( a ) === compare) ) {

			// Choose the first element that is related to our preferred document
			if ( a === doc || a.ownerDocument === preferredDoc && contains(preferredDoc, a) ) {
				return -1;
			}
			if ( b === doc || b.ownerDocument === preferredDoc && contains(preferredDoc, b) ) {
				return 1;
			}

			// Maintain original order
			return sortInput ?
				( indexOf.call( sortInput, a ) - indexOf.call( sortInput, b ) ) :
				0;
		}

		return compare & 4 ? -1 : 1;
	} :
	function( a, b ) {
		// Exit early if the nodes are identical
		if ( a === b ) {
			hasDuplicate = true;
			return 0;
		}

		var cur,
			i = 0,
			aup = a.parentNode,
			bup = b.parentNode,
			ap = [ a ],
			bp = [ b ];

		// Parentless nodes are either documents or disconnected
		if ( !aup || !bup ) {
			return a === doc ? -1 :
				b === doc ? 1 :
				aup ? -1 :
				bup ? 1 :
				sortInput ?
				( indexOf.call( sortInput, a ) - indexOf.call( sortInput, b ) ) :
				0;

		// If the nodes are siblings, we can do a quick check
		} else if ( aup === bup ) {
			return siblingCheck( a, b );
		}

		// Otherwise we need full lists of their ancestors for comparison
		cur = a;
		while ( (cur = cur.parentNode) ) {
			ap.unshift( cur );
		}
		cur = b;
		while ( (cur = cur.parentNode) ) {
			bp.unshift( cur );
		}

		// Walk down the tree looking for a discrepancy
		while ( ap[i] === bp[i] ) {
			i++;
		}

		return i ?
			// Do a sibling check if the nodes have a common ancestor
			siblingCheck( ap[i], bp[i] ) :

			// Otherwise nodes in our document sort first
			ap[i] === preferredDoc ? -1 :
			bp[i] === preferredDoc ? 1 :
			0;
	};

	return doc;
};

Sizzle.matches = function( expr, elements ) {
	return Sizzle( expr, null, null, elements );
};

Sizzle.matchesSelector = function( elem, expr ) {
	// Set document vars if needed
	if ( ( elem.ownerDocument || elem ) !== document ) {
		setDocument( elem );
	}

	// Make sure that attribute selectors are quoted
	expr = expr.replace( rattributeQuotes, "='$1']" );

	if ( support.matchesSelector && documentIsHTML &&
		( !rbuggyMatches || !rbuggyMatches.test( expr ) ) &&
		( !rbuggyQSA     || !rbuggyQSA.test( expr ) ) ) {

		try {
			var ret = matches.call( elem, expr );

			// IE 9's matchesSelector returns false on disconnected nodes
			if ( ret || support.disconnectedMatch ||
					// As well, disconnected nodes are said to be in a document
					// fragment in IE 9
					elem.document && elem.document.nodeType !== 11 ) {
				return ret;
			}
		} catch(e) {}
	}

	return Sizzle( expr, document, null, [ elem ] ).length > 0;
};

Sizzle.contains = function( context, elem ) {
	// Set document vars if needed
	if ( ( context.ownerDocument || context ) !== document ) {
		setDocument( context );
	}
	return contains( context, elem );
};

Sizzle.attr = function( elem, name ) {
	// Set document vars if needed
	if ( ( elem.ownerDocument || elem ) !== document ) {
		setDocument( elem );
	}

	var fn = Expr.attrHandle[ name.toLowerCase() ],
		// Don't get fooled by Object.prototype properties (jQuery #13807)
		val = fn && hasOwn.call( Expr.attrHandle, name.toLowerCase() ) ?
			fn( elem, name, !documentIsHTML ) :
			undefined;

	return val !== undefined ?
		val :
		support.attributes || !documentIsHTML ?
			elem.getAttribute( name ) :
			(val = elem.getAttributeNode(name)) && val.specified ?
				val.value :
				null;
};

Sizzle.error = function( msg ) {
	throw new Error( "Syntax error, unrecognized expression: " + msg );
};

/**
 * Document sorting and removing duplicates
 * @param {ArrayLike} results
 */
Sizzle.uniqueSort = function( results ) {
	var elem,
		duplicates = [],
		j = 0,
		i = 0;

	// Unless we *know* we can detect duplicates, assume their presence
	hasDuplicate = !support.detectDuplicates;
	sortInput = !support.sortStable && results.slice( 0 );
	results.sort( sortOrder );

	if ( hasDuplicate ) {
		while ( (elem = results[i++]) ) {
			if ( elem === results[ i ] ) {
				j = duplicates.push( i );
			}
		}
		while ( j-- ) {
			results.splice( duplicates[ j ], 1 );
		}
	}

	// Clear input after sorting to release objects
	// See https://github.com/jquery/sizzle/pull/225
	sortInput = null;

	return results;
};

/**
 * Utility function for retrieving the text value of an array of DOM nodes
 * @param {Array|Element} elem
 */
getText = Sizzle.getText = function( elem ) {
	var node,
		ret = "",
		i = 0,
		nodeType = elem.nodeType;

	if ( !nodeType ) {
		// If no nodeType, this is expected to be an array
		while ( (node = elem[i++]) ) {
			// Do not traverse comment nodes
			ret += getText( node );
		}
	} else if ( nodeType === 1 || nodeType === 9 || nodeType === 11 ) {
		// Use textContent for elements
		// innerText usage removed for consistency of new lines (jQuery #11153)
		if ( typeof elem.textContent === "string" ) {
			return elem.textContent;
		} else {
			// Traverse its children
			for ( elem = elem.firstChild; elem; elem = elem.nextSibling ) {
				ret += getText( elem );
			}
		}
	} else if ( nodeType === 3 || nodeType === 4 ) {
		return elem.nodeValue;
	}
	// Do not include comment or processing instruction nodes

	return ret;
};

Expr = Sizzle.selectors = {

	// Can be adjusted by the user
	cacheLength: 50,

	createPseudo: markFunction,

	match: matchExpr,

	attrHandle: {},

	find: {},

	relative: {
		">": { dir: "parentNode", first: true },
		" ": { dir: "parentNode" },
		"+": { dir: "previousSibling", first: true },
		"~": { dir: "previousSibling" }
	},

	preFilter: {
		"ATTR": function( match ) {
			match[1] = match[1].replace( runescape, funescape );

			// Move the given value to match[3] whether quoted or unquoted
			match[3] = ( match[3] || match[4] || match[5] || "" ).replace( runescape, funescape );

			if ( match[2] === "~=" ) {
				match[3] = " " + match[3] + " ";
			}

			return match.slice( 0, 4 );
		},

		"CHILD": function( match ) {
			/* matches from matchExpr["CHILD"]
				1 type (only|nth|...)
				2 what (child|of-type)
				3 argument (even|odd|\d*|\d*n([+-]\d+)?|...)
				4 xn-component of xn+y argument ([+-]?\d*n|)
				5 sign of xn-component
				6 x of xn-component
				7 sign of y-component
				8 y of y-component
			*/
			match[1] = match[1].toLowerCase();

			if ( match[1].slice( 0, 3 ) === "nth" ) {
				// nth-* requires argument
				if ( !match[3] ) {
					Sizzle.error( match[0] );
				}

				// numeric x and y parameters for Expr.filter.CHILD
				// remember that false/true cast respectively to 0/1
				match[4] = +( match[4] ? match[5] + (match[6] || 1) : 2 * ( match[3] === "even" || match[3] === "odd" ) );
				match[5] = +( ( match[7] + match[8] ) || match[3] === "odd" );

			// other types prohibit arguments
			} else if ( match[3] ) {
				Sizzle.error( match[0] );
			}

			return match;
		},

		"PSEUDO": function( match ) {
			var excess,
				unquoted = !match[6] && match[2];

			if ( matchExpr["CHILD"].test( match[0] ) ) {
				return null;
			}

			// Accept quoted arguments as-is
			if ( match[3] ) {
				match[2] = match[4] || match[5] || "";

			// Strip excess characters from unquoted arguments
			} else if ( unquoted && rpseudo.test( unquoted ) &&
				// Get excess from tokenize (recursively)
				(excess = tokenize( unquoted, true )) &&
				// advance to the next closing parenthesis
				(excess = unquoted.indexOf( ")", unquoted.length - excess ) - unquoted.length) ) {

				// excess is a negative index
				match[0] = match[0].slice( 0, excess );
				match[2] = unquoted.slice( 0, excess );
			}

			// Return only captures needed by the pseudo filter method (type and argument)
			return match.slice( 0, 3 );
		}
	},

	filter: {

		"TAG": function( nodeNameSelector ) {
			var nodeName = nodeNameSelector.replace( runescape, funescape ).toLowerCase();
			return nodeNameSelector === "*" ?
				function() { return true; } :
				function( elem ) {
					return elem.nodeName && elem.nodeName.toLowerCase() === nodeName;
				};
		},

		"CLASS": function( className ) {
			var pattern = classCache[ className + " " ];

			return pattern ||
				(pattern = new RegExp( "(^|" + whitespace + ")" + className + "(" + whitespace + "|$)" )) &&
				classCache( className, function( elem ) {
					return pattern.test( typeof elem.className === "string" && elem.className || typeof elem.getAttribute !== strundefined && elem.getAttribute("class") || "" );
				});
		},

		"ATTR": function( name, operator, check ) {
			return function( elem ) {
				var result = Sizzle.attr( elem, name );

				if ( result == null ) {
					return operator === "!=";
				}
				if ( !operator ) {
					return true;
				}

				result += "";

				return operator === "=" ? result === check :
					operator === "!=" ? result !== check :
					operator === "^=" ? check && result.indexOf( check ) === 0 :
					operator === "*=" ? check && result.indexOf( check ) > -1 :
					operator === "$=" ? check && result.slice( -check.length ) === check :
					operator === "~=" ? ( " " + result + " " ).indexOf( check ) > -1 :
					operator === "|=" ? result === check || result.slice( 0, check.length + 1 ) === check + "-" :
					false;
			};
		},

		"CHILD": function( type, what, argument, first, last ) {
			var simple = type.slice( 0, 3 ) !== "nth",
				forward = type.slice( -4 ) !== "last",
				ofType = what === "of-type";

			return first === 1 && last === 0 ?

				// Shortcut for :nth-*(n)
				function( elem ) {
					return !!elem.parentNode;
				} :

				function( elem, context, xml ) {
					var cache, outerCache, node, diff, nodeIndex, start,
						dir = simple !== forward ? "nextSibling" : "previousSibling",
						parent = elem.parentNode,
						name = ofType && elem.nodeName.toLowerCase(),
						useCache = !xml && !ofType;

					if ( parent ) {

						// :(first|last|only)-(child|of-type)
						if ( simple ) {
							while ( dir ) {
								node = elem;
								while ( (node = node[ dir ]) ) {
									if ( ofType ? node.nodeName.toLowerCase() === name : node.nodeType === 1 ) {
										return false;
									}
								}
								// Reverse direction for :only-* (if we haven't yet done so)
								start = dir = type === "only" && !start && "nextSibling";
							}
							return true;
						}

						start = [ forward ? parent.firstChild : parent.lastChild ];

						// non-xml :nth-child(...) stores cache data on `parent`
						if ( forward && useCache ) {
							// Seek `elem` from a previously-cached index
							outerCache = parent[ expando ] || (parent[ expando ] = {});
							cache = outerCache[ type ] || [];
							nodeIndex = cache[0] === dirruns && cache[1];
							diff = cache[0] === dirruns && cache[2];
							node = nodeIndex && parent.childNodes[ nodeIndex ];

							while ( (node = ++nodeIndex && node && node[ dir ] ||

								// Fallback to seeking `elem` from the start
								(diff = nodeIndex = 0) || start.pop()) ) {

								// When found, cache indexes on `parent` and break
								if ( node.nodeType === 1 && ++diff && node === elem ) {
									outerCache[ type ] = [ dirruns, nodeIndex, diff ];
									break;
								}
							}

						// Use previously-cached element index if available
						} else if ( useCache && (cache = (elem[ expando ] || (elem[ expando ] = {}))[ type ]) && cache[0] === dirruns ) {
							diff = cache[1];

						// xml :nth-child(...) or :nth-last-child(...) or :nth(-last)?-of-type(...)
						} else {
							// Use the same loop as above to seek `elem` from the start
							while ( (node = ++nodeIndex && node && node[ dir ] ||
								(diff = nodeIndex = 0) || start.pop()) ) {

								if ( ( ofType ? node.nodeName.toLowerCase() === name : node.nodeType === 1 ) && ++diff ) {
									// Cache the index of each encountered element
									if ( useCache ) {
										(node[ expando ] || (node[ expando ] = {}))[ type ] = [ dirruns, diff ];
									}

									if ( node === elem ) {
										break;
									}
								}
							}
						}

						// Incorporate the offset, then check against cycle size
						diff -= last;
						return diff === first || ( diff % first === 0 && diff / first >= 0 );
					}
				};
		},

		"PSEUDO": function( pseudo, argument ) {
			// pseudo-class names are case-insensitive
			// http://www.w3.org/TR/selectors/#pseudo-classes
			// Prioritize by case sensitivity in case custom pseudos are added with uppercase letters
			// Remember that setFilters inherits from pseudos
			var args,
				fn = Expr.pseudos[ pseudo ] || Expr.setFilters[ pseudo.toLowerCase() ] ||
					Sizzle.error( "unsupported pseudo: " + pseudo );

			// The user may use createPseudo to indicate that
			// arguments are needed to create the filter function
			// just as Sizzle does
			if ( fn[ expando ] ) {
				return fn( argument );
			}

			// But maintain support for old signatures
			if ( fn.length > 1 ) {
				args = [ pseudo, pseudo, "", argument ];
				return Expr.setFilters.hasOwnProperty( pseudo.toLowerCase() ) ?
					markFunction(function( seed, matches ) {
						var idx,
							matched = fn( seed, argument ),
							i = matched.length;
						while ( i-- ) {
							idx = indexOf.call( seed, matched[i] );
							seed[ idx ] = !( matches[ idx ] = matched[i] );
						}
					}) :
					function( elem ) {
						return fn( elem, 0, args );
					};
			}

			return fn;
		}
	},

	pseudos: {
		// Potentially complex pseudos
		"not": markFunction(function( selector ) {
			// Trim the selector passed to compile
			// to avoid treating leading and trailing
			// spaces as combinators
			var input = [],
				results = [],
				matcher = compile( selector.replace( rtrim, "$1" ) );

			return matcher[ expando ] ?
				markFunction(function( seed, matches, context, xml ) {
					var elem,
						unmatched = matcher( seed, null, xml, [] ),
						i = seed.length;

					// Match elements unmatched by `matcher`
					while ( i-- ) {
						if ( (elem = unmatched[i]) ) {
							seed[i] = !(matches[i] = elem);
						}
					}
				}) :
				function( elem, context, xml ) {
					input[0] = elem;
					matcher( input, null, xml, results );
					return !results.pop();
				};
		}),

		"has": markFunction(function( selector ) {
			return function( elem ) {
				return Sizzle( selector, elem ).length > 0;
			};
		}),

		"contains": markFunction(function( text ) {
			return function( elem ) {
				return ( elem.textContent || elem.innerText || getText( elem ) ).indexOf( text ) > -1;
			};
		}),

		// "Whether an element is represented by a :lang() selector
		// is based solely on the element's language value
		// being equal to the identifier C,
		// or beginning with the identifier C immediately followed by "-".
		// The matching of C against the element's language value is performed case-insensitively.
		// The identifier C does not have to be a valid language name."
		// http://www.w3.org/TR/selectors/#lang-pseudo
		"lang": markFunction( function( lang ) {
			// lang value must be a valid identifier
			if ( !ridentifier.test(lang || "") ) {
				Sizzle.error( "unsupported lang: " + lang );
			}
			lang = lang.replace( runescape, funescape ).toLowerCase();
			return function( elem ) {
				var elemLang;
				do {
					if ( (elemLang = documentIsHTML ?
						elem.lang :
						elem.getAttribute("xml:lang") || elem.getAttribute("lang")) ) {

						elemLang = elemLang.toLowerCase();
						return elemLang === lang || elemLang.indexOf( lang + "-" ) === 0;
					}
				} while ( (elem = elem.parentNode) && elem.nodeType === 1 );
				return false;
			};
		}),

		// Miscellaneous
		"target": function( elem ) {
			var hash = window.location && window.location.hash;
			return hash && hash.slice( 1 ) === elem.id;
		},

		"root": function( elem ) {
			return elem === docElem;
		},

		"focus": function( elem ) {
			return elem === document.activeElement && (!document.hasFocus || document.hasFocus()) && !!(elem.type || elem.href || ~elem.tabIndex);
		},

		// Boolean properties
		"enabled": function( elem ) {
			return elem.disabled === false;
		},

		"disabled": function( elem ) {
			return elem.disabled === true;
		},

		"checked": function( elem ) {
			// In CSS3, :checked should return both checked and selected elements
			// http://www.w3.org/TR/2011/REC-css3-selectors-20110929/#checked
			var nodeName = elem.nodeName.toLowerCase();
			return (nodeName === "input" && !!elem.checked) || (nodeName === "option" && !!elem.selected);
		},

		"selected": function( elem ) {
			// Accessing this property makes selected-by-default
			// options in Safari work properly
			if ( elem.parentNode ) {
				elem.parentNode.selectedIndex;
			}

			return elem.selected === true;
		},

		// Contents
		"empty": function( elem ) {
			// http://www.w3.org/TR/selectors/#empty-pseudo
			// :empty is negated by element (1) or content nodes (text: 3; cdata: 4; entity ref: 5),
			//   but not by others (comment: 8; processing instruction: 7; etc.)
			// nodeType < 6 works because attributes (2) do not appear as children
			for ( elem = elem.firstChild; elem; elem = elem.nextSibling ) {
				if ( elem.nodeType < 6 ) {
					return false;
				}
			}
			return true;
		},

		"parent": function( elem ) {
			return !Expr.pseudos["empty"]( elem );
		},

		// Element/input types
		"header": function( elem ) {
			return rheader.test( elem.nodeName );
		},

		"input": function( elem ) {
			return rinputs.test( elem.nodeName );
		},

		"button": function( elem ) {
			var name = elem.nodeName.toLowerCase();
			return name === "input" && elem.type === "button" || name === "button";
		},

		"text": function( elem ) {
			var attr;
			return elem.nodeName.toLowerCase() === "input" &&
				elem.type === "text" &&

				// Support: IE<8
				// New HTML5 attribute values (e.g., "search") appear with elem.type === "text"
				( (attr = elem.getAttribute("type")) == null || attr.toLowerCase() === "text" );
		},

		// Position-in-collection
		"first": createPositionalPseudo(function() {
			return [ 0 ];
		}),

		"last": createPositionalPseudo(function( matchIndexes, length ) {
			return [ length - 1 ];
		}),

		"eq": createPositionalPseudo(function( matchIndexes, length, argument ) {
			return [ argument < 0 ? argument + length : argument ];
		}),

		"even": createPositionalPseudo(function( matchIndexes, length ) {
			var i = 0;
			for ( ; i < length; i += 2 ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"odd": createPositionalPseudo(function( matchIndexes, length ) {
			var i = 1;
			for ( ; i < length; i += 2 ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"lt": createPositionalPseudo(function( matchIndexes, length, argument ) {
			var i = argument < 0 ? argument + length : argument;
			for ( ; --i >= 0; ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"gt": createPositionalPseudo(function( matchIndexes, length, argument ) {
			var i = argument < 0 ? argument + length : argument;
			for ( ; ++i < length; ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		})
	}
};

Expr.pseudos["nth"] = Expr.pseudos["eq"];

// Add button/input type pseudos
for ( i in { radio: true, checkbox: true, file: true, password: true, image: true } ) {
	Expr.pseudos[ i ] = createInputPseudo( i );
}
for ( i in { submit: true, reset: true } ) {
	Expr.pseudos[ i ] = createButtonPseudo( i );
}

// Easy API for creating new setFilters
function setFilters() {}
setFilters.prototype = Expr.filters = Expr.pseudos;
Expr.setFilters = new setFilters();

tokenize = Sizzle.tokenize = function( selector, parseOnly ) {
	var matched, match, tokens, type,
		soFar, groups, preFilters,
		cached = tokenCache[ selector + " " ];

	if ( cached ) {
		return parseOnly ? 0 : cached.slice( 0 );
	}

	soFar = selector;
	groups = [];
	preFilters = Expr.preFilter;

	while ( soFar ) {

		// Comma and first run
		if ( !matched || (match = rcomma.exec( soFar )) ) {
			if ( match ) {
				// Don't consume trailing commas as valid
				soFar = soFar.slice( match[0].length ) || soFar;
			}
			groups.push( (tokens = []) );
		}

		matched = false;

		// Combinators
		if ( (match = rcombinators.exec( soFar )) ) {
			matched = match.shift();
			tokens.push({
				value: matched,
				// Cast descendant combinators to space
				type: match[0].replace( rtrim, " " )
			});
			soFar = soFar.slice( matched.length );
		}

		// Filters
		for ( type in Expr.filter ) {
			if ( (match = matchExpr[ type ].exec( soFar )) && (!preFilters[ type ] ||
				(match = preFilters[ type ]( match ))) ) {
				matched = match.shift();
				tokens.push({
					value: matched,
					type: type,
					matches: match
				});
				soFar = soFar.slice( matched.length );
			}
		}

		if ( !matched ) {
			break;
		}
	}

	// Return the length of the invalid excess
	// if we're just parsing
	// Otherwise, throw an error or return tokens
	return parseOnly ?
		soFar.length :
		soFar ?
			Sizzle.error( selector ) :
			// Cache the tokens
			tokenCache( selector, groups ).slice( 0 );
};

function toSelector( tokens ) {
	var i = 0,
		len = tokens.length,
		selector = "";
	for ( ; i < len; i++ ) {
		selector += tokens[i].value;
	}
	return selector;
}

function addCombinator( matcher, combinator, base ) {
	var dir = combinator.dir,
		checkNonElements = base && dir === "parentNode",
		doneName = done++;

	return combinator.first ?
		// Check against closest ancestor/preceding element
		function( elem, context, xml ) {
			while ( (elem = elem[ dir ]) ) {
				if ( elem.nodeType === 1 || checkNonElements ) {
					return matcher( elem, context, xml );
				}
			}
		} :

		// Check against all ancestor/preceding elements
		function( elem, context, xml ) {
			var oldCache, outerCache,
				newCache = [ dirruns, doneName ];

			// We can't set arbitrary data on XML nodes, so they don't benefit from dir caching
			if ( xml ) {
				while ( (elem = elem[ dir ]) ) {
					if ( elem.nodeType === 1 || checkNonElements ) {
						if ( matcher( elem, context, xml ) ) {
							return true;
						}
					}
				}
			} else {
				while ( (elem = elem[ dir ]) ) {
					if ( elem.nodeType === 1 || checkNonElements ) {
						outerCache = elem[ expando ] || (elem[ expando ] = {});
						if ( (oldCache = outerCache[ dir ]) &&
							oldCache[ 0 ] === dirruns && oldCache[ 1 ] === doneName ) {

							// Assign to newCache so results back-propagate to previous elements
							return (newCache[ 2 ] = oldCache[ 2 ]);
						} else {
							// Reuse newcache so results back-propagate to previous elements
							outerCache[ dir ] = newCache;

							// A match means we're done; a fail means we have to keep checking
							if ( (newCache[ 2 ] = matcher( elem, context, xml )) ) {
								return true;
							}
						}
					}
				}
			}
		};
}

function elementMatcher( matchers ) {
	return matchers.length > 1 ?
		function( elem, context, xml ) {
			var i = matchers.length;
			while ( i-- ) {
				if ( !matchers[i]( elem, context, xml ) ) {
					return false;
				}
			}
			return true;
		} :
		matchers[0];
}

function multipleContexts( selector, contexts, results ) {
	var i = 0,
		len = contexts.length;
	for ( ; i < len; i++ ) {
		Sizzle( selector, contexts[i], results );
	}
	return results;
}

function condense( unmatched, map, filter, context, xml ) {
	var elem,
		newUnmatched = [],
		i = 0,
		len = unmatched.length,
		mapped = map != null;

	for ( ; i < len; i++ ) {
		if ( (elem = unmatched[i]) ) {
			if ( !filter || filter( elem, context, xml ) ) {
				newUnmatched.push( elem );
				if ( mapped ) {
					map.push( i );
				}
			}
		}
	}

	return newUnmatched;
}

function setMatcher( preFilter, selector, matcher, postFilter, postFinder, postSelector ) {
	if ( postFilter && !postFilter[ expando ] ) {
		postFilter = setMatcher( postFilter );
	}
	if ( postFinder && !postFinder[ expando ] ) {
		postFinder = setMatcher( postFinder, postSelector );
	}
	return markFunction(function( seed, results, context, xml ) {
		var temp, i, elem,
			preMap = [],
			postMap = [],
			preexisting = results.length,

			// Get initial elements from seed or context
			elems = seed || multipleContexts( selector || "*", context.nodeType ? [ context ] : context, [] ),

			// Prefilter to get matcher input, preserving a map for seed-results synchronization
			matcherIn = preFilter && ( seed || !selector ) ?
				condense( elems, preMap, preFilter, context, xml ) :
				elems,

			matcherOut = matcher ?
				// If we have a postFinder, or filtered seed, or non-seed postFilter or preexisting results,
				postFinder || ( seed ? preFilter : preexisting || postFilter ) ?

					// ...intermediate processing is necessary
					[] :

					// ...otherwise use results directly
					results :
				matcherIn;

		// Find primary matches
		if ( matcher ) {
			matcher( matcherIn, matcherOut, context, xml );
		}

		// Apply postFilter
		if ( postFilter ) {
			temp = condense( matcherOut, postMap );
			postFilter( temp, [], context, xml );

			// Un-match failing elements by moving them back to matcherIn
			i = temp.length;
			while ( i-- ) {
				if ( (elem = temp[i]) ) {
					matcherOut[ postMap[i] ] = !(matcherIn[ postMap[i] ] = elem);
				}
			}
		}

		if ( seed ) {
			if ( postFinder || preFilter ) {
				if ( postFinder ) {
					// Get the final matcherOut by condensing this intermediate into postFinder contexts
					temp = [];
					i = matcherOut.length;
					while ( i-- ) {
						if ( (elem = matcherOut[i]) ) {
							// Restore matcherIn since elem is not yet a final match
							temp.push( (matcherIn[i] = elem) );
						}
					}
					postFinder( null, (matcherOut = []), temp, xml );
				}

				// Move matched elements from seed to results to keep them synchronized
				i = matcherOut.length;
				while ( i-- ) {
					if ( (elem = matcherOut[i]) &&
						(temp = postFinder ? indexOf.call( seed, elem ) : preMap[i]) > -1 ) {

						seed[temp] = !(results[temp] = elem);
					}
				}
			}

		// Add elements to results, through postFinder if defined
		} else {
			matcherOut = condense(
				matcherOut === results ?
					matcherOut.splice( preexisting, matcherOut.length ) :
					matcherOut
			);
			if ( postFinder ) {
				postFinder( null, results, matcherOut, xml );
			} else {
				push.apply( results, matcherOut );
			}
		}
	});
}

function matcherFromTokens( tokens ) {
	var checkContext, matcher, j,
		len = tokens.length,
		leadingRelative = Expr.relative[ tokens[0].type ],
		implicitRelative = leadingRelative || Expr.relative[" "],
		i = leadingRelative ? 1 : 0,

		// The foundational matcher ensures that elements are reachable from top-level context(s)
		matchContext = addCombinator( function( elem ) {
			return elem === checkContext;
		}, implicitRelative, true ),
		matchAnyContext = addCombinator( function( elem ) {
			return indexOf.call( checkContext, elem ) > -1;
		}, implicitRelative, true ),
		matchers = [ function( elem, context, xml ) {
			return ( !leadingRelative && ( xml || context !== outermostContext ) ) || (
				(checkContext = context).nodeType ?
					matchContext( elem, context, xml ) :
					matchAnyContext( elem, context, xml ) );
		} ];

	for ( ; i < len; i++ ) {
		if ( (matcher = Expr.relative[ tokens[i].type ]) ) {
			matchers = [ addCombinator(elementMatcher( matchers ), matcher) ];
		} else {
			matcher = Expr.filter[ tokens[i].type ].apply( null, tokens[i].matches );

			// Return special upon seeing a positional matcher
			if ( matcher[ expando ] ) {
				// Find the next relative operator (if any) for proper handling
				j = ++i;
				for ( ; j < len; j++ ) {
					if ( Expr.relative[ tokens[j].type ] ) {
						break;
					}
				}
				return setMatcher(
					i > 1 && elementMatcher( matchers ),
					i > 1 && toSelector(
						// If the preceding token was a descendant combinator, insert an implicit any-element `*`
						tokens.slice( 0, i - 1 ).concat({ value: tokens[ i - 2 ].type === " " ? "*" : "" })
					).replace( rtrim, "$1" ),
					matcher,
					i < j && matcherFromTokens( tokens.slice( i, j ) ),
					j < len && matcherFromTokens( (tokens = tokens.slice( j )) ),
					j < len && toSelector( tokens )
				);
			}
			matchers.push( matcher );
		}
	}

	return elementMatcher( matchers );
}

function matcherFromGroupMatchers( elementMatchers, setMatchers ) {
	var bySet = setMatchers.length > 0,
		byElement = elementMatchers.length > 0,
		superMatcher = function( seed, context, xml, results, outermost ) {
			var elem, j, matcher,
				matchedCount = 0,
				i = "0",
				unmatched = seed && [],
				setMatched = [],
				contextBackup = outermostContext,
				// We must always have either seed elements or outermost context
				elems = seed || byElement && Expr.find["TAG"]( "*", outermost ),
				// Use integer dirruns iff this is the outermost matcher
				dirrunsUnique = (dirruns += contextBackup == null ? 1 : Math.random() || 0.1),
				len = elems.length;

			if ( outermost ) {
				outermostContext = context !== document && context;
			}

			// Add elements passing elementMatchers directly to results
			// Keep `i` a string if there are no elements so `matchedCount` will be "00" below
			// Support: IE<9, Safari
			// Tolerate NodeList properties (IE: "length"; Safari: <number>) matching elements by id
			for ( ; i !== len && (elem = elems[i]) != null; i++ ) {
				if ( byElement && elem ) {
					j = 0;
					while ( (matcher = elementMatchers[j++]) ) {
						if ( matcher( elem, context, xml ) ) {
							results.push( elem );
							break;
						}
					}
					if ( outermost ) {
						dirruns = dirrunsUnique;
					}
				}

				// Track unmatched elements for set filters
				if ( bySet ) {
					// They will have gone through all possible matchers
					if ( (elem = !matcher && elem) ) {
						matchedCount--;
					}

					// Lengthen the array for every element, matched or not
					if ( seed ) {
						unmatched.push( elem );
					}
				}
			}

			// Apply set filters to unmatched elements
			matchedCount += i;
			if ( bySet && i !== matchedCount ) {
				j = 0;
				while ( (matcher = setMatchers[j++]) ) {
					matcher( unmatched, setMatched, context, xml );
				}

				if ( seed ) {
					// Reintegrate element matches to eliminate the need for sorting
					if ( matchedCount > 0 ) {
						while ( i-- ) {
							if ( !(unmatched[i] || setMatched[i]) ) {
								setMatched[i] = pop.call( results );
							}
						}
					}

					// Discard index placeholder values to get only actual matches
					setMatched = condense( setMatched );
				}

				// Add matches to results
				push.apply( results, setMatched );

				// Seedless set matches succeeding multiple successful matchers stipulate sorting
				if ( outermost && !seed && setMatched.length > 0 &&
					( matchedCount + setMatchers.length ) > 1 ) {

					Sizzle.uniqueSort( results );
				}
			}

			// Override manipulation of globals by nested matchers
			if ( outermost ) {
				dirruns = dirrunsUnique;
				outermostContext = contextBackup;
			}

			return unmatched;
		};

	return bySet ?
		markFunction( superMatcher ) :
		superMatcher;
}

compile = Sizzle.compile = function( selector, match /* Internal Use Only */ ) {
	var i,
		setMatchers = [],
		elementMatchers = [],
		cached = compilerCache[ selector + " " ];

	if ( !cached ) {
		// Generate a function of recursive functions that can be used to check each element
		if ( !match ) {
			match = tokenize( selector );
		}
		i = match.length;
		while ( i-- ) {
			cached = matcherFromTokens( match[i] );
			if ( cached[ expando ] ) {
				setMatchers.push( cached );
			} else {
				elementMatchers.push( cached );
			}
		}

		// Cache the compiled function
		cached = compilerCache( selector, matcherFromGroupMatchers( elementMatchers, setMatchers ) );

		// Save selector and tokenization
		cached.selector = selector;
	}
	return cached;
};

/**
 * A low-level selection function that works with Sizzle's compiled
 *  selector functions
 * @param {String|Function} selector A selector or a pre-compiled
 *  selector function built with Sizzle.compile
 * @param {Element} context
 * @param {Array} [results]
 * @param {Array} [seed] A set of elements to match against
 */
select = Sizzle.select = function( selector, context, results, seed ) {
	var i, tokens, token, type, find,
		compiled = typeof selector === "function" && selector,
		match = !seed && tokenize( (selector = compiled.selector || selector) );

	results = results || [];

	// Try to minimize operations if there is no seed and only one group
	if ( match.length === 1 ) {

		// Take a shortcut and set the context if the root selector is an ID
		tokens = match[0] = match[0].slice( 0 );
		if ( tokens.length > 2 && (token = tokens[0]).type === "ID" &&
				support.getById && context.nodeType === 9 && documentIsHTML &&
				Expr.relative[ tokens[1].type ] ) {

			context = ( Expr.find["ID"]( token.matches[0].replace(runescape, funescape), context ) || [] )[0];
			if ( !context ) {
				return results;

			// Precompiled matchers will still verify ancestry, so step up a level
			} else if ( compiled ) {
				context = context.parentNode;
			}

			selector = selector.slice( tokens.shift().value.length );
		}

		// Fetch a seed set for right-to-left matching
		i = matchExpr["needsContext"].test( selector ) ? 0 : tokens.length;
		while ( i-- ) {
			token = tokens[i];

			// Abort if we hit a combinator
			if ( Expr.relative[ (type = token.type) ] ) {
				break;
			}
			if ( (find = Expr.find[ type ]) ) {
				// Search, expanding context for leading sibling combinators
				if ( (seed = find(
					token.matches[0].replace( runescape, funescape ),
					rsibling.test( tokens[0].type ) && testContext( context.parentNode ) || context
				)) ) {

					// If seed is empty or no tokens remain, we can return early
					tokens.splice( i, 1 );
					selector = seed.length && toSelector( tokens );
					if ( !selector ) {
						push.apply( results, seed );
						return results;
					}

					break;
				}
			}
		}
	}

	// Compile and execute a filtering function if one is not provided
	// Provide `match` to avoid retokenization if we modified the selector above
	( compiled || compile( selector, match ) )(
		seed,
		context,
		!documentIsHTML,
		results,
		rsibling.test( selector ) && testContext( context.parentNode ) || context
	);
	return results;
};

// One-time assignments

// Sort stability
support.sortStable = expando.split("").sort( sortOrder ).join("") === expando;

// Support: Chrome<14
// Always assume duplicates if they aren't passed to the comparison function
support.detectDuplicates = !!hasDuplicate;

// Initialize against the default document
setDocument();

// Support: Webkit<537.32 - Safari 6.0.3/Chrome 25 (fixed in Chrome 27)
// Detached nodes confoundingly follow *each other*
support.sortDetached = assert(function( div1 ) {
	// Should return 1, but returns 4 (following)
	return div1.compareDocumentPosition( document.createElement("div") ) & 1;
});

// Support: IE<8
// Prevent attribute/property "interpolation"
// http://msdn.microsoft.com/en-us/library/ms536429%28VS.85%29.aspx
if ( !assert(function( div ) {
	div.innerHTML = "<a href='#'></a>";
	return div.firstChild.getAttribute("href") === "#" ;
}) ) {
	addHandle( "type|href|height|width", function( elem, name, isXML ) {
		if ( !isXML ) {
			return elem.getAttribute( name, name.toLowerCase() === "type" ? 1 : 2 );
		}
	});
}

// Support: IE<9
// Use defaultValue in place of getAttribute("value")
if ( !support.attributes || !assert(function( div ) {
	div.innerHTML = "<input/>";
	div.firstChild.setAttribute( "value", "" );
	return div.firstChild.getAttribute( "value" ) === "";
}) ) {
	addHandle( "value", function( elem, name, isXML ) {
		if ( !isXML && elem.nodeName.toLowerCase() === "input" ) {
			return elem.defaultValue;
		}
	});
}

// Support: IE<9
// Use getAttributeNode to fetch booleans when getAttribute lies
if ( !assert(function( div ) {
	return div.getAttribute("disabled") == null;
}) ) {
	addHandle( booleans, function( elem, name, isXML ) {
		var val;
		if ( !isXML ) {
			return elem[ name ] === true ? name.toLowerCase() :
					(val = elem.getAttributeNode( name )) && val.specified ?
					val.value :
				null;
		}
	});
}

return Sizzle;

})( window );



jQuery.find = Sizzle;
jQuery.expr = Sizzle.selectors;
jQuery.expr[":"] = jQuery.expr.pseudos;
jQuery.unique = Sizzle.uniqueSort;
jQuery.text = Sizzle.getText;
jQuery.isXMLDoc = Sizzle.isXML;
jQuery.contains = Sizzle.contains;



var rneedsContext = jQuery.expr.match.needsContext;

var rsingleTag = (/^<(\w+)\s*\/?>(?:<\/\1>|)$/);



var risSimple = /^.[^:#\[\.,]*$/;

// Implement the identical functionality for filter and not
function winnow( elements, qualifier, not ) {
	if ( jQuery.isFunction( qualifier ) ) {
		return jQuery.grep( elements, function( elem, i ) {
			/* jshint -W018 */
			return !!qualifier.call( elem, i, elem ) !== not;
		});

	}

	if ( qualifier.nodeType ) {
		return jQuery.grep( elements, function( elem ) {
			return ( elem === qualifier ) !== not;
		});

	}

	if ( typeof qualifier === "string" ) {
		if ( risSimple.test( qualifier ) ) {
			return jQuery.filter( qualifier, elements, not );
		}

		qualifier = jQuery.filter( qualifier, elements );
	}

	return jQuery.grep( elements, function( elem ) {
		return ( indexOf.call( qualifier, elem ) >= 0 ) !== not;
	});
}

jQuery.filter = function( expr, elems, not ) {
	var elem = elems[ 0 ];

	if ( not ) {
		expr = ":not(" + expr + ")";
	}

	return elems.length === 1 && elem.nodeType === 1 ?
		jQuery.find.matchesSelector( elem, expr ) ? [ elem ] : [] :
		jQuery.find.matches( expr, jQuery.grep( elems, function( elem ) {
			return elem.nodeType === 1;
		}));
};

jQuery.fn.extend({
	find: function( selector ) {
		var i,
			len = this.length,
			ret = [],
			self = this;

		if ( typeof selector !== "string" ) {
			return this.pushStack( jQuery( selector ).filter(function() {
				for ( i = 0; i < len; i++ ) {
					if ( jQuery.contains( self[ i ], this ) ) {
						return true;
					}
				}
			}) );
		}

		for ( i = 0; i < len; i++ ) {
			jQuery.find( selector, self[ i ], ret );
		}

		// Needed because $( selector, context ) becomes $( context ).find( selector )
		ret = this.pushStack( len > 1 ? jQuery.unique( ret ) : ret );
		ret.selector = this.selector ? this.selector + " " + selector : selector;
		return ret;
	},
	filter: function( selector ) {
		return this.pushStack( winnow(this, selector || [], false) );
	},
	not: function( selector ) {
		return this.pushStack( winnow(this, selector || [], true) );
	},
	is: function( selector ) {
		return !!winnow(
			this,

			// If this is a positional/relative selector, check membership in the returned set
			// so $("p:first").is("p:last") won't return true for a doc with two "p".
			typeof selector === "string" && rneedsContext.test( selector ) ?
				jQuery( selector ) :
				selector || [],
			false
		).length;
	}
});


// Initialize a jQuery object


// A central reference to the root jQuery(document)
var rootjQuery,

	// A simple way to check for HTML strings
	// Prioritize #id over <tag> to avoid XSS via location.hash (#9521)
	// Strict HTML recognition (#11290: must start with <)
	rquickExpr = /^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]*))$/,

	init = jQuery.fn.init = function( selector, context ) {
		var match, elem;

		// HANDLE: $(""), $(null), $(undefined), $(false)
		if ( !selector ) {
			return this;
		}

		// Handle HTML strings
		if ( typeof selector === "string" ) {
			if ( selector[0] === "<" && selector[ selector.length - 1 ] === ">" && selector.length >= 3 ) {
				// Assume that strings that start and end with <> are HTML and skip the regex check
				match = [ null, selector, null ];

			} else {
				match = rquickExpr.exec( selector );
			}

			// Match html or make sure no context is specified for #id
			if ( match && (match[1] || !context) ) {

				// HANDLE: $(html) -> $(array)
				if ( match[1] ) {
					context = context instanceof jQuery ? context[0] : context;

					// scripts is true for back-compat
					// Intentionally let the error be thrown if parseHTML is not present
					jQuery.merge( this, jQuery.parseHTML(
						match[1],
						context && context.nodeType ? context.ownerDocument || context : document,
						true
					) );

					// HANDLE: $(html, props)
					if ( rsingleTag.test( match[1] ) && jQuery.isPlainObject( context ) ) {
						for ( match in context ) {
							// Properties of context are called as methods if possible
							if ( jQuery.isFunction( this[ match ] ) ) {
								this[ match ]( context[ match ] );

							// ...and otherwise set as attributes
							} else {
								this.attr( match, context[ match ] );
							}
						}
					}

					return this;

				// HANDLE: $(#id)
				} else {
					elem = document.getElementById( match[2] );

					// Check parentNode to catch when Blackberry 4.6 returns
					// nodes that are no longer in the document #6963
					if ( elem && elem.parentNode ) {
						// Inject the element directly into the jQuery object
						this.length = 1;
						this[0] = elem;
					}

					this.context = document;
					this.selector = selector;
					return this;
				}

			// HANDLE: $(expr, $(...))
			} else if ( !context || context.jquery ) {
				return ( context || rootjQuery ).find( selector );

			// HANDLE: $(expr, context)
			// (which is just equivalent to: $(context).find(expr)
			} else {
				return this.constructor( context ).find( selector );
			}

		// HANDLE: $(DOMElement)
		} else if ( selector.nodeType ) {
			this.context = this[0] = selector;
			this.length = 1;
			return this;

		// HANDLE: $(function)
		// Shortcut for document ready
		} else if ( jQuery.isFunction( selector ) ) {
			return typeof rootjQuery.ready !== "undefined" ?
				rootjQuery.ready( selector ) :
				// Execute immediately if ready is not present
				selector( jQuery );
		}

		if ( selector.selector !== undefined ) {
			this.selector = selector.selector;
			this.context = selector.context;
		}

		return jQuery.makeArray( selector, this );
	};

// Give the init function the jQuery prototype for later instantiation
init.prototype = jQuery.fn;

// Initialize central reference
rootjQuery = jQuery( document );


var rparentsprev = /^(?:parents|prev(?:Until|All))/,
	// methods guaranteed to produce a unique set when starting from a unique set
	guaranteedUnique = {
		children: true,
		contents: true,
		next: true,
		prev: true
	};

jQuery.extend({
	dir: function( elem, dir, until ) {
		var matched = [],
			truncate = until !== undefined;

		while ( (elem = elem[ dir ]) && elem.nodeType !== 9 ) {
			if ( elem.nodeType === 1 ) {
				if ( truncate && jQuery( elem ).is( until ) ) {
					break;
				}
				matched.push( elem );
			}
		}
		return matched;
	},

	sibling: function( n, elem ) {
		var matched = [];

		for ( ; n; n = n.nextSibling ) {
			if ( n.nodeType === 1 && n !== elem ) {
				matched.push( n );
			}
		}

		return matched;
	}
});

jQuery.fn.extend({
	has: function( target ) {
		var targets = jQuery( target, this ),
			l = targets.length;

		return this.filter(function() {
			var i = 0;
			for ( ; i < l; i++ ) {
				if ( jQuery.contains( this, targets[i] ) ) {
					return true;
				}
			}
		});
	},

	closest: function( selectors, context ) {
		var cur,
			i = 0,
			l = this.length,
			matched = [],
			pos = rneedsContext.test( selectors ) || typeof selectors !== "string" ?
				jQuery( selectors, context || this.context ) :
				0;

		for ( ; i < l; i++ ) {
			for ( cur = this[i]; cur && cur !== context; cur = cur.parentNode ) {
				// Always skip document fragments
				if ( cur.nodeType < 11 && (pos ?
					pos.index(cur) > -1 :

					// Don't pass non-elements to Sizzle
					cur.nodeType === 1 &&
						jQuery.find.matchesSelector(cur, selectors)) ) {

					matched.push( cur );
					break;
				}
			}
		}

		return this.pushStack( matched.length > 1 ? jQuery.unique( matched ) : matched );
	},

	// Determine the position of an element within
	// the matched set of elements
	index: function( elem ) {

		// No argument, return index in parent
		if ( !elem ) {
			return ( this[ 0 ] && this[ 0 ].parentNode ) ? this.first().prevAll().length : -1;
		}

		// index in selector
		if ( typeof elem === "string" ) {
			return indexOf.call( jQuery( elem ), this[ 0 ] );
		}

		// Locate the position of the desired element
		return indexOf.call( this,

			// If it receives a jQuery object, the first element is used
			elem.jquery ? elem[ 0 ] : elem
		);
	},

	add: function( selector, context ) {
		return this.pushStack(
			jQuery.unique(
				jQuery.merge( this.get(), jQuery( selector, context ) )
			)
		);
	},

	addBack: function( selector ) {
		return this.add( selector == null ?
			this.prevObject : this.prevObject.filter(selector)
		);
	}
});

function sibling( cur, dir ) {
	while ( (cur = cur[dir]) && cur.nodeType !== 1 ) {}
	return cur;
}

jQuery.each({
	parent: function( elem ) {
		var parent = elem.parentNode;
		return parent && parent.nodeType !== 11 ? parent : null;
	},
	parents: function( elem ) {
		return jQuery.dir( elem, "parentNode" );
	},
	parentsUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "parentNode", until );
	},
	next: function( elem ) {
		return sibling( elem, "nextSibling" );
	},
	prev: function( elem ) {
		return sibling( elem, "previousSibling" );
	},
	nextAll: function( elem ) {
		return jQuery.dir( elem, "nextSibling" );
	},
	prevAll: function( elem ) {
		return jQuery.dir( elem, "previousSibling" );
	},
	nextUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "nextSibling", until );
	},
	prevUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "previousSibling", until );
	},
	siblings: function( elem ) {
		return jQuery.sibling( ( elem.parentNode || {} ).firstChild, elem );
	},
	children: function( elem ) {
		return jQuery.sibling( elem.firstChild );
	},
	contents: function( elem ) {
		return elem.contentDocument || jQuery.merge( [], elem.childNodes );
	}
}, function( name, fn ) {
	jQuery.fn[ name ] = function( until, selector ) {
		var matched = jQuery.map( this, fn, until );

		if ( name.slice( -5 ) !== "Until" ) {
			selector = until;
		}

		if ( selector && typeof selector === "string" ) {
			matched = jQuery.filter( selector, matched );
		}

		if ( this.length > 1 ) {
			// Remove duplicates
			if ( !guaranteedUnique[ name ] ) {
				jQuery.unique( matched );
			}

			// Reverse order for parents* and prev-derivatives
			if ( rparentsprev.test( name ) ) {
				matched.reverse();
			}
		}

		return this.pushStack( matched );
	};
});
var rnotwhite = (/\S+/g);



// String to Object options format cache
var optionsCache = {};

// Convert String-formatted options into Object-formatted ones and store in cache
function createOptions( options ) {
	var object = optionsCache[ options ] = {};
	jQuery.each( options.match( rnotwhite ) || [], function( _, flag ) {
		object[ flag ] = true;
	});
	return object;
}

/*
 * Create a callback list using the following parameters:
 *
 *	options: an optional list of space-separated options that will change how
 *			the callback list behaves or a more traditional option object
 *
 * By default a callback list will act like an event callback list and can be
 * "fired" multiple times.
 *
 * Possible options:
 *
 *	once:			will ensure the callback list can only be fired once (like a Deferred)
 *
 *	memory:			will keep track of previous values and will call any callback added
 *					after the list has been fired right away with the latest "memorized"
 *					values (like a Deferred)
 *
 *	unique:			will ensure a callback can only be added once (no duplicate in the list)
 *
 *	stopOnFalse:	interrupt callings when a callback returns false
 *
 */
jQuery.Callbacks = function( options ) {

	// Convert options from String-formatted to Object-formatted if needed
	// (we check in cache first)
	options = typeof options === "string" ?
		( optionsCache[ options ] || createOptions( options ) ) :
		jQuery.extend( {}, options );

	var // Last fire value (for non-forgettable lists)
		memory,
		// Flag to know if list was already fired
		fired,
		// Flag to know if list is currently firing
		firing,
		// First callback to fire (used internally by add and fireWith)
		firingStart,
		// End of the loop when firing
		firingLength,
		// Index of currently firing callback (modified by remove if needed)
		firingIndex,
		// Actual callback list
		list = [],
		// Stack of fire calls for repeatable lists
		stack = !options.once && [],
		// Fire callbacks
		fire = function( data ) {
			memory = options.memory && data;
			fired = true;
			firingIndex = firingStart || 0;
			firingStart = 0;
			firingLength = list.length;
			firing = true;
			for ( ; list && firingIndex < firingLength; firingIndex++ ) {
				if ( list[ firingIndex ].apply( data[ 0 ], data[ 1 ] ) === false && options.stopOnFalse ) {
					memory = false; // To prevent further calls using add
					break;
				}
			}
			firing = false;
			if ( list ) {
				if ( stack ) {
					if ( stack.length ) {
						fire( stack.shift() );
					}
				} else if ( memory ) {
					list = [];
				} else {
					self.disable();
				}
			}
		},
		// Actual Callbacks object
		self = {
			// Add a callback or a collection of callbacks to the list
			add: function() {
				if ( list ) {
					// First, we save the current length
					var start = list.length;
					(function add( args ) {
						jQuery.each( args, function( _, arg ) {
							var type = jQuery.type( arg );
							if ( type === "function" ) {
								if ( !options.unique || !self.has( arg ) ) {
									list.push( arg );
								}
							} else if ( arg && arg.length && type !== "string" ) {
								// Inspect recursively
								add( arg );
							}
						});
					})( arguments );
					// Do we need to add the callbacks to the
					// current firing batch?
					if ( firing ) {
						firingLength = list.length;
					// With memory, if we're not firing then
					// we should call right away
					} else if ( memory ) {
						firingStart = start;
						fire( memory );
					}
				}
				return this;
			},
			// Remove a callback from the list
			remove: function() {
				if ( list ) {
					jQuery.each( arguments, function( _, arg ) {
						var index;
						while ( ( index = jQuery.inArray( arg, list, index ) ) > -1 ) {
							list.splice( index, 1 );
							// Handle firing indexes
							if ( firing ) {
								if ( index <= firingLength ) {
									firingLength--;
								}
								if ( index <= firingIndex ) {
									firingIndex--;
								}
							}
						}
					});
				}
				return this;
			},
			// Check if a given callback is in the list.
			// If no argument is given, return whether or not list has callbacks attached.
			has: function( fn ) {
				return fn ? jQuery.inArray( fn, list ) > -1 : !!( list && list.length );
			},
			// Remove all callbacks from the list
			empty: function() {
				list = [];
				firingLength = 0;
				return this;
			},
			// Have the list do nothing anymore
			disable: function() {
				list = stack = memory = undefined;
				return this;
			},
			// Is it disabled?
			disabled: function() {
				return !list;
			},
			// Lock the list in its current state
			lock: function() {
				stack = undefined;
				if ( !memory ) {
					self.disable();
				}
				return this;
			},
			// Is it locked?
			locked: function() {
				return !stack;
			},
			// Call all callbacks with the given context and arguments
			fireWith: function( context, args ) {
				if ( list && ( !fired || stack ) ) {
					args = args || [];
					args = [ context, args.slice ? args.slice() : args ];
					if ( firing ) {
						stack.push( args );
					} else {
						fire( args );
					}
				}
				return this;
			},
			// Call all the callbacks with the given arguments
			fire: function() {
				self.fireWith( this, arguments );
				return this;
			},
			// To know if the callbacks have already been called at least once
			fired: function() {
				return !!fired;
			}
		};

	return self;
};


jQuery.extend({

	Deferred: function( func ) {
		var tuples = [
				// action, add listener, listener list, final state
				[ "resolve", "done", jQuery.Callbacks("once memory"), "resolved" ],
				[ "reject", "fail", jQuery.Callbacks("once memory"), "rejected" ],
				[ "notify", "progress", jQuery.Callbacks("memory") ]
			],
			state = "pending",
			promise = {
				state: function() {
					return state;
				},
				always: function() {
					deferred.done( arguments ).fail( arguments );
					return this;
				},
				then: function( /* fnDone, fnFail, fnProgress */ ) {
					var fns = arguments;
					return jQuery.Deferred(function( newDefer ) {
						jQuery.each( tuples, function( i, tuple ) {
							var fn = jQuery.isFunction( fns[ i ] ) && fns[ i ];
							// deferred[ done | fail | progress ] for forwarding actions to newDefer
							deferred[ tuple[1] ](function() {
								var returned = fn && fn.apply( this, arguments );
								if ( returned && jQuery.isFunction( returned.promise ) ) {
									returned.promise()
										.done( newDefer.resolve )
										.fail( newDefer.reject )
										.progress( newDefer.notify );
								} else {
									newDefer[ tuple[ 0 ] + "With" ]( this === promise ? newDefer.promise() : this, fn ? [ returned ] : arguments );
								}
							});
						});
						fns = null;
					}).promise();
				},
				// Get a promise for this deferred
				// If obj is provided, the promise aspect is added to the object
				promise: function( obj ) {
					return obj != null ? jQuery.extend( obj, promise ) : promise;
				}
			},
			deferred = {};

		// Keep pipe for back-compat
		promise.pipe = promise.then;

		// Add list-specific methods
		jQuery.each( tuples, function( i, tuple ) {
			var list = tuple[ 2 ],
				stateString = tuple[ 3 ];

			// promise[ done | fail | progress ] = list.add
			promise[ tuple[1] ] = list.add;

			// Handle state
			if ( stateString ) {
				list.add(function() {
					// state = [ resolved | rejected ]
					state = stateString;

				// [ reject_list | resolve_list ].disable; progress_list.lock
				}, tuples[ i ^ 1 ][ 2 ].disable, tuples[ 2 ][ 2 ].lock );
			}

			// deferred[ resolve | reject | notify ]
			deferred[ tuple[0] ] = function() {
				deferred[ tuple[0] + "With" ]( this === deferred ? promise : this, arguments );
				return this;
			};
			deferred[ tuple[0] + "With" ] = list.fireWith;
		});

		// Make the deferred a promise
		promise.promise( deferred );

		// Call given func if any
		if ( func ) {
			func.call( deferred, deferred );
		}

		// All done!
		return deferred;
	},

	// Deferred helper
	when: function( subordinate /* , ..., subordinateN */ ) {
		var i = 0,
			resolveValues = slice.call( arguments ),
			length = resolveValues.length,

			// the count of uncompleted subordinates
			remaining = length !== 1 || ( subordinate && jQuery.isFunction( subordinate.promise ) ) ? length : 0,

			// the master Deferred. If resolveValues consist of only a single Deferred, just use that.
			deferred = remaining === 1 ? subordinate : jQuery.Deferred(),

			// Update function for both resolve and progress values
			updateFunc = function( i, contexts, values ) {
				return function( value ) {
					contexts[ i ] = this;
					values[ i ] = arguments.length > 1 ? slice.call( arguments ) : value;
					if ( values === progressValues ) {
						deferred.notifyWith( contexts, values );
					} else if ( !( --remaining ) ) {
						deferred.resolveWith( contexts, values );
					}
				};
			},

			progressValues, progressContexts, resolveContexts;

		// add listeners to Deferred subordinates; treat others as resolved
		if ( length > 1 ) {
			progressValues = new Array( length );
			progressContexts = new Array( length );
			resolveContexts = new Array( length );
			for ( ; i < length; i++ ) {
				if ( resolveValues[ i ] && jQuery.isFunction( resolveValues[ i ].promise ) ) {
					resolveValues[ i ].promise()
						.done( updateFunc( i, resolveContexts, resolveValues ) )
						.fail( deferred.reject )
						.progress( updateFunc( i, progressContexts, progressValues ) );
				} else {
					--remaining;
				}
			}
		}

		// if we're not waiting on anything, resolve the master
		if ( !remaining ) {
			deferred.resolveWith( resolveContexts, resolveValues );
		}

		return deferred.promise();
	}
});


// The deferred used on DOM ready
var readyList;

jQuery.fn.ready = function( fn ) {
	// Add the callback
	jQuery.ready.promise().done( fn );

	return this;
};

jQuery.extend({
	// Is the DOM ready to be used? Set to true once it occurs.
	isReady: false,

	// A counter to track how many items to wait for before
	// the ready event fires. See #6781
	readyWait: 1,

	// Hold (or release) the ready event
	holdReady: function( hold ) {
		if ( hold ) {
			jQuery.readyWait++;
		} else {
			jQuery.ready( true );
		}
	},

	// Handle when the DOM is ready
	ready: function( wait ) {

		// Abort if there are pending holds or we're already ready
		if ( wait === true ? --jQuery.readyWait : jQuery.isReady ) {
			return;
		}

		// Remember that the DOM is ready
		jQuery.isReady = true;

		// If a normal DOM Ready event fired, decrement, and wait if need be
		if ( wait !== true && --jQuery.readyWait > 0 ) {
			return;
		}

		// If there are functions bound, to execute
		readyList.resolveWith( document, [ jQuery ] );

		// Trigger any bound ready events
		if ( jQuery.fn.triggerHandler ) {
			jQuery( document ).triggerHandler( "ready" );
			jQuery( document ).off( "ready" );
		}
	}
});

/**
 * The ready event handler and self cleanup method
 */
function completed() {
	document.removeEventListener( "DOMContentLoaded", completed, false );
	window.removeEventListener( "load", completed, false );
	jQuery.ready();
}

jQuery.ready.promise = function( obj ) {
	if ( !readyList ) {

		readyList = jQuery.Deferred();

		// Catch cases where $(document).ready() is called after the browser event has already occurred.
		// we once tried to use readyState "interactive" here, but it caused issues like the one
		// discovered by ChrisS here: http://bugs.jquery.com/ticket/12282#comment:15
		if ( document.readyState === "complete" ) {
			// Handle it asynchronously to allow scripts the opportunity to delay ready
			setTimeout( jQuery.ready );

		} else {

			// Use the handy event callback
			document.addEventListener( "DOMContentLoaded", completed, false );

			// A fallback to window.onload, that will always work
			window.addEventListener( "load", completed, false );
		}
	}
	return readyList.promise( obj );
};

// Kick off the DOM ready check even if the user does not
jQuery.ready.promise();




// Multifunctional method to get and set values of a collection
// The value/s can optionally be executed if it's a function
var access = jQuery.access = function( elems, fn, key, value, chainable, emptyGet, raw ) {
	var i = 0,
		len = elems.length,
		bulk = key == null;

	// Sets many values
	if ( jQuery.type( key ) === "object" ) {
		chainable = true;
		for ( i in key ) {
			jQuery.access( elems, fn, i, key[i], true, emptyGet, raw );
		}

	// Sets one value
	} else if ( value !== undefined ) {
		chainable = true;

		if ( !jQuery.isFunction( value ) ) {
			raw = true;
		}

		if ( bulk ) {
			// Bulk operations run against the entire set
			if ( raw ) {
				fn.call( elems, value );
				fn = null;

			// ...except when executing function values
			} else {
				bulk = fn;
				fn = function( elem, key, value ) {
					return bulk.call( jQuery( elem ), value );
				};
			}
		}

		if ( fn ) {
			for ( ; i < len; i++ ) {
				fn( elems[i], key, raw ? value : value.call( elems[i], i, fn( elems[i], key ) ) );
			}
		}
	}

	return chainable ?
		elems :

		// Gets
		bulk ?
			fn.call( elems ) :
			len ? fn( elems[0], key ) : emptyGet;
};


/**
 * Determines whether an object can have data
 */
jQuery.acceptData = function( owner ) {
	// Accepts only:
	//  - Node
	//    - Node.ELEMENT_NODE
	//    - Node.DOCUMENT_NODE
	//  - Object
	//    - Any
	/* jshint -W018 */
	return owner.nodeType === 1 || owner.nodeType === 9 || !( +owner.nodeType );
};


function Data() {
	// Support: Android < 4,
	// Old WebKit does not have Object.preventExtensions/freeze method,
	// return new empty object instead with no [[set]] accessor
	Object.defineProperty( this.cache = {}, 0, {
		get: function() {
			return {};
		}
	});

	this.expando = jQuery.expando + Math.random();
}

Data.uid = 1;
Data.accepts = jQuery.acceptData;

Data.prototype = {
	key: function( owner ) {
		// We can accept data for non-element nodes in modern browsers,
		// but we should not, see #8335.
		// Always return the key for a frozen object.
		if ( !Data.accepts( owner ) ) {
			return 0;
		}

		var descriptor = {},
			// Check if the owner object already has a cache key
			unlock = owner[ this.expando ];

		// If not, create one
		if ( !unlock ) {
			unlock = Data.uid++;

			// Secure it in a non-enumerable, non-writable property
			try {
				descriptor[ this.expando ] = { value: unlock };
				Object.defineProperties( owner, descriptor );

			// Support: Android < 4
			// Fallback to a less secure definition
			} catch ( e ) {
				descriptor[ this.expando ] = unlock;
				jQuery.extend( owner, descriptor );
			}
		}

		// Ensure the cache object
		if ( !this.cache[ unlock ] ) {
			this.cache[ unlock ] = {};
		}

		return unlock;
	},
	set: function( owner, data, value ) {
		var prop,
			// There may be an unlock assigned to this node,
			// if there is no entry for this "owner", create one inline
			// and set the unlock as though an owner entry had always existed
			unlock = this.key( owner ),
			cache = this.cache[ unlock ];

		// Handle: [ owner, key, value ] args
		if ( typeof data === "string" ) {
			cache[ data ] = value;

		// Handle: [ owner, { properties } ] args
		} else {
			// Fresh assignments by object are shallow copied
			if ( jQuery.isEmptyObject( cache ) ) {
				jQuery.extend( this.cache[ unlock ], data );
			// Otherwise, copy the properties one-by-one to the cache object
			} else {
				for ( prop in data ) {
					cache[ prop ] = data[ prop ];
				}
			}
		}
		return cache;
	},
	get: function( owner, key ) {
		// Either a valid cache is found, or will be created.
		// New caches will be created and the unlock returned,
		// allowing direct access to the newly created
		// empty data object. A valid owner object must be provided.
		var cache = this.cache[ this.key( owner ) ];

		return key === undefined ?
			cache : cache[ key ];
	},
	access: function( owner, key, value ) {
		var stored;
		// In cases where either:
		//
		//   1. No key was specified
		//   2. A string key was specified, but no value provided
		//
		// Take the "read" path and allow the get method to determine
		// which value to return, respectively either:
		//
		//   1. The entire cache object
		//   2. The data stored at the key
		//
		if ( key === undefined ||
				((key && typeof key === "string") && value === undefined) ) {

			stored = this.get( owner, key );

			return stored !== undefined ?
				stored : this.get( owner, jQuery.camelCase(key) );
		}

		// [*]When the key is not a string, or both a key and value
		// are specified, set or extend (existing objects) with either:
		//
		//   1. An object of properties
		//   2. A key and value
		//
		this.set( owner, key, value );

		// Since the "set" path can have two possible entry points
		// return the expected data based on which path was taken[*]
		return value !== undefined ? value : key;
	},
	remove: function( owner, key ) {
		var i, name, camel,
			unlock = this.key( owner ),
			cache = this.cache[ unlock ];

		if ( key === undefined ) {
			this.cache[ unlock ] = {};

		} else {
			// Support array or space separated string of keys
			if ( jQuery.isArray( key ) ) {
				// If "name" is an array of keys...
				// When data is initially created, via ("key", "val") signature,
				// keys will be converted to camelCase.
				// Since there is no way to tell _how_ a key was added, remove
				// both plain key and camelCase key. #12786
				// This will only penalize the array argument path.
				name = key.concat( key.map( jQuery.camelCase ) );
			} else {
				camel = jQuery.camelCase( key );
				// Try the string as a key before any manipulation
				if ( key in cache ) {
					name = [ key, camel ];
				} else {
					// If a key with the spaces exists, use it.
					// Otherwise, create an array by matching non-whitespace
					name = camel;
					name = name in cache ?
						[ name ] : ( name.match( rnotwhite ) || [] );
				}
			}

			i = name.length;
			while ( i-- ) {
				delete cache[ name[ i ] ];
			}
		}
	},
	hasData: function( owner ) {
		return !jQuery.isEmptyObject(
			this.cache[ owner[ this.expando ] ] || {}
		);
	},
	discard: function( owner ) {
		if ( owner[ this.expando ] ) {
			delete this.cache[ owner[ this.expando ] ];
		}
	}
};
var data_priv = new Data();

var data_user = new Data();



/*
	Implementation Summary

	1. Enforce API surface and semantic compatibility with 1.9.x branch
	2. Improve the module's maintainability by reducing the storage
		paths to a single mechanism.
	3. Use the same single mechanism to support "private" and "user" data.
	4. _Never_ expose "private" data to user code (TODO: Drop _data, _removeData)
	5. Avoid exposing implementation details on user objects (eg. expando properties)
	6. Provide a clear path for implementation upgrade to WeakMap in 2014
*/
var rbrace = /^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,
	rmultiDash = /([A-Z])/g;

function dataAttr( elem, key, data ) {
	var name;

	// If nothing was found internally, try to fetch any
	// data from the HTML5 data-* attribute
	if ( data === undefined && elem.nodeType === 1 ) {
		name = "data-" + key.replace( rmultiDash, "-$1" ).toLowerCase();
		data = elem.getAttribute( name );

		if ( typeof data === "string" ) {
			try {
				data = data === "true" ? true :
					data === "false" ? false :
					data === "null" ? null :
					// Only convert to a number if it doesn't change the string
					+data + "" === data ? +data :
					rbrace.test( data ) ? jQuery.parseJSON( data ) :
					data;
			} catch( e ) {}

			// Make sure we set the data so it isn't changed later
			data_user.set( elem, key, data );
		} else {
			data = undefined;
		}
	}
	return data;
}

jQuery.extend({
	hasData: function( elem ) {
		return data_user.hasData( elem ) || data_priv.hasData( elem );
	},

	data: function( elem, name, data ) {
		return data_user.access( elem, name, data );
	},

	removeData: function( elem, name ) {
		data_user.remove( elem, name );
	},

	// TODO: Now that all calls to _data and _removeData have been replaced
	// with direct calls to data_priv methods, these can be deprecated.
	_data: function( elem, name, data ) {
		return data_priv.access( elem, name, data );
	},

	_removeData: function( elem, name ) {
		data_priv.remove( elem, name );
	}
});

jQuery.fn.extend({
	data: function( key, value ) {
		var i, name, data,
			elem = this[ 0 ],
			attrs = elem && elem.attributes;

		// Gets all values
		if ( key === undefined ) {
			if ( this.length ) {
				data = data_user.get( elem );

				if ( elem.nodeType === 1 && !data_priv.get( elem, "hasDataAttrs" ) ) {
					i = attrs.length;
					while ( i-- ) {

						// Support: IE11+
						// The attrs elements can be null (#14894)
						if ( attrs[ i ] ) {
							name = attrs[ i ].name;
							if ( name.indexOf( "data-" ) === 0 ) {
								name = jQuery.camelCase( name.slice(5) );
								dataAttr( elem, name, data[ name ] );
							}
						}
					}
					data_priv.set( elem, "hasDataAttrs", true );
				}
			}

			return data;
		}

		// Sets multiple values
		if ( typeof key === "object" ) {
			return this.each(function() {
				data_user.set( this, key );
			});
		}

		return access( this, function( value ) {
			var data,
				camelKey = jQuery.camelCase( key );

			// The calling jQuery object (element matches) is not empty
			// (and therefore has an element appears at this[ 0 ]) and the
			// `value` parameter was not undefined. An empty jQuery object
			// will result in `undefined` for elem = this[ 0 ] which will
			// throw an exception if an attempt to read a data cache is made.
			if ( elem && value === undefined ) {
				// Attempt to get data from the cache
				// with the key as-is
				data = data_user.get( elem, key );
				if ( data !== undefined ) {
					return data;
				}

				// Attempt to get data from the cache
				// with the key camelized
				data = data_user.get( elem, camelKey );
				if ( data !== undefined ) {
					return data;
				}

				// Attempt to "discover" the data in
				// HTML5 custom data-* attrs
				data = dataAttr( elem, camelKey, undefined );
				if ( data !== undefined ) {
					return data;
				}

				// We tried really hard, but the data doesn't exist.
				return;
			}

			// Set the data...
			this.each(function() {
				// First, attempt to store a copy or reference of any
				// data that might've been store with a camelCased key.
				var data = data_user.get( this, camelKey );

				// For HTML5 data-* attribute interop, we have to
				// store property names with dashes in a camelCase form.
				// This might not apply to all properties...*
				data_user.set( this, camelKey, value );

				// *... In the case of properties that might _actually_
				// have dashes, we need to also store a copy of that
				// unchanged property.
				if ( key.indexOf("-") !== -1 && data !== undefined ) {
					data_user.set( this, key, value );
				}
			});
		}, null, value, arguments.length > 1, null, true );
	},

	removeData: function( key ) {
		return this.each(function() {
			data_user.remove( this, key );
		});
	}
});


jQuery.extend({
	queue: function( elem, type, data ) {
		var queue;

		if ( elem ) {
			type = ( type || "fx" ) + "queue";
			queue = data_priv.get( elem, type );

			// Speed up dequeue by getting out quickly if this is just a lookup
			if ( data ) {
				if ( !queue || jQuery.isArray( data ) ) {
					queue = data_priv.access( elem, type, jQuery.makeArray(data) );
				} else {
					queue.push( data );
				}
			}
			return queue || [];
		}
	},

	dequeue: function( elem, type ) {
		type = type || "fx";

		var queue = jQuery.queue( elem, type ),
			startLength = queue.length,
			fn = queue.shift(),
			hooks = jQuery._queueHooks( elem, type ),
			next = function() {
				jQuery.dequeue( elem, type );
			};

		// If the fx queue is dequeued, always remove the progress sentinel
		if ( fn === "inprogress" ) {
			fn = queue.shift();
			startLength--;
		}

		if ( fn ) {

			// Add a progress sentinel to prevent the fx queue from being
			// automatically dequeued
			if ( type === "fx" ) {
				queue.unshift( "inprogress" );
			}

			// clear up the last queue stop function
			delete hooks.stop;
			fn.call( elem, next, hooks );
		}

		if ( !startLength && hooks ) {
			hooks.empty.fire();
		}
	},

	// not intended for public consumption - generates a queueHooks object, or returns the current one
	_queueHooks: function( elem, type ) {
		var key = type + "queueHooks";
		return data_priv.get( elem, key ) || data_priv.access( elem, key, {
			empty: jQuery.Callbacks("once memory").add(function() {
				data_priv.remove( elem, [ type + "queue", key ] );
			})
		});
	}
});

jQuery.fn.extend({
	queue: function( type, data ) {
		var setter = 2;

		if ( typeof type !== "string" ) {
			data = type;
			type = "fx";
			setter--;
		}

		if ( arguments.length < setter ) {
			return jQuery.queue( this[0], type );
		}

		return data === undefined ?
			this :
			this.each(function() {
				var queue = jQuery.queue( this, type, data );

				// ensure a hooks for this queue
				jQuery._queueHooks( this, type );

				if ( type === "fx" && queue[0] !== "inprogress" ) {
					jQuery.dequeue( this, type );
				}
			});
	},
	dequeue: function( type ) {
		return this.each(function() {
			jQuery.dequeue( this, type );
		});
	},
	clearQueue: function( type ) {
		return this.queue( type || "fx", [] );
	},
	// Get a promise resolved when queues of a certain type
	// are emptied (fx is the type by default)
	promise: function( type, obj ) {
		var tmp,
			count = 1,
			defer = jQuery.Deferred(),
			elements = this,
			i = this.length,
			resolve = function() {
				if ( !( --count ) ) {
					defer.resolveWith( elements, [ elements ] );
				}
			};

		if ( typeof type !== "string" ) {
			obj = type;
			type = undefined;
		}
		type = type || "fx";

		while ( i-- ) {
			tmp = data_priv.get( elements[ i ], type + "queueHooks" );
			if ( tmp && tmp.empty ) {
				count++;
				tmp.empty.add( resolve );
			}
		}
		resolve();
		return defer.promise( obj );
	}
});
var pnum = (/[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/).source;

var cssExpand = [ "Top", "Right", "Bottom", "Left" ];

var isHidden = function( elem, el ) {
		// isHidden might be called from jQuery#filter function;
		// in that case, element will be second argument
		elem = el || elem;
		return jQuery.css( elem, "display" ) === "none" || !jQuery.contains( elem.ownerDocument, elem );
	};

var rcheckableType = (/^(?:checkbox|radio)$/i);



(function() {
	var fragment = document.createDocumentFragment(),
		div = fragment.appendChild( document.createElement( "div" ) ),
		input = document.createElement( "input" );

	// #11217 - WebKit loses check when the name is after the checked attribute
	// Support: Windows Web Apps (WWA)
	// `name` and `type` need .setAttribute for WWA
	input.setAttribute( "type", "radio" );
	input.setAttribute( "checked", "checked" );
	input.setAttribute( "name", "t" );

	div.appendChild( input );

	// Support: Safari 5.1, iOS 5.1, Android 4.x, Android 2.3
	// old WebKit doesn't clone checked state correctly in fragments
	support.checkClone = div.cloneNode( true ).cloneNode( true ).lastChild.checked;

	// Make sure textarea (and checkbox) defaultValue is properly cloned
	// Support: IE9-IE11+
	div.innerHTML = "<textarea>x</textarea>";
	support.noCloneChecked = !!div.cloneNode( true ).lastChild.defaultValue;
})();
var strundefined = typeof undefined;



support.focusinBubbles = "onfocusin" in window;


var
	rkeyEvent = /^key/,
	rmouseEvent = /^(?:mouse|pointer|contextmenu)|click/,
	rfocusMorph = /^(?:focusinfocus|focusoutblur)$/,
	rtypenamespace = /^([^.]*)(?:\.(.+)|)$/;

function returnTrue() {
	return true;
}

function returnFalse() {
	return false;
}

function safeActiveElement() {
	try {
		return document.activeElement;
	} catch ( err ) { }
}

/*
 * Helper functions for managing events -- not part of the public interface.
 * Props to Dean Edwards' addEvent library for many of the ideas.
 */
jQuery.event = {

	global: {},

	add: function( elem, types, handler, data, selector ) {

		var handleObjIn, eventHandle, tmp,
			events, t, handleObj,
			special, handlers, type, namespaces, origType,
			elemData = data_priv.get( elem );

		// Don't attach events to noData or text/comment nodes (but allow plain objects)
		if ( !elemData ) {
			return;
		}

		// Caller can pass in an object of custom data in lieu of the handler
		if ( handler.handler ) {
			handleObjIn = handler;
			handler = handleObjIn.handler;
			selector = handleObjIn.selector;
		}

		// Make sure that the handler has a unique ID, used to find/remove it later
		if ( !handler.guid ) {
			handler.guid = jQuery.guid++;
		}

		// Init the element's event structure and main handler, if this is the first
		if ( !(events = elemData.events) ) {
			events = elemData.events = {};
		}
		if ( !(eventHandle = elemData.handle) ) {
			eventHandle = elemData.handle = function( e ) {
				// Discard the second event of a jQuery.event.trigger() and
				// when an event is called after a page has unloaded
				return typeof jQuery !== strundefined && jQuery.event.triggered !== e.type ?
					jQuery.event.dispatch.apply( elem, arguments ) : undefined;
			};
		}

		// Handle multiple events separated by a space
		types = ( types || "" ).match( rnotwhite ) || [ "" ];
		t = types.length;
		while ( t-- ) {
			tmp = rtypenamespace.exec( types[t] ) || [];
			type = origType = tmp[1];
			namespaces = ( tmp[2] || "" ).split( "." ).sort();

			// There *must* be a type, no attaching namespace-only handlers
			if ( !type ) {
				continue;
			}

			// If event changes its type, use the special event handlers for the changed type
			special = jQuery.event.special[ type ] || {};

			// If selector defined, determine special event api type, otherwise given type
			type = ( selector ? special.delegateType : special.bindType ) || type;

			// Update special based on newly reset type
			special = jQuery.event.special[ type ] || {};

			// handleObj is passed to all event handlers
			handleObj = jQuery.extend({
				type: type,
				origType: origType,
				data: data,
				handler: handler,
				guid: handler.guid,
				selector: selector,
				needsContext: selector && jQuery.expr.match.needsContext.test( selector ),
				namespace: namespaces.join(".")
			}, handleObjIn );

			// Init the event handler queue if we're the first
			if ( !(handlers = events[ type ]) ) {
				handlers = events[ type ] = [];
				handlers.delegateCount = 0;

				// Only use addEventListener if the special events handler returns false
				if ( !special.setup || special.setup.call( elem, data, namespaces, eventHandle ) === false ) {
					if ( elem.addEventListener ) {
						elem.addEventListener( type, eventHandle, false );
					}
				}
			}

			if ( special.add ) {
				special.add.call( elem, handleObj );

				if ( !handleObj.handler.guid ) {
					handleObj.handler.guid = handler.guid;
				}
			}

			// Add to the element's handler list, delegates in front
			if ( selector ) {
				handlers.splice( handlers.delegateCount++, 0, handleObj );
			} else {
				handlers.push( handleObj );
			}

			// Keep track of which events have ever been used, for event optimization
			jQuery.event.global[ type ] = true;
		}

	},

	// Detach an event or set of events from an element
	remove: function( elem, types, handler, selector, mappedTypes ) {

		var j, origCount, tmp,
			events, t, handleObj,
			special, handlers, type, namespaces, origType,
			elemData = data_priv.hasData( elem ) && data_priv.get( elem );

		if ( !elemData || !(events = elemData.events) ) {
			return;
		}

		// Once for each type.namespace in types; type may be omitted
		types = ( types || "" ).match( rnotwhite ) || [ "" ];
		t = types.length;
		while ( t-- ) {
			tmp = rtypenamespace.exec( types[t] ) || [];
			type = origType = tmp[1];
			namespaces = ( tmp[2] || "" ).split( "." ).sort();

			// Unbind all events (on this namespace, if provided) for the element
			if ( !type ) {
				for ( type in events ) {
					jQuery.event.remove( elem, type + types[ t ], handler, selector, true );
				}
				continue;
			}

			special = jQuery.event.special[ type ] || {};
			type = ( selector ? special.delegateType : special.bindType ) || type;
			handlers = events[ type ] || [];
			tmp = tmp[2] && new RegExp( "(^|\\.)" + namespaces.join("\\.(?:.*\\.|)") + "(\\.|$)" );

			// Remove matching events
			origCount = j = handlers.length;
			while ( j-- ) {
				handleObj = handlers[ j ];

				if ( ( mappedTypes || origType === handleObj.origType ) &&
					( !handler || handler.guid === handleObj.guid ) &&
					( !tmp || tmp.test( handleObj.namespace ) ) &&
					( !selector || selector === handleObj.selector || selector === "**" && handleObj.selector ) ) {
					handlers.splice( j, 1 );

					if ( handleObj.selector ) {
						handlers.delegateCount--;
					}
					if ( special.remove ) {
						special.remove.call( elem, handleObj );
					}
				}
			}

			// Remove generic event handler if we removed something and no more handlers exist
			// (avoids potential for endless recursion during removal of special event handlers)
			if ( origCount && !handlers.length ) {
				if ( !special.teardown || special.teardown.call( elem, namespaces, elemData.handle ) === false ) {
					jQuery.removeEvent( elem, type, elemData.handle );
				}

				delete events[ type ];
			}
		}

		// Remove the expando if it's no longer used
		if ( jQuery.isEmptyObject( events ) ) {
			delete elemData.handle;
			data_priv.remove( elem, "events" );
		}
	},

	trigger: function( event, data, elem, onlyHandlers ) {

		var i, cur, tmp, bubbleType, ontype, handle, special,
			eventPath = [ elem || document ],
			type = hasOwn.call( event, "type" ) ? event.type : event,
			namespaces = hasOwn.call( event, "namespace" ) ? event.namespace.split(".") : [];

		cur = tmp = elem = elem || document;

		// Don't do events on text and comment nodes
		if ( elem.nodeType === 3 || elem.nodeType === 8 ) {
			return;
		}

		// focus/blur morphs to focusin/out; ensure we're not firing them right now
		if ( rfocusMorph.test( type + jQuery.event.triggered ) ) {
			return;
		}

		if ( type.indexOf(".") >= 0 ) {
			// Namespaced trigger; create a regexp to match event type in handle()
			namespaces = type.split(".");
			type = namespaces.shift();
			namespaces.sort();
		}
		ontype = type.indexOf(":") < 0 && "on" + type;

		// Caller can pass in a jQuery.Event object, Object, or just an event type string
		event = event[ jQuery.expando ] ?
			event :
			new jQuery.Event( type, typeof event === "object" && event );

		// Trigger bitmask: & 1 for native handlers; & 2 for jQuery (always true)
		event.isTrigger = onlyHandlers ? 2 : 3;
		event.namespace = namespaces.join(".");
		event.namespace_re = event.namespace ?
			new RegExp( "(^|\\.)" + namespaces.join("\\.(?:.*\\.|)") + "(\\.|$)" ) :
			null;

		// Clean up the event in case it is being reused
		event.result = undefined;
		if ( !event.target ) {
			event.target = elem;
		}

		// Clone any incoming data and prepend the event, creating the handler arg list
		data = data == null ?
			[ event ] :
			jQuery.makeArray( data, [ event ] );

		// Allow special events to draw outside the lines
		special = jQuery.event.special[ type ] || {};
		if ( !onlyHandlers && special.trigger && special.trigger.apply( elem, data ) === false ) {
			return;
		}

		// Determine event propagation path in advance, per W3C events spec (#9951)
		// Bubble up to document, then to window; watch for a global ownerDocument var (#9724)
		if ( !onlyHandlers && !special.noBubble && !jQuery.isWindow( elem ) ) {

			bubbleType = special.delegateType || type;
			if ( !rfocusMorph.test( bubbleType + type ) ) {
				cur = cur.parentNode;
			}
			for ( ; cur; cur = cur.parentNode ) {
				eventPath.push( cur );
				tmp = cur;
			}

			// Only add window if we got to document (e.g., not plain obj or detached DOM)
			if ( tmp === (elem.ownerDocument || document) ) {
				eventPath.push( tmp.defaultView || tmp.parentWindow || window );
			}
		}

		// Fire handlers on the event path
		i = 0;
		while ( (cur = eventPath[i++]) && !event.isPropagationStopped() ) {

			event.type = i > 1 ?
				bubbleType :
				special.bindType || type;

			// jQuery handler
			handle = ( data_priv.get( cur, "events" ) || {} )[ event.type ] && data_priv.get( cur, "handle" );
			if ( handle ) {
				handle.apply( cur, data );
			}

			// Native handler
			handle = ontype && cur[ ontype ];
			if ( handle && handle.apply && jQuery.acceptData( cur ) ) {
				event.result = handle.apply( cur, data );
				if ( event.result === false ) {
					event.preventDefault();
				}
			}
		}
		event.type = type;

		// If nobody prevented the default action, do it now
		if ( !onlyHandlers && !event.isDefaultPrevented() ) {

			if ( (!special._default || special._default.apply( eventPath.pop(), data ) === false) &&
				jQuery.acceptData( elem ) ) {

				// Call a native DOM method on the target with the same name name as the event.
				// Don't do default actions on window, that's where global variables be (#6170)
				if ( ontype && jQuery.isFunction( elem[ type ] ) && !jQuery.isWindow( elem ) ) {

					// Don't re-trigger an onFOO event when we call its FOO() method
					tmp = elem[ ontype ];

					if ( tmp ) {
						elem[ ontype ] = null;
					}

					// Prevent re-triggering of the same event, since we already bubbled it above
					jQuery.event.triggered = type;
					elem[ type ]();
					jQuery.event.triggered = undefined;

					if ( tmp ) {
						elem[ ontype ] = tmp;
					}
				}
			}
		}

		return event.result;
	},

	dispatch: function( event ) {

		// Make a writable jQuery.Event from the native event object
		event = jQuery.event.fix( event );

		var i, j, ret, matched, handleObj,
			handlerQueue = [],
			args = slice.call( arguments ),
			handlers = ( data_priv.get( this, "events" ) || {} )[ event.type ] || [],
			special = jQuery.event.special[ event.type ] || {};

		// Use the fix-ed jQuery.Event rather than the (read-only) native event
		args[0] = event;
		event.delegateTarget = this;

		// Call the preDispatch hook for the mapped type, and let it bail if desired
		if ( special.preDispatch && special.preDispatch.call( this, event ) === false ) {
			return;
		}

		// Determine handlers
		handlerQueue = jQuery.event.handlers.call( this, event, handlers );

		// Run delegates first; they may want to stop propagation beneath us
		i = 0;
		while ( (matched = handlerQueue[ i++ ]) && !event.isPropagationStopped() ) {
			event.currentTarget = matched.elem;

			j = 0;
			while ( (handleObj = matched.handlers[ j++ ]) && !event.isImmediatePropagationStopped() ) {

				// Triggered event must either 1) have no namespace, or
				// 2) have namespace(s) a subset or equal to those in the bound event (both can have no namespace).
				if ( !event.namespace_re || event.namespace_re.test( handleObj.namespace ) ) {

					event.handleObj = handleObj;
					event.data = handleObj.data;

					ret = ( (jQuery.event.special[ handleObj.origType ] || {}).handle || handleObj.handler )
							.apply( matched.elem, args );

					if ( ret !== undefined ) {
						if ( (event.result = ret) === false ) {
							event.preventDefault();
							event.stopPropagation();
						}
					}
				}
			}
		}

		// Call the postDispatch hook for the mapped type
		if ( special.postDispatch ) {
			special.postDispatch.call( this, event );
		}

		return event.result;
	},

	handlers: function( event, handlers ) {
		var i, matches, sel, handleObj,
			handlerQueue = [],
			delegateCount = handlers.delegateCount,
			cur = event.target;

		// Find delegate handlers
		// Black-hole SVG <use> instance trees (#13180)
		// Avoid non-left-click bubbling in Firefox (#3861)
		if ( delegateCount && cur.nodeType && (!event.button || event.type !== "click") ) {

			for ( ; cur !== this; cur = cur.parentNode || this ) {

				// Don't process clicks on disabled elements (#6911, #8165, #11382, #11764)
				if ( cur.disabled !== true || event.type !== "click" ) {
					matches = [];
					for ( i = 0; i < delegateCount; i++ ) {
						handleObj = handlers[ i ];

						// Don't conflict with Object.prototype properties (#13203)
						sel = handleObj.selector + " ";

						if ( matches[ sel ] === undefined ) {
							matches[ sel ] = handleObj.needsContext ?
								jQuery( sel, this ).index( cur ) >= 0 :
								jQuery.find( sel, this, null, [ cur ] ).length;
						}
						if ( matches[ sel ] ) {
							matches.push( handleObj );
						}
					}
					if ( matches.length ) {
						handlerQueue.push({ elem: cur, handlers: matches });
					}
				}
			}
		}

		// Add the remaining (directly-bound) handlers
		if ( delegateCount < handlers.length ) {
			handlerQueue.push({ elem: this, handlers: handlers.slice( delegateCount ) });
		}

		return handlerQueue;
	},

	// Includes some event props shared by KeyEvent and MouseEvent
	props: "altKey bubbles cancelable ctrlKey currentTarget eventPhase metaKey relatedTarget shiftKey target timeStamp view which".split(" "),

	fixHooks: {},

	keyHooks: {
		props: "char charCode key keyCode".split(" "),
		filter: function( event, original ) {

			// Add which for key events
			if ( event.which == null ) {
				event.which = original.charCode != null ? original.charCode : original.keyCode;
			}

			return event;
		}
	},

	mouseHooks: {
		props: "button buttons clientX clientY offsetX offsetY pageX pageY screenX screenY toElement".split(" "),
		filter: function( event, original ) {
			var eventDoc, doc, body,
				button = original.button;

			// Calculate pageX/Y if missing and clientX/Y available
			if ( event.pageX == null && original.clientX != null ) {
				eventDoc = event.target.ownerDocument || document;
				doc = eventDoc.documentElement;
				body = eventDoc.body;

				event.pageX = original.clientX + ( doc && doc.scrollLeft || body && body.scrollLeft || 0 ) - ( doc && doc.clientLeft || body && body.clientLeft || 0 );
				event.pageY = original.clientY + ( doc && doc.scrollTop  || body && body.scrollTop  || 0 ) - ( doc && doc.clientTop  || body && body.clientTop  || 0 );
			}

			// Add which for click: 1 === left; 2 === middle; 3 === right
			// Note: button is not normalized, so don't use it
			if ( !event.which && button !== undefined ) {
				event.which = ( button & 1 ? 1 : ( button & 2 ? 3 : ( button & 4 ? 2 : 0 ) ) );
			}

			return event;
		}
	},

	fix: function( event ) {
		if ( event[ jQuery.expando ] ) {
			return event;
		}

		// Create a writable copy of the event object and normalize some properties
		var i, prop, copy,
			type = event.type,
			originalEvent = event,
			fixHook = this.fixHooks[ type ];

		if ( !fixHook ) {
			this.fixHooks[ type ] = fixHook =
				rmouseEvent.test( type ) ? this.mouseHooks :
				rkeyEvent.test( type ) ? this.keyHooks :
				{};
		}
		copy = fixHook.props ? this.props.concat( fixHook.props ) : this.props;

		event = new jQuery.Event( originalEvent );

		i = copy.length;
		while ( i-- ) {
			prop = copy[ i ];
			event[ prop ] = originalEvent[ prop ];
		}

		// Support: Cordova 2.5 (WebKit) (#13255)
		// All events should have a target; Cordova deviceready doesn't
		if ( !event.target ) {
			event.target = document;
		}

		// Support: Safari 6.0+, Chrome < 28
		// Target should not be a text node (#504, #13143)
		if ( event.target.nodeType === 3 ) {
			event.target = event.target.parentNode;
		}

		return fixHook.filter ? fixHook.filter( event, originalEvent ) : event;
	},

	special: {
		load: {
			// Prevent triggered image.load events from bubbling to window.load
			noBubble: true
		},
		focus: {
			// Fire native event if possible so blur/focus sequence is correct
			trigger: function() {
				if ( this !== safeActiveElement() && this.focus ) {
					this.focus();
					return false;
				}
			},
			delegateType: "focusin"
		},
		blur: {
			trigger: function() {
				if ( this === safeActiveElement() && this.blur ) {
					this.blur();
					return false;
				}
			},
			delegateType: "focusout"
		},
		click: {
			// For checkbox, fire native event so checked state will be right
			trigger: function() {
				if ( this.type === "checkbox" && this.click && jQuery.nodeName( this, "input" ) ) {
					this.click();
					return false;
				}
			},

			// For cross-browser consistency, don't fire native .click() on links
			_default: function( event ) {
				return jQuery.nodeName( event.target, "a" );
			}
		},

		beforeunload: {
			postDispatch: function( event ) {

				// Support: Firefox 20+
				// Firefox doesn't alert if the returnValue field is not set.
				if ( event.result !== undefined && event.originalEvent ) {
					event.originalEvent.returnValue = event.result;
				}
			}
		}
	},

	simulate: function( type, elem, event, bubble ) {
		// Piggyback on a donor event to simulate a different one.
		// Fake originalEvent to avoid donor's stopPropagation, but if the
		// simulated event prevents default then we do the same on the donor.
		var e = jQuery.extend(
			new jQuery.Event(),
			event,
			{
				type: type,
				isSimulated: true,
				originalEvent: {}
			}
		);
		if ( bubble ) {
			jQuery.event.trigger( e, null, elem );
		} else {
			jQuery.event.dispatch.call( elem, e );
		}
		if ( e.isDefaultPrevented() ) {
			event.preventDefault();
		}
	}
};

jQuery.removeEvent = function( elem, type, handle ) {
	if ( elem.removeEventListener ) {
		elem.removeEventListener( type, handle, false );
	}
};

jQuery.Event = function( src, props ) {
	// Allow instantiation without the 'new' keyword
	if ( !(this instanceof jQuery.Event) ) {
		return new jQuery.Event( src, props );
	}

	// Event object
	if ( src && src.type ) {
		this.originalEvent = src;
		this.type = src.type;

		// Events bubbling up the document may have been marked as prevented
		// by a handler lower down the tree; reflect the correct value.
		this.isDefaultPrevented = src.defaultPrevented ||
				src.defaultPrevented === undefined &&
				// Support: Android < 4.0
				src.returnValue === false ?
			returnTrue :
			returnFalse;

	// Event type
	} else {
		this.type = src;
	}

	// Put explicitly provided properties onto the event object
	if ( props ) {
		jQuery.extend( this, props );
	}

	// Create a timestamp if incoming event doesn't have one
	this.timeStamp = src && src.timeStamp || jQuery.now();

	// Mark it as fixed
	this[ jQuery.expando ] = true;
};

// jQuery.Event is based on DOM3 Events as specified by the ECMAScript Language Binding
// http://www.w3.org/TR/2003/WD-DOM-Level-3-Events-20030331/ecma-script-binding.html
jQuery.Event.prototype = {
	isDefaultPrevented: returnFalse,
	isPropagationStopped: returnFalse,
	isImmediatePropagationStopped: returnFalse,

	preventDefault: function() {
		var e = this.originalEvent;

		this.isDefaultPrevented = returnTrue;

		if ( e && e.preventDefault ) {
			e.preventDefault();
		}
	},
	stopPropagation: function() {
		var e = this.originalEvent;

		this.isPropagationStopped = returnTrue;

		if ( e && e.stopPropagation ) {
			e.stopPropagation();
		}
	},
	stopImmediatePropagation: function() {
		var e = this.originalEvent;

		this.isImmediatePropagationStopped = returnTrue;

		if ( e && e.stopImmediatePropagation ) {
			e.stopImmediatePropagation();
		}

		this.stopPropagation();
	}
};

// Create mouseenter/leave events using mouseover/out and event-time checks
// Support: Chrome 15+
jQuery.each({
	mouseenter: "mouseover",
	mouseleave: "mouseout",
	pointerenter: "pointerover",
	pointerleave: "pointerout"
}, function( orig, fix ) {
	jQuery.event.special[ orig ] = {
		delegateType: fix,
		bindType: fix,

		handle: function( event ) {
			var ret,
				target = this,
				related = event.relatedTarget,
				handleObj = event.handleObj;

			// For mousenter/leave call the handler if related is outside the target.
			// NB: No relatedTarget if the mouse left/entered the browser window
			if ( !related || (related !== target && !jQuery.contains( target, related )) ) {
				event.type = handleObj.origType;
				ret = handleObj.handler.apply( this, arguments );
				event.type = fix;
			}
			return ret;
		}
	};
});

// Create "bubbling" focus and blur events
// Support: Firefox, Chrome, Safari
if ( !support.focusinBubbles ) {
	jQuery.each({ focus: "focusin", blur: "focusout" }, function( orig, fix ) {

		// Attach a single capturing handler on the document while someone wants focusin/focusout
		var handler = function( event ) {
				jQuery.event.simulate( fix, event.target, jQuery.event.fix( event ), true );
			};

		jQuery.event.special[ fix ] = {
			setup: function() {
				var doc = this.ownerDocument || this,
					attaches = data_priv.access( doc, fix );

				if ( !attaches ) {
					doc.addEventListener( orig, handler, true );
				}
				data_priv.access( doc, fix, ( attaches || 0 ) + 1 );
			},
			teardown: function() {
				var doc = this.ownerDocument || this,
					attaches = data_priv.access( doc, fix ) - 1;

				if ( !attaches ) {
					doc.removeEventListener( orig, handler, true );
					data_priv.remove( doc, fix );

				} else {
					data_priv.access( doc, fix, attaches );
				}
			}
		};
	});
}

jQuery.fn.extend({

	on: function( types, selector, data, fn, /*INTERNAL*/ one ) {
		var origFn, type;

		// Types can be a map of types/handlers
		if ( typeof types === "object" ) {
			// ( types-Object, selector, data )
			if ( typeof selector !== "string" ) {
				// ( types-Object, data )
				data = data || selector;
				selector = undefined;
			}
			for ( type in types ) {
				this.on( type, selector, data, types[ type ], one );
			}
			return this;
		}

		if ( data == null && fn == null ) {
			// ( types, fn )
			fn = selector;
			data = selector = undefined;
		} else if ( fn == null ) {
			if ( typeof selector === "string" ) {
				// ( types, selector, fn )
				fn = data;
				data = undefined;
			} else {
				// ( types, data, fn )
				fn = data;
				data = selector;
				selector = undefined;
			}
		}
		if ( fn === false ) {
			fn = returnFalse;
		} else if ( !fn ) {
			return this;
		}

		if ( one === 1 ) {
			origFn = fn;
			fn = function( event ) {
				// Can use an empty set, since event contains the info
				jQuery().off( event );
				return origFn.apply( this, arguments );
			};
			// Use same guid so caller can remove using origFn
			fn.guid = origFn.guid || ( origFn.guid = jQuery.guid++ );
		}
		return this.each( function() {
			jQuery.event.add( this, types, fn, data, selector );
		});
	},
	one: function( types, selector, data, fn ) {
		return this.on( types, selector, data, fn, 1 );
	},
	off: function( types, selector, fn ) {
		var handleObj, type;
		if ( types && types.preventDefault && types.handleObj ) {
			// ( event )  dispatched jQuery.Event
			handleObj = types.handleObj;
			jQuery( types.delegateTarget ).off(
				handleObj.namespace ? handleObj.origType + "." + handleObj.namespace : handleObj.origType,
				handleObj.selector,
				handleObj.handler
			);
			return this;
		}
		if ( typeof types === "object" ) {
			// ( types-object [, selector] )
			for ( type in types ) {
				this.off( type, selector, types[ type ] );
			}
			return this;
		}
		if ( selector === false || typeof selector === "function" ) {
			// ( types [, fn] )
			fn = selector;
			selector = undefined;
		}
		if ( fn === false ) {
			fn = returnFalse;
		}
		return this.each(function() {
			jQuery.event.remove( this, types, fn, selector );
		});
	},

	trigger: function( type, data ) {
		return this.each(function() {
			jQuery.event.trigger( type, data, this );
		});
	},
	triggerHandler: function( type, data ) {
		var elem = this[0];
		if ( elem ) {
			return jQuery.event.trigger( type, data, elem, true );
		}
	}
});


var
	rxhtmlTag = /<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:]+)[^>]*)\/>/gi,
	rtagName = /<([\w:]+)/,
	rhtml = /<|&#?\w+;/,
	rnoInnerhtml = /<(?:script|style|link)/i,
	// checked="checked" or checked
	rchecked = /checked\s*(?:[^=]|=\s*.checked.)/i,
	rscriptType = /^$|\/(?:java|ecma)script/i,
	rscriptTypeMasked = /^true\/(.*)/,
	rcleanScript = /^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g,

	// We have to close these tags to support XHTML (#13200)
	wrapMap = {

		// Support: IE 9
		option: [ 1, "<select multiple='multiple'>", "</select>" ],

		thead: [ 1, "<table>", "</table>" ],
		col: [ 2, "<table><colgroup>", "</colgroup></table>" ],
		tr: [ 2, "<table><tbody>", "</tbody></table>" ],
		td: [ 3, "<table><tbody><tr>", "</tr></tbody></table>" ],

		_default: [ 0, "", "" ]
	};

// Support: IE 9
wrapMap.optgroup = wrapMap.option;

wrapMap.tbody = wrapMap.tfoot = wrapMap.colgroup = wrapMap.caption = wrapMap.thead;
wrapMap.th = wrapMap.td;

// Support: 1.x compatibility
// Manipulating tables requires a tbody
function manipulationTarget( elem, content ) {
	return jQuery.nodeName( elem, "table" ) &&
		jQuery.nodeName( content.nodeType !== 11 ? content : content.firstChild, "tr" ) ?

		elem.getElementsByTagName("tbody")[0] ||
			elem.appendChild( elem.ownerDocument.createElement("tbody") ) :
		elem;
}

// Replace/restore the type attribute of script elements for safe DOM manipulation
function disableScript( elem ) {
	elem.type = (elem.getAttribute("type") !== null) + "/" + elem.type;
	return elem;
}
function restoreScript( elem ) {
	var match = rscriptTypeMasked.exec( elem.type );

	if ( match ) {
		elem.type = match[ 1 ];
	} else {
		elem.removeAttribute("type");
	}

	return elem;
}

// Mark scripts as having already been evaluated
function setGlobalEval( elems, refElements ) {
	var i = 0,
		l = elems.length;

	for ( ; i < l; i++ ) {
		data_priv.set(
			elems[ i ], "globalEval", !refElements || data_priv.get( refElements[ i ], "globalEval" )
		);
	}
}

function cloneCopyEvent( src, dest ) {
	var i, l, type, pdataOld, pdataCur, udataOld, udataCur, events;

	if ( dest.nodeType !== 1 ) {
		return;
	}

	// 1. Copy private data: events, handlers, etc.
	if ( data_priv.hasData( src ) ) {
		pdataOld = data_priv.access( src );
		pdataCur = data_priv.set( dest, pdataOld );
		events = pdataOld.events;

		if ( events ) {
			delete pdataCur.handle;
			pdataCur.events = {};

			for ( type in events ) {
				for ( i = 0, l = events[ type ].length; i < l; i++ ) {
					jQuery.event.add( dest, type, events[ type ][ i ] );
				}
			}
		}
	}

	// 2. Copy user data
	if ( data_user.hasData( src ) ) {
		udataOld = data_user.access( src );
		udataCur = jQuery.extend( {}, udataOld );

		data_user.set( dest, udataCur );
	}
}

function getAll( context, tag ) {
	var ret = context.getElementsByTagName ? context.getElementsByTagName( tag || "*" ) :
			context.querySelectorAll ? context.querySelectorAll( tag || "*" ) :
			[];

	return tag === undefined || tag && jQuery.nodeName( context, tag ) ?
		jQuery.merge( [ context ], ret ) :
		ret;
}

// Support: IE >= 9
function fixInput( src, dest ) {
	var nodeName = dest.nodeName.toLowerCase();

	// Fails to persist the checked state of a cloned checkbox or radio button.
	if ( nodeName === "input" && rcheckableType.test( src.type ) ) {
		dest.checked = src.checked;

	// Fails to return the selected option to the default selected state when cloning options
	} else if ( nodeName === "input" || nodeName === "textarea" ) {
		dest.defaultValue = src.defaultValue;
	}
}

jQuery.extend({
	clone: function( elem, dataAndEvents, deepDataAndEvents ) {
		var i, l, srcElements, destElements,
			clone = elem.cloneNode( true ),
			inPage = jQuery.contains( elem.ownerDocument, elem );

		// Support: IE >= 9
		// Fix Cloning issues
		if ( !support.noCloneChecked && ( elem.nodeType === 1 || elem.nodeType === 11 ) &&
				!jQuery.isXMLDoc( elem ) ) {

			// We eschew Sizzle here for performance reasons: http://jsperf.com/getall-vs-sizzle/2
			destElements = getAll( clone );
			srcElements = getAll( elem );

			for ( i = 0, l = srcElements.length; i < l; i++ ) {
				fixInput( srcElements[ i ], destElements[ i ] );
			}
		}

		// Copy the events from the original to the clone
		if ( dataAndEvents ) {
			if ( deepDataAndEvents ) {
				srcElements = srcElements || getAll( elem );
				destElements = destElements || getAll( clone );

				for ( i = 0, l = srcElements.length; i < l; i++ ) {
					cloneCopyEvent( srcElements[ i ], destElements[ i ] );
				}
			} else {
				cloneCopyEvent( elem, clone );
			}
		}

		// Preserve script evaluation history
		destElements = getAll( clone, "script" );
		if ( destElements.length > 0 ) {
			setGlobalEval( destElements, !inPage && getAll( elem, "script" ) );
		}

		// Return the cloned set
		return clone;
	},

	buildFragment: function( elems, context, scripts, selection ) {
		var elem, tmp, tag, wrap, contains, j,
			fragment = context.createDocumentFragment(),
			nodes = [],
			i = 0,
			l = elems.length;

		for ( ; i < l; i++ ) {
			elem = elems[ i ];

			if ( elem || elem === 0 ) {

				// Add nodes directly
				if ( jQuery.type( elem ) === "object" ) {
					// Support: QtWebKit
					// jQuery.merge because push.apply(_, arraylike) throws
					jQuery.merge( nodes, elem.nodeType ? [ elem ] : elem );

				// Convert non-html into a text node
				} else if ( !rhtml.test( elem ) ) {
					nodes.push( context.createTextNode( elem ) );

				// Convert html into DOM nodes
				} else {
					tmp = tmp || fragment.appendChild( context.createElement("div") );

					// Deserialize a standard representation
					tag = ( rtagName.exec( elem ) || [ "", "" ] )[ 1 ].toLowerCase();
					wrap = wrapMap[ tag ] || wrapMap._default;
					tmp.innerHTML = wrap[ 1 ] + elem.replace( rxhtmlTag, "<$1></$2>" ) + wrap[ 2 ];

					// Descend through wrappers to the right content
					j = wrap[ 0 ];
					while ( j-- ) {
						tmp = tmp.lastChild;
					}

					// Support: QtWebKit
					// jQuery.merge because push.apply(_, arraylike) throws
					jQuery.merge( nodes, tmp.childNodes );

					// Remember the top-level container
					tmp = fragment.firstChild;

					// Fixes #12346
					// Support: Webkit, IE
					tmp.textContent = "";
				}
			}
		}

		// Remove wrapper from fragment
		fragment.textContent = "";

		i = 0;
		while ( (elem = nodes[ i++ ]) ) {

			// #4087 - If origin and destination elements are the same, and this is
			// that element, do not do anything
			if ( selection && jQuery.inArray( elem, selection ) !== -1 ) {
				continue;
			}

			contains = jQuery.contains( elem.ownerDocument, elem );

			// Append to fragment
			tmp = getAll( fragment.appendChild( elem ), "script" );

			// Preserve script evaluation history
			if ( contains ) {
				setGlobalEval( tmp );
			}

			// Capture executables
			if ( scripts ) {
				j = 0;
				while ( (elem = tmp[ j++ ]) ) {
					if ( rscriptType.test( elem.type || "" ) ) {
						scripts.push( elem );
					}
				}
			}
		}

		return fragment;
	},

	cleanData: function( elems ) {
		var data, elem, type, key,
			special = jQuery.event.special,
			i = 0;

		for ( ; (elem = elems[ i ]) !== undefined; i++ ) {
			if ( jQuery.acceptData( elem ) ) {
				key = elem[ data_priv.expando ];

				if ( key && (data = data_priv.cache[ key ]) ) {
					if ( data.events ) {
						for ( type in data.events ) {
							if ( special[ type ] ) {
								jQuery.event.remove( elem, type );

							// This is a shortcut to avoid jQuery.event.remove's overhead
							} else {
								jQuery.removeEvent( elem, type, data.handle );
							}
						}
					}
					if ( data_priv.cache[ key ] ) {
						// Discard any remaining `private` data
						delete data_priv.cache[ key ];
					}
				}
			}
			// Discard any remaining `user` data
			delete data_user.cache[ elem[ data_user.expando ] ];
		}
	}
});

jQuery.fn.extend({
	text: function( value ) {
		return access( this, function( value ) {
			return value === undefined ?
				jQuery.text( this ) :
				this.empty().each(function() {
					if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
						this.textContent = value;
					}
				});
		}, null, value, arguments.length );
	},

	append: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
				var target = manipulationTarget( this, elem );
				target.appendChild( elem );
			}
		});
	},

	prepend: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
				var target = manipulationTarget( this, elem );
				target.insertBefore( elem, target.firstChild );
			}
		});
	},

	before: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.parentNode ) {
				this.parentNode.insertBefore( elem, this );
			}
		});
	},

	after: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.parentNode ) {
				this.parentNode.insertBefore( elem, this.nextSibling );
			}
		});
	},

	remove: function( selector, keepData /* Internal Use Only */ ) {
		var elem,
			elems = selector ? jQuery.filter( selector, this ) : this,
			i = 0;

		for ( ; (elem = elems[i]) != null; i++ ) {
			if ( !keepData && elem.nodeType === 1 ) {
				jQuery.cleanData( getAll( elem ) );
			}

			if ( elem.parentNode ) {
				if ( keepData && jQuery.contains( elem.ownerDocument, elem ) ) {
					setGlobalEval( getAll( elem, "script" ) );
				}
				elem.parentNode.removeChild( elem );
			}
		}

		return this;
	},

	empty: function() {
		var elem,
			i = 0;

		for ( ; (elem = this[i]) != null; i++ ) {
			if ( elem.nodeType === 1 ) {

				// Prevent memory leaks
				jQuery.cleanData( getAll( elem, false ) );

				// Remove any remaining nodes
				elem.textContent = "";
			}
		}

		return this;
	},

	clone: function( dataAndEvents, deepDataAndEvents ) {
		dataAndEvents = dataAndEvents == null ? false : dataAndEvents;
		deepDataAndEvents = deepDataAndEvents == null ? dataAndEvents : deepDataAndEvents;

		return this.map(function() {
			return jQuery.clone( this, dataAndEvents, deepDataAndEvents );
		});
	},

	html: function( value ) {
		return access( this, function( value ) {
			var elem = this[ 0 ] || {},
				i = 0,
				l = this.length;

			if ( value === undefined && elem.nodeType === 1 ) {
				return elem.innerHTML;
			}

			// See if we can take a shortcut and just use innerHTML
			if ( typeof value === "string" && !rnoInnerhtml.test( value ) &&
				!wrapMap[ ( rtagName.exec( value ) || [ "", "" ] )[ 1 ].toLowerCase() ] ) {

				value = value.replace( rxhtmlTag, "<$1></$2>" );

				try {
					for ( ; i < l; i++ ) {
						elem = this[ i ] || {};

						// Remove element nodes and prevent memory leaks
						if ( elem.nodeType === 1 ) {
							jQuery.cleanData( getAll( elem, false ) );
							elem.innerHTML = value;
						}
					}

					elem = 0;

				// If using innerHTML throws an exception, use the fallback method
				} catch( e ) {}
			}

			if ( elem ) {
				this.empty().append( value );
			}
		}, null, value, arguments.length );
	},

	replaceWith: function() {
		var arg = arguments[ 0 ];

		// Make the changes, replacing each context element with the new content
		this.domManip( arguments, function( elem ) {
			arg = this.parentNode;

			jQuery.cleanData( getAll( this ) );

			if ( arg ) {
				arg.replaceChild( elem, this );
			}
		});

		// Force removal if there was no new content (e.g., from empty arguments)
		return arg && (arg.length || arg.nodeType) ? this : this.remove();
	},

	detach: function( selector ) {
		return this.remove( selector, true );
	},

	domManip: function( args, callback ) {

		// Flatten any nested arrays
		args = concat.apply( [], args );

		var fragment, first, scripts, hasScripts, node, doc,
			i = 0,
			l = this.length,
			set = this,
			iNoClone = l - 1,
			value = args[ 0 ],
			isFunction = jQuery.isFunction( value );

		// We can't cloneNode fragments that contain checked, in WebKit
		if ( isFunction ||
				( l > 1 && typeof value === "string" &&
					!support.checkClone && rchecked.test( value ) ) ) {
			return this.each(function( index ) {
				var self = set.eq( index );
				if ( isFunction ) {
					args[ 0 ] = value.call( this, index, self.html() );
				}
				self.domManip( args, callback );
			});
		}

		if ( l ) {
			fragment = jQuery.buildFragment( args, this[ 0 ].ownerDocument, false, this );
			first = fragment.firstChild;

			if ( fragment.childNodes.length === 1 ) {
				fragment = first;
			}

			if ( first ) {
				scripts = jQuery.map( getAll( fragment, "script" ), disableScript );
				hasScripts = scripts.length;

				// Use the original fragment for the last item instead of the first because it can end up
				// being emptied incorrectly in certain situations (#8070).
				for ( ; i < l; i++ ) {
					node = fragment;

					if ( i !== iNoClone ) {
						node = jQuery.clone( node, true, true );

						// Keep references to cloned scripts for later restoration
						if ( hasScripts ) {
							// Support: QtWebKit
							// jQuery.merge because push.apply(_, arraylike) throws
							jQuery.merge( scripts, getAll( node, "script" ) );
						}
					}

					callback.call( this[ i ], node, i );
				}

				if ( hasScripts ) {
					doc = scripts[ scripts.length - 1 ].ownerDocument;

					// Reenable scripts
					jQuery.map( scripts, restoreScript );

					// Evaluate executable scripts on first document insertion
					for ( i = 0; i < hasScripts; i++ ) {
						node = scripts[ i ];
						if ( rscriptType.test( node.type || "" ) &&
							!data_priv.access( node, "globalEval" ) && jQuery.contains( doc, node ) ) {

							if ( node.src ) {
								// Optional AJAX dependency, but won't run scripts if not present
								if ( jQuery._evalUrl ) {
									jQuery._evalUrl( node.src );
								}
							} else {
								jQuery.globalEval( node.textContent.replace( rcleanScript, "" ) );
							}
						}
					}
				}
			}
		}

		return this;
	}
});

jQuery.each({
	appendTo: "append",
	prependTo: "prepend",
	insertBefore: "before",
	insertAfter: "after",
	replaceAll: "replaceWith"
}, function( name, original ) {
	jQuery.fn[ name ] = function( selector ) {
		var elems,
			ret = [],
			insert = jQuery( selector ),
			last = insert.length - 1,
			i = 0;

		for ( ; i <= last; i++ ) {
			elems = i === last ? this : this.clone( true );
			jQuery( insert[ i ] )[ original ]( elems );

			// Support: QtWebKit
			// .get() because push.apply(_, arraylike) throws
			push.apply( ret, elems.get() );
		}

		return this.pushStack( ret );
	};
});


var iframe,
	elemdisplay = {};

/**
 * Retrieve the actual display of a element
 * @param {String} name nodeName of the element
 * @param {Object} doc Document object
 */
// Called only from within defaultDisplay
function actualDisplay( name, doc ) {
	var style,
		elem = jQuery( doc.createElement( name ) ).appendTo( doc.body ),

		// getDefaultComputedStyle might be reliably used only on attached element
		display = window.getDefaultComputedStyle && ( style = window.getDefaultComputedStyle( elem[ 0 ] ) ) ?

			// Use of this method is a temporary fix (more like optmization) until something better comes along,
			// since it was removed from specification and supported only in FF
			style.display : jQuery.css( elem[ 0 ], "display" );

	// We don't have any data stored on the element,
	// so use "detach" method as fast way to get rid of the element
	elem.detach();

	return display;
}

/**
 * Try to determine the default display value of an element
 * @param {String} nodeName
 */
function defaultDisplay( nodeName ) {
	var doc = document,
		display = elemdisplay[ nodeName ];

	if ( !display ) {
		display = actualDisplay( nodeName, doc );

		// If the simple way fails, read from inside an iframe
		if ( display === "none" || !display ) {

			// Use the already-created iframe if possible
			iframe = (iframe || jQuery( "<iframe frameborder='0' width='0' height='0'/>" )).appendTo( doc.documentElement );

			// Always write a new HTML skeleton so Webkit and Firefox don't choke on reuse
			doc = iframe[ 0 ].contentDocument;

			// Support: IE
			doc.write();
			doc.close();

			display = actualDisplay( nodeName, doc );
			iframe.detach();
		}

		// Store the correct default display
		elemdisplay[ nodeName ] = display;
	}

	return display;
}
var rmargin = (/^margin/);

var rnumnonpx = new RegExp( "^(" + pnum + ")(?!px)[a-z%]+$", "i" );

var getStyles = function( elem ) {
		return elem.ownerDocument.defaultView.getComputedStyle( elem, null );
	};



function curCSS( elem, name, computed ) {
	var width, minWidth, maxWidth, ret,
		style = elem.style;

	computed = computed || getStyles( elem );

	// Support: IE9
	// getPropertyValue is only needed for .css('filter') in IE9, see #12537
	if ( computed ) {
		ret = computed.getPropertyValue( name ) || computed[ name ];
	}

	if ( computed ) {

		if ( ret === "" && !jQuery.contains( elem.ownerDocument, elem ) ) {
			ret = jQuery.style( elem, name );
		}

		// Support: iOS < 6
		// A tribute to the "awesome hack by Dean Edwards"
		// iOS < 6 (at least) returns percentage for a larger set of values, but width seems to be reliably pixels
		// this is against the CSSOM draft spec: http://dev.w3.org/csswg/cssom/#resolved-values
		if ( rnumnonpx.test( ret ) && rmargin.test( name ) ) {

			// Remember the original values
			width = style.width;
			minWidth = style.minWidth;
			maxWidth = style.maxWidth;

			// Put in the new values to get a computed value out
			style.minWidth = style.maxWidth = style.width = ret;
			ret = computed.width;

			// Revert the changed values
			style.width = width;
			style.minWidth = minWidth;
			style.maxWidth = maxWidth;
		}
	}

	return ret !== undefined ?
		// Support: IE
		// IE returns zIndex value as an integer.
		ret + "" :
		ret;
}


function addGetHookIf( conditionFn, hookFn ) {
	// Define the hook, we'll check on the first run if it's really needed.
	return {
		get: function() {
			if ( conditionFn() ) {
				// Hook not needed (or it's not possible to use it due to missing dependency),
				// remove it.
				// Since there are no other hooks for marginRight, remove the whole object.
				delete this.get;
				return;
			}

			// Hook needed; redefine it so that the support test is not executed again.

			return (this.get = hookFn).apply( this, arguments );
		}
	};
}


(function() {
	var pixelPositionVal, boxSizingReliableVal,
		docElem = document.documentElement,
		container = document.createElement( "div" ),
		div = document.createElement( "div" );

	if ( !div.style ) {
		return;
	}

	div.style.backgroundClip = "content-box";
	div.cloneNode( true ).style.backgroundClip = "";
	support.clearCloneStyle = div.style.backgroundClip === "content-box";

	container.style.cssText = "border:0;width:0;height:0;top:0;left:-9999px;margin-top:1px;" +
		"position:absolute";
	container.appendChild( div );

	// Executing both pixelPosition & boxSizingReliable tests require only one layout
	// so they're executed at the same time to save the second computation.
	function computePixelPositionAndBoxSizingReliable() {
		div.style.cssText =
			// Support: Firefox<29, Android 2.3
			// Vendor-prefix box-sizing
			"-webkit-box-sizing:border-box;-moz-box-sizing:border-box;" +
			"box-sizing:border-box;display:block;margin-top:1%;top:1%;" +
			"border:1px;padding:1px;width:4px;position:absolute";
		div.innerHTML = "";
		docElem.appendChild( container );

		var divStyle = window.getComputedStyle( div, null );
		pixelPositionVal = divStyle.top !== "1%";
		boxSizingReliableVal = divStyle.width === "4px";

		docElem.removeChild( container );
	}

	// Support: node.js jsdom
	// Don't assume that getComputedStyle is a property of the global object
	if ( window.getComputedStyle ) {
		jQuery.extend( support, {
			pixelPosition: function() {
				// This test is executed only once but we still do memoizing
				// since we can use the boxSizingReliable pre-computing.
				// No need to check if the test was already performed, though.
				computePixelPositionAndBoxSizingReliable();
				return pixelPositionVal;
			},
			boxSizingReliable: function() {
				if ( boxSizingReliableVal == null ) {
					computePixelPositionAndBoxSizingReliable();
				}
				return boxSizingReliableVal;
			},
			reliableMarginRight: function() {
				// Support: Android 2.3
				// Check if div with explicit width and no margin-right incorrectly
				// gets computed margin-right based on width of container. (#3333)
				// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
				// This support function is only executed once so no memoizing is needed.
				var ret,
					marginDiv = div.appendChild( document.createElement( "div" ) );

				// Reset CSS: box-sizing; display; margin; border; padding
				marginDiv.style.cssText = div.style.cssText =
					// Support: Firefox<29, Android 2.3
					// Vendor-prefix box-sizing
					"-webkit-box-sizing:content-box;-moz-box-sizing:content-box;" +
					"box-sizing:content-box;display:block;margin:0;border:0;padding:0";
				marginDiv.style.marginRight = marginDiv.style.width = "0";
				div.style.width = "1px";
				docElem.appendChild( container );

				ret = !parseFloat( window.getComputedStyle( marginDiv, null ).marginRight );

				docElem.removeChild( container );

				return ret;
			}
		});
	}
})();


// A method for quickly swapping in/out CSS properties to get correct calculations.
jQuery.swap = function( elem, options, callback, args ) {
	var ret, name,
		old = {};

	// Remember the old values, and insert the new ones
	for ( name in options ) {
		old[ name ] = elem.style[ name ];
		elem.style[ name ] = options[ name ];
	}

	ret = callback.apply( elem, args || [] );

	// Revert the old values
	for ( name in options ) {
		elem.style[ name ] = old[ name ];
	}

	return ret;
};


var
	// swappable if display is none or starts with table except "table", "table-cell", or "table-caption"
	// see here for display values: https://developer.mozilla.org/en-US/docs/CSS/display
	rdisplayswap = /^(none|table(?!-c[ea]).+)/,
	rnumsplit = new RegExp( "^(" + pnum + ")(.*)$", "i" ),
	rrelNum = new RegExp( "^([+-])=(" + pnum + ")", "i" ),

	cssShow = { position: "absolute", visibility: "hidden", display: "block" },
	cssNormalTransform = {
		letterSpacing: "0",
		fontWeight: "400"
	},

	cssPrefixes = [ "Webkit", "O", "Moz", "ms" ];

// return a css property mapped to a potentially vendor prefixed property
function vendorPropName( style, name ) {

	// shortcut for names that are not vendor prefixed
	if ( name in style ) {
		return name;
	}

	// check for vendor prefixed names
	var capName = name[0].toUpperCase() + name.slice(1),
		origName = name,
		i = cssPrefixes.length;

	while ( i-- ) {
		name = cssPrefixes[ i ] + capName;
		if ( name in style ) {
			return name;
		}
	}

	return origName;
}

function setPositiveNumber( elem, value, subtract ) {
	var matches = rnumsplit.exec( value );
	return matches ?
		// Guard against undefined "subtract", e.g., when used as in cssHooks
		Math.max( 0, matches[ 1 ] - ( subtract || 0 ) ) + ( matches[ 2 ] || "px" ) :
		value;
}

function augmentWidthOrHeight( elem, name, extra, isBorderBox, styles ) {
	var i = extra === ( isBorderBox ? "border" : "content" ) ?
		// If we already have the right measurement, avoid augmentation
		4 :
		// Otherwise initialize for horizontal or vertical properties
		name === "width" ? 1 : 0,

		val = 0;

	for ( ; i < 4; i += 2 ) {
		// both box models exclude margin, so add it if we want it
		if ( extra === "margin" ) {
			val += jQuery.css( elem, extra + cssExpand[ i ], true, styles );
		}

		if ( isBorderBox ) {
			// border-box includes padding, so remove it if we want content
			if ( extra === "content" ) {
				val -= jQuery.css( elem, "padding" + cssExpand[ i ], true, styles );
			}

			// at this point, extra isn't border nor margin, so remove border
			if ( extra !== "margin" ) {
				val -= jQuery.css( elem, "border" + cssExpand[ i ] + "Width", true, styles );
			}
		} else {
			// at this point, extra isn't content, so add padding
			val += jQuery.css( elem, "padding" + cssExpand[ i ], true, styles );

			// at this point, extra isn't content nor padding, so add border
			if ( extra !== "padding" ) {
				val += jQuery.css( elem, "border" + cssExpand[ i ] + "Width", true, styles );
			}
		}
	}

	return val;
}

function getWidthOrHeight( elem, name, extra ) {

	// Start with offset property, which is equivalent to the border-box value
	var valueIsBorderBox = true,
		val = name === "width" ? elem.offsetWidth : elem.offsetHeight,
		styles = getStyles( elem ),
		isBorderBox = jQuery.css( elem, "boxSizing", false, styles ) === "border-box";

	// some non-html elements return undefined for offsetWidth, so check for null/undefined
	// svg - https://bugzilla.mozilla.org/show_bug.cgi?id=649285
	// MathML - https://bugzilla.mozilla.org/show_bug.cgi?id=491668
	if ( val <= 0 || val == null ) {
		// Fall back to computed then uncomputed css if necessary
		val = curCSS( elem, name, styles );
		if ( val < 0 || val == null ) {
			val = elem.style[ name ];
		}

		// Computed unit is not pixels. Stop here and return.
		if ( rnumnonpx.test(val) ) {
			return val;
		}

		// we need the check for style in case a browser which returns unreliable values
		// for getComputedStyle silently falls back to the reliable elem.style
		valueIsBorderBox = isBorderBox &&
			( support.boxSizingReliable() || val === elem.style[ name ] );

		// Normalize "", auto, and prepare for extra
		val = parseFloat( val ) || 0;
	}

	// use the active box-sizing model to add/subtract irrelevant styles
	return ( val +
		augmentWidthOrHeight(
			elem,
			name,
			extra || ( isBorderBox ? "border" : "content" ),
			valueIsBorderBox,
			styles
		)
	) + "px";
}

function showHide( elements, show ) {
	var display, elem, hidden,
		values = [],
		index = 0,
		length = elements.length;

	for ( ; index < length; index++ ) {
		elem = elements[ index ];
		if ( !elem.style ) {
			continue;
		}

		values[ index ] = data_priv.get( elem, "olddisplay" );
		display = elem.style.display;
		if ( show ) {
			// Reset the inline display of this element to learn if it is
			// being hidden by cascaded rules or not
			if ( !values[ index ] && display === "none" ) {
				elem.style.display = "";
			}

			// Set elements which have been overridden with display: none
			// in a stylesheet to whatever the default browser style is
			// for such an element
			if ( elem.style.display === "" && isHidden( elem ) ) {
				values[ index ] = data_priv.access( elem, "olddisplay", defaultDisplay(elem.nodeName) );
			}
		} else {
			hidden = isHidden( elem );

			if ( display !== "none" || !hidden ) {
				data_priv.set( elem, "olddisplay", hidden ? display : jQuery.css( elem, "display" ) );
			}
		}
	}

	// Set the display of most of the elements in a second loop
	// to avoid the constant reflow
	for ( index = 0; index < length; index++ ) {
		elem = elements[ index ];
		if ( !elem.style ) {
			continue;
		}
		if ( !show || elem.style.display === "none" || elem.style.display === "" ) {
			elem.style.display = show ? values[ index ] || "" : "none";
		}
	}

	return elements;
}

jQuery.extend({
	// Add in style property hooks for overriding the default
	// behavior of getting and setting a style property
	cssHooks: {
		opacity: {
			get: function( elem, computed ) {
				if ( computed ) {
					// We should always get a number back from opacity
					var ret = curCSS( elem, "opacity" );
					return ret === "" ? "1" : ret;
				}
			}
		}
	},

	// Don't automatically add "px" to these possibly-unitless properties
	cssNumber: {
		"columnCount": true,
		"fillOpacity": true,
		"flexGrow": true,
		"flexShrink": true,
		"fontWeight": true,
		"lineHeight": true,
		"opacity": true,
		"order": true,
		"orphans": true,
		"widows": true,
		"zIndex": true,
		"zoom": true
	},

	// Add in properties whose names you wish to fix before
	// setting or getting the value
	cssProps: {
		// normalize float css property
		"float": "cssFloat"
	},

	// Get and set the style property on a DOM Node
	style: function( elem, name, value, extra ) {
		// Don't set styles on text and comment nodes
		if ( !elem || elem.nodeType === 3 || elem.nodeType === 8 || !elem.style ) {
			return;
		}

		// Make sure that we're working with the right name
		var ret, type, hooks,
			origName = jQuery.camelCase( name ),
			style = elem.style;

		name = jQuery.cssProps[ origName ] || ( jQuery.cssProps[ origName ] = vendorPropName( style, origName ) );

		// gets hook for the prefixed version
		// followed by the unprefixed version
		hooks = jQuery.cssHooks[ name ] || jQuery.cssHooks[ origName ];

		// Check if we're setting a value
		if ( value !== undefined ) {
			type = typeof value;

			// convert relative number strings (+= or -=) to relative numbers. #7345
			if ( type === "string" && (ret = rrelNum.exec( value )) ) {
				value = ( ret[1] + 1 ) * ret[2] + parseFloat( jQuery.css( elem, name ) );
				// Fixes bug #9237
				type = "number";
			}

			// Make sure that null and NaN values aren't set. See: #7116
			if ( value == null || value !== value ) {
				return;
			}

			// If a number was passed in, add 'px' to the (except for certain CSS properties)
			if ( type === "number" && !jQuery.cssNumber[ origName ] ) {
				value += "px";
			}

			// Fixes #8908, it can be done more correctly by specifying setters in cssHooks,
			// but it would mean to define eight (for every problematic property) identical functions
			if ( !support.clearCloneStyle && value === "" && name.indexOf( "background" ) === 0 ) {
				style[ name ] = "inherit";
			}

			// If a hook was provided, use that value, otherwise just set the specified value
			if ( !hooks || !("set" in hooks) || (value = hooks.set( elem, value, extra )) !== undefined ) {
				style[ name ] = value;
			}

		} else {
			// If a hook was provided get the non-computed value from there
			if ( hooks && "get" in hooks && (ret = hooks.get( elem, false, extra )) !== undefined ) {
				return ret;
			}

			// Otherwise just get the value from the style object
			return style[ name ];
		}
	},

	css: function( elem, name, extra, styles ) {
		var val, num, hooks,
			origName = jQuery.camelCase( name );

		// Make sure that we're working with the right name
		name = jQuery.cssProps[ origName ] || ( jQuery.cssProps[ origName ] = vendorPropName( elem.style, origName ) );

		// gets hook for the prefixed version
		// followed by the unprefixed version
		hooks = jQuery.cssHooks[ name ] || jQuery.cssHooks[ origName ];

		// If a hook was provided get the computed value from there
		if ( hooks && "get" in hooks ) {
			val = hooks.get( elem, true, extra );
		}

		// Otherwise, if a way to get the computed value exists, use that
		if ( val === undefined ) {
			val = curCSS( elem, name, styles );
		}

		//convert "normal" to computed value
		if ( val === "normal" && name in cssNormalTransform ) {
			val = cssNormalTransform[ name ];
		}

		// Return, converting to number if forced or a qualifier was provided and val looks numeric
		if ( extra === "" || extra ) {
			num = parseFloat( val );
			return extra === true || jQuery.isNumeric( num ) ? num || 0 : val;
		}
		return val;
	}
});

jQuery.each([ "height", "width" ], function( i, name ) {
	jQuery.cssHooks[ name ] = {
		get: function( elem, computed, extra ) {
			if ( computed ) {
				// certain elements can have dimension info if we invisibly show them
				// however, it must have a current display style that would benefit from this
				return rdisplayswap.test( jQuery.css( elem, "display" ) ) && elem.offsetWidth === 0 ?
					jQuery.swap( elem, cssShow, function() {
						return getWidthOrHeight( elem, name, extra );
					}) :
					getWidthOrHeight( elem, name, extra );
			}
		},

		set: function( elem, value, extra ) {
			var styles = extra && getStyles( elem );
			return setPositiveNumber( elem, value, extra ?
				augmentWidthOrHeight(
					elem,
					name,
					extra,
					jQuery.css( elem, "boxSizing", false, styles ) === "border-box",
					styles
				) : 0
			);
		}
	};
});

// Support: Android 2.3
jQuery.cssHooks.marginRight = addGetHookIf( support.reliableMarginRight,
	function( elem, computed ) {
		if ( computed ) {
			// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
			// Work around by temporarily setting element display to inline-block
			return jQuery.swap( elem, { "display": "inline-block" },
				curCSS, [ elem, "marginRight" ] );
		}
	}
);

// These hooks are used by animate to expand properties
jQuery.each({
	margin: "",
	padding: "",
	border: "Width"
}, function( prefix, suffix ) {
	jQuery.cssHooks[ prefix + suffix ] = {
		expand: function( value ) {
			var i = 0,
				expanded = {},

				// assumes a single number if not a string
				parts = typeof value === "string" ? value.split(" ") : [ value ];

			for ( ; i < 4; i++ ) {
				expanded[ prefix + cssExpand[ i ] + suffix ] =
					parts[ i ] || parts[ i - 2 ] || parts[ 0 ];
			}

			return expanded;
		}
	};

	if ( !rmargin.test( prefix ) ) {
		jQuery.cssHooks[ prefix + suffix ].set = setPositiveNumber;
	}
});

jQuery.fn.extend({
	css: function( name, value ) {
		return access( this, function( elem, name, value ) {
			var styles, len,
				map = {},
				i = 0;

			if ( jQuery.isArray( name ) ) {
				styles = getStyles( elem );
				len = name.length;

				for ( ; i < len; i++ ) {
					map[ name[ i ] ] = jQuery.css( elem, name[ i ], false, styles );
				}

				return map;
			}

			return value !== undefined ?
				jQuery.style( elem, name, value ) :
				jQuery.css( elem, name );
		}, name, value, arguments.length > 1 );
	},
	show: function() {
		return showHide( this, true );
	},
	hide: function() {
		return showHide( this );
	},
	toggle: function( state ) {
		if ( typeof state === "boolean" ) {
			return state ? this.show() : this.hide();
		}

		return this.each(function() {
			if ( isHidden( this ) ) {
				jQuery( this ).show();
			} else {
				jQuery( this ).hide();
			}
		});
	}
});


function Tween( elem, options, prop, end, easing ) {
	return new Tween.prototype.init( elem, options, prop, end, easing );
}
jQuery.Tween = Tween;

Tween.prototype = {
	constructor: Tween,
	init: function( elem, options, prop, end, easing, unit ) {
		this.elem = elem;
		this.prop = prop;
		this.easing = easing || "swing";
		this.options = options;
		this.start = this.now = this.cur();
		this.end = end;
		this.unit = unit || ( jQuery.cssNumber[ prop ] ? "" : "px" );
	},
	cur: function() {
		var hooks = Tween.propHooks[ this.prop ];

		return hooks && hooks.get ?
			hooks.get( this ) :
			Tween.propHooks._default.get( this );
	},
	run: function( percent ) {
		var eased,
			hooks = Tween.propHooks[ this.prop ];

		if ( this.options.duration ) {
			this.pos = eased = jQuery.easing[ this.easing ](
				percent, this.options.duration * percent, 0, 1, this.options.duration
			);
		} else {
			this.pos = eased = percent;
		}
		this.now = ( this.end - this.start ) * eased + this.start;

		if ( this.options.step ) {
			this.options.step.call( this.elem, this.now, this );
		}

		if ( hooks && hooks.set ) {
			hooks.set( this );
		} else {
			Tween.propHooks._default.set( this );
		}
		return this;
	}
};

Tween.prototype.init.prototype = Tween.prototype;

Tween.propHooks = {
	_default: {
		get: function( tween ) {
			var result;

			if ( tween.elem[ tween.prop ] != null &&
				(!tween.elem.style || tween.elem.style[ tween.prop ] == null) ) {
				return tween.elem[ tween.prop ];
			}

			// passing an empty string as a 3rd parameter to .css will automatically
			// attempt a parseFloat and fallback to a string if the parse fails
			// so, simple values such as "10px" are parsed to Float.
			// complex values such as "rotate(1rad)" are returned as is.
			result = jQuery.css( tween.elem, tween.prop, "" );
			// Empty strings, null, undefined and "auto" are converted to 0.
			return !result || result === "auto" ? 0 : result;
		},
		set: function( tween ) {
			// use step hook for back compat - use cssHook if its there - use .style if its
			// available and use plain properties where available
			if ( jQuery.fx.step[ tween.prop ] ) {
				jQuery.fx.step[ tween.prop ]( tween );
			} else if ( tween.elem.style && ( tween.elem.style[ jQuery.cssProps[ tween.prop ] ] != null || jQuery.cssHooks[ tween.prop ] ) ) {
				jQuery.style( tween.elem, tween.prop, tween.now + tween.unit );
			} else {
				tween.elem[ tween.prop ] = tween.now;
			}
		}
	}
};

// Support: IE9
// Panic based approach to setting things on disconnected nodes

Tween.propHooks.scrollTop = Tween.propHooks.scrollLeft = {
	set: function( tween ) {
		if ( tween.elem.nodeType && tween.elem.parentNode ) {
			tween.elem[ tween.prop ] = tween.now;
		}
	}
};

jQuery.easing = {
	linear: function( p ) {
		return p;
	},
	swing: function( p ) {
		return 0.5 - Math.cos( p * Math.PI ) / 2;
	}
};

jQuery.fx = Tween.prototype.init;

// Back Compat <1.8 extension point
jQuery.fx.step = {};




var
	fxNow, timerId,
	rfxtypes = /^(?:toggle|show|hide)$/,
	rfxnum = new RegExp( "^(?:([+-])=|)(" + pnum + ")([a-z%]*)$", "i" ),
	rrun = /queueHooks$/,
	animationPrefilters = [ defaultPrefilter ],
	tweeners = {
		"*": [ function( prop, value ) {
			var tween = this.createTween( prop, value ),
				target = tween.cur(),
				parts = rfxnum.exec( value ),
				unit = parts && parts[ 3 ] || ( jQuery.cssNumber[ prop ] ? "" : "px" ),

				// Starting value computation is required for potential unit mismatches
				start = ( jQuery.cssNumber[ prop ] || unit !== "px" && +target ) &&
					rfxnum.exec( jQuery.css( tween.elem, prop ) ),
				scale = 1,
				maxIterations = 20;

			if ( start && start[ 3 ] !== unit ) {
				// Trust units reported by jQuery.css
				unit = unit || start[ 3 ];

				// Make sure we update the tween properties later on
				parts = parts || [];

				// Iteratively approximate from a nonzero starting point
				start = +target || 1;

				do {
					// If previous iteration zeroed out, double until we get *something*
					// Use a string for doubling factor so we don't accidentally see scale as unchanged below
					scale = scale || ".5";

					// Adjust and apply
					start = start / scale;
					jQuery.style( tween.elem, prop, start + unit );

				// Update scale, tolerating zero or NaN from tween.cur()
				// And breaking the loop if scale is unchanged or perfect, or if we've just had enough
				} while ( scale !== (scale = tween.cur() / target) && scale !== 1 && --maxIterations );
			}

			// Update tween properties
			if ( parts ) {
				start = tween.start = +start || +target || 0;
				tween.unit = unit;
				// If a +=/-= token was provided, we're doing a relative animation
				tween.end = parts[ 1 ] ?
					start + ( parts[ 1 ] + 1 ) * parts[ 2 ] :
					+parts[ 2 ];
			}

			return tween;
		} ]
	};

// Animations created synchronously will run synchronously
function createFxNow() {
	setTimeout(function() {
		fxNow = undefined;
	});
	return ( fxNow = jQuery.now() );
}

// Generate parameters to create a standard animation
function genFx( type, includeWidth ) {
	var which,
		i = 0,
		attrs = { height: type };

	// if we include width, step value is 1 to do all cssExpand values,
	// if we don't include width, step value is 2 to skip over Left and Right
	includeWidth = includeWidth ? 1 : 0;
	for ( ; i < 4 ; i += 2 - includeWidth ) {
		which = cssExpand[ i ];
		attrs[ "margin" + which ] = attrs[ "padding" + which ] = type;
	}

	if ( includeWidth ) {
		attrs.opacity = attrs.width = type;
	}

	return attrs;
}

function createTween( value, prop, animation ) {
	var tween,
		collection = ( tweeners[ prop ] || [] ).concat( tweeners[ "*" ] ),
		index = 0,
		length = collection.length;
	for ( ; index < length; index++ ) {
		if ( (tween = collection[ index ].call( animation, prop, value )) ) {

			// we're done with this property
			return tween;
		}
	}
}

function defaultPrefilter( elem, props, opts ) {
	/* jshint validthis: true */
	var prop, value, toggle, tween, hooks, oldfire, display, checkDisplay,
		anim = this,
		orig = {},
		style = elem.style,
		hidden = elem.nodeType && isHidden( elem ),
		dataShow = data_priv.get( elem, "fxshow" );

	// handle queue: false promises
	if ( !opts.queue ) {
		hooks = jQuery._queueHooks( elem, "fx" );
		if ( hooks.unqueued == null ) {
			hooks.unqueued = 0;
			oldfire = hooks.empty.fire;
			hooks.empty.fire = function() {
				if ( !hooks.unqueued ) {
					oldfire();
				}
			};
		}
		hooks.unqueued++;

		anim.always(function() {
			// doing this makes sure that the complete handler will be called
			// before this completes
			anim.always(function() {
				hooks.unqueued--;
				if ( !jQuery.queue( elem, "fx" ).length ) {
					hooks.empty.fire();
				}
			});
		});
	}

	// height/width overflow pass
	if ( elem.nodeType === 1 && ( "height" in props || "width" in props ) ) {
		// Make sure that nothing sneaks out
		// Record all 3 overflow attributes because IE9-10 do not
		// change the overflow attribute when overflowX and
		// overflowY are set to the same value
		opts.overflow = [ style.overflow, style.overflowX, style.overflowY ];

		// Set display property to inline-block for height/width
		// animations on inline elements that are having width/height animated
		display = jQuery.css( elem, "display" );

		// Test default display if display is currently "none"
		checkDisplay = display === "none" ?
			data_priv.get( elem, "olddisplay" ) || defaultDisplay( elem.nodeName ) : display;

		if ( checkDisplay === "inline" && jQuery.css( elem, "float" ) === "none" ) {
			style.display = "inline-block";
		}
	}

	if ( opts.overflow ) {
		style.overflow = "hidden";
		anim.always(function() {
			style.overflow = opts.overflow[ 0 ];
			style.overflowX = opts.overflow[ 1 ];
			style.overflowY = opts.overflow[ 2 ];
		});
	}

	// show/hide pass
	for ( prop in props ) {
		value = props[ prop ];
		if ( rfxtypes.exec( value ) ) {
			delete props[ prop ];
			toggle = toggle || value === "toggle";
			if ( value === ( hidden ? "hide" : "show" ) ) {

				// If there is dataShow left over from a stopped hide or show and we are going to proceed with show, we should pretend to be hidden
				if ( value === "show" && dataShow && dataShow[ prop ] !== undefined ) {
					hidden = true;
				} else {
					continue;
				}
			}
			orig[ prop ] = dataShow && dataShow[ prop ] || jQuery.style( elem, prop );

		// Any non-fx value stops us from restoring the original display value
		} else {
			display = undefined;
		}
	}

	if ( !jQuery.isEmptyObject( orig ) ) {
		if ( dataShow ) {
			if ( "hidden" in dataShow ) {
				hidden = dataShow.hidden;
			}
		} else {
			dataShow = data_priv.access( elem, "fxshow", {} );
		}

		// store state if its toggle - enables .stop().toggle() to "reverse"
		if ( toggle ) {
			dataShow.hidden = !hidden;
		}
		if ( hidden ) {
			jQuery( elem ).show();
		} else {
			anim.done(function() {
				jQuery( elem ).hide();
			});
		}
		anim.done(function() {
			var prop;

			data_priv.remove( elem, "fxshow" );
			for ( prop in orig ) {
				jQuery.style( elem, prop, orig[ prop ] );
			}
		});
		for ( prop in orig ) {
			tween = createTween( hidden ? dataShow[ prop ] : 0, prop, anim );

			if ( !( prop in dataShow ) ) {
				dataShow[ prop ] = tween.start;
				if ( hidden ) {
					tween.end = tween.start;
					tween.start = prop === "width" || prop === "height" ? 1 : 0;
				}
			}
		}

	// If this is a noop like .hide().hide(), restore an overwritten display value
	} else if ( (display === "none" ? defaultDisplay( elem.nodeName ) : display) === "inline" ) {
		style.display = display;
	}
}

function propFilter( props, specialEasing ) {
	var index, name, easing, value, hooks;

	// camelCase, specialEasing and expand cssHook pass
	for ( index in props ) {
		name = jQuery.camelCase( index );
		easing = specialEasing[ name ];
		value = props[ index ];
		if ( jQuery.isArray( value ) ) {
			easing = value[ 1 ];
			value = props[ index ] = value[ 0 ];
		}

		if ( index !== name ) {
			props[ name ] = value;
			delete props[ index ];
		}

		hooks = jQuery.cssHooks[ name ];
		if ( hooks && "expand" in hooks ) {
			value = hooks.expand( value );
			delete props[ name ];

			// not quite $.extend, this wont overwrite keys already present.
			// also - reusing 'index' from above because we have the correct "name"
			for ( index in value ) {
				if ( !( index in props ) ) {
					props[ index ] = value[ index ];
					specialEasing[ index ] = easing;
				}
			}
		} else {
			specialEasing[ name ] = easing;
		}
	}
}

function Animation( elem, properties, options ) {
	var result,
		stopped,
		index = 0,
		length = animationPrefilters.length,
		deferred = jQuery.Deferred().always( function() {
			// don't match elem in the :animated selector
			delete tick.elem;
		}),
		tick = function() {
			if ( stopped ) {
				return false;
			}
			var currentTime = fxNow || createFxNow(),
				remaining = Math.max( 0, animation.startTime + animation.duration - currentTime ),
				// archaic crash bug won't allow us to use 1 - ( 0.5 || 0 ) (#12497)
				temp = remaining / animation.duration || 0,
				percent = 1 - temp,
				index = 0,
				length = animation.tweens.length;

			for ( ; index < length ; index++ ) {
				animation.tweens[ index ].run( percent );
			}

			deferred.notifyWith( elem, [ animation, percent, remaining ]);

			if ( percent < 1 && length ) {
				return remaining;
			} else {
				deferred.resolveWith( elem, [ animation ] );
				return false;
			}
		},
		animation = deferred.promise({
			elem: elem,
			props: jQuery.extend( {}, properties ),
			opts: jQuery.extend( true, { specialEasing: {} }, options ),
			originalProperties: properties,
			originalOptions: options,
			startTime: fxNow || createFxNow(),
			duration: options.duration,
			tweens: [],
			createTween: function( prop, end ) {
				var tween = jQuery.Tween( elem, animation.opts, prop, end,
						animation.opts.specialEasing[ prop ] || animation.opts.easing );
				animation.tweens.push( tween );
				return tween;
			},
			stop: function( gotoEnd ) {
				var index = 0,
					// if we are going to the end, we want to run all the tweens
					// otherwise we skip this part
					length = gotoEnd ? animation.tweens.length : 0;
				if ( stopped ) {
					return this;
				}
				stopped = true;
				for ( ; index < length ; index++ ) {
					animation.tweens[ index ].run( 1 );
				}

				// resolve when we played the last frame
				// otherwise, reject
				if ( gotoEnd ) {
					deferred.resolveWith( elem, [ animation, gotoEnd ] );
				} else {
					deferred.rejectWith( elem, [ animation, gotoEnd ] );
				}
				return this;
			}
		}),
		props = animation.props;

	propFilter( props, animation.opts.specialEasing );

	for ( ; index < length ; index++ ) {
		result = animationPrefilters[ index ].call( animation, elem, props, animation.opts );
		if ( result ) {
			return result;
		}
	}

	jQuery.map( props, createTween, animation );

	if ( jQuery.isFunction( animation.opts.start ) ) {
		animation.opts.start.call( elem, animation );
	}

	jQuery.fx.timer(
		jQuery.extend( tick, {
			elem: elem,
			anim: animation,
			queue: animation.opts.queue
		})
	);

	// attach callbacks from options
	return animation.progress( animation.opts.progress )
		.done( animation.opts.done, animation.opts.complete )
		.fail( animation.opts.fail )
		.always( animation.opts.always );
}

jQuery.Animation = jQuery.extend( Animation, {

	tweener: function( props, callback ) {
		if ( jQuery.isFunction( props ) ) {
			callback = props;
			props = [ "*" ];
		} else {
			props = props.split(" ");
		}

		var prop,
			index = 0,
			length = props.length;

		for ( ; index < length ; index++ ) {
			prop = props[ index ];
			tweeners[ prop ] = tweeners[ prop ] || [];
			tweeners[ prop ].unshift( callback );
		}
	},

	prefilter: function( callback, prepend ) {
		if ( prepend ) {
			animationPrefilters.unshift( callback );
		} else {
			animationPrefilters.push( callback );
		}
	}
});

jQuery.speed = function( speed, easing, fn ) {
	var opt = speed && typeof speed === "object" ? jQuery.extend( {}, speed ) : {
		complete: fn || !fn && easing ||
			jQuery.isFunction( speed ) && speed,
		duration: speed,
		easing: fn && easing || easing && !jQuery.isFunction( easing ) && easing
	};

	opt.duration = jQuery.fx.off ? 0 : typeof opt.duration === "number" ? opt.duration :
		opt.duration in jQuery.fx.speeds ? jQuery.fx.speeds[ opt.duration ] : jQuery.fx.speeds._default;

	// normalize opt.queue - true/undefined/null -> "fx"
	if ( opt.queue == null || opt.queue === true ) {
		opt.queue = "fx";
	}

	// Queueing
	opt.old = opt.complete;

	opt.complete = function() {
		if ( jQuery.isFunction( opt.old ) ) {
			opt.old.call( this );
		}

		if ( opt.queue ) {
			jQuery.dequeue( this, opt.queue );
		}
	};

	return opt;
};

jQuery.fn.extend({
	fadeTo: function( speed, to, easing, callback ) {

		// show any hidden elements after setting opacity to 0
		return this.filter( isHidden ).css( "opacity", 0 ).show()

			// animate to the value specified
			.end().animate({ opacity: to }, speed, easing, callback );
	},
	animate: function( prop, speed, easing, callback ) {
		var empty = jQuery.isEmptyObject( prop ),
			optall = jQuery.speed( speed, easing, callback ),
			doAnimation = function() {
				// Operate on a copy of prop so per-property easing won't be lost
				var anim = Animation( this, jQuery.extend( {}, prop ), optall );

				// Empty animations, or finishing resolves immediately
				if ( empty || data_priv.get( this, "finish" ) ) {
					anim.stop( true );
				}
			};
			doAnimation.finish = doAnimation;

		return empty || optall.queue === false ?
			this.each( doAnimation ) :
			this.queue( optall.queue, doAnimation );
	},
	stop: function( type, clearQueue, gotoEnd ) {
		var stopQueue = function( hooks ) {
			var stop = hooks.stop;
			delete hooks.stop;
			stop( gotoEnd );
		};

		if ( typeof type !== "string" ) {
			gotoEnd = clearQueue;
			clearQueue = type;
			type = undefined;
		}
		if ( clearQueue && type !== false ) {
			this.queue( type || "fx", [] );
		}

		return this.each(function() {
			var dequeue = true,
				index = type != null && type + "queueHooks",
				timers = jQuery.timers,
				data = data_priv.get( this );

			if ( index ) {
				if ( data[ index ] && data[ index ].stop ) {
					stopQueue( data[ index ] );
				}
			} else {
				for ( index in data ) {
					if ( data[ index ] && data[ index ].stop && rrun.test( index ) ) {
						stopQueue( data[ index ] );
					}
				}
			}

			for ( index = timers.length; index--; ) {
				if ( timers[ index ].elem === this && (type == null || timers[ index ].queue === type) ) {
					timers[ index ].anim.stop( gotoEnd );
					dequeue = false;
					timers.splice( index, 1 );
				}
			}

			// start the next in the queue if the last step wasn't forced
			// timers currently will call their complete callbacks, which will dequeue
			// but only if they were gotoEnd
			if ( dequeue || !gotoEnd ) {
				jQuery.dequeue( this, type );
			}
		});
	},
	finish: function( type ) {
		if ( type !== false ) {
			type = type || "fx";
		}
		return this.each(function() {
			var index,
				data = data_priv.get( this ),
				queue = data[ type + "queue" ],
				hooks = data[ type + "queueHooks" ],
				timers = jQuery.timers,
				length = queue ? queue.length : 0;

			// enable finishing flag on private data
			data.finish = true;

			// empty the queue first
			jQuery.queue( this, type, [] );

			if ( hooks && hooks.stop ) {
				hooks.stop.call( this, true );
			}

			// look for any active animations, and finish them
			for ( index = timers.length; index--; ) {
				if ( timers[ index ].elem === this && timers[ index ].queue === type ) {
					timers[ index ].anim.stop( true );
					timers.splice( index, 1 );
				}
			}

			// look for any animations in the old queue and finish them
			for ( index = 0; index < length; index++ ) {
				if ( queue[ index ] && queue[ index ].finish ) {
					queue[ index ].finish.call( this );
				}
			}

			// turn off finishing flag
			delete data.finish;
		});
	}
});

jQuery.each([ "toggle", "show", "hide" ], function( i, name ) {
	var cssFn = jQuery.fn[ name ];
	jQuery.fn[ name ] = function( speed, easing, callback ) {
		return speed == null || typeof speed === "boolean" ?
			cssFn.apply( this, arguments ) :
			this.animate( genFx( name, true ), speed, easing, callback );
	};
});

// Generate shortcuts for custom animations
jQuery.each({
	slideDown: genFx("show"),
	slideUp: genFx("hide"),
	slideToggle: genFx("toggle"),
	fadeIn: { opacity: "show" },
	fadeOut: { opacity: "hide" },
	fadeToggle: { opacity: "toggle" }
}, function( name, props ) {
	jQuery.fn[ name ] = function( speed, easing, callback ) {
		return this.animate( props, speed, easing, callback );
	};
});

jQuery.timers = [];
jQuery.fx.tick = function() {
	var timer,
		i = 0,
		timers = jQuery.timers;

	fxNow = jQuery.now();

	for ( ; i < timers.length; i++ ) {
		timer = timers[ i ];
		// Checks the timer has not already been removed
		if ( !timer() && timers[ i ] === timer ) {
			timers.splice( i--, 1 );
		}
	}

	if ( !timers.length ) {
		jQuery.fx.stop();
	}
	fxNow = undefined;
};

jQuery.fx.timer = function( timer ) {
	jQuery.timers.push( timer );
	if ( timer() ) {
		jQuery.fx.start();
	} else {
		jQuery.timers.pop();
	}
};

jQuery.fx.interval = 13;

jQuery.fx.start = function() {
	if ( !timerId ) {
		timerId = setInterval( jQuery.fx.tick, jQuery.fx.interval );
	}
};

jQuery.fx.stop = function() {
	clearInterval( timerId );
	timerId = null;
};

jQuery.fx.speeds = {
	slow: 600,
	fast: 200,
	// Default speed
	_default: 400
};


// Based off of the plugin by Clint Helfers, with permission.
// http://blindsignals.com/index.php/2009/07/jquery-delay/
jQuery.fn.delay = function( time, type ) {
	time = jQuery.fx ? jQuery.fx.speeds[ time ] || time : time;
	type = type || "fx";

	return this.queue( type, function( next, hooks ) {
		var timeout = setTimeout( next, time );
		hooks.stop = function() {
			clearTimeout( timeout );
		};
	});
};


(function() {
	var input = document.createElement( "input" ),
		select = document.createElement( "select" ),
		opt = select.appendChild( document.createElement( "option" ) );

	input.type = "checkbox";

	// Support: iOS 5.1, Android 4.x, Android 2.3
	// Check the default checkbox/radio value ("" on old WebKit; "on" elsewhere)
	support.checkOn = input.value !== "";

	// Must access the parent to make an option select properly
	// Support: IE9, IE10
	support.optSelected = opt.selected;

	// Make sure that the options inside disabled selects aren't marked as disabled
	// (WebKit marks them as disabled)
	select.disabled = true;
	support.optDisabled = !opt.disabled;

	// Check if an input maintains its value after becoming a radio
	// Support: IE9, IE10
	input = document.createElement( "input" );
	input.value = "t";
	input.type = "radio";
	support.radioValue = input.value === "t";
})();


var nodeHook, boolHook,
	attrHandle = jQuery.expr.attrHandle;

jQuery.fn.extend({
	attr: function( name, value ) {
		return access( this, jQuery.attr, name, value, arguments.length > 1 );
	},

	removeAttr: function( name ) {
		return this.each(function() {
			jQuery.removeAttr( this, name );
		});
	}
});

jQuery.extend({
	attr: function( elem, name, value ) {
		var hooks, ret,
			nType = elem.nodeType;

		// don't get/set attributes on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		// Fallback to prop when attributes are not supported
		if ( typeof elem.getAttribute === strundefined ) {
			return jQuery.prop( elem, name, value );
		}

		// All attributes are lowercase
		// Grab necessary hook if one is defined
		if ( nType !== 1 || !jQuery.isXMLDoc( elem ) ) {
			name = name.toLowerCase();
			hooks = jQuery.attrHooks[ name ] ||
				( jQuery.expr.match.bool.test( name ) ? boolHook : nodeHook );
		}

		if ( value !== undefined ) {

			if ( value === null ) {
				jQuery.removeAttr( elem, name );

			} else if ( hooks && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ) {
				return ret;

			} else {
				elem.setAttribute( name, value + "" );
				return value;
			}

		} else if ( hooks && "get" in hooks && (ret = hooks.get( elem, name )) !== null ) {
			return ret;

		} else {
			ret = jQuery.find.attr( elem, name );

			// Non-existent attributes return null, we normalize to undefined
			return ret == null ?
				undefined :
				ret;
		}
	},

	removeAttr: function( elem, value ) {
		var name, propName,
			i = 0,
			attrNames = value && value.match( rnotwhite );

		if ( attrNames && elem.nodeType === 1 ) {
			while ( (name = attrNames[i++]) ) {
				propName = jQuery.propFix[ name ] || name;

				// Boolean attributes get special treatment (#10870)
				if ( jQuery.expr.match.bool.test( name ) ) {
					// Set corresponding property to false
					elem[ propName ] = false;
				}

				elem.removeAttribute( name );
			}
		}
	},

	attrHooks: {
		type: {
			set: function( elem, value ) {
				if ( !support.radioValue && value === "radio" &&
					jQuery.nodeName( elem, "input" ) ) {
					// Setting the type on a radio button after the value resets the value in IE6-9
					// Reset value to default in case type is set after value during creation
					var val = elem.value;
					elem.setAttribute( "type", value );
					if ( val ) {
						elem.value = val;
					}
					return value;
				}
			}
		}
	}
});

// Hooks for boolean attributes
boolHook = {
	set: function( elem, value, name ) {
		if ( value === false ) {
			// Remove boolean attributes when set to false
			jQuery.removeAttr( elem, name );
		} else {
			elem.setAttribute( name, name );
		}
		return name;
	}
};
jQuery.each( jQuery.expr.match.bool.source.match( /\w+/g ), function( i, name ) {
	var getter = attrHandle[ name ] || jQuery.find.attr;

	attrHandle[ name ] = function( elem, name, isXML ) {
		var ret, handle;
		if ( !isXML ) {
			// Avoid an infinite loop by temporarily removing this function from the getter
			handle = attrHandle[ name ];
			attrHandle[ name ] = ret;
			ret = getter( elem, name, isXML ) != null ?
				name.toLowerCase() :
				null;
			attrHandle[ name ] = handle;
		}
		return ret;
	};
});




var rfocusable = /^(?:input|select|textarea|button)$/i;

jQuery.fn.extend({
	prop: function( name, value ) {
		return access( this, jQuery.prop, name, value, arguments.length > 1 );
	},

	removeProp: function( name ) {
		return this.each(function() {
			delete this[ jQuery.propFix[ name ] || name ];
		});
	}
});

jQuery.extend({
	propFix: {
		"for": "htmlFor",
		"class": "className"
	},

	prop: function( elem, name, value ) {
		var ret, hooks, notxml,
			nType = elem.nodeType;

		// don't get/set properties on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		notxml = nType !== 1 || !jQuery.isXMLDoc( elem );

		if ( notxml ) {
			// Fix name and attach hooks
			name = jQuery.propFix[ name ] || name;
			hooks = jQuery.propHooks[ name ];
		}

		if ( value !== undefined ) {
			return hooks && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ?
				ret :
				( elem[ name ] = value );

		} else {
			return hooks && "get" in hooks && (ret = hooks.get( elem, name )) !== null ?
				ret :
				elem[ name ];
		}
	},

	propHooks: {
		tabIndex: {
			get: function( elem ) {
				return elem.hasAttribute( "tabindex" ) || rfocusable.test( elem.nodeName ) || elem.href ?
					elem.tabIndex :
					-1;
			}
		}
	}
});

// Support: IE9+
// Selectedness for an option in an optgroup can be inaccurate
if ( !support.optSelected ) {
	jQuery.propHooks.selected = {
		get: function( elem ) {
			var parent = elem.parentNode;
			if ( parent && parent.parentNode ) {
				parent.parentNode.selectedIndex;
			}
			return null;
		}
	};
}

jQuery.each([
	"tabIndex",
	"readOnly",
	"maxLength",
	"cellSpacing",
	"cellPadding",
	"rowSpan",
	"colSpan",
	"useMap",
	"frameBorder",
	"contentEditable"
], function() {
	jQuery.propFix[ this.toLowerCase() ] = this;
});




var rclass = /[\t\r\n\f]/g;

jQuery.fn.extend({
	addClass: function( value ) {
		var classes, elem, cur, clazz, j, finalValue,
			proceed = typeof value === "string" && value,
			i = 0,
			len = this.length;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).addClass( value.call( this, j, this.className ) );
			});
		}

		if ( proceed ) {
			// The disjunction here is for better compressibility (see removeClass)
			classes = ( value || "" ).match( rnotwhite ) || [];

			for ( ; i < len; i++ ) {
				elem = this[ i ];
				cur = elem.nodeType === 1 && ( elem.className ?
					( " " + elem.className + " " ).replace( rclass, " " ) :
					" "
				);

				if ( cur ) {
					j = 0;
					while ( (clazz = classes[j++]) ) {
						if ( cur.indexOf( " " + clazz + " " ) < 0 ) {
							cur += clazz + " ";
						}
					}

					// only assign if different to avoid unneeded rendering.
					finalValue = jQuery.trim( cur );
					if ( elem.className !== finalValue ) {
						elem.className = finalValue;
					}
				}
			}
		}

		return this;
	},

	removeClass: function( value ) {
		var classes, elem, cur, clazz, j, finalValue,
			proceed = arguments.length === 0 || typeof value === "string" && value,
			i = 0,
			len = this.length;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).removeClass( value.call( this, j, this.className ) );
			});
		}
		if ( proceed ) {
			classes = ( value || "" ).match( rnotwhite ) || [];

			for ( ; i < len; i++ ) {
				elem = this[ i ];
				// This expression is here for better compressibility (see addClass)
				cur = elem.nodeType === 1 && ( elem.className ?
					( " " + elem.className + " " ).replace( rclass, " " ) :
					""
				);

				if ( cur ) {
					j = 0;
					while ( (clazz = classes[j++]) ) {
						// Remove *all* instances
						while ( cur.indexOf( " " + clazz + " " ) >= 0 ) {
							cur = cur.replace( " " + clazz + " ", " " );
						}
					}

					// only assign if different to avoid unneeded rendering.
					finalValue = value ? jQuery.trim( cur ) : "";
					if ( elem.className !== finalValue ) {
						elem.className = finalValue;
					}
				}
			}
		}

		return this;
	},

	toggleClass: function( value, stateVal ) {
		var type = typeof value;

		if ( typeof stateVal === "boolean" && type === "string" ) {
			return stateVal ? this.addClass( value ) : this.removeClass( value );
		}

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( i ) {
				jQuery( this ).toggleClass( value.call(this, i, this.className, stateVal), stateVal );
			});
		}

		return this.each(function() {
			if ( type === "string" ) {
				// toggle individual class names
				var className,
					i = 0,
					self = jQuery( this ),
					classNames = value.match( rnotwhite ) || [];

				while ( (className = classNames[ i++ ]) ) {
					// check each className given, space separated list
					if ( self.hasClass( className ) ) {
						self.removeClass( className );
					} else {
						self.addClass( className );
					}
				}

			// Toggle whole class name
			} else if ( type === strundefined || type === "boolean" ) {
				if ( this.className ) {
					// store className if set
					data_priv.set( this, "__className__", this.className );
				}

				// If the element has a class name or if we're passed "false",
				// then remove the whole classname (if there was one, the above saved it).
				// Otherwise bring back whatever was previously saved (if anything),
				// falling back to the empty string if nothing was stored.
				this.className = this.className || value === false ? "" : data_priv.get( this, "__className__" ) || "";
			}
		});
	},

	hasClass: function( selector ) {
		var className = " " + selector + " ",
			i = 0,
			l = this.length;
		for ( ; i < l; i++ ) {
			if ( this[i].nodeType === 1 && (" " + this[i].className + " ").replace(rclass, " ").indexOf( className ) >= 0 ) {
				return true;
			}
		}

		return false;
	}
});




var rreturn = /\r/g;

jQuery.fn.extend({
	val: function( value ) {
		var hooks, ret, isFunction,
			elem = this[0];

		if ( !arguments.length ) {
			if ( elem ) {
				hooks = jQuery.valHooks[ elem.type ] || jQuery.valHooks[ elem.nodeName.toLowerCase() ];

				if ( hooks && "get" in hooks && (ret = hooks.get( elem, "value" )) !== undefined ) {
					return ret;
				}

				ret = elem.value;

				return typeof ret === "string" ?
					// handle most common string cases
					ret.replace(rreturn, "") :
					// handle cases where value is null/undef or number
					ret == null ? "" : ret;
			}

			return;
		}

		isFunction = jQuery.isFunction( value );

		return this.each(function( i ) {
			var val;

			if ( this.nodeType !== 1 ) {
				return;
			}

			if ( isFunction ) {
				val = value.call( this, i, jQuery( this ).val() );
			} else {
				val = value;
			}

			// Treat null/undefined as ""; convert numbers to string
			if ( val == null ) {
				val = "";

			} else if ( typeof val === "number" ) {
				val += "";

			} else if ( jQuery.isArray( val ) ) {
				val = jQuery.map( val, function( value ) {
					return value == null ? "" : value + "";
				});
			}

			hooks = jQuery.valHooks[ this.type ] || jQuery.valHooks[ this.nodeName.toLowerCase() ];

			// If set returns undefined, fall back to normal setting
			if ( !hooks || !("set" in hooks) || hooks.set( this, val, "value" ) === undefined ) {
				this.value = val;
			}
		});
	}
});

jQuery.extend({
	valHooks: {
		option: {
			get: function( elem ) {
				var val = jQuery.find.attr( elem, "value" );
				return val != null ?
					val :
					// Support: IE10-11+
					// option.text throws exceptions (#14686, #14858)
					jQuery.trim( jQuery.text( elem ) );
			}
		},
		select: {
			get: function( elem ) {
				var value, option,
					options = elem.options,
					index = elem.selectedIndex,
					one = elem.type === "select-one" || index < 0,
					values = one ? null : [],
					max = one ? index + 1 : options.length,
					i = index < 0 ?
						max :
						one ? index : 0;

				// Loop through all the selected options
				for ( ; i < max; i++ ) {
					option = options[ i ];

					// IE6-9 doesn't update selected after form reset (#2551)
					if ( ( option.selected || i === index ) &&
							// Don't return options that are disabled or in a disabled optgroup
							( support.optDisabled ? !option.disabled : option.getAttribute( "disabled" ) === null ) &&
							( !option.parentNode.disabled || !jQuery.nodeName( option.parentNode, "optgroup" ) ) ) {

						// Get the specific value for the option
						value = jQuery( option ).val();

						// We don't need an array for one selects
						if ( one ) {
							return value;
						}

						// Multi-Selects return an array
						values.push( value );
					}
				}

				return values;
			},

			set: function( elem, value ) {
				var optionSet, option,
					options = elem.options,
					values = jQuery.makeArray( value ),
					i = options.length;

				while ( i-- ) {
					option = options[ i ];
					if ( (option.selected = jQuery.inArray( option.value, values ) >= 0) ) {
						optionSet = true;
					}
				}

				// force browsers to behave consistently when non-matching value is set
				if ( !optionSet ) {
					elem.selectedIndex = -1;
				}
				return values;
			}
		}
	}
});

// Radios and checkboxes getter/setter
jQuery.each([ "radio", "checkbox" ], function() {
	jQuery.valHooks[ this ] = {
		set: function( elem, value ) {
			if ( jQuery.isArray( value ) ) {
				return ( elem.checked = jQuery.inArray( jQuery(elem).val(), value ) >= 0 );
			}
		}
	};
	if ( !support.checkOn ) {
		jQuery.valHooks[ this ].get = function( elem ) {
			// Support: Webkit
			// "" is returned instead of "on" if a value isn't specified
			return elem.getAttribute("value") === null ? "on" : elem.value;
		};
	}
});




// Return jQuery for attributes-only inclusion


jQuery.each( ("blur focus focusin focusout load resize scroll unload click dblclick " +
	"mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave " +
	"change select submit keydown keypress keyup error contextmenu").split(" "), function( i, name ) {

	// Handle event binding
	jQuery.fn[ name ] = function( data, fn ) {
		return arguments.length > 0 ?
			this.on( name, null, data, fn ) :
			this.trigger( name );
	};
});

jQuery.fn.extend({
	hover: function( fnOver, fnOut ) {
		return this.mouseenter( fnOver ).mouseleave( fnOut || fnOver );
	},

	bind: function( types, data, fn ) {
		return this.on( types, null, data, fn );
	},
	unbind: function( types, fn ) {
		return this.off( types, null, fn );
	},

	delegate: function( selector, types, data, fn ) {
		return this.on( types, selector, data, fn );
	},
	undelegate: function( selector, types, fn ) {
		// ( namespace ) or ( selector, types [, fn] )
		return arguments.length === 1 ? this.off( selector, "**" ) : this.off( types, selector || "**", fn );
	}
});


var nonce = jQuery.now();

var rquery = (/\?/);



// Support: Android 2.3
// Workaround failure to string-cast null input
jQuery.parseJSON = function( data ) {
	return JSON.parse( data + "" );
};


// Cross-browser xml parsing
jQuery.parseXML = function( data ) {
	var xml, tmp;
	if ( !data || typeof data !== "string" ) {
		return null;
	}

	// Support: IE9
	try {
		tmp = new DOMParser();
		xml = tmp.parseFromString( data, "text/xml" );
	} catch ( e ) {
		xml = undefined;
	}

	if ( !xml || xml.getElementsByTagName( "parsererror" ).length ) {
		jQuery.error( "Invalid XML: " + data );
	}
	return xml;
};


var
	// Document location
	ajaxLocParts,
	ajaxLocation,

	rhash = /#.*$/,
	rts = /([?&])_=[^&]*/,
	rheaders = /^(.*?):[ \t]*([^\r\n]*)$/mg,
	// #7653, #8125, #8152: local protocol detection
	rlocalProtocol = /^(?:about|app|app-storage|.+-extension|file|res|widget):$/,
	rnoContent = /^(?:GET|HEAD)$/,
	rprotocol = /^\/\//,
	rurl = /^([\w.+-]+:)(?:\/\/(?:[^\/?#]*@|)([^\/?#:]*)(?::(\d+)|)|)/,

	/* Prefilters
	 * 1) They are useful to introduce custom dataTypes (see ajax/jsonp.js for an example)
	 * 2) These are called:
	 *    - BEFORE asking for a transport
	 *    - AFTER param serialization (s.data is a string if s.processData is true)
	 * 3) key is the dataType
	 * 4) the catchall symbol "*" can be used
	 * 5) execution will start with transport dataType and THEN continue down to "*" if needed
	 */
	prefilters = {},

	/* Transports bindings
	 * 1) key is the dataType
	 * 2) the catchall symbol "*" can be used
	 * 3) selection will start with transport dataType and THEN go to "*" if needed
	 */
	transports = {},

	// Avoid comment-prolog char sequence (#10098); must appease lint and evade compression
	allTypes = "*/".concat("*");

// #8138, IE may throw an exception when accessing
// a field from window.location if document.domain has been set
try {
	ajaxLocation = location.href;
} catch( e ) {
	// Use the href attribute of an A element
	// since IE will modify it given document.location
	ajaxLocation = document.createElement( "a" );
	ajaxLocation.href = "";
	ajaxLocation = ajaxLocation.href;
}

// Segment location into parts
ajaxLocParts = rurl.exec( ajaxLocation.toLowerCase() ) || [];

// Base "constructor" for jQuery.ajaxPrefilter and jQuery.ajaxTransport
function addToPrefiltersOrTransports( structure ) {

	// dataTypeExpression is optional and defaults to "*"
	return function( dataTypeExpression, func ) {

		if ( typeof dataTypeExpression !== "string" ) {
			func = dataTypeExpression;
			dataTypeExpression = "*";
		}

		var dataType,
			i = 0,
			dataTypes = dataTypeExpression.toLowerCase().match( rnotwhite ) || [];

		if ( jQuery.isFunction( func ) ) {
			// For each dataType in the dataTypeExpression
			while ( (dataType = dataTypes[i++]) ) {
				// Prepend if requested
				if ( dataType[0] === "+" ) {
					dataType = dataType.slice( 1 ) || "*";
					(structure[ dataType ] = structure[ dataType ] || []).unshift( func );

				// Otherwise append
				} else {
					(structure[ dataType ] = structure[ dataType ] || []).push( func );
				}
			}
		}
	};
}

// Base inspection function for prefilters and transports
function inspectPrefiltersOrTransports( structure, options, originalOptions, jqXHR ) {

	var inspected = {},
		seekingTransport = ( structure === transports );

	function inspect( dataType ) {
		var selected;
		inspected[ dataType ] = true;
		jQuery.each( structure[ dataType ] || [], function( _, prefilterOrFactory ) {
			var dataTypeOrTransport = prefilterOrFactory( options, originalOptions, jqXHR );
			if ( typeof dataTypeOrTransport === "string" && !seekingTransport && !inspected[ dataTypeOrTransport ] ) {
				options.dataTypes.unshift( dataTypeOrTransport );
				inspect( dataTypeOrTransport );
				return false;
			} else if ( seekingTransport ) {
				return !( selected = dataTypeOrTransport );
			}
		});
		return selected;
	}

	return inspect( options.dataTypes[ 0 ] ) || !inspected[ "*" ] && inspect( "*" );
}

// A special extend for ajax options
// that takes "flat" options (not to be deep extended)
// Fixes #9887
function ajaxExtend( target, src ) {
	var key, deep,
		flatOptions = jQuery.ajaxSettings.flatOptions || {};

	for ( key in src ) {
		if ( src[ key ] !== undefined ) {
			( flatOptions[ key ] ? target : ( deep || (deep = {}) ) )[ key ] = src[ key ];
		}
	}
	if ( deep ) {
		jQuery.extend( true, target, deep );
	}

	return target;
}

/* Handles responses to an ajax request:
 * - finds the right dataType (mediates between content-type and expected dataType)
 * - returns the corresponding response
 */
function ajaxHandleResponses( s, jqXHR, responses ) {

	var ct, type, finalDataType, firstDataType,
		contents = s.contents,
		dataTypes = s.dataTypes;

	// Remove auto dataType and get content-type in the process
	while ( dataTypes[ 0 ] === "*" ) {
		dataTypes.shift();
		if ( ct === undefined ) {
			ct = s.mimeType || jqXHR.getResponseHeader("Content-Type");
		}
	}

	// Check if we're dealing with a known content-type
	if ( ct ) {
		for ( type in contents ) {
			if ( contents[ type ] && contents[ type ].test( ct ) ) {
				dataTypes.unshift( type );
				break;
			}
		}
	}

	// Check to see if we have a response for the expected dataType
	if ( dataTypes[ 0 ] in responses ) {
		finalDataType = dataTypes[ 0 ];
	} else {
		// Try convertible dataTypes
		for ( type in responses ) {
			if ( !dataTypes[ 0 ] || s.converters[ type + " " + dataTypes[0] ] ) {
				finalDataType = type;
				break;
			}
			if ( !firstDataType ) {
				firstDataType = type;
			}
		}
		// Or just use first one
		finalDataType = finalDataType || firstDataType;
	}

	// If we found a dataType
	// We add the dataType to the list if needed
	// and return the corresponding response
	if ( finalDataType ) {
		if ( finalDataType !== dataTypes[ 0 ] ) {
			dataTypes.unshift( finalDataType );
		}
		return responses[ finalDataType ];
	}
}

/* Chain conversions given the request and the original response
 * Also sets the responseXXX fields on the jqXHR instance
 */
function ajaxConvert( s, response, jqXHR, isSuccess ) {
	var conv2, current, conv, tmp, prev,
		converters = {},
		// Work with a copy of dataTypes in case we need to modify it for conversion
		dataTypes = s.dataTypes.slice();

	// Create converters map with lowercased keys
	if ( dataTypes[ 1 ] ) {
		for ( conv in s.converters ) {
			converters[ conv.toLowerCase() ] = s.converters[ conv ];
		}
	}

	current = dataTypes.shift();

	// Convert to each sequential dataType
	while ( current ) {

		if ( s.responseFields[ current ] ) {
			jqXHR[ s.responseFields[ current ] ] = response;
		}

		// Apply the dataFilter if provided
		if ( !prev && isSuccess && s.dataFilter ) {
			response = s.dataFilter( response, s.dataType );
		}

		prev = current;
		current = dataTypes.shift();

		if ( current ) {

		// There's only work to do if current dataType is non-auto
			if ( current === "*" ) {

				current = prev;

			// Convert response if prev dataType is non-auto and differs from current
			} else if ( prev !== "*" && prev !== current ) {

				// Seek a direct converter
				conv = converters[ prev + " " + current ] || converters[ "* " + current ];

				// If none found, seek a pair
				if ( !conv ) {
					for ( conv2 in converters ) {

						// If conv2 outputs current
						tmp = conv2.split( " " );
						if ( tmp[ 1 ] === current ) {

							// If prev can be converted to accepted input
							conv = converters[ prev + " " + tmp[ 0 ] ] ||
								converters[ "* " + tmp[ 0 ] ];
							if ( conv ) {
								// Condense equivalence converters
								if ( conv === true ) {
									conv = converters[ conv2 ];

								// Otherwise, insert the intermediate dataType
								} else if ( converters[ conv2 ] !== true ) {
									current = tmp[ 0 ];
									dataTypes.unshift( tmp[ 1 ] );
								}
								break;
							}
						}
					}
				}

				// Apply converter (if not an equivalence)
				if ( conv !== true ) {

					// Unless errors are allowed to bubble, catch and return them
					if ( conv && s[ "throws" ] ) {
						response = conv( response );
					} else {
						try {
							response = conv( response );
						} catch ( e ) {
							return { state: "parsererror", error: conv ? e : "No conversion from " + prev + " to " + current };
						}
					}
				}
			}
		}
	}

	return { state: "success", data: response };
}

jQuery.extend({

	// Counter for holding the number of active queries
	active: 0,

	// Last-Modified header cache for next request
	lastModified: {},
	etag: {},

	ajaxSettings: {
		url: ajaxLocation,
		type: "GET",
		isLocal: rlocalProtocol.test( ajaxLocParts[ 1 ] ),
		global: true,
		processData: true,
		async: true,
		contentType: "application/x-www-form-urlencoded; charset=UTF-8",
		/*
		timeout: 0,
		data: null,
		dataType: null,
		username: null,
		password: null,
		cache: null,
		throws: false,
		traditional: false,
		headers: {},
		*/

		accepts: {
			"*": allTypes,
			text: "text/plain",
			html: "text/html",
			xml: "application/xml, text/xml",
			json: "application/json, text/javascript"
		},

		contents: {
			xml: /xml/,
			html: /html/,
			json: /json/
		},

		responseFields: {
			xml: "responseXML",
			text: "responseText",
			json: "responseJSON"
		},

		// Data converters
		// Keys separate source (or catchall "*") and destination types with a single space
		converters: {

			// Convert anything to text
			"* text": String,

			// Text to html (true = no transformation)
			"text html": true,

			// Evaluate text as a json expression
			"text json": jQuery.parseJSON,

			// Parse text as xml
			"text xml": jQuery.parseXML
		},

		// For options that shouldn't be deep extended:
		// you can add your own custom options here if
		// and when you create one that shouldn't be
		// deep extended (see ajaxExtend)
		flatOptions: {
			url: true,
			context: true
		}
	},

	// Creates a full fledged settings object into target
	// with both ajaxSettings and settings fields.
	// If target is omitted, writes into ajaxSettings.
	ajaxSetup: function( target, settings ) {
		return settings ?

			// Building a settings object
			ajaxExtend( ajaxExtend( target, jQuery.ajaxSettings ), settings ) :

			// Extending ajaxSettings
			ajaxExtend( jQuery.ajaxSettings, target );
	},

	ajaxPrefilter: addToPrefiltersOrTransports( prefilters ),
	ajaxTransport: addToPrefiltersOrTransports( transports ),

	// Main method
	ajax: function( url, options ) {

		// If url is an object, simulate pre-1.5 signature
		if ( typeof url === "object" ) {
			options = url;
			url = undefined;
		}

		// Force options to be an object
		options = options || {};

		var transport,
			// URL without anti-cache param
			cacheURL,
			// Response headers
			responseHeadersString,
			responseHeaders,
			// timeout handle
			timeoutTimer,
			// Cross-domain detection vars
			parts,
			// To know if global events are to be dispatched
			fireGlobals,
			// Loop variable
			i,
			// Create the final options object
			s = jQuery.ajaxSetup( {}, options ),
			// Callbacks context
			callbackContext = s.context || s,
			// Context for global events is callbackContext if it is a DOM node or jQuery collection
			globalEventContext = s.context && ( callbackContext.nodeType || callbackContext.jquery ) ?
				jQuery( callbackContext ) :
				jQuery.event,
			// Deferreds
			deferred = jQuery.Deferred(),
			completeDeferred = jQuery.Callbacks("once memory"),
			// Status-dependent callbacks
			statusCode = s.statusCode || {},
			// Headers (they are sent all at once)
			requestHeaders = {},
			requestHeadersNames = {},
			// The jqXHR state
			state = 0,
			// Default abort message
			strAbort = "canceled",
			// Fake xhr
			jqXHR = {
				readyState: 0,

				// Builds headers hashtable if needed
				getResponseHeader: function( key ) {
					var match;
					if ( state === 2 ) {
						if ( !responseHeaders ) {
							responseHeaders = {};
							while ( (match = rheaders.exec( responseHeadersString )) ) {
								responseHeaders[ match[1].toLowerCase() ] = match[ 2 ];
							}
						}
						match = responseHeaders[ key.toLowerCase() ];
					}
					return match == null ? null : match;
				},

				// Raw string
				getAllResponseHeaders: function() {
					return state === 2 ? responseHeadersString : null;
				},

				// Caches the header
				setRequestHeader: function( name, value ) {
					var lname = name.toLowerCase();
					if ( !state ) {
						name = requestHeadersNames[ lname ] = requestHeadersNames[ lname ] || name;
						requestHeaders[ name ] = value;
					}
					return this;
				},

				// Overrides response content-type header
				overrideMimeType: function( type ) {
					if ( !state ) {
						s.mimeType = type;
					}
					return this;
				},

				// Status-dependent callbacks
				statusCode: function( map ) {
					var code;
					if ( map ) {
						if ( state < 2 ) {
							for ( code in map ) {
								// Lazy-add the new callback in a way that preserves old ones
								statusCode[ code ] = [ statusCode[ code ], map[ code ] ];
							}
						} else {
							// Execute the appropriate callbacks
							jqXHR.always( map[ jqXHR.status ] );
						}
					}
					return this;
				},

				// Cancel the request
				abort: function( statusText ) {
					var finalText = statusText || strAbort;
					if ( transport ) {
						transport.abort( finalText );
					}
					done( 0, finalText );
					return this;
				}
			};

		// Attach deferreds
		deferred.promise( jqXHR ).complete = completeDeferred.add;
		jqXHR.success = jqXHR.done;
		jqXHR.error = jqXHR.fail;

		// Remove hash character (#7531: and string promotion)
		// Add protocol if not provided (prefilters might expect it)
		// Handle falsy url in the settings object (#10093: consistency with old signature)
		// We also use the url parameter if available
		s.url = ( ( url || s.url || ajaxLocation ) + "" ).replace( rhash, "" )
			.replace( rprotocol, ajaxLocParts[ 1 ] + "//" );

		// Alias method option to type as per ticket #12004
		s.type = options.method || options.type || s.method || s.type;

		// Extract dataTypes list
		s.dataTypes = jQuery.trim( s.dataType || "*" ).toLowerCase().match( rnotwhite ) || [ "" ];

		// A cross-domain request is in order when we have a protocol:host:port mismatch
		if ( s.crossDomain == null ) {
			parts = rurl.exec( s.url.toLowerCase() );
			s.crossDomain = !!( parts &&
				( parts[ 1 ] !== ajaxLocParts[ 1 ] || parts[ 2 ] !== ajaxLocParts[ 2 ] ||
					( parts[ 3 ] || ( parts[ 1 ] === "http:" ? "80" : "443" ) ) !==
						( ajaxLocParts[ 3 ] || ( ajaxLocParts[ 1 ] === "http:" ? "80" : "443" ) ) )
			);
		}

		// Convert data if not already a string
		if ( s.data && s.processData && typeof s.data !== "string" ) {
			s.data = jQuery.param( s.data, s.traditional );
		}

		// Apply prefilters
		inspectPrefiltersOrTransports( prefilters, s, options, jqXHR );

		// If request was aborted inside a prefilter, stop there
		if ( state === 2 ) {
			return jqXHR;
		}

		// We can fire global events as of now if asked to
		fireGlobals = s.global;

		// Watch for a new set of requests
		if ( fireGlobals && jQuery.active++ === 0 ) {
			jQuery.event.trigger("ajaxStart");
		}

		// Uppercase the type
		s.type = s.type.toUpperCase();

		// Determine if request has content
		s.hasContent = !rnoContent.test( s.type );

		// Save the URL in case we're toying with the If-Modified-Since
		// and/or If-None-Match header later on
		cacheURL = s.url;

		// More options handling for requests with no content
		if ( !s.hasContent ) {

			// If data is available, append data to url
			if ( s.data ) {
				cacheURL = ( s.url += ( rquery.test( cacheURL ) ? "&" : "?" ) + s.data );
				// #9682: remove data so that it's not used in an eventual retry
				delete s.data;
			}

			// Add anti-cache in url if needed
			if ( s.cache === false ) {
				s.url = rts.test( cacheURL ) ?

					// If there is already a '_' parameter, set its value
					cacheURL.replace( rts, "$1_=" + nonce++ ) :

					// Otherwise add one to the end
					cacheURL + ( rquery.test( cacheURL ) ? "&" : "?" ) + "_=" + nonce++;
			}
		}

		// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
		if ( s.ifModified ) {
			if ( jQuery.lastModified[ cacheURL ] ) {
				jqXHR.setRequestHeader( "If-Modified-Since", jQuery.lastModified[ cacheURL ] );
			}
			if ( jQuery.etag[ cacheURL ] ) {
				jqXHR.setRequestHeader( "If-None-Match", jQuery.etag[ cacheURL ] );
			}
		}

		// Set the correct header, if data is being sent
		if ( s.data && s.hasContent && s.contentType !== false || options.contentType ) {
			jqXHR.setRequestHeader( "Content-Type", s.contentType );
		}

		// Set the Accepts header for the server, depending on the dataType
		jqXHR.setRequestHeader(
			"Accept",
			s.dataTypes[ 0 ] && s.accepts[ s.dataTypes[0] ] ?
				s.accepts[ s.dataTypes[0] ] + ( s.dataTypes[ 0 ] !== "*" ? ", " + allTypes + "; q=0.01" : "" ) :
				s.accepts[ "*" ]
		);

		// Check for headers option
		for ( i in s.headers ) {
			jqXHR.setRequestHeader( i, s.headers[ i ] );
		}

		// Allow custom headers/mimetypes and early abort
		if ( s.beforeSend && ( s.beforeSend.call( callbackContext, jqXHR, s ) === false || state === 2 ) ) {
			// Abort if not done already and return
			return jqXHR.abort();
		}

		// aborting is no longer a cancellation
		strAbort = "abort";

		// Install callbacks on deferreds
		for ( i in { success: 1, error: 1, complete: 1 } ) {
			jqXHR[ i ]( s[ i ] );
		}

		// Get transport
		transport = inspectPrefiltersOrTransports( transports, s, options, jqXHR );

		// If no transport, we auto-abort
		if ( !transport ) {
			done( -1, "No Transport" );
		} else {
			jqXHR.readyState = 1;

			// Send global event
			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxSend", [ jqXHR, s ] );
			}
			// Timeout
			if ( s.async && s.timeout > 0 ) {
				timeoutTimer = setTimeout(function() {
					jqXHR.abort("timeout");
				}, s.timeout );
			}

			try {
				state = 1;
				transport.send( requestHeaders, done );
			} catch ( e ) {
				// Propagate exception as error if not done
				if ( state < 2 ) {
					done( -1, e );
				// Simply rethrow otherwise
				} else {
					throw e;
				}
			}
		}

		// Callback for when everything is done
		function done( status, nativeStatusText, responses, headers ) {
			var isSuccess, success, error, response, modified,
				statusText = nativeStatusText;

			// Called once
			if ( state === 2 ) {
				return;
			}

			// State is "done" now
			state = 2;

			// Clear timeout if it exists
			if ( timeoutTimer ) {
				clearTimeout( timeoutTimer );
			}

			// Dereference transport for early garbage collection
			// (no matter how long the jqXHR object will be used)
			transport = undefined;

			// Cache response headers
			responseHeadersString = headers || "";

			// Set readyState
			jqXHR.readyState = status > 0 ? 4 : 0;

			// Determine if successful
			isSuccess = status >= 200 && status < 300 || status === 304;

			// Get response data
			if ( responses ) {
				response = ajaxHandleResponses( s, jqXHR, responses );
			}

			// Convert no matter what (that way responseXXX fields are always set)
			response = ajaxConvert( s, response, jqXHR, isSuccess );

			// If successful, handle type chaining
			if ( isSuccess ) {

				// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
				if ( s.ifModified ) {
					modified = jqXHR.getResponseHeader("Last-Modified");
					if ( modified ) {
						jQuery.lastModified[ cacheURL ] = modified;
					}
					modified = jqXHR.getResponseHeader("etag");
					if ( modified ) {
						jQuery.etag[ cacheURL ] = modified;
					}
				}

				// if no content
				if ( status === 204 || s.type === "HEAD" ) {
					statusText = "nocontent";

				// if not modified
				} else if ( status === 304 ) {
					statusText = "notmodified";

				// If we have data, let's convert it
				} else {
					statusText = response.state;
					success = response.data;
					error = response.error;
					isSuccess = !error;
				}
			} else {
				// We extract error from statusText
				// then normalize statusText and status for non-aborts
				error = statusText;
				if ( status || !statusText ) {
					statusText = "error";
					if ( status < 0 ) {
						status = 0;
					}
				}
			}

			// Set data for the fake xhr object
			jqXHR.status = status;
			jqXHR.statusText = ( nativeStatusText || statusText ) + "";

			// Success/Error
			if ( isSuccess ) {
				deferred.resolveWith( callbackContext, [ success, statusText, jqXHR ] );
			} else {
				deferred.rejectWith( callbackContext, [ jqXHR, statusText, error ] );
			}

			// Status-dependent callbacks
			jqXHR.statusCode( statusCode );
			statusCode = undefined;

			if ( fireGlobals ) {
				globalEventContext.trigger( isSuccess ? "ajaxSuccess" : "ajaxError",
					[ jqXHR, s, isSuccess ? success : error ] );
			}

			// Complete
			completeDeferred.fireWith( callbackContext, [ jqXHR, statusText ] );

			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxComplete", [ jqXHR, s ] );
				// Handle the global AJAX counter
				if ( !( --jQuery.active ) ) {
					jQuery.event.trigger("ajaxStop");
				}
			}
		}

		return jqXHR;
	},

	getJSON: function( url, data, callback ) {
		return jQuery.get( url, data, callback, "json" );
	},

	getScript: function( url, callback ) {
		return jQuery.get( url, undefined, callback, "script" );
	}
});

jQuery.each( [ "get", "post" ], function( i, method ) {
	jQuery[ method ] = function( url, data, callback, type ) {
		// shift arguments if data argument was omitted
		if ( jQuery.isFunction( data ) ) {
			type = type || callback;
			callback = data;
			data = undefined;
		}

		return jQuery.ajax({
			url: url,
			type: method,
			dataType: type,
			data: data,
			success: callback
		});
	};
});

// Attach a bunch of functions for handling common AJAX events
jQuery.each( [ "ajaxStart", "ajaxStop", "ajaxComplete", "ajaxError", "ajaxSuccess", "ajaxSend" ], function( i, type ) {
	jQuery.fn[ type ] = function( fn ) {
		return this.on( type, fn );
	};
});


jQuery._evalUrl = function( url ) {
	return jQuery.ajax({
		url: url,
		type: "GET",
		dataType: "script",
		async: false,
		global: false,
		"throws": true
	});
};


jQuery.fn.extend({
	wrapAll: function( html ) {
		var wrap;

		if ( jQuery.isFunction( html ) ) {
			return this.each(function( i ) {
				jQuery( this ).wrapAll( html.call(this, i) );
			});
		}

		if ( this[ 0 ] ) {

			// The elements to wrap the target around
			wrap = jQuery( html, this[ 0 ].ownerDocument ).eq( 0 ).clone( true );

			if ( this[ 0 ].parentNode ) {
				wrap.insertBefore( this[ 0 ] );
			}

			wrap.map(function() {
				var elem = this;

				while ( elem.firstElementChild ) {
					elem = elem.firstElementChild;
				}

				return elem;
			}).append( this );
		}

		return this;
	},

	wrapInner: function( html ) {
		if ( jQuery.isFunction( html ) ) {
			return this.each(function( i ) {
				jQuery( this ).wrapInner( html.call(this, i) );
			});
		}

		return this.each(function() {
			var self = jQuery( this ),
				contents = self.contents();

			if ( contents.length ) {
				contents.wrapAll( html );

			} else {
				self.append( html );
			}
		});
	},

	wrap: function( html ) {
		var isFunction = jQuery.isFunction( html );

		return this.each(function( i ) {
			jQuery( this ).wrapAll( isFunction ? html.call(this, i) : html );
		});
	},

	unwrap: function() {
		return this.parent().each(function() {
			if ( !jQuery.nodeName( this, "body" ) ) {
				jQuery( this ).replaceWith( this.childNodes );
			}
		}).end();
	}
});


jQuery.expr.filters.hidden = function( elem ) {
	// Support: Opera <= 12.12
	// Opera reports offsetWidths and offsetHeights less than zero on some elements
	return elem.offsetWidth <= 0 && elem.offsetHeight <= 0;
};
jQuery.expr.filters.visible = function( elem ) {
	return !jQuery.expr.filters.hidden( elem );
};




var r20 = /%20/g,
	rbracket = /\[\]$/,
	rCRLF = /\r?\n/g,
	rsubmitterTypes = /^(?:submit|button|image|reset|file)$/i,
	rsubmittable = /^(?:input|select|textarea|keygen)/i;

function buildParams( prefix, obj, traditional, add ) {
	var name;

	if ( jQuery.isArray( obj ) ) {
		// Serialize array item.
		jQuery.each( obj, function( i, v ) {
			if ( traditional || rbracket.test( prefix ) ) {
				// Treat each array item as a scalar.
				add( prefix, v );

			} else {
				// Item is non-scalar (array or object), encode its numeric index.
				buildParams( prefix + "[" + ( typeof v === "object" ? i : "" ) + "]", v, traditional, add );
			}
		});

	} else if ( !traditional && jQuery.type( obj ) === "object" ) {
		// Serialize object item.
		for ( name in obj ) {
			buildParams( prefix + "[" + name + "]", obj[ name ], traditional, add );
		}

	} else {
		// Serialize scalar item.
		add( prefix, obj );
	}
}

// Serialize an array of form elements or a set of
// key/values into a query string
jQuery.param = function( a, traditional ) {
	var prefix,
		s = [],
		add = function( key, value ) {
			// If value is a function, invoke it and return its value
			value = jQuery.isFunction( value ) ? value() : ( value == null ? "" : value );
			s[ s.length ] = encodeURIComponent( key ) + "=" + encodeURIComponent( value );
		};

	// Set traditional to true for jQuery <= 1.3.2 behavior.
	if ( traditional === undefined ) {
		traditional = jQuery.ajaxSettings && jQuery.ajaxSettings.traditional;
	}

	// If an array was passed in, assume that it is an array of form elements.
	if ( jQuery.isArray( a ) || ( a.jquery && !jQuery.isPlainObject( a ) ) ) {
		// Serialize the form elements
		jQuery.each( a, function() {
			add( this.name, this.value );
		});

	} else {
		// If traditional, encode the "old" way (the way 1.3.2 or older
		// did it), otherwise encode params recursively.
		for ( prefix in a ) {
			buildParams( prefix, a[ prefix ], traditional, add );
		}
	}

	// Return the resulting serialization
	return s.join( "&" ).replace( r20, "+" );
};

jQuery.fn.extend({
	serialize: function() {
		return jQuery.param( this.serializeArray() );
	},
	serializeArray: function() {
		return this.map(function() {
			// Can add propHook for "elements" to filter or add form elements
			var elements = jQuery.prop( this, "elements" );
			return elements ? jQuery.makeArray( elements ) : this;
		})
		.filter(function() {
			var type = this.type;

			// Use .is( ":disabled" ) so that fieldset[disabled] works
			return this.name && !jQuery( this ).is( ":disabled" ) &&
				rsubmittable.test( this.nodeName ) && !rsubmitterTypes.test( type ) &&
				( this.checked || !rcheckableType.test( type ) );
		})
		.map(function( i, elem ) {
			var val = jQuery( this ).val();

			return val == null ?
				null :
				jQuery.isArray( val ) ?
					jQuery.map( val, function( val ) {
						return { name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
					}) :
					{ name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
		}).get();
	}
});


jQuery.ajaxSettings.xhr = function() {
	try {
		return new XMLHttpRequest();
	} catch( e ) {}
};

var xhrId = 0,
	xhrCallbacks = {},
	xhrSuccessStatus = {
		// file protocol always yields status code 0, assume 200
		0: 200,
		// Support: IE9
		// #1450: sometimes IE returns 1223 when it should be 204
		1223: 204
	},
	xhrSupported = jQuery.ajaxSettings.xhr();

// Support: IE9
// Open requests must be manually aborted on unload (#5280)
if ( window.ActiveXObject ) {
	jQuery( window ).on( "unload", function() {
		for ( var key in xhrCallbacks ) {
			xhrCallbacks[ key ]();
		}
	});
}

support.cors = !!xhrSupported && ( "withCredentials" in xhrSupported );
support.ajax = xhrSupported = !!xhrSupported;

jQuery.ajaxTransport(function( options ) {
	var callback;

	// Cross domain only allowed if supported through XMLHttpRequest
	if ( support.cors || xhrSupported && !options.crossDomain ) {
		return {
			send: function( headers, complete ) {
				var i,
					xhr = options.xhr(),
					id = ++xhrId;

				xhr.open( options.type, options.url, options.async, options.username, options.password );

				// Apply custom fields if provided
				if ( options.xhrFields ) {
					for ( i in options.xhrFields ) {
						xhr[ i ] = options.xhrFields[ i ];
					}
				}

				// Override mime type if needed
				if ( options.mimeType && xhr.overrideMimeType ) {
					xhr.overrideMimeType( options.mimeType );
				}

				// X-Requested-With header
				// For cross-domain requests, seeing as conditions for a preflight are
				// akin to a jigsaw puzzle, we simply never set it to be sure.
				// (it can always be set on a per-request basis or even using ajaxSetup)
				// For same-domain requests, won't change header if already provided.
				if ( !options.crossDomain && !headers["X-Requested-With"] ) {
					headers["X-Requested-With"] = "XMLHttpRequest";
				}

				// Set headers
				for ( i in headers ) {
					xhr.setRequestHeader( i, headers[ i ] );
				}

				// Callback
				callback = function( type ) {
					return function() {
						if ( callback ) {
							delete xhrCallbacks[ id ];
							callback = xhr.onload = xhr.onerror = null;

							if ( type === "abort" ) {
								xhr.abort();
							} else if ( type === "error" ) {
								complete(
									// file: protocol always yields status 0; see #8605, #14207
									xhr.status,
									xhr.statusText
								);
							} else {
								complete(
									xhrSuccessStatus[ xhr.status ] || xhr.status,
									xhr.statusText,
									// Support: IE9
									// Accessing binary-data responseText throws an exception
									// (#11426)
									typeof xhr.responseText === "string" ? {
										text: xhr.responseText
									} : undefined,
									xhr.getAllResponseHeaders()
								);
							}
						}
					};
				};

				// Listen to events
				xhr.onload = callback();
				xhr.onerror = callback("error");

				// Create the abort callback
				callback = xhrCallbacks[ id ] = callback("abort");

				try {
					// Do send the request (this may raise an exception)
					xhr.send( options.hasContent && options.data || null );
				} catch ( e ) {
					// #14683: Only rethrow if this hasn't been notified as an error yet
					if ( callback ) {
						throw e;
					}
				}
			},

			abort: function() {
				if ( callback ) {
					callback();
				}
			}
		};
	}
});




// Install script dataType
jQuery.ajaxSetup({
	accepts: {
		script: "text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"
	},
	contents: {
		script: /(?:java|ecma)script/
	},
	converters: {
		"text script": function( text ) {
			jQuery.globalEval( text );
			return text;
		}
	}
});

// Handle cache's special case and crossDomain
jQuery.ajaxPrefilter( "script", function( s ) {
	if ( s.cache === undefined ) {
		s.cache = false;
	}
	if ( s.crossDomain ) {
		s.type = "GET";
	}
});

// Bind script tag hack transport
jQuery.ajaxTransport( "script", function( s ) {
	// This transport only deals with cross domain requests
	if ( s.crossDomain ) {
		var script, callback;
		return {
			send: function( _, complete ) {
				script = jQuery("<script>").prop({
					async: true,
					charset: s.scriptCharset,
					src: s.url
				}).on(
					"load error",
					callback = function( evt ) {
						script.remove();
						callback = null;
						if ( evt ) {
							complete( evt.type === "error" ? 404 : 200, evt.type );
						}
					}
				);
				document.head.appendChild( script[ 0 ] );
			},
			abort: function() {
				if ( callback ) {
					callback();
				}
			}
		};
	}
});




var oldCallbacks = [],
	rjsonp = /(=)\?(?=&|$)|\?\?/;

// Default jsonp settings
jQuery.ajaxSetup({
	jsonp: "callback",
	jsonpCallback: function() {
		var callback = oldCallbacks.pop() || ( jQuery.expando + "_" + ( nonce++ ) );
		this[ callback ] = true;
		return callback;
	}
});

// Detect, normalize options and install callbacks for jsonp requests
jQuery.ajaxPrefilter( "json jsonp", function( s, originalSettings, jqXHR ) {

	var callbackName, overwritten, responseContainer,
		jsonProp = s.jsonp !== false && ( rjsonp.test( s.url ) ?
			"url" :
			typeof s.data === "string" && !( s.contentType || "" ).indexOf("application/x-www-form-urlencoded") && rjsonp.test( s.data ) && "data"
		);

	// Handle iff the expected data type is "jsonp" or we have a parameter to set
	if ( jsonProp || s.dataTypes[ 0 ] === "jsonp" ) {

		// Get callback name, remembering preexisting value associated with it
		callbackName = s.jsonpCallback = jQuery.isFunction( s.jsonpCallback ) ?
			s.jsonpCallback() :
			s.jsonpCallback;

		// Insert callback into url or form data
		if ( jsonProp ) {
			s[ jsonProp ] = s[ jsonProp ].replace( rjsonp, "$1" + callbackName );
		} else if ( s.jsonp !== false ) {
			s.url += ( rquery.test( s.url ) ? "&" : "?" ) + s.jsonp + "=" + callbackName;
		}

		// Use data converter to retrieve json after script execution
		s.converters["script json"] = function() {
			if ( !responseContainer ) {
				jQuery.error( callbackName + " was not called" );
			}
			return responseContainer[ 0 ];
		};

		// force json dataType
		s.dataTypes[ 0 ] = "json";

		// Install callback
		overwritten = window[ callbackName ];
		window[ callbackName ] = function() {
			responseContainer = arguments;
		};

		// Clean-up function (fires after converters)
		jqXHR.always(function() {
			// Restore preexisting value
			window[ callbackName ] = overwritten;

			// Save back as free
			if ( s[ callbackName ] ) {
				// make sure that re-using the options doesn't screw things around
				s.jsonpCallback = originalSettings.jsonpCallback;

				// save the callback name for future use
				oldCallbacks.push( callbackName );
			}

			// Call if it was a function and we have a response
			if ( responseContainer && jQuery.isFunction( overwritten ) ) {
				overwritten( responseContainer[ 0 ] );
			}

			responseContainer = overwritten = undefined;
		});

		// Delegate to script
		return "script";
	}
});




// data: string of html
// context (optional): If specified, the fragment will be created in this context, defaults to document
// keepScripts (optional): If true, will include scripts passed in the html string
jQuery.parseHTML = function( data, context, keepScripts ) {
	if ( !data || typeof data !== "string" ) {
		return null;
	}
	if ( typeof context === "boolean" ) {
		keepScripts = context;
		context = false;
	}
	context = context || document;

	var parsed = rsingleTag.exec( data ),
		scripts = !keepScripts && [];

	// Single tag
	if ( parsed ) {
		return [ context.createElement( parsed[1] ) ];
	}

	parsed = jQuery.buildFragment( [ data ], context, scripts );

	if ( scripts && scripts.length ) {
		jQuery( scripts ).remove();
	}

	return jQuery.merge( [], parsed.childNodes );
};


// Keep a copy of the old load method
var _load = jQuery.fn.load;

/**
 * Load a url into a page
 */
jQuery.fn.load = function( url, params, callback ) {
	if ( typeof url !== "string" && _load ) {
		return _load.apply( this, arguments );
	}

	var selector, type, response,
		self = this,
		off = url.indexOf(" ");

	if ( off >= 0 ) {
		selector = jQuery.trim( url.slice( off ) );
		url = url.slice( 0, off );
	}

	// If it's a function
	if ( jQuery.isFunction( params ) ) {

		// We assume that it's the callback
		callback = params;
		params = undefined;

	// Otherwise, build a param string
	} else if ( params && typeof params === "object" ) {
		type = "POST";
	}

	// If we have elements to modify, make the request
	if ( self.length > 0 ) {
		jQuery.ajax({
			url: url,

			// if "type" variable is undefined, then "GET" method will be used
			type: type,
			dataType: "html",
			data: params
		}).done(function( responseText ) {

			// Save response for use in complete callback
			response = arguments;

			self.html( selector ?

				// If a selector was specified, locate the right elements in a dummy div
				// Exclude scripts to avoid IE 'Permission Denied' errors
				jQuery("<div>").append( jQuery.parseHTML( responseText ) ).find( selector ) :

				// Otherwise use the full result
				responseText );

		}).complete( callback && function( jqXHR, status ) {
			self.each( callback, response || [ jqXHR.responseText, status, jqXHR ] );
		});
	}

	return this;
};




jQuery.expr.filters.animated = function( elem ) {
	return jQuery.grep(jQuery.timers, function( fn ) {
		return elem === fn.elem;
	}).length;
};




var docElem = window.document.documentElement;

/**
 * Gets a window from an element
 */
function getWindow( elem ) {
	return jQuery.isWindow( elem ) ? elem : elem.nodeType === 9 && elem.defaultView;
}

jQuery.offset = {
	setOffset: function( elem, options, i ) {
		var curPosition, curLeft, curCSSTop, curTop, curOffset, curCSSLeft, calculatePosition,
			position = jQuery.css( elem, "position" ),
			curElem = jQuery( elem ),
			props = {};

		// Set position first, in-case top/left are set even on static elem
		if ( position === "static" ) {
			elem.style.position = "relative";
		}

		curOffset = curElem.offset();
		curCSSTop = jQuery.css( elem, "top" );
		curCSSLeft = jQuery.css( elem, "left" );
		calculatePosition = ( position === "absolute" || position === "fixed" ) &&
			( curCSSTop + curCSSLeft ).indexOf("auto") > -1;

		// Need to be able to calculate position if either top or left is auto and position is either absolute or fixed
		if ( calculatePosition ) {
			curPosition = curElem.position();
			curTop = curPosition.top;
			curLeft = curPosition.left;

		} else {
			curTop = parseFloat( curCSSTop ) || 0;
			curLeft = parseFloat( curCSSLeft ) || 0;
		}

		if ( jQuery.isFunction( options ) ) {
			options = options.call( elem, i, curOffset );
		}

		if ( options.top != null ) {
			props.top = ( options.top - curOffset.top ) + curTop;
		}
		if ( options.left != null ) {
			props.left = ( options.left - curOffset.left ) + curLeft;
		}

		if ( "using" in options ) {
			options.using.call( elem, props );

		} else {
			curElem.css( props );
		}
	}
};

jQuery.fn.extend({
	offset: function( options ) {
		if ( arguments.length ) {
			return options === undefined ?
				this :
				this.each(function( i ) {
					jQuery.offset.setOffset( this, options, i );
				});
		}

		var docElem, win,
			elem = this[ 0 ],
			box = { top: 0, left: 0 },
			doc = elem && elem.ownerDocument;

		if ( !doc ) {
			return;
		}

		docElem = doc.documentElement;

		// Make sure it's not a disconnected DOM node
		if ( !jQuery.contains( docElem, elem ) ) {
			return box;
		}

		// If we don't have gBCR, just use 0,0 rather than error
		// BlackBerry 5, iOS 3 (original iPhone)
		if ( typeof elem.getBoundingClientRect !== strundefined ) {
			box = elem.getBoundingClientRect();
		}
		win = getWindow( doc );
		return {
			top: box.top + win.pageYOffset - docElem.clientTop,
			left: box.left + win.pageXOffset - docElem.clientLeft
		};
	},

	position: function() {
		if ( !this[ 0 ] ) {
			return;
		}

		var offsetParent, offset,
			elem = this[ 0 ],
			parentOffset = { top: 0, left: 0 };

		// Fixed elements are offset from window (parentOffset = {top:0, left: 0}, because it is its only offset parent
		if ( jQuery.css( elem, "position" ) === "fixed" ) {
			// We assume that getBoundingClientRect is available when computed position is fixed
			offset = elem.getBoundingClientRect();

		} else {
			// Get *real* offsetParent
			offsetParent = this.offsetParent();

			// Get correct offsets
			offset = this.offset();
			if ( !jQuery.nodeName( offsetParent[ 0 ], "html" ) ) {
				parentOffset = offsetParent.offset();
			}

			// Add offsetParent borders
			parentOffset.top += jQuery.css( offsetParent[ 0 ], "borderTopWidth", true );
			parentOffset.left += jQuery.css( offsetParent[ 0 ], "borderLeftWidth", true );
		}

		// Subtract parent offsets and element margins
		return {
			top: offset.top - parentOffset.top - jQuery.css( elem, "marginTop", true ),
			left: offset.left - parentOffset.left - jQuery.css( elem, "marginLeft", true )
		};
	},

	offsetParent: function() {
		return this.map(function() {
			var offsetParent = this.offsetParent || docElem;

			while ( offsetParent && ( !jQuery.nodeName( offsetParent, "html" ) && jQuery.css( offsetParent, "position" ) === "static" ) ) {
				offsetParent = offsetParent.offsetParent;
			}

			return offsetParent || docElem;
		});
	}
});

// Create scrollLeft and scrollTop methods
jQuery.each( { scrollLeft: "pageXOffset", scrollTop: "pageYOffset" }, function( method, prop ) {
	var top = "pageYOffset" === prop;

	jQuery.fn[ method ] = function( val ) {
		return access( this, function( elem, method, val ) {
			var win = getWindow( elem );

			if ( val === undefined ) {
				return win ? win[ prop ] : elem[ method ];
			}

			if ( win ) {
				win.scrollTo(
					!top ? val : window.pageXOffset,
					top ? val : window.pageYOffset
				);

			} else {
				elem[ method ] = val;
			}
		}, method, val, arguments.length, null );
	};
});

// Add the top/left cssHooks using jQuery.fn.position
// Webkit bug: https://bugs.webkit.org/show_bug.cgi?id=29084
// getComputedStyle returns percent when specified for top/left/bottom/right
// rather than make the css module depend on the offset module, we just check for it here
jQuery.each( [ "top", "left" ], function( i, prop ) {
	jQuery.cssHooks[ prop ] = addGetHookIf( support.pixelPosition,
		function( elem, computed ) {
			if ( computed ) {
				computed = curCSS( elem, prop );
				// if curCSS returns percentage, fallback to offset
				return rnumnonpx.test( computed ) ?
					jQuery( elem ).position()[ prop ] + "px" :
					computed;
			}
		}
	);
});


// Create innerHeight, innerWidth, height, width, outerHeight and outerWidth methods
jQuery.each( { Height: "height", Width: "width" }, function( name, type ) {
	jQuery.each( { padding: "inner" + name, content: type, "": "outer" + name }, function( defaultExtra, funcName ) {
		// margin is only for outerHeight, outerWidth
		jQuery.fn[ funcName ] = function( margin, value ) {
			var chainable = arguments.length && ( defaultExtra || typeof margin !== "boolean" ),
				extra = defaultExtra || ( margin === true || value === true ? "margin" : "border" );

			return access( this, function( elem, type, value ) {
				var doc;

				if ( jQuery.isWindow( elem ) ) {
					// As of 5/8/2012 this will yield incorrect results for Mobile Safari, but there
					// isn't a whole lot we can do. See pull request at this URL for discussion:
					// https://github.com/jquery/jquery/pull/764
					return elem.document.documentElement[ "client" + name ];
				}

				// Get document width or height
				if ( elem.nodeType === 9 ) {
					doc = elem.documentElement;

					// Either scroll[Width/Height] or offset[Width/Height] or client[Width/Height],
					// whichever is greatest
					return Math.max(
						elem.body[ "scroll" + name ], doc[ "scroll" + name ],
						elem.body[ "offset" + name ], doc[ "offset" + name ],
						doc[ "client" + name ]
					);
				}

				return value === undefined ?
					// Get width or height on the element, requesting but not forcing parseFloat
					jQuery.css( elem, type, extra ) :

					// Set width or height on the element
					jQuery.style( elem, type, value, extra );
			}, type, chainable ? margin : undefined, chainable, null );
		};
	});
});


// The number of elements contained in the matched element set
jQuery.fn.size = function() {
	return this.length;
};

jQuery.fn.andSelf = jQuery.fn.addBack;




// Register as a named AMD module, since jQuery can be concatenated with other
// files that may use define, but not via a proper concatenation script that
// understands anonymous AMD modules. A named AMD is safest and most robust
// way to register. Lowercase jquery is used because AMD module names are
// derived from file names, and jQuery is normally delivered in a lowercase
// file name. Do this after creating the global so that if an AMD module wants
// to call noConflict to hide this version of jQuery, it will work.

// Note that for maximum portability, libraries that are not jQuery should
// declare themselves as anonymous modules, and avoid setting a global if an
// AMD loader is present. jQuery is a special case. For more information, see
// https://github.com/jrburke/requirejs/wiki/Updating-existing-libraries#wiki-anon

if ( typeof define === "function" && define.amd ) {
	define( "jquery", [], function() {
		return jQuery;
	});
}




var
	// Map over jQuery in case of overwrite
	_jQuery = window.jQuery,

	// Map over the $ in case of overwrite
	_$ = window.$;

jQuery.noConflict = function( deep ) {
	if ( window.$ === jQuery ) {
		window.$ = _$;
	}

	if ( deep && window.jQuery === jQuery ) {
		window.jQuery = _jQuery;
	}

	return jQuery;
};

// Expose jQuery and $ identifiers, even in
// AMD (#7102#comment:10, https://github.com/jquery/jquery/pull/557)
// and CommonJS for browser emulators (#13566)
if ( typeof noGlobal === strundefined ) {
	window.jQuery = window.$ = jQuery;
}




return jQuery;

}));
/**
 * @license
 * lodash 3.10.0 (Custom Build) <https://lodash.com/>
 * Build: `lodash modern -o ./lodash.js`
 * Copyright 2012-2015 The Dojo Foundation <http://dojofoundation.org/>
 * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>
 * Copyright 2009-2015 Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
 * Available under MIT license <https://lodash.com/license>
 */
;(function() {

  /** Used as a safe reference for `undefined` in pre-ES5 environments. */
  var undefined;

  /** Used as the semantic version number. */
  var VERSION = '3.10.0';

  /** Used to compose bitmasks for wrapper metadata. */
  var BIND_FLAG = 1,
      BIND_KEY_FLAG = 2,
      CURRY_BOUND_FLAG = 4,
      CURRY_FLAG = 8,
      CURRY_RIGHT_FLAG = 16,
      PARTIAL_FLAG = 32,
      PARTIAL_RIGHT_FLAG = 64,
      ARY_FLAG = 128,
      REARG_FLAG = 256;

  /** Used as default options for `_.trunc`. */
  var DEFAULT_TRUNC_LENGTH = 30,
      DEFAULT_TRUNC_OMISSION = '...';

  /** Used to detect when a function becomes hot. */
  var HOT_COUNT = 150,
      HOT_SPAN = 16;

  /** Used as the size to enable large array optimizations. */
  var LARGE_ARRAY_SIZE = 200;

  /** Used to indicate the type of lazy iteratees. */
  var LAZY_FILTER_FLAG = 1,
      LAZY_MAP_FLAG = 2;

  /** Used as the `TypeError` message for "Functions" methods. */
  var FUNC_ERROR_TEXT = 'Expected a function';

  /** Used as the internal argument placeholder. */
  var PLACEHOLDER = '__lodash_placeholder__';

  /** `Object#toString` result references. */
  var argsTag = '[object Arguments]',
      arrayTag = '[object Array]',
      boolTag = '[object Boolean]',
      dateTag = '[object Date]',
      errorTag = '[object Error]',
      funcTag = '[object Function]',
      mapTag = '[object Map]',
      numberTag = '[object Number]',
      objectTag = '[object Object]',
      regexpTag = '[object RegExp]',
      setTag = '[object Set]',
      stringTag = '[object String]',
      weakMapTag = '[object WeakMap]';

  var arrayBufferTag = '[object ArrayBuffer]',
      float32Tag = '[object Float32Array]',
      float64Tag = '[object Float64Array]',
      int8Tag = '[object Int8Array]',
      int16Tag = '[object Int16Array]',
      int32Tag = '[object Int32Array]',
      uint8Tag = '[object Uint8Array]',
      uint8ClampedTag = '[object Uint8ClampedArray]',
      uint16Tag = '[object Uint16Array]',
      uint32Tag = '[object Uint32Array]';

  /** Used to match empty string literals in compiled template source. */
  var reEmptyStringLeading = /\b__p \+= '';/g,
      reEmptyStringMiddle = /\b(__p \+=) '' \+/g,
      reEmptyStringTrailing = /(__e\(.*?\)|\b__t\)) \+\n'';/g;

  /** Used to match HTML entities and HTML characters. */
  var reEscapedHtml = /&(?:amp|lt|gt|quot|#39|#96);/g,
      reUnescapedHtml = /[&<>"'`]/g,
      reHasEscapedHtml = RegExp(reEscapedHtml.source),
      reHasUnescapedHtml = RegExp(reUnescapedHtml.source);

  /** Used to match template delimiters. */
  var reEscape = /<%-([\s\S]+?)%>/g,
      reEvaluate = /<%([\s\S]+?)%>/g,
      reInterpolate = /<%=([\s\S]+?)%>/g;

  /** Used to match property names within property paths. */
  var reIsDeepProp = /\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\n\\]|\\.)*?\1)\]/,
      reIsPlainProp = /^\w*$/,
      rePropName = /[^.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\n\\]|\\.)*?)\2)\]/g;

  /**
   * Used to match `RegExp` [syntax characters](http://ecma-international.org/ecma-262/6.0/#sec-patterns)
   * and those outlined by [`EscapeRegExpPattern`](http://ecma-international.org/ecma-262/6.0/#sec-escaperegexppattern).
   */
  var reRegExpChars = /^[:!,]|[\\^$.*+?()[\]{}|\/]|(^[0-9a-fA-Fnrtuvx])|([\n\r\u2028\u2029])/g,
      reHasRegExpChars = RegExp(reRegExpChars.source);

  /** Used to match [combining diacritical marks](https://en.wikipedia.org/wiki/Combining_Diacritical_Marks). */
  var reComboMark = /[\u0300-\u036f\ufe20-\ufe23]/g;

  /** Used to match backslashes in property paths. */
  var reEscapeChar = /\\(\\)?/g;

  /** Used to match [ES template delimiters](http://ecma-international.org/ecma-262/6.0/#sec-template-literal-lexical-components). */
  var reEsTemplate = /\$\{([^\\}]*(?:\\.[^\\}]*)*)\}/g;

  /** Used to match `RegExp` flags from their coerced string values. */
  var reFlags = /\w*$/;

  /** Used to detect hexadecimal string values. */
  var reHasHexPrefix = /^0[xX]/;

  /** Used to detect host constructors (Safari > 5). */
  var reIsHostCtor = /^\[object .+?Constructor\]$/;

  /** Used to detect unsigned integer values. */
  var reIsUint = /^\d+$/;

  /** Used to match latin-1 supplementary letters (excluding mathematical operators). */
  var reLatin1 = /[\xc0-\xd6\xd8-\xde\xdf-\xf6\xf8-\xff]/g;

  /** Used to ensure capturing order of template delimiters. */
  var reNoMatch = /($^)/;

  /** Used to match unescaped characters in compiled string literals. */
  var reUnescapedString = /['\n\r\u2028\u2029\\]/g;

  /** Used to match words to create compound words. */
  var reWords = (function() {
    var upper = '[A-Z\\xc0-\\xd6\\xd8-\\xde]',
        lower = '[a-z\\xdf-\\xf6\\xf8-\\xff]+';

    return RegExp(upper + '+(?=' + upper + lower + ')|' + upper + '?' + lower + '|' + upper + '+|[0-9]+', 'g');
  }());

  /** Used to assign default `context` object properties. */
  var contextProps = [
    'Array', 'ArrayBuffer', 'Date', 'Error', 'Float32Array', 'Float64Array',
    'Function', 'Int8Array', 'Int16Array', 'Int32Array', 'Math', 'Number',
    'Object', 'RegExp', 'Set', 'String', '_', 'clearTimeout', 'isFinite',
    'parseFloat', 'parseInt', 'setTimeout', 'TypeError', 'Uint8Array',
    'Uint8ClampedArray', 'Uint16Array', 'Uint32Array', 'WeakMap'
  ];

  /** Used to make template sourceURLs easier to identify. */
  var templateCounter = -1;

  /** Used to identify `toStringTag` values of typed arrays. */
  var typedArrayTags = {};
  typedArrayTags[float32Tag] = typedArrayTags[float64Tag] =
  typedArrayTags[int8Tag] = typedArrayTags[int16Tag] =
  typedArrayTags[int32Tag] = typedArrayTags[uint8Tag] =
  typedArrayTags[uint8ClampedTag] = typedArrayTags[uint16Tag] =
  typedArrayTags[uint32Tag] = true;
  typedArrayTags[argsTag] = typedArrayTags[arrayTag] =
  typedArrayTags[arrayBufferTag] = typedArrayTags[boolTag] =
  typedArrayTags[dateTag] = typedArrayTags[errorTag] =
  typedArrayTags[funcTag] = typedArrayTags[mapTag] =
  typedArrayTags[numberTag] = typedArrayTags[objectTag] =
  typedArrayTags[regexpTag] = typedArrayTags[setTag] =
  typedArrayTags[stringTag] = typedArrayTags[weakMapTag] = false;

  /** Used to identify `toStringTag` values supported by `_.clone`. */
  var cloneableTags = {};
  cloneableTags[argsTag] = cloneableTags[arrayTag] =
  cloneableTags[arrayBufferTag] = cloneableTags[boolTag] =
  cloneableTags[dateTag] = cloneableTags[float32Tag] =
  cloneableTags[float64Tag] = cloneableTags[int8Tag] =
  cloneableTags[int16Tag] = cloneableTags[int32Tag] =
  cloneableTags[numberTag] = cloneableTags[objectTag] =
  cloneableTags[regexpTag] = cloneableTags[stringTag] =
  cloneableTags[uint8Tag] = cloneableTags[uint8ClampedTag] =
  cloneableTags[uint16Tag] = cloneableTags[uint32Tag] = true;
  cloneableTags[errorTag] = cloneableTags[funcTag] =
  cloneableTags[mapTag] = cloneableTags[setTag] =
  cloneableTags[weakMapTag] = false;

  /** Used to map latin-1 supplementary letters to basic latin letters. */
  var deburredLetters = {
    '\xc0': 'A',  '\xc1': 'A', '\xc2': 'A', '\xc3': 'A', '\xc4': 'A', '\xc5': 'A',
    '\xe0': 'a',  '\xe1': 'a', '\xe2': 'a', '\xe3': 'a', '\xe4': 'a', '\xe5': 'a',
    '\xc7': 'C',  '\xe7': 'c',
    '\xd0': 'D',  '\xf0': 'd',
    '\xc8': 'E',  '\xc9': 'E', '\xca': 'E', '\xcb': 'E',
    '\xe8': 'e',  '\xe9': 'e', '\xea': 'e', '\xeb': 'e',
    '\xcC': 'I',  '\xcd': 'I', '\xce': 'I', '\xcf': 'I',
    '\xeC': 'i',  '\xed': 'i', '\xee': 'i', '\xef': 'i',
    '\xd1': 'N',  '\xf1': 'n',
    '\xd2': 'O',  '\xd3': 'O', '\xd4': 'O', '\xd5': 'O', '\xd6': 'O', '\xd8': 'O',
    '\xf2': 'o',  '\xf3': 'o', '\xf4': 'o', '\xf5': 'o', '\xf6': 'o', '\xf8': 'o',
    '\xd9': 'U',  '\xda': 'U', '\xdb': 'U', '\xdc': 'U',
    '\xf9': 'u',  '\xfa': 'u', '\xfb': 'u', '\xfc': 'u',
    '\xdd': 'Y',  '\xfd': 'y', '\xff': 'y',
    '\xc6': 'Ae', '\xe6': 'ae',
    '\xde': 'Th', '\xfe': 'th',
    '\xdf': 'ss'
  };

  /** Used to map characters to HTML entities. */
  var htmlEscapes = {
    '&': '&amp;',
    '<': '&lt;',
    '>': '&gt;',
    '"': '&quot;',
    "'": '&#39;',
    '`': '&#96;'
  };

  /** Used to map HTML entities to characters. */
  var htmlUnescapes = {
    '&amp;': '&',
    '&lt;': '<',
    '&gt;': '>',
    '&quot;': '"',
    '&#39;': "'",
    '&#96;': '`'
  };

  /** Used to determine if values are of the language type `Object`. */
  var objectTypes = {
    'function': true,
    'object': true
  };

  /** Used to escape characters for inclusion in compiled regexes. */
  var regexpEscapes = {
    '0': 'x30', '1': 'x31', '2': 'x32', '3': 'x33', '4': 'x34',
    '5': 'x35', '6': 'x36', '7': 'x37', '8': 'x38', '9': 'x39',
    'A': 'x41', 'B': 'x42', 'C': 'x43', 'D': 'x44', 'E': 'x45', 'F': 'x46',
    'a': 'x61', 'b': 'x62', 'c': 'x63', 'd': 'x64', 'e': 'x65', 'f': 'x66',
    'n': 'x6e', 'r': 'x72', 't': 'x74', 'u': 'x75', 'v': 'x76', 'x': 'x78'
  };

  /** Used to escape characters for inclusion in compiled string literals. */
  var stringEscapes = {
    '\\': '\\',
    "'": "'",
    '\n': 'n',
    '\r': 'r',
    '\u2028': 'u2028',
    '\u2029': 'u2029'
  };

  /** Detect free variable `exports`. */
  var freeExports = objectTypes[typeof exports] && exports && !exports.nodeType && exports;

  /** Detect free variable `module`. */
  var freeModule = objectTypes[typeof module] && module && !module.nodeType && module;

  /** Detect free variable `global` from Node.js. */
  var freeGlobal = freeExports && freeModule && typeof global == 'object' && global && global.Object && global;

  /** Detect free variable `self`. */
  var freeSelf = objectTypes[typeof self] && self && self.Object && self;

  /** Detect free variable `window`. */
  var freeWindow = objectTypes[typeof window] && window && window.Object && window;

  /** Detect the popular CommonJS extension `module.exports`. */
  var moduleExports = freeModule && freeModule.exports === freeExports && freeExports;

  /**
   * Used as a reference to the global object.
   *
   * The `this` value is used if it's the global object to avoid Greasemonkey's
   * restricted `window` object, otherwise the `window` object is used.
   */
  var root = freeGlobal || ((freeWindow !== (this && this.window)) && freeWindow) || freeSelf || this;

  /*--------------------------------------------------------------------------*/

  /**
   * The base implementation of `compareAscending` which compares values and
   * sorts them in ascending order without guaranteeing a stable sort.
   *
   * @private
   * @param {*} value The value to compare.
   * @param {*} other The other value to compare.
   * @returns {number} Returns the sort order indicator for `value`.
   */
  function baseCompareAscending(value, other) {
    if (value !== other) {
      var valIsNull = value === null,
          valIsUndef = value === undefined,
          valIsReflexive = value === value;

      var othIsNull = other === null,
          othIsUndef = other === undefined,
          othIsReflexive = other === other;

      if ((value > other && !othIsNull) || !valIsReflexive ||
          (valIsNull && !othIsUndef && othIsReflexive) ||
          (valIsUndef && othIsReflexive)) {
        return 1;
      }
      if ((value < other && !valIsNull) || !othIsReflexive ||
          (othIsNull && !valIsUndef && valIsReflexive) ||
          (othIsUndef && valIsReflexive)) {
        return -1;
      }
    }
    return 0;
  }

  /**
   * The base implementation of `_.findIndex` and `_.findLastIndex` without
   * support for callback shorthands and `this` binding.
   *
   * @private
   * @param {Array} array The array to search.
   * @param {Function} predicate The function invoked per iteration.
   * @param {boolean} [fromRight] Specify iterating from right to left.
   * @returns {number} Returns the index of the matched value, else `-1`.
   */
  function baseFindIndex(array, predicate, fromRight) {
    var length = array.length,
        index = fromRight ? length : -1;

    while ((fromRight ? index-- : ++index < length)) {
      if (predicate(array[index], index, array)) {
        return index;
      }
    }
    return -1;
  }

  /**
   * The base implementation of `_.indexOf` without support for binary searches.
   *
   * @private
   * @param {Array} array The array to search.
   * @param {*} value The value to search for.
   * @param {number} fromIndex The index to search from.
   * @returns {number} Returns the index of the matched value, else `-1`.
   */
  function baseIndexOf(array, value, fromIndex) {
    if (value !== value) {
      return indexOfNaN(array, fromIndex);
    }
    var index = fromIndex - 1,
        length = array.length;

    while (++index < length) {
      if (array[index] === value) {
        return index;
      }
    }
    return -1;
  }

  /**
   * The base implementation of `_.isFunction` without support for environments
   * with incorrect `typeof` results.
   *
   * @private
   * @param {*} value The value to check.
   * @returns {boolean} Returns `true` if `value` is correctly classified, else `false`.
   */
  function baseIsFunction(value) {
    // Avoid a Chakra JIT bug in compatibility modes of IE 11.
    // See https://github.com/jashkenas/underscore/issues/1621 for more details.
    return typeof value == 'function' || false;
  }

  /**
   * Converts `value` to a string if it's not one. An empty string is returned
   * for `null` or `undefined` values.
   *
   * @private
   * @param {*} value The value to process.
   * @returns {string} Returns the string.
   */
  function baseToString(value) {
    return value == null ? '' : (value + '');
  }

  /**
   * Used by `_.trim` and `_.trimLeft` to get the index of the first character
   * of `string` that is not found in `chars`.
   *
   * @private
   * @param {string} string The string to inspect.
   * @param {string} chars The characters to find.
   * @returns {number} Returns the index of the first character not found in `chars`.
   */
  function charsLeftIndex(string, chars) {
    var index = -1,
        length = string.length;

    while (++index < length && chars.indexOf(string.charAt(index)) > -1) {}
    return index;
  }

  /**
   * Used by `_.trim` and `_.trimRight` to get the index of the last character
   * of `string` that is not found in `chars`.
   *
   * @private
   * @param {string} string The string to inspect.
   * @param {string} chars The characters to find.
   * @returns {number} Returns the index of the last character not found in `chars`.
   */
  function charsRightIndex(string, chars) {
    var index = string.length;

    while (index-- && chars.indexOf(string.charAt(index)) > -1) {}
    return index;
  }

  /**
   * Used by `_.sortBy` to compare transformed elements of a collection and stable
   * sort them in ascending order.
   *
   * @private
   * @param {Object} object The object to compare.
   * @param {Object} other The other object to compare.
   * @returns {number} Returns the sort order indicator for `object`.
   */
  function compareAscending(object, other) {
    return baseCompareAscending(object.criteria, other.criteria) || (object.index - other.index);
  }

  /**
   * Used by `_.sortByOrder` to compare multiple properties of a value to another
   * and stable sort them.
   *
   * If `orders` is unspecified, all valuess are sorted in ascending order. Otherwise,
   * a value is sorted in ascending order if its corresponding order is "asc", and
   * descending if "desc".
   *
   * @private
   * @param {Object} object The object to compare.
   * @param {Object} other The other object to compare.
   * @param {boolean[]} orders The order to sort by for each property.
   * @returns {number} Returns the sort order indicator for `object`.
   */
  function compareMultiple(object, other, orders) {
    var index = -1,
        objCriteria = object.criteria,
        othCriteria = other.criteria,
        length = objCriteria.length,
        ordersLength = orders.length;

    while (++index < length) {
      var result = baseCompareAscending(objCriteria[index], othCriteria[index]);
      if (result) {
        if (index >= ordersLength) {
          return result;
        }
        var order = orders[index];
        return result * ((order === 'asc' || order === true) ? 1 : -1);
      }
    }
    // Fixes an `Array#sort` bug in the JS engine embedded in Adobe applications
    // that causes it, under certain circumstances, to provide the same value for
    // `object` and `other`. See https://github.com/jashkenas/underscore/pull/1247
    // for more details.
    //
    // This also ensures a stable sort in V8 and other engines.
    // See https://code.google.com/p/v8/issues/detail?id=90 for more details.
    return object.index - other.index;
  }

  /**
   * Used by `_.deburr` to convert latin-1 supplementary letters to basic latin letters.
   *
   * @private
   * @param {string} letter The matched letter to deburr.
   * @returns {string} Returns the deburred letter.
   */
  function deburrLetter(letter) {
    return deburredLetters[letter];
  }

  /**
   * Used by `_.escape` to convert characters to HTML entities.
   *
   * @private
   * @param {string} chr The matched character to escape.
   * @returns {string} Returns the escaped character.
   */
  function escapeHtmlChar(chr) {
    return htmlEscapes[chr];
  }

  /**
   * Used by `_.escapeRegExp` to escape characters for inclusion in compiled regexes.
   *
   * @private
   * @param {string} chr The matched character to escape.
   * @param {string} leadingChar The capture group for a leading character.
   * @param {string} whitespaceChar The capture group for a whitespace character.
   * @returns {string} Returns the escaped character.
   */
  function escapeRegExpChar(chr, leadingChar, whitespaceChar) {
    if (leadingChar) {
      chr = regexpEscapes[chr];
    } else if (whitespaceChar) {
      chr = stringEscapes[chr];
    }
    return '\\' + chr;
  }

  /**
   * Used by `_.template` to escape characters for inclusion in compiled string literals.
   *
   * @private
   * @param {string} chr The matched character to escape.
   * @returns {string} Returns the escaped character.
   */
  function escapeStringChar(chr) {
    return '\\' + stringEscapes[chr];
  }

  /**
   * Gets the index at which the first occurrence of `NaN` is found in `array`.
   *
   * @private
   * @param {Array} array The array to search.
   * @param {number} fromIndex The index to search from.
   * @param {boolean} [fromRight] Specify iterating from right to left.
   * @returns {number} Returns the index of the matched `NaN`, else `-1`.
   */
  function indexOfNaN(array, fromIndex, fromRight) {
    var length = array.length,
        index = fromIndex + (fromRight ? 0 : -1);

    while ((fromRight ? index-- : ++index < length)) {
      var other = array[index];
      if (other !== other) {
        return index;
      }
    }
    return -1;
  }

  /**
   * Checks if `value` is object-like.
   *
   * @private
   * @param {*} value The value to check.
   * @returns {boolean} Returns `true` if `value` is object-like, else `false`.
   */
  function isObjectLike(value) {
    return !!value && typeof value == 'object';
  }

  /**
   * Used by `trimmedLeftIndex` and `trimmedRightIndex` to determine if a
   * character code is whitespace.
   *
   * @private
   * @param {number} charCode The character code to inspect.
   * @returns {boolean} Returns `true` if `charCode` is whitespace, else `false`.
   */
  function isSpace(charCode) {
    return ((charCode <= 160 && (charCode >= 9 && charCode <= 13) || charCode == 32 || charCode == 160) || charCode == 5760 || charCode == 6158 ||
      (charCode >= 8192 && (charCode <= 8202 || charCode == 8232 || charCode == 8233 || charCode == 8239 || charCode == 8287 || charCode == 12288 || charCode == 65279)));
  }

  /**
   * Replaces all `placeholder` elements in `array` with an internal placeholder
   * and returns an array of their indexes.
   *
   * @private
   * @param {Array} array The array to modify.
   * @param {*} placeholder The placeholder to replace.
   * @returns {Array} Returns the new array of placeholder indexes.
   */
  function replaceHolders(array, placeholder) {
    var index = -1,
        length = array.length,
        resIndex = -1,
        result = [];

    while (++index < length) {
      if (array[index] === placeholder) {
        array[index] = PLACEHOLDER;
        result[++resIndex] = index;
      }
    }
    return result;
  }

  /**
   * An implementation of `_.uniq` optimized for sorted arrays without support
   * for callback shorthands and `this` binding.
   *
   * @private
   * @param {Array} array The array to inspect.
   * @param {Function} [iteratee] The function invoked per iteration.
   * @returns {Array} Returns the new duplicate-value-free array.
   */
  function sortedUniq(array, iteratee) {
    var seen,
        index = -1,
        length = array.length,
        resIndex = -1,
        result = [];

    while (++index < length) {
      var value = array[index],
          computed = iteratee ? iteratee(value, index, array) : value;

      if (!index || seen !== computed) {
        seen = computed;
        result[++resIndex] = value;
      }
    }
    return result;
  }

  /**
   * Used by `_.trim` and `_.trimLeft` to get the index of the first non-whitespace
   * character of `string`.
   *
   * @private
   * @param {string} string The string to inspect.
   * @returns {number} Returns the index of the first non-whitespace character.
   */
  function trimmedLeftIndex(string) {
    var index = -1,
        length = string.length;

    while (++index < length && isSpace(string.charCodeAt(index))) {}
    return index;
  }

  /**
   * Used by `_.trim` and `_.trimRight` to get the index of the last non-whitespace
   * character of `string`.
   *
   * @private
   * @param {string} string The string to inspect.
   * @returns {number} Returns the index of the last non-whitespace character.
   */
  function trimmedRightIndex(string) {
    var index = string.length;

    while (index-- && isSpace(string.charCodeAt(index))) {}
    return index;
  }

  /**
   * Used by `_.unescape` to convert HTML entities to characters.
   *
   * @private
   * @param {string} chr The matched character to unescape.
   * @returns {string} Returns the unescaped character.
   */
  function unescapeHtmlChar(chr) {
    return htmlUnescapes[chr];
  }

  /*--------------------------------------------------------------------------*/

  /**
   * Create a new pristine `lodash` function using the given `context` object.
   *
   * @static
   * @memberOf _
   * @category Utility
   * @param {Object} [context=root] The context object.
   * @returns {Function} Returns a new `lodash` function.
   * @example
   *
   * _.mixin({ 'foo': _.constant('foo') });
   *
   * var lodash = _.runInContext();
   * lodash.mixin({ 'bar': lodash.constant('bar') });
   *
   * _.isFunction(_.foo);
   * // => true
   * _.isFunction(_.bar);
   * // => false
   *
   * lodash.isFunction(lodash.foo);
   * // => false
   * lodash.isFunction(lodash.bar);
   * // => true
   *
   * // using `context` to mock `Date#getTime` use in `_.now`
   * var mock = _.runInContext({
   *   'Date': function() {
   *     return { 'getTime': getTimeMock };
   *   }
   * });
   *
   * // or creating a suped-up `defer` in Node.js
   * var defer = _.runInContext({ 'setTimeout': setImmediate }).defer;
   */
  function runInContext(context) {
    // Avoid issues with some ES3 environments that attempt to use values, named
    // after built-in constructors like `Object`, for the creation of literals.
    // ES5 clears this up by stating that literals must use built-in constructors.
    // See https://es5.github.io/#x11.1.5 for more details.
    context = context ? _.defaults(root.Object(), context, _.pick(root, contextProps)) : root;

    /** Native constructor references. */
    var Array = context.Array,
        Date = context.Date,
        Error = context.Error,
        Function = context.Function,
        Math = context.Math,
        Number = context.Number,
        Object = context.Object,
        RegExp = context.RegExp,
        String = context.String,
        TypeError = context.TypeError;

    /** Used for native method references. */
    var arrayProto = Array.prototype,
        objectProto = Object.prototype,
        stringProto = String.prototype;

    /** Used to resolve the decompiled source of functions. */
    var fnToString = Function.prototype.toString;

    /** Used to check objects for own properties. */
    var hasOwnProperty = objectProto.hasOwnProperty;

    /** Used to generate unique IDs. */
    var idCounter = 0;

    /**
     * Used to resolve the [`toStringTag`](http://ecma-international.org/ecma-262/6.0/#sec-object.prototype.tostring)
     * of values.
     */
    var objToString = objectProto.toString;

    /** Used to restore the original `_` reference in `_.noConflict`. */
    var oldDash = root._;

    /** Used to detect if a method is native. */
    var reIsNative = RegExp('^' +
      fnToString.call(hasOwnProperty).replace(/[\\^$.*+?()[\]{}|]/g, '\\$&')
      .replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, '$1.*?') + '$'
    );

    /** Native method references. */
    var ArrayBuffer = context.ArrayBuffer,
        clearTimeout = context.clearTimeout,
        parseFloat = context.parseFloat,
        pow = Math.pow,
        propertyIsEnumerable = objectProto.propertyIsEnumerable,
        Set = getNative(context, 'Set'),
        setTimeout = context.setTimeout,
        splice = arrayProto.splice,
        Uint8Array = context.Uint8Array,
        WeakMap = getNative(context, 'WeakMap');

    /* Native method references for those with the same name as other `lodash` methods. */
    var nativeCeil = Math.ceil,
        nativeCreate = getNative(Object, 'create'),
        nativeFloor = Math.floor,
        nativeIsArray = getNative(Array, 'isArray'),
        nativeIsFinite = context.isFinite,
        nativeKeys = getNative(Object, 'keys'),
        nativeMax = Math.max,
        nativeMin = Math.min,
        nativeNow = getNative(Date, 'now'),
        nativeParseInt = context.parseInt,
        nativeRandom = Math.random;

    /** Used as references for `-Infinity` and `Infinity`. */
    var NEGATIVE_INFINITY = Number.NEGATIVE_INFINITY,
        POSITIVE_INFINITY = Number.POSITIVE_INFINITY;

    /** Used as references for the maximum length and index of an array. */
    var MAX_ARRAY_LENGTH = 4294967295,
        MAX_ARRAY_INDEX = MAX_ARRAY_LENGTH - 1,
        HALF_MAX_ARRAY_LENGTH = MAX_ARRAY_LENGTH >>> 1;

    /**
     * Used as the [maximum length](http://ecma-international.org/ecma-262/6.0/#sec-number.max_safe_integer)
     * of an array-like value.
     */
    var MAX_SAFE_INTEGER = 9007199254740991;

    /** Used to store function metadata. */
    var metaMap = WeakMap && new WeakMap;

    /** Used to lookup unminified function names. */
    var realNames = {};

    /*------------------------------------------------------------------------*/

    /**
     * Creates a `lodash` object which wraps `value` to enable implicit chaining.
     * Methods that operate on and return arrays, collections, and functions can
     * be chained together. Methods that retrieve a single value or may return a
     * primitive value will automatically end the chain returning the unwrapped
     * value. Explicit chaining may be enabled using `_.chain`. The execution of
     * chained methods is lazy, that is, execution is deferred until `_#value`
     * is implicitly or explicitly called.
     *
     * Lazy evaluation allows several methods to support shortcut fusion. Shortcut
     * fusion is an optimization strategy which merge iteratee calls; this can help
     * to avoid the creation of intermediate data structures and greatly reduce the
     * number of iteratee executions.
     *
     * Chaining is supported in custom builds as long as the `_#value` method is
     * directly or indirectly included in the build.
     *
     * In addition to lodash methods, wrappers have `Array` and `String` methods.
     *
     * The wrapper `Array` methods are:
     * `concat`, `join`, `pop`, `push`, `reverse`, `shift`, `slice`, `sort`,
     * `splice`, and `unshift`
     *
     * The wrapper `String` methods are:
     * `replace` and `split`
     *
     * The wrapper methods that support shortcut fusion are:
     * `compact`, `drop`, `dropRight`, `dropRightWhile`, `dropWhile`, `filter`,
     * `first`, `initial`, `last`, `map`, `pluck`, `reject`, `rest`, `reverse`,
     * `slice`, `take`, `takeRight`, `takeRightWhile`, `takeWhile`, `toArray`,
     * and `where`
     *
     * The chainable wrapper methods are:
     * `after`, `ary`, `assign`, `at`, `before`, `bind`, `bindAll`, `bindKey`,
     * `callback`, `chain`, `chunk`, `commit`, `compact`, `concat`, `constant`,
     * `countBy`, `create`, `curry`, `debounce`, `defaults`, `defaultsDeep`,
     * `defer`, `delay`, `difference`, `drop`, `dropRight`, `dropRightWhile`,
     * `dropWhile`, `fill`, `filter`, `flatten`, `flattenDeep`, `flow`, `flowRight`,
     * `forEach`, `forEachRight`, `forIn`, `forInRight`, `forOwn`, `forOwnRight`,
     * `functions`, `groupBy`, `indexBy`, `initial`, `intersection`, `invert`,
     * `invoke`, `keys`, `keysIn`, `map`, `mapKeys`, `mapValues`, `matches`,
     * `matchesProperty`, `memoize`, `merge`, `method`, `methodOf`, `mixin`,
     * `modArgs`, `negate`, `omit`, `once`, `pairs`, `partial`, `partialRight`,
     * `partition`, `pick`, `plant`, `pluck`, `property`, `propertyOf`, `pull`,
     * `pullAt`, `push`, `range`, `rearg`, `reject`, `remove`, `rest`, `restParam`,
     * `reverse`, `set`, `shuffle`, `slice`, `sort`, `sortBy`, `sortByAll`,
     * `sortByOrder`, `splice`, `spread`, `take`, `takeRight`, `takeRightWhile`,
     * `takeWhile`, `tap`, `throttle`, `thru`, `times`, `toArray`, `toPlainObject`,
     * `transform`, `union`, `uniq`, `unshift`, `unzip`, `unzipWith`, `values`,
     * `valuesIn`, `where`, `without`, `wrap`, `xor`, `zip`, `zipObject`, `zipWith`
     *
     * The wrapper methods that are **not** chainable by default are:
     * `add`, `attempt`, `camelCase`, `capitalize`, `ceil`, `clone`, `cloneDeep`,
     * `deburr`, `endsWith`, `escape`, `escapeRegExp`, `every`, `find`, `findIndex`,
     * `findKey`, `findLast`, `findLastIndex`, `findLastKey`, `findWhere`, `first`,
     * `floor`, `get`, `gt`, `gte`, `has`, `identity`, `includes`, `indexOf`,
     * `inRange`, `isArguments`, `isArray`, `isBoolean`, `isDate`, `isElement`,
     * `isEmpty`, `isEqual`, `isError`, `isFinite` `isFunction`, `isMatch`,
     * `isNative`, `isNaN`, `isNull`, `isNumber`, `isObject`, `isPlainObject`,
     * `isRegExp`, `isString`, `isUndefined`, `isTypedArray`, `join`, `kebabCase`,
     * `last`, `lastIndexOf`, `lt`, `lte`, `max`, `min`, `noConflict`, `noop`,
     * `now`, `pad`, `padLeft`, `padRight`, `parseInt`, `pop`, `random`, `reduce`,
     * `reduceRight`, `repeat`, `result`, `round`, `runInContext`, `shift`, `size`,
     * `snakeCase`, `some`, `sortedIndex`, `sortedLastIndex`, `startCase`,
     * `startsWith`, `sum`, `template`, `trim`, `trimLeft`, `trimRight`, `trunc`,
     * `unescape`, `uniqueId`, `value`, and `words`
     *
     * The wrapper method `sample` will return a wrapped value when `n` is provided,
     * otherwise an unwrapped value is returned.
     *
     * @name _
     * @constructor
     * @category Chain
     * @param {*} value The value to wrap in a `lodash` instance.
     * @returns {Object} Returns the new `lodash` wrapper instance.
     * @example
     *
     * var wrapped = _([1, 2, 3]);
     *
     * // returns an unwrapped value
     * wrapped.reduce(function(total, n) {
     *   return total + n;
     * });
     * // => 6
     *
     * // returns a wrapped value
     * var squares = wrapped.map(function(n) {
     *   return n * n;
     * });
     *
     * _.isArray(squares);
     * // => false
     *
     * _.isArray(squares.value());
     * // => true
     */
    function lodash(value) {
      if (isObjectLike(value) && !isArray(value) && !(value instanceof LazyWrapper)) {
        if (value instanceof LodashWrapper) {
          return value;
        }
        if (hasOwnProperty.call(value, '__chain__') && hasOwnProperty.call(value, '__wrapped__')) {
          return wrapperClone(value);
        }
      }
      return new LodashWrapper(value);
    }

    /**
     * The function whose prototype all chaining wrappers inherit from.
     *
     * @private
     */
    function baseLodash() {
      // No operation performed.
    }

    /**
     * The base constructor for creating `lodash` wrapper objects.
     *
     * @private
     * @param {*} value The value to wrap.
     * @param {boolean} [chainAll] Enable chaining for all wrapper methods.
     * @param {Array} [actions=[]] Actions to peform to resolve the unwrapped value.
     */
    function LodashWrapper(value, chainAll, actions) {
      this.__wrapped__ = value;
      this.__actions__ = actions || [];
      this.__chain__ = !!chainAll;
    }

    /**
     * An object environment feature flags.
     *
     * @static
     * @memberOf _
     * @type Object
     */
    var support = lodash.support = {};

    /**
     * By default, the template delimiters used by lodash are like those in
     * embedded Ruby (ERB). Change the following template settings to use
     * alternative delimiters.
     *
     * @static
     * @memberOf _
     * @type Object
     */
    lodash.templateSettings = {

      /**
       * Used to detect `data` property values to be HTML-escaped.
       *
       * @memberOf _.templateSettings
       * @type RegExp
       */
      'escape': reEscape,

      /**
       * Used to detect code to be evaluated.
       *
       * @memberOf _.templateSettings
       * @type RegExp
       */
      'evaluate': reEvaluate,

      /**
       * Used to detect `data` property values to inject.
       *
       * @memberOf _.templateSettings
       * @type RegExp
       */
      'interpolate': reInterpolate,

      /**
       * Used to reference the data object in the template text.
       *
       * @memberOf _.templateSettings
       * @type string
       */
      'variable': '',

      /**
       * Used to import variables into the compiled template.
       *
       * @memberOf _.templateSettings
       * @type Object
       */
      'imports': {

        /**
         * A reference to the `lodash` function.
         *
         * @memberOf _.templateSettings.imports
         * @type Function
         */
        '_': lodash
      }
    };

    /*------------------------------------------------------------------------*/

    /**
     * Creates a lazy wrapper object which wraps `value` to enable lazy evaluation.
     *
     * @private
     * @param {*} value The value to wrap.
     */
    function LazyWrapper(value) {
      this.__wrapped__ = value;
      this.__actions__ = [];
      this.__dir__ = 1;
      this.__filtered__ = false;
      this.__iteratees__ = [];
      this.__takeCount__ = POSITIVE_INFINITY;
      this.__views__ = [];
    }

    /**
     * Creates a clone of the lazy wrapper object.
     *
     * @private
     * @name clone
     * @memberOf LazyWrapper
     * @returns {Object} Returns the cloned `LazyWrapper` object.
     */
    function lazyClone() {
      var result = new LazyWrapper(this.__wrapped__);
      result.__actions__ = arrayCopy(this.__actions__);
      result.__dir__ = this.__dir__;
      result.__filtered__ = this.__filtered__;
      result.__iteratees__ = arrayCopy(this.__iteratees__);
      result.__takeCount__ = this.__takeCount__;
      result.__views__ = arrayCopy(this.__views__);
      return result;
    }

    /**
     * Reverses the direction of lazy iteration.
     *
     * @private
     * @name reverse
     * @memberOf LazyWrapper
     * @returns {Object} Returns the new reversed `LazyWrapper` object.
     */
    function lazyReverse() {
      if (this.__filtered__) {
        var result = new LazyWrapper(this);
        result.__dir__ = -1;
        result.__filtered__ = true;
      } else {
        result = this.clone();
        result.__dir__ *= -1;
      }
      return result;
    }

    /**
     * Extracts the unwrapped value from its lazy wrapper.
     *
     * @private
     * @name value
     * @memberOf LazyWrapper
     * @returns {*} Returns the unwrapped value.
     */
    function lazyValue() {
      var array = this.__wrapped__.value(),
          dir = this.__dir__,
          isArr = isArray(array),
          isRight = dir < 0,
          arrLength = isArr ? array.length : 0,
          view = getView(0, arrLength, this.__views__),
          start = view.start,
          end = view.end,
          length = end - start,
          index = isRight ? end : (start - 1),
          iteratees = this.__iteratees__,
          iterLength = iteratees.length,
          resIndex = 0,
          takeCount = nativeMin(length, this.__takeCount__);

      if (!isArr || arrLength < LARGE_ARRAY_SIZE || (arrLength == length && takeCount == length)) {
        return baseWrapperValue((isRight && isArr) ? array.reverse() : array, this.__actions__);
      }
      var result = [];

      outer:
      while (length-- && resIndex < takeCount) {
        index += dir;

        var iterIndex = -1,
            value = array[index];

        while (++iterIndex < iterLength) {
          var data = iteratees[iterIndex],
              iteratee = data.iteratee,
              type = data.type,
              computed = iteratee(value);

          if (type == LAZY_MAP_FLAG) {
            value = computed;
          } else if (!computed) {
            if (type == LAZY_FILTER_FLAG) {
              continue outer;
            } else {
              break outer;
            }
          }
        }
        result[resIndex++] = value;
      }
      return result;
    }

    /*------------------------------------------------------------------------*/

    /**
     * Creates a cache object to store key/value pairs.
     *
     * @private
     * @static
     * @name Cache
     * @memberOf _.memoize
     */
    function MapCache() {
      this.__data__ = {};
    }

    /**
     * Removes `key` and its value from the cache.
     *
     * @private
     * @name delete
     * @memberOf _.memoize.Cache
     * @param {string} key The key of the value to remove.
     * @returns {boolean} Returns `true` if the entry was removed successfully, else `false`.
     */
    function mapDelete(key) {
      return this.has(key) && delete this.__data__[key];
    }

    /**
     * Gets the cached value for `key`.
     *
     * @private
     * @name get
     * @memberOf _.memoize.Cache
     * @param {string} key The key of the value to get.
     * @returns {*} Returns the cached value.
     */
    function mapGet(key) {
      return key == '__proto__' ? undefined : this.__data__[key];
    }

    /**
     * Checks if a cached value for `key` exists.
     *
     * @private
     * @name has
     * @memberOf _.memoize.Cache
     * @param {string} key The key of the entry to check.
     * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
     */
    function mapHas(key) {
      return key != '__proto__' && hasOwnProperty.call(this.__data__, key);
    }

    /**
     * Sets `value` to `key` of the cache.
     *
     * @private
     * @name set
     * @memberOf _.memoize.Cache
     * @param {string} key The key of the value to cache.
     * @param {*} value The value to cache.
     * @returns {Object} Returns the cache object.
     */
    function mapSet(key, value) {
      if (key != '__proto__') {
        this.__data__[key] = value;
      }
      return this;
    }

    /*------------------------------------------------------------------------*/

    /**
     *
     * Creates a cache object to store unique values.
     *
     * @private
     * @param {Array} [values] The values to cache.
     */
    function SetCache(values) {
      var length = values ? values.length : 0;

      this.data = { 'hash': nativeCreate(null), 'set': new Set };
      while (length--) {
        this.push(values[length]);
      }
    }

    /**
     * Checks if `value` is in `cache` mimicking the return signature of
     * `_.indexOf` by returning `0` if the value is found, else `-1`.
     *
     * @private
     * @param {Object} cache The cache to search.
     * @param {*} value The value to search for.
     * @returns {number} Returns `0` if `value` is found, else `-1`.
     */
    function cacheIndexOf(cache, value) {
      var data = cache.data,
          result = (typeof value == 'string' || isObject(value)) ? data.set.has(value) : data.hash[value];

      return result ? 0 : -1;
    }

    /**
     * Adds `value` to the cache.
     *
     * @private
     * @name push
     * @memberOf SetCache
     * @param {*} value The value to cache.
     */
    function cachePush(value) {
      var data = this.data;
      if (typeof value == 'string' || isObject(value)) {
        data.set.add(value);
      } else {
        data.hash[value] = true;
      }
    }

    /*------------------------------------------------------------------------*/

    /**
     * Creates a new array joining `array` with `other`.
     *
     * @private
     * @param {Array} array The array to join.
     * @param {Array} other The other array to join.
     * @returns {Array} Returns the new concatenated array.
     */
    function arrayConcat(array, other) {
      var index = -1,
          length = array.length,
          othIndex = -1,
          othLength = other.length,
          result = Array(length + othLength);

      while (++index < length) {
        result[index] = array[index];
      }
      while (++othIndex < othLength) {
        result[index++] = other[othIndex];
      }
      return result;
    }

    /**
     * Copies the values of `source` to `array`.
     *
     * @private
     * @param {Array} source The array to copy values from.
     * @param {Array} [array=[]] The array to copy values to.
     * @returns {Array} Returns `array`.
     */
    function arrayCopy(source, array) {
      var index = -1,
          length = source.length;

      array || (array = Array(length));
      while (++index < length) {
        array[index] = source[index];
      }
      return array;
    }

    /**
     * A specialized version of `_.forEach` for arrays without support for callback
     * shorthands and `this` binding.
     *
     * @private
     * @param {Array} array The array to iterate over.
     * @param {Function} iteratee The function invoked per iteration.
     * @returns {Array} Returns `array`.
     */
    function arrayEach(array, iteratee) {
      var index = -1,
          length = array.length;

      while (++index < length) {
        if (iteratee(array[index], index, array) === false) {
          break;
        }
      }
      return array;
    }

    /**
     * A specialized version of `_.forEachRight` for arrays without support for
     * callback shorthands and `this` binding.
     *
     * @private
     * @param {Array} array The array to iterate over.
     * @param {Function} iteratee The function invoked per iteration.
     * @returns {Array} Returns `array`.
     */
    function arrayEachRight(array, iteratee) {
      var length = array.length;

      while (length--) {
        if (iteratee(array[length], length, array) === false) {
          break;
        }
      }
      return array;
    }

    /**
     * A specialized version of `_.every` for arrays without support for callback
     * shorthands and `this` binding.
     *
     * @private
     * @param {Array} array The array to iterate over.
     * @param {Function} predicate The function invoked per iteration.
     * @returns {boolean} Returns `true` if all elements pass the predicate check,
     *  else `false`.
     */
    function arrayEvery(array, predicate) {
      var index = -1,
          length = array.length;

      while (++index < length) {
        if (!predicate(array[index], index, array)) {
          return false;
        }
      }
      return true;
    }

    /**
     * A specialized version of `baseExtremum` for arrays which invokes `iteratee`
     * with one argument: (value).
     *
     * @private
     * @param {Array} array The array to iterate over.
     * @param {Function} iteratee The function invoked per iteration.
     * @param {Function} comparator The function used to compare values.
     * @param {*} exValue The initial extremum value.
     * @returns {*} Returns the extremum value.
     */
    function arrayExtremum(array, iteratee, comparator, exValue) {
      var index = -1,
          length = array.length,
          computed = exValue,
          result = computed;

      while (++index < length) {
        var value = array[index],
            current = +iteratee(value);

        if (comparator(current, computed)) {
          computed = current;
          result = value;
        }
      }
      return result;
    }

    /**
     * A specialized version of `_.filter` for arrays without support for callback
     * shorthands and `this` binding.
     *
     * @private
     * @param {Array} array The array to iterate over.
     * @param {Function} predicate The function invoked per iteration.
     * @returns {Array} Returns the new filtered array.
     */
    function arrayFilter(array, predicate) {
      var index = -1,
          length = array.length,
          resIndex = -1,
          result = [];

      while (++index < length) {
        var value = array[index];
        if (predicate(value, index, array)) {
          result[++resIndex] = value;
        }
      }
      return result;
    }

    /**
     * A specialized version of `_.map` for arrays without support for callback
     * shorthands and `this` binding.
     *
     * @private
     * @param {Array} array The array to iterate over.
     * @param {Function} iteratee The function invoked per iteration.
     * @returns {Array} Returns the new mapped array.
     */
    function arrayMap(array, iteratee) {
      var index = -1,
          length = array.length,
          result = Array(length);

      while (++index < length) {
        result[index] = iteratee(array[index], index, array);
      }
      return result;
    }

    /**
     * Appends the elements of `values` to `array`.
     *
     * @private
     * @param {Array} array The array to modify.
     * @param {Array} values The values to append.
     * @returns {Array} Returns `array`.
     */
    function arrayPush(array, values) {
      var index = -1,
          length = values.length,
          offset = array.length;

      while (++index < length) {
        array[offset + index] = values[index];
      }
      return array;
    }

    /**
     * A specialized version of `_.reduce` for arrays without support for callback
     * shorthands and `this` binding.
     *
     * @private
     * @param {Array} array The array to iterate over.
     * @param {Function} iteratee The function invoked per iteration.
     * @param {*} [accumulator] The initial value.
     * @param {boolean} [initFromArray] Specify using the first element of `array`
     *  as the initial value.
     * @returns {*} Returns the accumulated value.
     */
    function arrayReduce(array, iteratee, accumulator, initFromArray) {
      var index = -1,
          length = array.length;

      if (initFromArray && length) {
        accumulator = array[++index];
      }
      while (++index < length) {
        accumulator = iteratee(accumulator, array[index], index, array);
      }
      return accumulator;
    }

    /**
     * A specialized version of `_.reduceRight` for arrays without support for
     * callback shorthands and `this` binding.
     *
     * @private
     * @param {Array} array The array to iterate over.
     * @param {Function} iteratee The function invoked per iteration.
     * @param {*} [accumulator] The initial value.
     * @param {boolean} [initFromArray] Specify using the last element of `array`
     *  as the initial value.
     * @returns {*} Returns the accumulated value.
     */
    function arrayReduceRight(array, iteratee, accumulator, initFromArray) {
      var length = array.length;
      if (initFromArray && length) {
        accumulator = array[--length];
      }
      while (length--) {
        accumulator = iteratee(accumulator, array[length], length, array);
      }
      return accumulator;
    }

    /**
     * A specialized version of `_.some` for arrays without support for callback
     * shorthands and `this` binding.
     *
     * @private
     * @param {Array} array The array to iterate over.
     * @param {Function} predicate The function invoked per iteration.
     * @returns {boolean} Returns `true` if any element passes the predicate check,
     *  else `false`.
     */
    function arraySome(array, predicate) {
      var index = -1,
          length = array.length;

      while (++index < length) {
        if (predicate(array[index], index, array)) {
          return true;
        }
      }
      return false;
    }

    /**
     * A specialized version of `_.sum` for arrays without support for callback
     * shorthands and `this` binding..
     *
     * @private
     * @param {Array} array The array to iterate over.
     * @param {Function} iteratee The function invoked per iteration.
     * @returns {number} Returns the sum.
     */
    function arraySum(array, iteratee) {
      var length = array.length,
          result = 0;

      while (length--) {
        result += +iteratee(array[length]) || 0;
      }
      return result;
    }

    /**
     * Used by `_.defaults` to customize its `_.assign` use.
     *
     * @private
     * @param {*} objectValue The destination object property value.
     * @param {*} sourceValue The source object property value.
     * @returns {*} Returns the value to assign to the destination object.
     */
    function assignDefaults(objectValue, sourceValue) {
      return objectValue === undefined ? sourceValue : objectValue;
    }

    /**
     * Used by `_.template` to customize its `_.assign` use.
     *
     * **Note:** This function is like `assignDefaults` except that it ignores
     * inherited property values when checking if a property is `undefined`.
     *
     * @private
     * @param {*} objectValue The destination object property value.
     * @param {*} sourceValue The source object property value.
     * @param {string} key The key associated with the object and source values.
     * @param {Object} object The destination object.
     * @returns {*} Returns the value to assign to the destination object.
     */
    function assignOwnDefaults(objectValue, sourceValue, key, object) {
      return (objectValue === undefined || !hasOwnProperty.call(object, key))
        ? sourceValue
        : objectValue;
    }

    /**
     * A specialized version of `_.assign` for customizing assigned values without
     * support for argument juggling, multiple sources, and `this` binding `customizer`
     * functions.
     *
     * @private
     * @param {Object} object The destination object.
     * @param {Object} source The source object.
     * @param {Function} customizer The function to customize assigned values.
     * @returns {Object} Returns `object`.
     */
    function assignWith(object, source, customizer) {
      var index = -1,
          props = keys(source),
          length = props.length;

      while (++index < length) {
        var key = props[index],
            value = object[key],
            result = customizer(value, source[key], key, object, source);

        if ((result === result ? (result !== value) : (value === value)) ||
            (value === undefined && !(key in object))) {
          object[key] = result;
        }
      }
      return object;
    }

    /**
     * The base implementation of `_.assign` without support for argument juggling,
     * multiple sources, and `customizer` functions.
     *
     * @private
     * @param {Object} object The destination object.
     * @param {Object} source The source object.
     * @returns {Object} Returns `object`.
     */
    function baseAssign(object, source) {
      return source == null
        ? object
        : baseCopy(source, keys(source), object);
    }

    /**
     * The base implementation of `_.at` without support for string collections
     * and individual key arguments.
     *
     * @private
     * @param {Array|Object} collection The collection to iterate over.
     * @param {number[]|string[]} props The property names or indexes of elements to pick.
     * @returns {Array} Returns the new array of picked elements.
     */
    function baseAt(collection, props) {
      var index = -1,
          isNil = collection == null,
          isArr = !isNil && isArrayLike(collection),
          length = isArr ? collection.length : 0,
          propsLength = props.length,
          result = Array(propsLength);

      while(++index < propsLength) {
        var key = props[index];
        if (isArr) {
          result[index] = isIndex(key, length) ? collection[key] : undefined;
        } else {
          result[index] = isNil ? undefined : collection[key];
        }
      }
      return result;
    }

    /**
     * Copies properties of `source` to `object`.
     *
     * @private
     * @param {Object} source The object to copy properties from.
     * @param {Array} props The property names to copy.
     * @param {Object} [object={}] The object to copy properties to.
     * @returns {Object} Returns `object`.
     */
    function baseCopy(source, props, object) {
      object || (object = {});

      var index = -1,
          length = props.length;

      while (++index < length) {
        var key = props[index];
        object[key] = source[key];
      }
      return object;
    }

    /**
     * The base implementation of `_.callback` which supports specifying the
     * number of arguments to provide to `func`.
     *
     * @private
     * @param {*} [func=_.identity] The value to convert to a callback.
     * @param {*} [thisArg] The `this` binding of `func`.
     * @param {number} [argCount] The number of arguments to provide to `func`.
     * @returns {Function} Returns the callback.
     */
    function baseCallback(func, thisArg, argCount) {
      var type = typeof func;
      if (type == 'function') {
        return thisArg === undefined
          ? func
          : bindCallback(func, thisArg, argCount);
      }
      if (func == null) {
        return identity;
      }
      if (type == 'object') {
        return baseMatches(func);
      }
      return thisArg === undefined
        ? property(func)
        : baseMatchesProperty(func, thisArg);
    }

    /**
     * The base implementation of `_.clone` without support for argument juggling
     * and `this` binding `customizer` functions.
     *
     * @private
     * @param {*} value The value to clone.
     * @param {boolean} [isDeep] Specify a deep clone.
     * @param {Function} [customizer] The function to customize cloning values.
     * @param {string} [key] The key of `value`.
     * @param {Object} [object] The object `value` belongs to.
     * @param {Array} [stackA=[]] Tracks traversed source objects.
     * @param {Array} [stackB=[]] Associates clones with source counterparts.
     * @returns {*} Returns the cloned value.
     */
    function baseClone(value, isDeep, customizer, key, object, stackA, stackB) {
      var result;
      if (customizer) {
        result = object ? customizer(value, key, object) : customizer(value);
      }
      if (result !== undefined) {
        return result;
      }
      if (!isObject(value)) {
        return value;
      }
      var isArr = isArray(value);
      if (isArr) {
        result = initCloneArray(value);
        if (!isDeep) {
          return arrayCopy(value, result);
        }
      } else {
        var tag = objToString.call(value),
            isFunc = tag == funcTag;

        if (tag == objectTag || tag == argsTag || (isFunc && !object)) {
          result = initCloneObject(isFunc ? {} : value);
          if (!isDeep) {
            return baseAssign(result, value);
          }
        } else {
          return cloneableTags[tag]
            ? initCloneByTag(value, tag, isDeep)
            : (object ? value : {});
        }
      }
      // Check for circular references and return its corresponding clone.
      stackA || (stackA = []);
      stackB || (stackB = []);

      var length = stackA.length;
      while (length--) {
        if (stackA[length] == value) {
          return stackB[length];
        }
      }
      // Add the source value to the stack of traversed objects and associate it with its clone.
      stackA.push(value);
      stackB.push(result);

      // Recursively populate clone (susceptible to call stack limits).
      (isArr ? arrayEach : baseForOwn)(value, function(subValue, key) {
        result[key] = baseClone(subValue, isDeep, customizer, key, value, stackA, stackB);
      });
      return result;
    }

    /**
     * The base implementation of `_.create` without support for assigning
     * properties to the created object.
     *
     * @private
     * @param {Object} prototype The object to inherit from.
     * @returns {Object} Returns the new object.
     */
    var baseCreate = (function() {
      function object() {}
      return function(prototype) {
        if (isObject(prototype)) {
          object.prototype = prototype;
          var result = new object;
          object.prototype = undefined;
        }
        return result || {};
      };
    }());

    /**
     * The base implementation of `_.delay` and `_.defer` which accepts an index
     * of where to slice the arguments to provide to `func`.
     *
     * @private
     * @param {Function} func The function to delay.
     * @param {number} wait The number of milliseconds to delay invocation.
     * @param {Object} args The arguments provide to `func`.
     * @returns {number} Returns the timer id.
     */
    function baseDelay(func, wait, args) {
      if (typeof func != 'function') {
        throw new TypeError(FUNC_ERROR_TEXT);
      }
      return setTimeout(function() { func.apply(undefined, args); }, wait);
    }

    /**
     * The base implementation of `_.difference` which accepts a single array
     * of values to exclude.
     *
     * @private
     * @param {Array} array The array to inspect.
     * @param {Array} values The values to exclude.
     * @returns {Array} Returns the new array of filtered values.
     */
    function baseDifference(array, values) {
      var length = array ? array.length : 0,
          result = [];

      if (!length) {
        return result;
      }
      var index = -1,
          indexOf = getIndexOf(),
          isCommon = indexOf == baseIndexOf,
          cache = (isCommon && values.length >= LARGE_ARRAY_SIZE) ? createCache(values) : null,
          valuesLength = values.length;

      if (cache) {
        indexOf = cacheIndexOf;
        isCommon = false;
        values = cache;
      }
      outer:
      while (++index < length) {
        var value = array[index];

        if (isCommon && value === value) {
          var valuesIndex = valuesLength;
          while (valuesIndex--) {
            if (values[valuesIndex] === value) {
              continue outer;
            }
          }
          result.push(value);
        }
        else if (indexOf(values, value, 0) < 0) {
          result.push(value);
        }
      }
      return result;
    }

    /**
     * The base implementation of `_.forEach` without support for callback
     * shorthands and `this` binding.
     *
     * @private
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function} iteratee The function invoked per iteration.
     * @returns {Array|Object|string} Returns `collection`.
     */
    var baseEach = createBaseEach(baseForOwn);

    /**
     * The base implementation of `_.forEachRight` without support for callback
     * shorthands and `this` binding.
     *
     * @private
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function} iteratee The function invoked per iteration.
     * @returns {Array|Object|string} Returns `collection`.
     */
    var baseEachRight = createBaseEach(baseForOwnRight, true);

    /**
     * The base implementation of `_.every` without support for callback
     * shorthands and `this` binding.
     *
     * @private
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function} predicate The function invoked per iteration.
     * @returns {boolean} Returns `true` if all elements pass the predicate check,
     *  else `false`
     */
    function baseEvery(collection, predicate) {
      var result = true;
      baseEach(collection, function(value, index, collection) {
        result = !!predicate(value, index, collection);
        return result;
      });
      return result;
    }

    /**
     * Gets the extremum value of `collection` invoking `iteratee` for each value
     * in `collection` to generate the criterion by which the value is ranked.
     * The `iteratee` is invoked with three arguments: (value, index|key, collection).
     *
     * @private
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function} iteratee The function invoked per iteration.
     * @param {Function} comparator The function used to compare values.
     * @param {*} exValue The initial extremum value.
     * @returns {*} Returns the extremum value.
     */
    function baseExtremum(collection, iteratee, comparator, exValue) {
      var computed = exValue,
          result = computed;

      baseEach(collection, function(value, index, collection) {
        var current = +iteratee(value, index, collection);
        if (comparator(current, computed) || (current === exValue && current === result)) {
          computed = current;
          result = value;
        }
      });
      return result;
    }

    /**
     * The base implementation of `_.fill` without an iteratee call guard.
     *
     * @private
     * @param {Array} array The array to fill.
     * @param {*} value The value to fill `array` with.
     * @param {number} [start=0] The start position.
     * @param {number} [end=array.length] The end position.
     * @returns {Array} Returns `array`.
     */
    function baseFill(array, value, start, end) {
      var length = array.length;

      start = start == null ? 0 : (+start || 0);
      if (start < 0) {
        start = -start > length ? 0 : (length + start);
      }
      end = (end === undefined || end > length) ? length : (+end || 0);
      if (end < 0) {
        end += length;
      }
      length = start > end ? 0 : (end >>> 0);
      start >>>= 0;

      while (start < length) {
        array[start++] = value;
      }
      return array;
    }

    /**
     * The base implementation of `_.filter` without support for callback
     * shorthands and `this` binding.
     *
     * @private
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function} predicate The function invoked per iteration.
     * @returns {Array} Returns the new filtered array.
     */
    function baseFilter(collection, predicate) {
      var result = [];
      baseEach(collection, function(value, index, collection) {
        if (predicate(value, index, collection)) {
          result.push(value);
        }
      });
      return result;
    }

    /**
     * The base implementation of `_.find`, `_.findLast`, `_.findKey`, and `_.findLastKey`,
     * without support for callback shorthands and `this` binding, which iterates
     * over `collection` using the provided `eachFunc`.
     *
     * @private
     * @param {Array|Object|string} collection The collection to search.
     * @param {Function} predicate The function invoked per iteration.
     * @param {Function} eachFunc The function to iterate over `collection`.
     * @param {boolean} [retKey] Specify returning the key of the found element
     *  instead of the element itself.
     * @returns {*} Returns the found element or its key, else `undefined`.
     */
    function baseFind(collection, predicate, eachFunc, retKey) {
      var result;
      eachFunc(collection, function(value, key, collection) {
        if (predicate(value, key, collection)) {
          result = retKey ? key : value;
          return false;
        }
      });
      return result;
    }

    /**
     * The base implementation of `_.flatten` with added support for restricting
     * flattening and specifying the start index.
     *
     * @private
     * @param {Array} array The array to flatten.
     * @param {boolean} [isDeep] Specify a deep flatten.
     * @param {boolean} [isStrict] Restrict flattening to arrays-like objects.
     * @param {Array} [result=[]] The initial result value.
     * @returns {Array} Returns the new flattened array.
     */
    function baseFlatten(array, isDeep, isStrict, result) {
      result || (result = []);

      var index = -1,
          length = array.length;

      while (++index < length) {
        var value = array[index];
        if (isObjectLike(value) && isArrayLike(value) &&
            (isStrict || isArray(value) || isArguments(value))) {
          if (isDeep) {
            // Recursively flatten arrays (susceptible to call stack limits).
            baseFlatten(value, isDeep, isStrict, result);
          } else {
            arrayPush(result, value);
          }
        } else if (!isStrict) {
          result[result.length] = value;
        }
      }
      return result;
    }

    /**
     * The base implementation of `baseForIn` and `baseForOwn` which iterates
     * over `object` properties returned by `keysFunc` invoking `iteratee` for
     * each property. Iteratee functions may exit iteration early by explicitly
     * returning `false`.
     *
     * @private
     * @param {Object} object The object to iterate over.
     * @param {Function} iteratee The function invoked per iteration.
     * @param {Function} keysFunc The function to get the keys of `object`.
     * @returns {Object} Returns `object`.
     */
    var baseFor = createBaseFor();

    /**
     * This function is like `baseFor` except that it iterates over properties
     * in the opposite order.
     *
     * @private
     * @param {Object} object The object to iterate over.
     * @param {Function} iteratee The function invoked per iteration.
     * @param {Function} keysFunc The function to get the keys of `object`.
     * @returns {Object} Returns `object`.
     */
    var baseForRight = createBaseFor(true);

    /**
     * The base implementation of `_.forIn` without support for callback
     * shorthands and `this` binding.
     *
     * @private
     * @param {Object} object The object to iterate over.
     * @param {Function} iteratee The function invoked per iteration.
     * @returns {Object} Returns `object`.
     */
    function baseForIn(object, iteratee) {
      return baseFor(object, iteratee, keysIn);
    }

    /**
     * The base implementation of `_.forOwn` without support for callback
     * shorthands and `this` binding.
     *
     * @private
     * @param {Object} object The object to iterate over.
     * @param {Function} iteratee The function invoked per iteration.
     * @returns {Object} Returns `object`.
     */
    function baseForOwn(object, iteratee) {
      return baseFor(object, iteratee, keys);
    }

    /**
     * The base implementation of `_.forOwnRight` without support for callback
     * shorthands and `this` binding.
     *
     * @private
     * @param {Object} object The object to iterate over.
     * @param {Function} iteratee The function invoked per iteration.
     * @returns {Object} Returns `object`.
     */
    function baseForOwnRight(object, iteratee) {
      return baseForRight(object, iteratee, keys);
    }

    /**
     * The base implementation of `_.functions` which creates an array of
     * `object` function property names filtered from those provided.
     *
     * @private
     * @param {Object} object The object to inspect.
     * @param {Array} props The property names to filter.
     * @returns {Array} Returns the new array of filtered property names.
     */
    function baseFunctions(object, props) {
      var index = -1,
          length = props.length,
          resIndex = -1,
          result = [];

      while (++index < length) {
        var key = props[index];
        if (isFunction(object[key])) {
          result[++resIndex] = key;
        }
      }
      return result;
    }

    /**
     * The base implementation of `get` without support for string paths
     * and default values.
     *
     * @private
     * @param {Object} object The object to query.
     * @param {Array} path The path of the property to get.
     * @param {string} [pathKey] The key representation of path.
     * @returns {*} Returns the resolved value.
     */
    function baseGet(object, path, pathKey) {
      if (object == null) {
        return;
      }
      if (pathKey !== undefined && pathKey in toObject(object)) {
        path = [pathKey];
      }
      var index = 0,
          length = path.length;

      while (object != null && index < length) {
        object = object[path[index++]];
      }
      return (index && index == length) ? object : undefined;
    }

    /**
     * The base implementation of `_.isEqual` without support for `this` binding
     * `customizer` functions.
     *
     * @private
     * @param {*} value The value to compare.
     * @param {*} other The other value to compare.
     * @param {Function} [customizer] The function to customize comparing values.
     * @param {boolean} [isLoose] Specify performing partial comparisons.
     * @param {Array} [stackA] Tracks traversed `value` objects.
     * @param {Array} [stackB] Tracks traversed `other` objects.
     * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
     */
    function baseIsEqual(value, other, customizer, isLoose, stackA, stackB) {
      if (value === other) {
        return true;
      }
      if (value == null || other == null || (!isObject(value) && !isObjectLike(other))) {
        return value !== value && other !== other;
      }
      return baseIsEqualDeep(value, other, baseIsEqual, customizer, isLoose, stackA, stackB);
    }

    /**
     * A specialized version of `baseIsEqual` for arrays and objects which performs
     * deep comparisons and tracks traversed objects enabling objects with circular
     * references to be compared.
     *
     * @private
     * @param {Object} object The object to compare.
     * @param {Object} other The other object to compare.
     * @param {Function} equalFunc The function to determine equivalents of values.
     * @param {Function} [customizer] The function to customize comparing objects.
     * @param {boolean} [isLoose] Specify performing partial comparisons.
     * @param {Array} [stackA=[]] Tracks traversed `value` objects.
     * @param {Array} [stackB=[]] Tracks traversed `other` objects.
     * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
     */
    function baseIsEqualDeep(object, other, equalFunc, customizer, isLoose, stackA, stackB) {
      var objIsArr = isArray(object),
          othIsArr = isArray(other),
          objTag = arrayTag,
          othTag = arrayTag;

      if (!objIsArr) {
        objTag = objToString.call(object);
        if (objTag == argsTag) {
          objTag = objectTag;
        } else if (objTag != objectTag) {
          objIsArr = isTypedArray(object);
        }
      }
      if (!othIsArr) {
        othTag = objToString.call(other);
        if (othTag == argsTag) {
          othTag = objectTag;
        } else if (othTag != objectTag) {
          othIsArr = isTypedArray(other);
        }
      }
      var objIsObj = objTag == objectTag,
          othIsObj = othTag == objectTag,
          isSameTag = objTag == othTag;

      if (isSameTag && !(objIsArr || objIsObj)) {
        return equalByTag(object, other, objTag);
      }
      if (!isLoose) {
        var objIsWrapped = objIsObj && hasOwnProperty.call(object, '__wrapped__'),
            othIsWrapped = othIsObj && hasOwnProperty.call(other, '__wrapped__');

        if (objIsWrapped || othIsWrapped) {
          return equalFunc(objIsWrapped ? object.value() : object, othIsWrapped ? other.value() : other, customizer, isLoose, stackA, stackB);
        }
      }
      if (!isSameTag) {
        return false;
      }
      // Assume cyclic values are equal.
      // For more information on detecting circular references see https://es5.github.io/#JO.
      stackA || (stackA = []);
      stackB || (stackB = []);

      var length = stackA.length;
      while (length--) {
        if (stackA[length] == object) {
          return stackB[length] == other;
        }
      }
      // Add `object` and `other` to the stack of traversed objects.
      stackA.push(object);
      stackB.push(other);

      var result = (objIsArr ? equalArrays : equalObjects)(object, other, equalFunc, customizer, isLoose, stackA, stackB);

      stackA.pop();
      stackB.pop();

      return result;
    }

    /**
     * The base implementation of `_.isMatch` without support for callback
     * shorthands and `this` binding.
     *
     * @private
     * @param {Object} object The object to inspect.
     * @param {Array} matchData The propery names, values, and compare flags to match.
     * @param {Function} [customizer] The function to customize comparing objects.
     * @returns {boolean} Returns `true` if `object` is a match, else `false`.
     */
    function baseIsMatch(object, matchData, customizer) {
      var index = matchData.length,
          length = index,
          noCustomizer = !customizer;

      if (object == null) {
        return !length;
      }
      object = toObject(object);
      while (index--) {
        var data = matchData[index];
        if ((noCustomizer && data[2])
              ? data[1] !== object[data[0]]
              : !(data[0] in object)
            ) {
          return false;
        }
      }
      while (++index < length) {
        data = matchData[index];
        var key = data[0],
            objValue = object[key],
            srcValue = data[1];

        if (noCustomizer && data[2]) {
          if (objValue === undefined && !(key in object)) {
            return false;
          }
        } else {
          var result = customizer ? customizer(objValue, srcValue, key) : undefined;
          if (!(result === undefined ? baseIsEqual(srcValue, objValue, customizer, true) : result)) {
            return false;
          }
        }
      }
      return true;
    }

    /**
     * The base implementation of `_.map` without support for callback shorthands
     * and `this` binding.
     *
     * @private
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function} iteratee The function invoked per iteration.
     * @returns {Array} Returns the new mapped array.
     */
    function baseMap(collection, iteratee) {
      var index = -1,
          result = isArrayLike(collection) ? Array(collection.length) : [];

      baseEach(collection, function(value, key, collection) {
        result[++index] = iteratee(value, key, collection);
      });
      return result;
    }

    /**
     * The base implementation of `_.matches` which does not clone `source`.
     *
     * @private
     * @param {Object} source The object of property values to match.
     * @returns {Function} Returns the new function.
     */
    function baseMatches(source) {
      var matchData = getMatchData(source);
      if (matchData.length == 1 && matchData[0][2]) {
        var key = matchData[0][0],
            value = matchData[0][1];

        return function(object) {
          if (object == null) {
            return false;
          }
          return object[key] === value && (value !== undefined || (key in toObject(object)));
        };
      }
      return function(object) {
        return baseIsMatch(object, matchData);
      };
    }

    /**
     * The base implementation of `_.matchesProperty` which does not clone `srcValue`.
     *
     * @private
     * @param {string} path The path of the property to get.
     * @param {*} srcValue The value to compare.
     * @returns {Function} Returns the new function.
     */
    function baseMatchesProperty(path, srcValue) {
      var isArr = isArray(path),
          isCommon = isKey(path) && isStrictComparable(srcValue),
          pathKey = (path + '');

      path = toPath(path);
      return function(object) {
        if (object == null) {
          return false;
        }
        var key = pathKey;
        object = toObject(object);
        if ((isArr || !isCommon) && !(key in object)) {
          object = path.length == 1 ? object : baseGet(object, baseSlice(path, 0, -1));
          if (object == null) {
            return false;
          }
          key = last(path);
          object = toObject(object);
        }
        return object[key] === srcValue
          ? (srcValue !== undefined || (key in object))
          : baseIsEqual(srcValue, object[key], undefined, true);
      };
    }

    /**
     * The base implementation of `_.merge` without support for argument juggling,
     * multiple sources, and `this` binding `customizer` functions.
     *
     * @private
     * @param {Object} object The destination object.
     * @param {Object} source The source object.
     * @param {Function} [customizer] The function to customize merged values.
     * @param {Array} [stackA=[]] Tracks traversed source objects.
     * @param {Array} [stackB=[]] Associates values with source counterparts.
     * @returns {Object} Returns `object`.
     */
    function baseMerge(object, source, customizer, stackA, stackB) {
      if (!isObject(object)) {
        return object;
      }
      var isSrcArr = isArrayLike(source) && (isArray(source) || isTypedArray(source)),
          props = isSrcArr ? undefined : keys(source);

      arrayEach(props || source, function(srcValue, key) {
        if (props) {
          key = srcValue;
          srcValue = source[key];
        }
        if (isObjectLike(srcValue)) {
          stackA || (stackA = []);
          stackB || (stackB = []);
          baseMergeDeep(object, source, key, baseMerge, customizer, stackA, stackB);
        }
        else {
          var value = object[key],
              result = customizer ? customizer(value, srcValue, key, object, source) : undefined,
              isCommon = result === undefined;

          if (isCommon) {
            result = srcValue;
          }
          if ((result !== undefined || (isSrcArr && !(key in object))) &&
              (isCommon || (result === result ? (result !== value) : (value === value)))) {
            object[key] = result;
          }
        }
      });
      return object;
    }

    /**
     * A specialized version of `baseMerge` for arrays and objects which performs
     * deep merges and tracks traversed objects enabling objects with circular
     * references to be merged.
     *
     * @private
     * @param {Object} object The destination object.
     * @param {Object} source The source object.
     * @param {string} key The key of the value to merge.
     * @param {Function} mergeFunc The function to merge values.
     * @param {Function} [customizer] The function to customize merged values.
     * @param {Array} [stackA=[]] Tracks traversed source objects.
     * @param {Array} [stackB=[]] Associates values with source counterparts.
     * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
     */
    function baseMergeDeep(object, source, key, mergeFunc, customizer, stackA, stackB) {
      var length = stackA.length,
          srcValue = source[key];

      while (length--) {
        if (stackA[length] == srcValue) {
          object[key] = stackB[length];
          return;
        }
      }
      var value = object[key],
          result = customizer ? customizer(value, srcValue, key, object, source) : undefined,
          isCommon = result === undefined;

      if (isCommon) {
        result = srcValue;
        if (isArrayLike(srcValue) && (isArray(srcValue) || isTypedArray(srcValue))) {
          result = isArray(value)
            ? value
            : (isArrayLike(value) ? arrayCopy(value) : []);
        }
        else if (isPlainObject(srcValue) || isArguments(srcValue)) {
          result = isArguments(value)
            ? toPlainObject(value)
            : (isPlainObject(value) ? value : {});
        }
        else {
          isCommon = false;
        }
      }
      // Add the source value to the stack of traversed objects and associate
      // it with its merged value.
      stackA.push(srcValue);
      stackB.push(result);

      if (isCommon) {
        // Recursively merge objects and arrays (susceptible to call stack limits).
        object[key] = mergeFunc(result, srcValue, customizer, stackA, stackB);
      } else if (result === result ? (result !== value) : (value === value)) {
        object[key] = result;
      }
    }

    /**
     * The base implementation of `_.property` without support for deep paths.
     *
     * @private
     * @param {string} key The key of the property to get.
     * @returns {Function} Returns the new function.
     */
    function baseProperty(key) {
      return function(object) {
        return object == null ? undefined : object[key];
      };
    }

    /**
     * A specialized version of `baseProperty` which supports deep paths.
     *
     * @private
     * @param {Array|string} path The path of the property to get.
     * @returns {Function} Returns the new function.
     */
    function basePropertyDeep(path) {
      var pathKey = (path + '');
      path = toPath(path);
      return function(object) {
        return baseGet(object, path, pathKey);
      };
    }

    /**
     * The base implementation of `_.pullAt` without support for individual
     * index arguments and capturing the removed elements.
     *
     * @private
     * @param {Array} array The array to modify.
     * @param {number[]} indexes The indexes of elements to remove.
     * @returns {Array} Returns `array`.
     */
    function basePullAt(array, indexes) {
      var length = array ? indexes.length : 0;
      while (length--) {
        var index = indexes[length];
        if (index != previous && isIndex(index)) {
          var previous = index;
          splice.call(array, index, 1);
        }
      }
      return array;
    }

    /**
     * The base implementation of `_.random` without support for argument juggling
     * and returning floating-point numbers.
     *
     * @private
     * @param {number} min The minimum possible value.
     * @param {number} max The maximum possible value.
     * @returns {number} Returns the random number.
     */
    function baseRandom(min, max) {
      return min + nativeFloor(nativeRandom() * (max - min + 1));
    }

    /**
     * The base implementation of `_.reduce` and `_.reduceRight` without support
     * for callback shorthands and `this` binding, which iterates over `collection`
     * using the provided `eachFunc`.
     *
     * @private
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function} iteratee The function invoked per iteration.
     * @param {*} accumulator The initial value.
     * @param {boolean} initFromCollection Specify using the first or last element
     *  of `collection` as the initial value.
     * @param {Function} eachFunc The function to iterate over `collection`.
     * @returns {*} Returns the accumulated value.
     */
    function baseReduce(collection, iteratee, accumulator, initFromCollection, eachFunc) {
      eachFunc(collection, function(value, index, collection) {
        accumulator = initFromCollection
          ? (initFromCollection = false, value)
          : iteratee(accumulator, value, index, collection);
      });
      return accumulator;
    }

    /**
     * The base implementation of `setData` without support for hot loop detection.
     *
     * @private
     * @param {Function} func The function to associate metadata with.
     * @param {*} data The metadata.
     * @returns {Function} Returns `func`.
     */
    var baseSetData = !metaMap ? identity : function(func, data) {
      metaMap.set(func, data);
      return func;
    };

    /**
     * The base implementation of `_.slice` without an iteratee call guard.
     *
     * @private
     * @param {Array} array The array to slice.
     * @param {number} [start=0] The start position.
     * @param {number} [end=array.length] The end position.
     * @returns {Array} Returns the slice of `array`.
     */
    function baseSlice(array, start, end) {
      var index = -1,
          length = array.length;

      start = start == null ? 0 : (+start || 0);
      if (start < 0) {
        start = -start > length ? 0 : (length + start);
      }
      end = (end === undefined || end > length) ? length : (+end || 0);
      if (end < 0) {
        end += length;
      }
      length = start > end ? 0 : ((end - start) >>> 0);
      start >>>= 0;

      var result = Array(length);
      while (++index < length) {
        result[index] = array[index + start];
      }
      return result;
    }

    /**
     * The base implementation of `_.some` without support for callback shorthands
     * and `this` binding.
     *
     * @private
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function} predicate The function invoked per iteration.
     * @returns {boolean} Returns `true` if any element passes the predicate check,
     *  else `false`.
     */
    function baseSome(collection, predicate) {
      var result;

      baseEach(collection, function(value, index, collection) {
        result = predicate(value, index, collection);
        return !result;
      });
      return !!result;
    }

    /**
     * The base implementation of `_.sortBy` which uses `comparer` to define
     * the sort order of `array` and replaces criteria objects with their
     * corresponding values.
     *
     * @private
     * @param {Array} array The array to sort.
     * @param {Function} comparer The function to define sort order.
     * @returns {Array} Returns `array`.
     */
    function baseSortBy(array, comparer) {
      var length = array.length;

      array.sort(comparer);
      while (length--) {
        array[length] = array[length].value;
      }
      return array;
    }

    /**
     * The base implementation of `_.sortByOrder` without param guards.
     *
     * @private
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function[]|Object[]|string[]} iteratees The iteratees to sort by.
     * @param {boolean[]} orders The sort orders of `iteratees`.
     * @returns {Array} Returns the new sorted array.
     */
    function baseSortByOrder(collection, iteratees, orders) {
      var callback = getCallback(),
          index = -1;

      iteratees = arrayMap(iteratees, function(iteratee) { return callback(iteratee); });

      var result = baseMap(collection, function(value) {
        var criteria = arrayMap(iteratees, function(iteratee) { return iteratee(value); });
        return { 'criteria': criteria, 'index': ++index, 'value': value };
      });

      return baseSortBy(result, function(object, other) {
        return compareMultiple(object, other, orders);
      });
    }

    /**
     * The base implementation of `_.sum` without support for callback shorthands
     * and `this` binding.
     *
     * @private
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function} iteratee The function invoked per iteration.
     * @returns {number} Returns the sum.
     */
    function baseSum(collection, iteratee) {
      var result = 0;
      baseEach(collection, function(value, index, collection) {
        result += +iteratee(value, index, collection) || 0;
      });
      return result;
    }

    /**
     * The base implementation of `_.uniq` without support for callback shorthands
     * and `this` binding.
     *
     * @private
     * @param {Array} array The array to inspect.
     * @param {Function} [iteratee] The function invoked per iteration.
     * @returns {Array} Returns the new duplicate-value-free array.
     */
    function baseUniq(array, iteratee) {
      var index = -1,
          indexOf = getIndexOf(),
          length = array.length,
          isCommon = indexOf == baseIndexOf,
          isLarge = isCommon && length >= LARGE_ARRAY_SIZE,
          seen = isLarge ? createCache() : null,
          result = [];

      if (seen) {
        indexOf = cacheIndexOf;
        isCommon = false;
      } else {
        isLarge = false;
        seen = iteratee ? [] : result;
      }
      outer:
      while (++index < length) {
        var value = array[index],
            computed = iteratee ? iteratee(value, index, array) : value;

        if (isCommon && value === value) {
          var seenIndex = seen.length;
          while (seenIndex--) {
            if (seen[seenIndex] === computed) {
              continue outer;
            }
          }
          if (iteratee) {
            seen.push(computed);
          }
          result.push(value);
        }
        else if (indexOf(seen, computed, 0) < 0) {
          if (iteratee || isLarge) {
            seen.push(computed);
          }
          result.push(value);
        }
      }
      return result;
    }

    /**
     * The base implementation of `_.values` and `_.valuesIn` which creates an
     * array of `object` property values corresponding to the property names
     * of `props`.
     *
     * @private
     * @param {Object} object The object to query.
     * @param {Array} props The property names to get values for.
     * @returns {Object} Returns the array of property values.
     */
    function baseValues(object, props) {
      var index = -1,
          length = props.length,
          result = Array(length);

      while (++index < length) {
        result[index] = object[props[index]];
      }
      return result;
    }

    /**
     * The base implementation of `_.dropRightWhile`, `_.dropWhile`, `_.takeRightWhile`,
     * and `_.takeWhile` without support for callback shorthands and `this` binding.
     *
     * @private
     * @param {Array} array The array to query.
     * @param {Function} predicate The function invoked per iteration.
     * @param {boolean} [isDrop] Specify dropping elements instead of taking them.
     * @param {boolean} [fromRight] Specify iterating from right to left.
     * @returns {Array} Returns the slice of `array`.
     */
    function baseWhile(array, predicate, isDrop, fromRight) {
      var length = array.length,
          index = fromRight ? length : -1;

      while ((fromRight ? index-- : ++index < length) && predicate(array[index], index, array)) {}
      return isDrop
        ? baseSlice(array, (fromRight ? 0 : index), (fromRight ? index + 1 : length))
        : baseSlice(array, (fromRight ? index + 1 : 0), (fromRight ? length : index));
    }

    /**
     * The base implementation of `wrapperValue` which returns the result of
     * performing a sequence of actions on the unwrapped `value`, where each
     * successive action is supplied the return value of the previous.
     *
     * @private
     * @param {*} value The unwrapped value.
     * @param {Array} actions Actions to peform to resolve the unwrapped value.
     * @returns {*} Returns the resolved value.
     */
    function baseWrapperValue(value, actions) {
      var result = value;
      if (result instanceof LazyWrapper) {
        result = result.value();
      }
      var index = -1,
          length = actions.length;

      while (++index < length) {
        var action = actions[index];
        result = action.func.apply(action.thisArg, arrayPush([result], action.args));
      }
      return result;
    }

    /**
     * Performs a binary search of `array` to determine the index at which `value`
     * should be inserted into `array` in order to maintain its sort order.
     *
     * @private
     * @param {Array} array The sorted array to inspect.
     * @param {*} value The value to evaluate.
     * @param {boolean} [retHighest] Specify returning the highest qualified index.
     * @returns {number} Returns the index at which `value` should be inserted
     *  into `array`.
     */
    function binaryIndex(array, value, retHighest) {
      var low = 0,
          high = array ? array.length : low;

      if (typeof value == 'number' && value === value && high <= HALF_MAX_ARRAY_LENGTH) {
        while (low < high) {
          var mid = (low + high) >>> 1,
              computed = array[mid];

          if ((retHighest ? (computed <= value) : (computed < value)) && computed !== null) {
            low = mid + 1;
          } else {
            high = mid;
          }
        }
        return high;
      }
      return binaryIndexBy(array, value, identity, retHighest);
    }

    /**
     * This function is like `binaryIndex` except that it invokes `iteratee` for
     * `value` and each element of `array` to compute their sort ranking. The
     * iteratee is invoked with one argument; (value).
     *
     * @private
     * @param {Array} array The sorted array to inspect.
     * @param {*} value The value to evaluate.
     * @param {Function} iteratee The function invoked per iteration.
     * @param {boolean} [retHighest] Specify returning the highest qualified index.
     * @returns {number} Returns the index at which `value` should be inserted
     *  into `array`.
     */
    function binaryIndexBy(array, value, iteratee, retHighest) {
      value = iteratee(value);

      var low = 0,
          high = array ? array.length : 0,
          valIsNaN = value !== value,
          valIsNull = value === null,
          valIsUndef = value === undefined;

      while (low < high) {
        var mid = nativeFloor((low + high) / 2),
            computed = iteratee(array[mid]),
            isDef = computed !== undefined,
            isReflexive = computed === computed;

        if (valIsNaN) {
          var setLow = isReflexive || retHighest;
        } else if (valIsNull) {
          setLow = isReflexive && isDef && (retHighest || computed != null);
        } else if (valIsUndef) {
          setLow = isReflexive && (retHighest || isDef);
        } else if (computed == null) {
          setLow = false;
        } else {
          setLow = retHighest ? (computed <= value) : (computed < value);
        }
        if (setLow) {
          low = mid + 1;
        } else {
          high = mid;
        }
      }
      return nativeMin(high, MAX_ARRAY_INDEX);
    }

    /**
     * A specialized version of `baseCallback` which only supports `this` binding
     * and specifying the number of arguments to provide to `func`.
     *
     * @private
     * @param {Function} func The function to bind.
     * @param {*} thisArg The `this` binding of `func`.
     * @param {number} [argCount] The number of arguments to provide to `func`.
     * @returns {Function} Returns the callback.
     */
    function bindCallback(func, thisArg, argCount) {
      if (typeof func != 'function') {
        return identity;
      }
      if (thisArg === undefined) {
        return func;
      }
      switch (argCount) {
        case 1: return function(value) {
          return func.call(thisArg, value);
        };
        case 3: return function(value, index, collection) {
          return func.call(thisArg, value, index, collection);
        };
        case 4: return function(accumulator, value, index, collection) {
          return func.call(thisArg, accumulator, value, index, collection);
        };
        case 5: return function(value, other, key, object, source) {
          return func.call(thisArg, value, other, key, object, source);
        };
      }
      return function() {
        return func.apply(thisArg, arguments);
      };
    }

    /**
     * Creates a clone of the given array buffer.
     *
     * @private
     * @param {ArrayBuffer} buffer The array buffer to clone.
     * @returns {ArrayBuffer} Returns the cloned array buffer.
     */
    function bufferClone(buffer) {
      var result = new ArrayBuffer(buffer.byteLength),
          view = new Uint8Array(result);

      view.set(new Uint8Array(buffer));
      return result;
    }

    /**
     * Creates an array that is the composition of partially applied arguments,
     * placeholders, and provided arguments into a single array of arguments.
     *
     * @private
     * @param {Array|Object} args The provided arguments.
     * @param {Array} partials The arguments to prepend to those provided.
     * @param {Array} holders The `partials` placeholder indexes.
     * @returns {Array} Returns the new array of composed arguments.
     */
    function composeArgs(args, partials, holders) {
      var holdersLength = holders.length,
          argsIndex = -1,
          argsLength = nativeMax(args.length - holdersLength, 0),
          leftIndex = -1,
          leftLength = partials.length,
          result = Array(leftLength + argsLength);

      while (++leftIndex < leftLength) {
        result[leftIndex] = partials[leftIndex];
      }
      while (++argsIndex < holdersLength) {
        result[holders[argsIndex]] = args[argsIndex];
      }
      while (argsLength--) {
        result[leftIndex++] = args[argsIndex++];
      }
      return result;
    }

    /**
     * This function is like `composeArgs` except that the arguments composition
     * is tailored for `_.partialRight`.
     *
     * @private
     * @param {Array|Object} args The provided arguments.
     * @param {Array} partials The arguments to append to those provided.
     * @param {Array} holders The `partials` placeholder indexes.
     * @returns {Array} Returns the new array of composed arguments.
     */
    function composeArgsRight(args, partials, holders) {
      var holdersIndex = -1,
          holdersLength = holders.length,
          argsIndex = -1,
          argsLength = nativeMax(args.length - holdersLength, 0),
          rightIndex = -1,
          rightLength = partials.length,
          result = Array(argsLength + rightLength);

      while (++argsIndex < argsLength) {
        result[argsIndex] = args[argsIndex];
      }
      var offset = argsIndex;
      while (++rightIndex < rightLength) {
        result[offset + rightIndex] = partials[rightIndex];
      }
      while (++holdersIndex < holdersLength) {
        result[offset + holders[holdersIndex]] = args[argsIndex++];
      }
      return result;
    }

    /**
     * Creates a `_.countBy`, `_.groupBy`, `_.indexBy`, or `_.partition` function.
     *
     * @private
     * @param {Function} setter The function to set keys and values of the accumulator object.
     * @param {Function} [initializer] The function to initialize the accumulator object.
     * @returns {Function} Returns the new aggregator function.
     */
    function createAggregator(setter, initializer) {
      return function(collection, iteratee, thisArg) {
        var result = initializer ? initializer() : {};
        iteratee = getCallback(iteratee, thisArg, 3);

        if (isArray(collection)) {
          var index = -1,
              length = collection.length;

          while (++index < length) {
            var value = collection[index];
            setter(result, value, iteratee(value, index, collection), collection);
          }
        } else {
          baseEach(collection, function(value, key, collection) {
            setter(result, value, iteratee(value, key, collection), collection);
          });
        }
        return result;
      };
    }

    /**
     * Creates a `_.assign`, `_.defaults`, or `_.merge` function.
     *
     * @private
     * @param {Function} assigner The function to assign values.
     * @returns {Function} Returns the new assigner function.
     */
    function createAssigner(assigner) {
      return restParam(function(object, sources) {
        var index = -1,
            length = object == null ? 0 : sources.length,
            customizer = length > 2 ? sources[length - 2] : undefined,
            guard = length > 2 ? sources[2] : undefined,
            thisArg = length > 1 ? sources[length - 1] : undefined;

        if (typeof customizer == 'function') {
          customizer = bindCallback(customizer, thisArg, 5);
          length -= 2;
        } else {
          customizer = typeof thisArg == 'function' ? thisArg : undefined;
          length -= (customizer ? 1 : 0);
        }
        if (guard && isIterateeCall(sources[0], sources[1], guard)) {
          customizer = length < 3 ? undefined : customizer;
          length = 1;
        }
        while (++index < length) {
          var source = sources[index];
          if (source) {
            assigner(object, source, customizer);
          }
        }
        return object;
      });
    }

    /**
     * Creates a `baseEach` or `baseEachRight` function.
     *
     * @private
     * @param {Function} eachFunc The function to iterate over a collection.
     * @param {boolean} [fromRight] Specify iterating from right to left.
     * @returns {Function} Returns the new base function.
     */
    function createBaseEach(eachFunc, fromRight) {
      return function(collection, iteratee) {
        var length = collection ? getLength(collection) : 0;
        if (!isLength(length)) {
          return eachFunc(collection, iteratee);
        }
        var index = fromRight ? length : -1,
            iterable = toObject(collection);

        while ((fromRight ? index-- : ++index < length)) {
          if (iteratee(iterable[index], index, iterable) === false) {
            break;
          }
        }
        return collection;
      };
    }

    /**
     * Creates a base function for `_.forIn` or `_.forInRight`.
     *
     * @private
     * @param {boolean} [fromRight] Specify iterating from right to left.
     * @returns {Function} Returns the new base function.
     */
    function createBaseFor(fromRight) {
      return function(object, iteratee, keysFunc) {
        var iterable = toObject(object),
            props = keysFunc(object),
            length = props.length,
            index = fromRight ? length : -1;

        while ((fromRight ? index-- : ++index < length)) {
          var key = props[index];
          if (iteratee(iterable[key], key, iterable) === false) {
            break;
          }
        }
        return object;
      };
    }

    /**
     * Creates a function that wraps `func` and invokes it with the `this`
     * binding of `thisArg`.
     *
     * @private
     * @param {Function} func The function to bind.
     * @param {*} [thisArg] The `this` binding of `func`.
     * @returns {Function} Returns the new bound function.
     */
    function createBindWrapper(func, thisArg) {
      var Ctor = createCtorWrapper(func);

      function wrapper() {
        var fn = (this && this !== root && this instanceof wrapper) ? Ctor : func;
        return fn.apply(thisArg, arguments);
      }
      return wrapper;
    }

    /**
     * Creates a `Set` cache object to optimize linear searches of large arrays.
     *
     * @private
     * @param {Array} [values] The values to cache.
     * @returns {null|Object} Returns the new cache object if `Set` is supported, else `null`.
     */
    function createCache(values) {
      return (nativeCreate && Set) ? new SetCache(values) : null;
    }

    /**
     * Creates a function that produces compound words out of the words in a
     * given string.
     *
     * @private
     * @param {Function} callback The function to combine each word.
     * @returns {Function} Returns the new compounder function.
     */
    function createCompounder(callback) {
      return function(string) {
        var index = -1,
            array = words(deburr(string)),
            length = array.length,
            result = '';

        while (++index < length) {
          result = callback(result, array[index], index);
        }
        return result;
      };
    }

    /**
     * Creates a function that produces an instance of `Ctor` regardless of
     * whether it was invoked as part of a `new` expression or by `call` or `apply`.
     *
     * @private
     * @param {Function} Ctor The constructor to wrap.
     * @returns {Function} Returns the new wrapped function.
     */
    function createCtorWrapper(Ctor) {
      return function() {
        // Use a `switch` statement to work with class constructors.
        // See http://ecma-international.org/ecma-262/6.0/#sec-ecmascript-function-objects-call-thisargument-argumentslist
        // for more details.
        var args = arguments;
        switch (args.length) {
          case 0: return new Ctor;
          case 1: return new Ctor(args[0]);
          case 2: return new Ctor(args[0], args[1]);
          case 3: return new Ctor(args[0], args[1], args[2]);
          case 4: return new Ctor(args[0], args[1], args[2], args[3]);
          case 5: return new Ctor(args[0], args[1], args[2], args[3], args[4]);
          case 6: return new Ctor(args[0], args[1], args[2], args[3], args[4], args[5]);
          case 7: return new Ctor(args[0], args[1], args[2], args[3], args[4], args[5], args[6]);
        }
        var thisBinding = baseCreate(Ctor.prototype),
            result = Ctor.apply(thisBinding, args);

        // Mimic the constructor's `return` behavior.
        // See https://es5.github.io/#x13.2.2 for more details.
        return isObject(result) ? result : thisBinding;
      };
    }

    /**
     * Creates a `_.curry` or `_.curryRight` function.
     *
     * @private
     * @param {boolean} flag The curry bit flag.
     * @returns {Function} Returns the new curry function.
     */
    function createCurry(flag) {
      function curryFunc(func, arity, guard) {
        if (guard && isIterateeCall(func, arity, guard)) {
          arity = undefined;
        }
        var result = createWrapper(func, flag, undefined, undefined, undefined, undefined, undefined, arity);
        result.placeholder = curryFunc.placeholder;
        return result;
      }
      return curryFunc;
    }

    /**
     * Creates a `_.defaults` or `_.defaultsDeep` function.
     *
     * @private
     * @param {Function} assigner The function to assign values.
     * @param {Function} customizer The function to customize assigned values.
     * @returns {Function} Returns the new defaults function.
     */
    function createDefaults(assigner, customizer) {
      return restParam(function(args) {
        var object = args[0];
        if (object == null) {
          return object;
        }
        args.push(customizer);
        return assigner.apply(undefined, args);
      });
    }

    /**
     * Creates a `_.max` or `_.min` function.
     *
     * @private
     * @param {Function} comparator The function used to compare values.
     * @param {*} exValue The initial extremum value.
     * @returns {Function} Returns the new extremum function.
     */
    function createExtremum(comparator, exValue) {
      return function(collection, iteratee, thisArg) {
        if (thisArg && isIterateeCall(collection, iteratee, thisArg)) {
          iteratee = undefined;
        }
        iteratee = getCallback(iteratee, thisArg, 3);
        if (iteratee.length == 1) {
          collection = isArray(collection) ? collection : toIterable(collection);
          var result = arrayExtremum(collection, iteratee, comparator, exValue);
          if (!(collection.length && result === exValue)) {
            return result;
          }
        }
        return baseExtremum(collection, iteratee, comparator, exValue);
      };
    }

    /**
     * Creates a `_.find` or `_.findLast` function.
     *
     * @private
     * @param {Function} eachFunc The function to iterate over a collection.
     * @param {boolean} [fromRight] Specify iterating from right to left.
     * @returns {Function} Returns the new find function.
     */
    function createFind(eachFunc, fromRight) {
      return function(collection, predicate, thisArg) {
        predicate = getCallback(predicate, thisArg, 3);
        if (isArray(collection)) {
          var index = baseFindIndex(collection, predicate, fromRight);
          return index > -1 ? collection[index] : undefined;
        }
        return baseFind(collection, predicate, eachFunc);
      };
    }

    /**
     * Creates a `_.findIndex` or `_.findLastIndex` function.
     *
     * @private
     * @param {boolean} [fromRight] Specify iterating from right to left.
     * @returns {Function} Returns the new find function.
     */
    function createFindIndex(fromRight) {
      return function(array, predicate, thisArg) {
        if (!(array && array.length)) {
          return -1;
        }
        predicate = getCallback(predicate, thisArg, 3);
        return baseFindIndex(array, predicate, fromRight);
      };
    }

    /**
     * Creates a `_.findKey` or `_.findLastKey` function.
     *
     * @private
     * @param {Function} objectFunc The function to iterate over an object.
     * @returns {Function} Returns the new find function.
     */
    function createFindKey(objectFunc) {
      return function(object, predicate, thisArg) {
        predicate = getCallback(predicate, thisArg, 3);
        return baseFind(object, predicate, objectFunc, true);
      };
    }

    /**
     * Creates a `_.flow` or `_.flowRight` function.
     *
     * @private
     * @param {boolean} [fromRight] Specify iterating from right to left.
     * @returns {Function} Returns the new flow function.
     */
    function createFlow(fromRight) {
      return function() {
        var wrapper,
            length = arguments.length,
            index = fromRight ? length : -1,
            leftIndex = 0,
            funcs = Array(length);

        while ((fromRight ? index-- : ++index < length)) {
          var func = funcs[leftIndex++] = arguments[index];
          if (typeof func != 'function') {
            throw new TypeError(FUNC_ERROR_TEXT);
          }
          if (!wrapper && LodashWrapper.prototype.thru && getFuncName(func) == 'wrapper') {
            wrapper = new LodashWrapper([], true);
          }
        }
        index = wrapper ? -1 : length;
        while (++index < length) {
          func = funcs[index];

          var funcName = getFuncName(func),
              data = funcName == 'wrapper' ? getData(func) : undefined;

          if (data && isLaziable(data[0]) && data[1] == (ARY_FLAG | CURRY_FLAG | PARTIAL_FLAG | REARG_FLAG) && !data[4].length && data[9] == 1) {
            wrapper = wrapper[getFuncName(data[0])].apply(wrapper, data[3]);
          } else {
            wrapper = (func.length == 1 && isLaziable(func)) ? wrapper[funcName]() : wrapper.thru(func);
          }
        }
        return function() {
          var args = arguments,
              value = args[0];

          if (wrapper && args.length == 1 && isArray(value) && value.length >= LARGE_ARRAY_SIZE) {
            return wrapper.plant(value).value();
          }
          var index = 0,
              result = length ? funcs[index].apply(this, args) : value;

          while (++index < length) {
            result = funcs[index].call(this, result);
          }
          return result;
        };
      };
    }

    /**
     * Creates a function for `_.forEach` or `_.forEachRight`.
     *
     * @private
     * @param {Function} arrayFunc The function to iterate over an array.
     * @param {Function} eachFunc The function to iterate over a collection.
     * @returns {Function} Returns the new each function.
     */
    function createForEach(arrayFunc, eachFunc) {
      return function(collection, iteratee, thisArg) {
        return (typeof iteratee == 'function' && thisArg === undefined && isArray(collection))
          ? arrayFunc(collection, iteratee)
          : eachFunc(collection, bindCallback(iteratee, thisArg, 3));
      };
    }

    /**
     * Creates a function for `_.forIn` or `_.forInRight`.
     *
     * @private
     * @param {Function} objectFunc The function to iterate over an object.
     * @returns {Function} Returns the new each function.
     */
    function createForIn(objectFunc) {
      return function(object, iteratee, thisArg) {
        if (typeof iteratee != 'function' || thisArg !== undefined) {
          iteratee = bindCallback(iteratee, thisArg, 3);
        }
        return objectFunc(object, iteratee, keysIn);
      };
    }

    /**
     * Creates a function for `_.forOwn` or `_.forOwnRight`.
     *
     * @private
     * @param {Function} objectFunc The function to iterate over an object.
     * @returns {Function} Returns the new each function.
     */
    function createForOwn(objectFunc) {
      return function(object, iteratee, thisArg) {
        if (typeof iteratee != 'function' || thisArg !== undefined) {
          iteratee = bindCallback(iteratee, thisArg, 3);
        }
        return objectFunc(object, iteratee);
      };
    }

    /**
     * Creates a function for `_.mapKeys` or `_.mapValues`.
     *
     * @private
     * @param {boolean} [isMapKeys] Specify mapping keys instead of values.
     * @returns {Function} Returns the new map function.
     */
    function createObjectMapper(isMapKeys) {
      return function(object, iteratee, thisArg) {
        var result = {};
        iteratee = getCallback(iteratee, thisArg, 3);

        baseForOwn(object, function(value, key, object) {
          var mapped = iteratee(value, key, object);
          key = isMapKeys ? mapped : key;
          value = isMapKeys ? value : mapped;
          result[key] = value;
        });
        return result;
      };
    }

    /**
     * Creates a function for `_.padLeft` or `_.padRight`.
     *
     * @private
     * @param {boolean} [fromRight] Specify padding from the right.
     * @returns {Function} Returns the new pad function.
     */
    function createPadDir(fromRight) {
      return function(string, length, chars) {
        string = baseToString(string);
        return (fromRight ? string : '') + createPadding(string, length, chars) + (fromRight ? '' : string);
      };
    }

    /**
     * Creates a `_.partial` or `_.partialRight` function.
     *
     * @private
     * @param {boolean} flag The partial bit flag.
     * @returns {Function} Returns the new partial function.
     */
    function createPartial(flag) {
      var partialFunc = restParam(function(func, partials) {
        var holders = replaceHolders(partials, partialFunc.placeholder);
        return createWrapper(func, flag, undefined, partials, holders);
      });
      return partialFunc;
    }

    /**
     * Creates a function for `_.reduce` or `_.reduceRight`.
     *
     * @private
     * @param {Function} arrayFunc The function to iterate over an array.
     * @param {Function} eachFunc The function to iterate over a collection.
     * @returns {Function} Returns the new each function.
     */
    function createReduce(arrayFunc, eachFunc) {
      return function(collection, iteratee, accumulator, thisArg) {
        var initFromArray = arguments.length < 3;
        return (typeof iteratee == 'function' && thisArg === undefined && isArray(collection))
          ? arrayFunc(collection, iteratee, accumulator, initFromArray)
          : baseReduce(collection, getCallback(iteratee, thisArg, 4), accumulator, initFromArray, eachFunc);
      };
    }

    /**
     * Creates a function that wraps `func` and invokes it with optional `this`
     * binding of, partial application, and currying.
     *
     * @private
     * @param {Function|string} func The function or method name to reference.
     * @param {number} bitmask The bitmask of flags. See `createWrapper` for more details.
     * @param {*} [thisArg] The `this` binding of `func`.
     * @param {Array} [partials] The arguments to prepend to those provided to the new function.
     * @param {Array} [holders] The `partials` placeholder indexes.
     * @param {Array} [partialsRight] The arguments to append to those provided to the new function.
     * @param {Array} [holdersRight] The `partialsRight` placeholder indexes.
     * @param {Array} [argPos] The argument positions of the new function.
     * @param {number} [ary] The arity cap of `func`.
     * @param {number} [arity] The arity of `func`.
     * @returns {Function} Returns the new wrapped function.
     */
    function createHybridWrapper(func, bitmask, thisArg, partials, holders, partialsRight, holdersRight, argPos, ary, arity) {
      var isAry = bitmask & ARY_FLAG,
          isBind = bitmask & BIND_FLAG,
          isBindKey = bitmask & BIND_KEY_FLAG,
          isCurry = bitmask & CURRY_FLAG,
          isCurryBound = bitmask & CURRY_BOUND_FLAG,
          isCurryRight = bitmask & CURRY_RIGHT_FLAG,
          Ctor = isBindKey ? undefined : createCtorWrapper(func);

      function wrapper() {
        // Avoid `arguments` object use disqualifying optimizations by
        // converting it to an array before providing it to other functions.
        var length = arguments.length,
            index = length,
            args = Array(length);

        while (index--) {
          args[index] = arguments[index];
        }
        if (partials) {
          args = composeArgs(args, partials, holders);
        }
        if (partialsRight) {
          args = composeArgsRight(args, partialsRight, holdersRight);
        }
        if (isCurry || isCurryRight) {
          var placeholder = wrapper.placeholder,
              argsHolders = replaceHolders(args, placeholder);

          length -= argsHolders.length;
          if (length < arity) {
            var newArgPos = argPos ? arrayCopy(argPos) : undefined,
                newArity = nativeMax(arity - length, 0),
                newsHolders = isCurry ? argsHolders : undefined,
                newHoldersRight = isCurry ? undefined : argsHolders,
                newPartials = isCurry ? args : undefined,
                newPartialsRight = isCurry ? undefined : args;

            bitmask |= (isCurry ? PARTIAL_FLAG : PARTIAL_RIGHT_FLAG);
            bitmask &= ~(isCurry ? PARTIAL_RIGHT_FLAG : PARTIAL_FLAG);

            if (!isCurryBound) {
              bitmask &= ~(BIND_FLAG | BIND_KEY_FLAG);
            }
            var newData = [func, bitmask, thisArg, newPartials, newsHolders, newPartialsRight, newHoldersRight, newArgPos, ary, newArity],
                result = createHybridWrapper.apply(undefined, newData);

            if (isLaziable(func)) {
              setData(result, newData);
            }
            result.placeholder = placeholder;
            return result;
          }
        }
        var thisBinding = isBind ? thisArg : this,
            fn = isBindKey ? thisBinding[func] : func;

        if (argPos) {
          args = reorder(args, argPos);
        }
        if (isAry && ary < args.length) {
          args.length = ary;
        }
        if (this && this !== root && this instanceof wrapper) {
          fn = Ctor || createCtorWrapper(func);
        }
        return fn.apply(thisBinding, args);
      }
      return wrapper;
    }

    /**
     * Creates the padding required for `string` based on the given `length`.
     * The `chars` string is truncated if the number of characters exceeds `length`.
     *
     * @private
     * @param {string} string The string to create padding for.
     * @param {number} [length=0] The padding length.
     * @param {string} [chars=' '] The string used as padding.
     * @returns {string} Returns the pad for `string`.
     */
    function createPadding(string, length, chars) {
      var strLength = string.length;
      length = +length;

      if (strLength >= length || !nativeIsFinite(length)) {
        return '';
      }
      var padLength = length - strLength;
      chars = chars == null ? ' ' : (chars + '');
      return repeat(chars, nativeCeil(padLength / chars.length)).slice(0, padLength);
    }

    /**
     * Creates a function that wraps `func` and invokes it with the optional `this`
     * binding of `thisArg` and the `partials` prepended to those provided to
     * the wrapper.
     *
     * @private
     * @param {Function} func The function to partially apply arguments to.
     * @param {number} bitmask The bitmask of flags. See `createWrapper` for more details.
     * @param {*} thisArg The `this` binding of `func`.
     * @param {Array} partials The arguments to prepend to those provided to the new function.
     * @returns {Function} Returns the new bound function.
     */
    function createPartialWrapper(func, bitmask, thisArg, partials) {
      var isBind = bitmask & BIND_FLAG,
          Ctor = createCtorWrapper(func);

      function wrapper() {
        // Avoid `arguments` object use disqualifying optimizations by
        // converting it to an array before providing it `func`.
        var argsIndex = -1,
            argsLength = arguments.length,
            leftIndex = -1,
            leftLength = partials.length,
            args = Array(leftLength + argsLength);

        while (++leftIndex < leftLength) {
          args[leftIndex] = partials[leftIndex];
        }
        while (argsLength--) {
          args[leftIndex++] = arguments[++argsIndex];
        }
        var fn = (this && this !== root && this instanceof wrapper) ? Ctor : func;
        return fn.apply(isBind ? thisArg : this, args);
      }
      return wrapper;
    }

    /**
     * Creates a `_.ceil`, `_.floor`, or `_.round` function.
     *
     * @private
     * @param {string} methodName The name of the `Math` method to use when rounding.
     * @returns {Function} Returns the new round function.
     */
    function createRound(methodName) {
      var func = Math[methodName];
      return function(number, precision) {
        precision = precision === undefined ? 0 : (+precision || 0);
        if (precision) {
          precision = pow(10, precision);
          return func(number * precision) / precision;
        }
        return func(number);
      };
    }

    /**
     * Creates a `_.sortedIndex` or `_.sortedLastIndex` function.
     *
     * @private
     * @param {boolean} [retHighest] Specify returning the highest qualified index.
     * @returns {Function} Returns the new index function.
     */
    function createSortedIndex(retHighest) {
      return function(array, value, iteratee, thisArg) {
        var callback = getCallback(iteratee);
        return (iteratee == null && callback === baseCallback)
          ? binaryIndex(array, value, retHighest)
          : binaryIndexBy(array, value, callback(iteratee, thisArg, 1), retHighest);
      };
    }

    /**
     * Creates a function that either curries or invokes `func` with optional
     * `this` binding and partially applied arguments.
     *
     * @private
     * @param {Function|string} func The function or method name to reference.
     * @param {number} bitmask The bitmask of flags.
     *  The bitmask may be composed of the following flags:
     *     1 - `_.bind`
     *     2 - `_.bindKey`
     *     4 - `_.curry` or `_.curryRight` of a bound function
     *     8 - `_.curry`
     *    16 - `_.curryRight`
     *    32 - `_.partial`
     *    64 - `_.partialRight`
     *   128 - `_.rearg`
     *   256 - `_.ary`
     * @param {*} [thisArg] The `this` binding of `func`.
     * @param {Array} [partials] The arguments to be partially applied.
     * @param {Array} [holders] The `partials` placeholder indexes.
     * @param {Array} [argPos] The argument positions of the new function.
     * @param {number} [ary] The arity cap of `func`.
     * @param {number} [arity] The arity of `func`.
     * @returns {Function} Returns the new wrapped function.
     */
    function createWrapper(func, bitmask, thisArg, partials, holders, argPos, ary, arity) {
      var isBindKey = bitmask & BIND_KEY_FLAG;
      if (!isBindKey && typeof func != 'function') {
        throw new TypeError(FUNC_ERROR_TEXT);
      }
      var length = partials ? partials.length : 0;
      if (!length) {
        bitmask &= ~(PARTIAL_FLAG | PARTIAL_RIGHT_FLAG);
        partials = holders = undefined;
      }
      length -= (holders ? holders.length : 0);
      if (bitmask & PARTIAL_RIGHT_FLAG) {
        var partialsRight = partials,
            holdersRight = holders;

        partials = holders = undefined;
      }
      var data = isBindKey ? undefined : getData(func),
          newData = [func, bitmask, thisArg, partials, holders, partialsRight, holdersRight, argPos, ary, arity];

      if (data) {
        mergeData(newData, data);
        bitmask = newData[1];
        arity = newData[9];
      }
      newData[9] = arity == null
        ? (isBindKey ? 0 : func.length)
        : (nativeMax(arity - length, 0) || 0);

      if (bitmask == BIND_FLAG) {
        var result = createBindWrapper(newData[0], newData[2]);
      } else if ((bitmask == PARTIAL_FLAG || bitmask == (BIND_FLAG | PARTIAL_FLAG)) && !newData[4].length) {
        result = createPartialWrapper.apply(undefined, newData);
      } else {
        result = createHybridWrapper.apply(undefined, newData);
      }
      var setter = data ? baseSetData : setData;
      return setter(result, newData);
    }

    /**
     * A specialized version of `baseIsEqualDeep` for arrays with support for
     * partial deep comparisons.
     *
     * @private
     * @param {Array} array The array to compare.
     * @param {Array} other The other array to compare.
     * @param {Function} equalFunc The function to determine equivalents of values.
     * @param {Function} [customizer] The function to customize comparing arrays.
     * @param {boolean} [isLoose] Specify performing partial comparisons.
     * @param {Array} [stackA] Tracks traversed `value` objects.
     * @param {Array} [stackB] Tracks traversed `other` objects.
     * @returns {boolean} Returns `true` if the arrays are equivalent, else `false`.
     */
    function equalArrays(array, other, equalFunc, customizer, isLoose, stackA, stackB) {
      var index = -1,
          arrLength = array.length,
          othLength = other.length;

      if (arrLength != othLength && !(isLoose && othLength > arrLength)) {
        return false;
      }
      // Ignore non-index properties.
      while (++index < arrLength) {
        var arrValue = array[index],
            othValue = other[index],
            result = customizer ? customizer(isLoose ? othValue : arrValue, isLoose ? arrValue : othValue, index) : undefined;

        if (result !== undefined) {
          if (result) {
            continue;
          }
          return false;
        }
        // Recursively compare arrays (susceptible to call stack limits).
        if (isLoose) {
          if (!arraySome(other, function(othValue) {
                return arrValue === othValue || equalFunc(arrValue, othValue, customizer, isLoose, stackA, stackB);
              })) {
            return false;
          }
        } else if (!(arrValue === othValue || equalFunc(arrValue, othValue, customizer, isLoose, stackA, stackB))) {
          return false;
        }
      }
      return true;
    }

    /**
     * A specialized version of `baseIsEqualDeep` for comparing objects of
     * the same `toStringTag`.
     *
     * **Note:** This function only supports comparing values with tags of
     * `Boolean`, `Date`, `Error`, `Number`, `RegExp`, or `String`.
     *
     * @private
     * @param {Object} object The object to compare.
     * @param {Object} other The other object to compare.
     * @param {string} tag The `toStringTag` of the objects to compare.
     * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
     */
    function equalByTag(object, other, tag) {
      switch (tag) {
        case boolTag:
        case dateTag:
          // Coerce dates and booleans to numbers, dates to milliseconds and booleans
          // to `1` or `0` treating invalid dates coerced to `NaN` as not equal.
          return +object == +other;

        case errorTag:
          return object.name == other.name && object.message == other.message;

        case numberTag:
          // Treat `NaN` vs. `NaN` as equal.
          return (object != +object)
            ? other != +other
            : object == +other;

        case regexpTag:
        case stringTag:
          // Coerce regexes to strings and treat strings primitives and string
          // objects as equal. See https://es5.github.io/#x15.10.6.4 for more details.
          return object == (other + '');
      }
      return false;
    }

    /**
     * A specialized version of `baseIsEqualDeep` for objects with support for
     * partial deep comparisons.
     *
     * @private
     * @param {Object} object The object to compare.
     * @param {Object} other The other object to compare.
     * @param {Function} equalFunc The function to determine equivalents of values.
     * @param {Function} [customizer] The function to customize comparing values.
     * @param {boolean} [isLoose] Specify performing partial comparisons.
     * @param {Array} [stackA] Tracks traversed `value` objects.
     * @param {Array} [stackB] Tracks traversed `other` objects.
     * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
     */
    function equalObjects(object, other, equalFunc, customizer, isLoose, stackA, stackB) {
      var objProps = keys(object),
          objLength = objProps.length,
          othProps = keys(other),
          othLength = othProps.length;

      if (objLength != othLength && !isLoose) {
        return false;
      }
      var index = objLength;
      while (index--) {
        var key = objProps[index];
        if (!(isLoose ? key in other : hasOwnProperty.call(other, key))) {
          return false;
        }
      }
      var skipCtor = isLoose;
      while (++index < objLength) {
        key = objProps[index];
        var objValue = object[key],
            othValue = other[key],
            result = customizer ? customizer(isLoose ? othValue : objValue, isLoose? objValue : othValue, key) : undefined;

        // Recursively compare objects (susceptible to call stack limits).
        if (!(result === undefined ? equalFunc(objValue, othValue, customizer, isLoose, stackA, stackB) : result)) {
          return false;
        }
        skipCtor || (skipCtor = key == 'constructor');
      }
      if (!skipCtor) {
        var objCtor = object.constructor,
            othCtor = other.constructor;

        // Non `Object` object instances with different constructors are not equal.
        if (objCtor != othCtor &&
            ('constructor' in object && 'constructor' in other) &&
            !(typeof objCtor == 'function' && objCtor instanceof objCtor &&
              typeof othCtor == 'function' && othCtor instanceof othCtor)) {
          return false;
        }
      }
      return true;
    }

    /**
     * Gets the appropriate "callback" function. If the `_.callback` method is
     * customized this function returns the custom method, otherwise it returns
     * the `baseCallback` function. If arguments are provided the chosen function
     * is invoked with them and its result is returned.
     *
     * @private
     * @returns {Function} Returns the chosen function or its result.
     */
    function getCallback(func, thisArg, argCount) {
      var result = lodash.callback || callback;
      result = result === callback ? baseCallback : result;
      return argCount ? result(func, thisArg, argCount) : result;
    }

    /**
     * Gets metadata for `func`.
     *
     * @private
     * @param {Function} func The function to query.
     * @returns {*} Returns the metadata for `func`.
     */
    var getData = !metaMap ? noop : function(func) {
      return metaMap.get(func);
    };

    /**
     * Gets the name of `func`.
     *
     * @private
     * @param {Function} func The function to query.
     * @returns {string} Returns the function name.
     */
    function getFuncName(func) {
      var result = func.name,
          array = realNames[result],
          length = array ? array.length : 0;

      while (length--) {
        var data = array[length],
            otherFunc = data.func;
        if (otherFunc == null || otherFunc == func) {
          return data.name;
        }
      }
      return result;
    }

    /**
     * Gets the appropriate "indexOf" function. If the `_.indexOf` method is
     * customized this function returns the custom method, otherwise it returns
     * the `baseIndexOf` function. If arguments are provided the chosen function
     * is invoked with them and its result is returned.
     *
     * @private
     * @returns {Function|number} Returns the chosen function or its result.
     */
    function getIndexOf(collection, target, fromIndex) {
      var result = lodash.indexOf || indexOf;
      result = result === indexOf ? baseIndexOf : result;
      return collection ? result(collection, target, fromIndex) : result;
    }

    /**
     * Gets the "length" property value of `object`.
     *
     * **Note:** This function is used to avoid a [JIT bug](https://bugs.webkit.org/show_bug.cgi?id=142792)
     * that affects Safari on at least iOS 8.1-8.3 ARM64.
     *
     * @private
     * @param {Object} object The object to query.
     * @returns {*} Returns the "length" value.
     */
    var getLength = baseProperty('length');

    /**
     * Gets the propery names, values, and compare flags of `object`.
     *
     * @private
     * @param {Object} object The object to query.
     * @returns {Array} Returns the match data of `object`.
     */
    function getMatchData(object) {
      var result = pairs(object),
          length = result.length;

      while (length--) {
        result[length][2] = isStrictComparable(result[length][1]);
      }
      return result;
    }

    /**
     * Gets the native function at `key` of `object`.
     *
     * @private
     * @param {Object} object The object to query.
     * @param {string} key The key of the method to get.
     * @returns {*} Returns the function if it's native, else `undefined`.
     */
    function getNative(object, key) {
      var value = object == null ? undefined : object[key];
      return isNative(value) ? value : undefined;
    }

    /**
     * Gets the view, applying any `transforms` to the `start` and `end` positions.
     *
     * @private
     * @param {number} start The start of the view.
     * @param {number} end The end of the view.
     * @param {Array} transforms The transformations to apply to the view.
     * @returns {Object} Returns an object containing the `start` and `end`
     *  positions of the view.
     */
    function getView(start, end, transforms) {
      var index = -1,
          length = transforms.length;

      while (++index < length) {
        var data = transforms[index],
            size = data.size;

        switch (data.type) {
          case 'drop':      start += size; break;
          case 'dropRight': end -= size; break;
          case 'take':      end = nativeMin(end, start + size); break;
          case 'takeRight': start = nativeMax(start, end - size); break;
        }
      }
      return { 'start': start, 'end': end };
    }

    /**
     * Initializes an array clone.
     *
     * @private
     * @param {Array} array The array to clone.
     * @returns {Array} Returns the initialized clone.
     */
    function initCloneArray(array) {
      var length = array.length,
          result = new array.constructor(length);

      // Add array properties assigned by `RegExp#exec`.
      if (length && typeof array[0] == 'string' && hasOwnProperty.call(array, 'index')) {
        result.index = array.index;
        result.input = array.input;
      }
      return result;
    }

    /**
     * Initializes an object clone.
     *
     * @private
     * @param {Object} object The object to clone.
     * @returns {Object} Returns the initialized clone.
     */
    function initCloneObject(object) {
      var Ctor = object.constructor;
      if (!(typeof Ctor == 'function' && Ctor instanceof Ctor)) {
        Ctor = Object;
      }
      return new Ctor;
    }

    /**
     * Initializes an object clone based on its `toStringTag`.
     *
     * **Note:** This function only supports cloning values with tags of
     * `Boolean`, `Date`, `Error`, `Number`, `RegExp`, or `String`.
     *
     * @private
     * @param {Object} object The object to clone.
     * @param {string} tag The `toStringTag` of the object to clone.
     * @param {boolean} [isDeep] Specify a deep clone.
     * @returns {Object} Returns the initialized clone.
     */
    function initCloneByTag(object, tag, isDeep) {
      var Ctor = object.constructor;
      switch (tag) {
        case arrayBufferTag:
          return bufferClone(object);

        case boolTag:
        case dateTag:
          return new Ctor(+object);

        case float32Tag: case float64Tag:
        case int8Tag: case int16Tag: case int32Tag:
        case uint8Tag: case uint8ClampedTag: case uint16Tag: case uint32Tag:
          var buffer = object.buffer;
          return new Ctor(isDeep ? bufferClone(buffer) : buffer, object.byteOffset, object.length);

        case numberTag:
        case stringTag:
          return new Ctor(object);

        case regexpTag:
          var result = new Ctor(object.source, reFlags.exec(object));
          result.lastIndex = object.lastIndex;
      }
      return result;
    }

    /**
     * Invokes the method at `path` on `object`.
     *
     * @private
     * @param {Object} object The object to query.
     * @param {Array|string} path The path of the method to invoke.
     * @param {Array} args The arguments to invoke the method with.
     * @returns {*} Returns the result of the invoked method.
     */
    function invokePath(object, path, args) {
      if (object != null && !isKey(path, object)) {
        path = toPath(path);
        object = path.length == 1 ? object : baseGet(object, baseSlice(path, 0, -1));
        path = last(path);
      }
      var func = object == null ? object : object[path];
      return func == null ? undefined : func.apply(object, args);
    }

    /**
     * Checks if `value` is array-like.
     *
     * @private
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is array-like, else `false`.
     */
    function isArrayLike(value) {
      return value != null && isLength(getLength(value));
    }

    /**
     * Checks if `value` is a valid array-like index.
     *
     * @private
     * @param {*} value The value to check.
     * @param {number} [length=MAX_SAFE_INTEGER] The upper bounds of a valid index.
     * @returns {boolean} Returns `true` if `value` is a valid index, else `false`.
     */
    function isIndex(value, length) {
      value = (typeof value == 'number' || reIsUint.test(value)) ? +value : -1;
      length = length == null ? MAX_SAFE_INTEGER : length;
      return value > -1 && value % 1 == 0 && value < length;
    }

    /**
     * Checks if the provided arguments are from an iteratee call.
     *
     * @private
     * @param {*} value The potential iteratee value argument.
     * @param {*} index The potential iteratee index or key argument.
     * @param {*} object The potential iteratee object argument.
     * @returns {boolean} Returns `true` if the arguments are from an iteratee call, else `false`.
     */
    function isIterateeCall(value, index, object) {
      if (!isObject(object)) {
        return false;
      }
      var type = typeof index;
      if (type == 'number'
          ? (isArrayLike(object) && isIndex(index, object.length))
          : (type == 'string' && index in object)) {
        var other = object[index];
        return value === value ? (value === other) : (other !== other);
      }
      return false;
    }

    /**
     * Checks if `value` is a property name and not a property path.
     *
     * @private
     * @param {*} value The value to check.
     * @param {Object} [object] The object to query keys on.
     * @returns {boolean} Returns `true` if `value` is a property name, else `false`.
     */
    function isKey(value, object) {
      var type = typeof value;
      if ((type == 'string' && reIsPlainProp.test(value)) || type == 'number') {
        return true;
      }
      if (isArray(value)) {
        return false;
      }
      var result = !reIsDeepProp.test(value);
      return result || (object != null && value in toObject(object));
    }

    /**
     * Checks if `func` has a lazy counterpart.
     *
     * @private
     * @param {Function} func The function to check.
     * @returns {boolean} Returns `true` if `func` has a lazy counterpart, else `false`.
     */
    function isLaziable(func) {
      var funcName = getFuncName(func);
      if (!(funcName in LazyWrapper.prototype)) {
        return false;
      }
      var other = lodash[funcName];
      if (func === other) {
        return true;
      }
      var data = getData(other);
      return !!data && func === data[0];
    }

    /**
     * Checks if `value` is a valid array-like length.
     *
     * **Note:** This function is based on [`ToLength`](http://ecma-international.org/ecma-262/6.0/#sec-tolength).
     *
     * @private
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is a valid length, else `false`.
     */
    function isLength(value) {
      return typeof value == 'number' && value > -1 && value % 1 == 0 && value <= MAX_SAFE_INTEGER;
    }

    /**
     * Checks if `value` is suitable for strict equality comparisons, i.e. `===`.
     *
     * @private
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` if suitable for strict
     *  equality comparisons, else `false`.
     */
    function isStrictComparable(value) {
      return value === value && !isObject(value);
    }

    /**
     * Merges the function metadata of `source` into `data`.
     *
     * Merging metadata reduces the number of wrappers required to invoke a function.
     * This is possible because methods like `_.bind`, `_.curry`, and `_.partial`
     * may be applied regardless of execution order. Methods like `_.ary` and `_.rearg`
     * augment function arguments, making the order in which they are executed important,
     * preventing the merging of metadata. However, we make an exception for a safe
     * common case where curried functions have `_.ary` and or `_.rearg` applied.
     *
     * @private
     * @param {Array} data The destination metadata.
     * @param {Array} source The source metadata.
     * @returns {Array} Returns `data`.
     */
    function mergeData(data, source) {
      var bitmask = data[1],
          srcBitmask = source[1],
          newBitmask = bitmask | srcBitmask,
          isCommon = newBitmask < ARY_FLAG;

      var isCombo =
        (srcBitmask == ARY_FLAG && bitmask == CURRY_FLAG) ||
        (srcBitmask == ARY_FLAG && bitmask == REARG_FLAG && data[7].length <= source[8]) ||
        (srcBitmask == (ARY_FLAG | REARG_FLAG) && bitmask == CURRY_FLAG);

      // Exit early if metadata can't be merged.
      if (!(isCommon || isCombo)) {
        return data;
      }
      // Use source `thisArg` if available.
      if (srcBitmask & BIND_FLAG) {
        data[2] = source[2];
        // Set when currying a bound function.
        newBitmask |= (bitmask & BIND_FLAG) ? 0 : CURRY_BOUND_FLAG;
      }
      // Compose partial arguments.
      var value = source[3];
      if (value) {
        var partials = data[3];
        data[3] = partials ? composeArgs(partials, value, source[4]) : arrayCopy(value);
        data[4] = partials ? replaceHolders(data[3], PLACEHOLDER) : arrayCopy(source[4]);
      }
      // Compose partial right arguments.
      value = source[5];
      if (value) {
        partials = data[5];
        data[5] = partials ? composeArgsRight(partials, value, source[6]) : arrayCopy(value);
        data[6] = partials ? replaceHolders(data[5], PLACEHOLDER) : arrayCopy(source[6]);
      }
      // Use source `argPos` if available.
      value = source[7];
      if (value) {
        data[7] = arrayCopy(value);
      }
      // Use source `ary` if it's smaller.
      if (srcBitmask & ARY_FLAG) {
        data[8] = data[8] == null ? source[8] : nativeMin(data[8], source[8]);
      }
      // Use source `arity` if one is not provided.
      if (data[9] == null) {
        data[9] = source[9];
      }
      // Use source `func` and merge bitmasks.
      data[0] = source[0];
      data[1] = newBitmask;

      return data;
    }

    /**
     * Used by `_.defaultsDeep` to customize its `_.merge` use.
     *
     * @private
     * @param {*} objectValue The destination object property value.
     * @param {*} sourceValue The source object property value.
     * @returns {*} Returns the value to assign to the destination object.
     */
    function mergeDefaults(objectValue, sourceValue) {
      return objectValue === undefined ? sourceValue : merge(objectValue, sourceValue, mergeDefaults);
    }

    /**
     * A specialized version of `_.pick` which picks `object` properties specified
     * by `props`.
     *
     * @private
     * @param {Object} object The source object.
     * @param {string[]} props The property names to pick.
     * @returns {Object} Returns the new object.
     */
    function pickByArray(object, props) {
      object = toObject(object);

      var index = -1,
          length = props.length,
          result = {};

      while (++index < length) {
        var key = props[index];
        if (key in object) {
          result[key] = object[key];
        }
      }
      return result;
    }

    /**
     * A specialized version of `_.pick` which picks `object` properties `predicate`
     * returns truthy for.
     *
     * @private
     * @param {Object} object The source object.
     * @param {Function} predicate The function invoked per iteration.
     * @returns {Object} Returns the new object.
     */
    function pickByCallback(object, predicate) {
      var result = {};
      baseForIn(object, function(value, key, object) {
        if (predicate(value, key, object)) {
          result[key] = value;
        }
      });
      return result;
    }

    /**
     * Reorder `array` according to the specified indexes where the element at
     * the first index is assigned as the first element, the element at
     * the second index is assigned as the second element, and so on.
     *
     * @private
     * @param {Array} array The array to reorder.
     * @param {Array} indexes The arranged array indexes.
     * @returns {Array} Returns `array`.
     */
    function reorder(array, indexes) {
      var arrLength = array.length,
          length = nativeMin(indexes.length, arrLength),
          oldArray = arrayCopy(array);

      while (length--) {
        var index = indexes[length];
        array[length] = isIndex(index, arrLength) ? oldArray[index] : undefined;
      }
      return array;
    }

    /**
     * Sets metadata for `func`.
     *
     * **Note:** If this function becomes hot, i.e. is invoked a lot in a short
     * period of time, it will trip its breaker and transition to an identity function
     * to avoid garbage collection pauses in V8. See [V8 issue 2070](https://code.google.com/p/v8/issues/detail?id=2070)
     * for more details.
     *
     * @private
     * @param {Function} func The function to associate metadata with.
     * @param {*} data The metadata.
     * @returns {Function} Returns `func`.
     */
    var setData = (function() {
      var count = 0,
          lastCalled = 0;

      return function(key, value) {
        var stamp = now(),
            remaining = HOT_SPAN - (stamp - lastCalled);

        lastCalled = stamp;
        if (remaining > 0) {
          if (++count >= HOT_COUNT) {
            return key;
          }
        } else {
          count = 0;
        }
        return baseSetData(key, value);
      };
    }());

    /**
     * A fallback implementation of `Object.keys` which creates an array of the
     * own enumerable property names of `object`.
     *
     * @private
     * @param {Object} object The object to query.
     * @returns {Array} Returns the array of property names.
     */
    function shimKeys(object) {
      var props = keysIn(object),
          propsLength = props.length,
          length = propsLength && object.length;

      var allowIndexes = !!length && isLength(length) &&
        (isArray(object) || isArguments(object));

      var index = -1,
          result = [];

      while (++index < propsLength) {
        var key = props[index];
        if ((allowIndexes && isIndex(key, length)) || hasOwnProperty.call(object, key)) {
          result.push(key);
        }
      }
      return result;
    }

    /**
     * Converts `value` to an array-like object if it's not one.
     *
     * @private
     * @param {*} value The value to process.
     * @returns {Array|Object} Returns the array-like object.
     */
    function toIterable(value) {
      if (value == null) {
        return [];
      }
      if (!isArrayLike(value)) {
        return values(value);
      }
      return isObject(value) ? value : Object(value);
    }

    /**
     * Converts `value` to an object if it's not one.
     *
     * @private
     * @param {*} value The value to process.
     * @returns {Object} Returns the object.
     */
    function toObject(value) {
      return isObject(value) ? value : Object(value);
    }

    /**
     * Converts `value` to property path array if it's not one.
     *
     * @private
     * @param {*} value The value to process.
     * @returns {Array} Returns the property path array.
     */
    function toPath(value) {
      if (isArray(value)) {
        return value;
      }
      var result = [];
      baseToString(value).replace(rePropName, function(match, number, quote, string) {
        result.push(quote ? string.replace(reEscapeChar, '$1') : (number || match));
      });
      return result;
    }

    /**
     * Creates a clone of `wrapper`.
     *
     * @private
     * @param {Object} wrapper The wrapper to clone.
     * @returns {Object} Returns the cloned wrapper.
     */
    function wrapperClone(wrapper) {
      return wrapper instanceof LazyWrapper
        ? wrapper.clone()
        : new LodashWrapper(wrapper.__wrapped__, wrapper.__chain__, arrayCopy(wrapper.__actions__));
    }

    /*------------------------------------------------------------------------*/

    /**
     * Creates an array of elements split into groups the length of `size`.
     * If `collection` can't be split evenly, the final chunk will be the remaining
     * elements.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to process.
     * @param {number} [size=1] The length of each chunk.
     * @param- {Object} [guard] Enables use as a callback for functions like `_.map`.
     * @returns {Array} Returns the new array containing chunks.
     * @example
     *
     * _.chunk(['a', 'b', 'c', 'd'], 2);
     * // => [['a', 'b'], ['c', 'd']]
     *
     * _.chunk(['a', 'b', 'c', 'd'], 3);
     * // => [['a', 'b', 'c'], ['d']]
     */
    function chunk(array, size, guard) {
      if (guard ? isIterateeCall(array, size, guard) : size == null) {
        size = 1;
      } else {
        size = nativeMax(nativeFloor(size) || 1, 1);
      }
      var index = 0,
          length = array ? array.length : 0,
          resIndex = -1,
          result = Array(nativeCeil(length / size));

      while (index < length) {
        result[++resIndex] = baseSlice(array, index, (index += size));
      }
      return result;
    }

    /**
     * Creates an array with all falsey values removed. The values `false`, `null`,
     * `0`, `""`, `undefined`, and `NaN` are falsey.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to compact.
     * @returns {Array} Returns the new array of filtered values.
     * @example
     *
     * _.compact([0, 1, false, 2, '', 3]);
     * // => [1, 2, 3]
     */
    function compact(array) {
      var index = -1,
          length = array ? array.length : 0,
          resIndex = -1,
          result = [];

      while (++index < length) {
        var value = array[index];
        if (value) {
          result[++resIndex] = value;
        }
      }
      return result;
    }

    /**
     * Creates an array of unique `array` values not included in the other
     * provided arrays using [`SameValueZero`](http://ecma-international.org/ecma-262/6.0/#sec-samevaluezero)
     * for equality comparisons.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to inspect.
     * @param {...Array} [values] The arrays of values to exclude.
     * @returns {Array} Returns the new array of filtered values.
     * @example
     *
     * _.difference([1, 2, 3], [4, 2]);
     * // => [1, 3]
     */
    var difference = restParam(function(array, values) {
      return (isObjectLike(array) && isArrayLike(array))
        ? baseDifference(array, baseFlatten(values, false, true))
        : [];
    });

    /**
     * Creates a slice of `array` with `n` elements dropped from the beginning.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to query.
     * @param {number} [n=1] The number of elements to drop.
     * @param- {Object} [guard] Enables use as a callback for functions like `_.map`.
     * @returns {Array} Returns the slice of `array`.
     * @example
     *
     * _.drop([1, 2, 3]);
     * // => [2, 3]
     *
     * _.drop([1, 2, 3], 2);
     * // => [3]
     *
     * _.drop([1, 2, 3], 5);
     * // => []
     *
     * _.drop([1, 2, 3], 0);
     * // => [1, 2, 3]
     */
    function drop(array, n, guard) {
      var length = array ? array.length : 0;
      if (!length) {
        return [];
      }
      if (guard ? isIterateeCall(array, n, guard) : n == null) {
        n = 1;
      }
      return baseSlice(array, n < 0 ? 0 : n);
    }

    /**
     * Creates a slice of `array` with `n` elements dropped from the end.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to query.
     * @param {number} [n=1] The number of elements to drop.
     * @param- {Object} [guard] Enables use as a callback for functions like `_.map`.
     * @returns {Array} Returns the slice of `array`.
     * @example
     *
     * _.dropRight([1, 2, 3]);
     * // => [1, 2]
     *
     * _.dropRight([1, 2, 3], 2);
     * // => [1]
     *
     * _.dropRight([1, 2, 3], 5);
     * // => []
     *
     * _.dropRight([1, 2, 3], 0);
     * // => [1, 2, 3]
     */
    function dropRight(array, n, guard) {
      var length = array ? array.length : 0;
      if (!length) {
        return [];
      }
      if (guard ? isIterateeCall(array, n, guard) : n == null) {
        n = 1;
      }
      n = length - (+n || 0);
      return baseSlice(array, 0, n < 0 ? 0 : n);
    }

    /**
     * Creates a slice of `array` excluding elements dropped from the end.
     * Elements are dropped until `predicate` returns falsey. The predicate is
     * bound to `thisArg` and invoked with three arguments: (value, index, array).
     *
     * If a property name is provided for `predicate` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `predicate` the created `_.matches` style
     * callback returns `true` for elements that match the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to query.
     * @param {Function|Object|string} [predicate=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `predicate`.
     * @returns {Array} Returns the slice of `array`.
     * @example
     *
     * _.dropRightWhile([1, 2, 3], function(n) {
     *   return n > 1;
     * });
     * // => [1]
     *
     * var users = [
     *   { 'user': 'barney',  'active': true },
     *   { 'user': 'fred',    'active': false },
     *   { 'user': 'pebbles', 'active': false }
     * ];
     *
     * // using the `_.matches` callback shorthand
     * _.pluck(_.dropRightWhile(users, { 'user': 'pebbles', 'active': false }), 'user');
     * // => ['barney', 'fred']
     *
     * // using the `_.matchesProperty` callback shorthand
     * _.pluck(_.dropRightWhile(users, 'active', false), 'user');
     * // => ['barney']
     *
     * // using the `_.property` callback shorthand
     * _.pluck(_.dropRightWhile(users, 'active'), 'user');
     * // => ['barney', 'fred', 'pebbles']
     */
    function dropRightWhile(array, predicate, thisArg) {
      return (array && array.length)
        ? baseWhile(array, getCallback(predicate, thisArg, 3), true, true)
        : [];
    }

    /**
     * Creates a slice of `array` excluding elements dropped from the beginning.
     * Elements are dropped until `predicate` returns falsey. The predicate is
     * bound to `thisArg` and invoked with three arguments: (value, index, array).
     *
     * If a property name is provided for `predicate` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `predicate` the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to query.
     * @param {Function|Object|string} [predicate=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `predicate`.
     * @returns {Array} Returns the slice of `array`.
     * @example
     *
     * _.dropWhile([1, 2, 3], function(n) {
     *   return n < 3;
     * });
     * // => [3]
     *
     * var users = [
     *   { 'user': 'barney',  'active': false },
     *   { 'user': 'fred',    'active': false },
     *   { 'user': 'pebbles', 'active': true }
     * ];
     *
     * // using the `_.matches` callback shorthand
     * _.pluck(_.dropWhile(users, { 'user': 'barney', 'active': false }), 'user');
     * // => ['fred', 'pebbles']
     *
     * // using the `_.matchesProperty` callback shorthand
     * _.pluck(_.dropWhile(users, 'active', false), 'user');
     * // => ['pebbles']
     *
     * // using the `_.property` callback shorthand
     * _.pluck(_.dropWhile(users, 'active'), 'user');
     * // => ['barney', 'fred', 'pebbles']
     */
    function dropWhile(array, predicate, thisArg) {
      return (array && array.length)
        ? baseWhile(array, getCallback(predicate, thisArg, 3), true)
        : [];
    }

    /**
     * Fills elements of `array` with `value` from `start` up to, but not
     * including, `end`.
     *
     * **Note:** This method mutates `array`.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to fill.
     * @param {*} value The value to fill `array` with.
     * @param {number} [start=0] The start position.
     * @param {number} [end=array.length] The end position.
     * @returns {Array} Returns `array`.
     * @example
     *
     * var array = [1, 2, 3];
     *
     * _.fill(array, 'a');
     * console.log(array);
     * // => ['a', 'a', 'a']
     *
     * _.fill(Array(3), 2);
     * // => [2, 2, 2]
     *
     * _.fill([4, 6, 8], '*', 1, 2);
     * // => [4, '*', 8]
     */
    function fill(array, value, start, end) {
      var length = array ? array.length : 0;
      if (!length) {
        return [];
      }
      if (start && typeof start != 'number' && isIterateeCall(array, value, start)) {
        start = 0;
        end = length;
      }
      return baseFill(array, value, start, end);
    }

    /**
     * This method is like `_.find` except that it returns the index of the first
     * element `predicate` returns truthy for instead of the element itself.
     *
     * If a property name is provided for `predicate` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `predicate` the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to search.
     * @param {Function|Object|string} [predicate=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `predicate`.
     * @returns {number} Returns the index of the found element, else `-1`.
     * @example
     *
     * var users = [
     *   { 'user': 'barney',  'active': false },
     *   { 'user': 'fred',    'active': false },
     *   { 'user': 'pebbles', 'active': true }
     * ];
     *
     * _.findIndex(users, function(chr) {
     *   return chr.user == 'barney';
     * });
     * // => 0
     *
     * // using the `_.matches` callback shorthand
     * _.findIndex(users, { 'user': 'fred', 'active': false });
     * // => 1
     *
     * // using the `_.matchesProperty` callback shorthand
     * _.findIndex(users, 'active', false);
     * // => 0
     *
     * // using the `_.property` callback shorthand
     * _.findIndex(users, 'active');
     * // => 2
     */
    var findIndex = createFindIndex();

    /**
     * This method is like `_.findIndex` except that it iterates over elements
     * of `collection` from right to left.
     *
     * If a property name is provided for `predicate` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `predicate` the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to search.
     * @param {Function|Object|string} [predicate=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `predicate`.
     * @returns {number} Returns the index of the found element, else `-1`.
     * @example
     *
     * var users = [
     *   { 'user': 'barney',  'active': true },
     *   { 'user': 'fred',    'active': false },
     *   { 'user': 'pebbles', 'active': false }
     * ];
     *
     * _.findLastIndex(users, function(chr) {
     *   return chr.user == 'pebbles';
     * });
     * // => 2
     *
     * // using the `_.matches` callback shorthand
     * _.findLastIndex(users, { 'user': 'barney', 'active': true });
     * // => 0
     *
     * // using the `_.matchesProperty` callback shorthand
     * _.findLastIndex(users, 'active', false);
     * // => 2
     *
     * // using the `_.property` callback shorthand
     * _.findLastIndex(users, 'active');
     * // => 0
     */
    var findLastIndex = createFindIndex(true);

    /**
     * Gets the first element of `array`.
     *
     * @static
     * @memberOf _
     * @alias head
     * @category Array
     * @param {Array} array The array to query.
     * @returns {*} Returns the first element of `array`.
     * @example
     *
     * _.first([1, 2, 3]);
     * // => 1
     *
     * _.first([]);
     * // => undefined
     */
    function first(array) {
      return array ? array[0] : undefined;
    }

    /**
     * Flattens a nested array. If `isDeep` is `true` the array is recursively
     * flattened, otherwise it is only flattened a single level.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to flatten.
     * @param {boolean} [isDeep] Specify a deep flatten.
     * @param- {Object} [guard] Enables use as a callback for functions like `_.map`.
     * @returns {Array} Returns the new flattened array.
     * @example
     *
     * _.flatten([1, [2, 3, [4]]]);
     * // => [1, 2, 3, [4]]
     *
     * // using `isDeep`
     * _.flatten([1, [2, 3, [4]]], true);
     * // => [1, 2, 3, 4]
     */
    function flatten(array, isDeep, guard) {
      var length = array ? array.length : 0;
      if (guard && isIterateeCall(array, isDeep, guard)) {
        isDeep = false;
      }
      return length ? baseFlatten(array, isDeep) : [];
    }

    /**
     * Recursively flattens a nested array.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to recursively flatten.
     * @returns {Array} Returns the new flattened array.
     * @example
     *
     * _.flattenDeep([1, [2, 3, [4]]]);
     * // => [1, 2, 3, 4]
     */
    function flattenDeep(array) {
      var length = array ? array.length : 0;
      return length ? baseFlatten(array, true) : [];
    }

    /**
     * Gets the index at which the first occurrence of `value` is found in `array`
     * using [`SameValueZero`](http://ecma-international.org/ecma-262/6.0/#sec-samevaluezero)
     * for equality comparisons. If `fromIndex` is negative, it is used as the offset
     * from the end of `array`. If `array` is sorted providing `true` for `fromIndex`
     * performs a faster binary search.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to search.
     * @param {*} value The value to search for.
     * @param {boolean|number} [fromIndex=0] The index to search from or `true`
     *  to perform a binary search on a sorted array.
     * @returns {number} Returns the index of the matched value, else `-1`.
     * @example
     *
     * _.indexOf([1, 2, 1, 2], 2);
     * // => 1
     *
     * // using `fromIndex`
     * _.indexOf([1, 2, 1, 2], 2, 2);
     * // => 3
     *
     * // performing a binary search
     * _.indexOf([1, 1, 2, 2], 2, true);
     * // => 2
     */
    function indexOf(array, value, fromIndex) {
      var length = array ? array.length : 0;
      if (!length) {
        return -1;
      }
      if (typeof fromIndex == 'number') {
        fromIndex = fromIndex < 0 ? nativeMax(length + fromIndex, 0) : fromIndex;
      } else if (fromIndex) {
        var index = binaryIndex(array, value);
        if (index < length &&
            (value === value ? (value === array[index]) : (array[index] !== array[index]))) {
          return index;
        }
        return -1;
      }
      return baseIndexOf(array, value, fromIndex || 0);
    }

    /**
     * Gets all but the last element of `array`.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to query.
     * @returns {Array} Returns the slice of `array`.
     * @example
     *
     * _.initial([1, 2, 3]);
     * // => [1, 2]
     */
    function initial(array) {
      return dropRight(array, 1);
    }

    /**
     * Creates an array of unique values that are included in all of the provided
     * arrays using [`SameValueZero`](http://ecma-international.org/ecma-262/6.0/#sec-samevaluezero)
     * for equality comparisons.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {...Array} [arrays] The arrays to inspect.
     * @returns {Array} Returns the new array of shared values.
     * @example
     * _.intersection([1, 2], [4, 2], [2, 1]);
     * // => [2]
     */
    var intersection = restParam(function(arrays) {
      var othLength = arrays.length,
          othIndex = othLength,
          caches = Array(length),
          indexOf = getIndexOf(),
          isCommon = indexOf == baseIndexOf,
          result = [];

      while (othIndex--) {
        var value = arrays[othIndex] = isArrayLike(value = arrays[othIndex]) ? value : [];
        caches[othIndex] = (isCommon && value.length >= 120) ? createCache(othIndex && value) : null;
      }
      var array = arrays[0],
          index = -1,
          length = array ? array.length : 0,
          seen = caches[0];

      outer:
      while (++index < length) {
        value = array[index];
        if ((seen ? cacheIndexOf(seen, value) : indexOf(result, value, 0)) < 0) {
          var othIndex = othLength;
          while (--othIndex) {
            var cache = caches[othIndex];
            if ((cache ? cacheIndexOf(cache, value) : indexOf(arrays[othIndex], value, 0)) < 0) {
              continue outer;
            }
          }
          if (seen) {
            seen.push(value);
          }
          result.push(value);
        }
      }
      return result;
    });

    /**
     * Gets the last element of `array`.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to query.
     * @returns {*} Returns the last element of `array`.
     * @example
     *
     * _.last([1, 2, 3]);
     * // => 3
     */
    function last(array) {
      var length = array ? array.length : 0;
      return length ? array[length - 1] : undefined;
    }

    /**
     * This method is like `_.indexOf` except that it iterates over elements of
     * `array` from right to left.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to search.
     * @param {*} value The value to search for.
     * @param {boolean|number} [fromIndex=array.length-1] The index to search from
     *  or `true` to perform a binary search on a sorted array.
     * @returns {number} Returns the index of the matched value, else `-1`.
     * @example
     *
     * _.lastIndexOf([1, 2, 1, 2], 2);
     * // => 3
     *
     * // using `fromIndex`
     * _.lastIndexOf([1, 2, 1, 2], 2, 2);
     * // => 1
     *
     * // performing a binary search
     * _.lastIndexOf([1, 1, 2, 2], 2, true);
     * // => 3
     */
    function lastIndexOf(array, value, fromIndex) {
      var length = array ? array.length : 0;
      if (!length) {
        return -1;
      }
      var index = length;
      if (typeof fromIndex == 'number') {
        index = (fromIndex < 0 ? nativeMax(length + fromIndex, 0) : nativeMin(fromIndex || 0, length - 1)) + 1;
      } else if (fromIndex) {
        index = binaryIndex(array, value, true) - 1;
        var other = array[index];
        if (value === value ? (value === other) : (other !== other)) {
          return index;
        }
        return -1;
      }
      if (value !== value) {
        return indexOfNaN(array, index, true);
      }
      while (index--) {
        if (array[index] === value) {
          return index;
        }
      }
      return -1;
    }

    /**
     * Removes all provided values from `array` using
     * [`SameValueZero`](http://ecma-international.org/ecma-262/6.0/#sec-samevaluezero)
     * for equality comparisons.
     *
     * **Note:** Unlike `_.without`, this method mutates `array`.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to modify.
     * @param {...*} [values] The values to remove.
     * @returns {Array} Returns `array`.
     * @example
     *
     * var array = [1, 2, 3, 1, 2, 3];
     *
     * _.pull(array, 2, 3);
     * console.log(array);
     * // => [1, 1]
     */
    function pull() {
      var args = arguments,
          array = args[0];

      if (!(array && array.length)) {
        return array;
      }
      var index = 0,
          indexOf = getIndexOf(),
          length = args.length;

      while (++index < length) {
        var fromIndex = 0,
            value = args[index];

        while ((fromIndex = indexOf(array, value, fromIndex)) > -1) {
          splice.call(array, fromIndex, 1);
        }
      }
      return array;
    }

    /**
     * Removes elements from `array` corresponding to the given indexes and returns
     * an array of the removed elements. Indexes may be specified as an array of
     * indexes or as individual arguments.
     *
     * **Note:** Unlike `_.at`, this method mutates `array`.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to modify.
     * @param {...(number|number[])} [indexes] The indexes of elements to remove,
     *  specified as individual indexes or arrays of indexes.
     * @returns {Array} Returns the new array of removed elements.
     * @example
     *
     * var array = [5, 10, 15, 20];
     * var evens = _.pullAt(array, 1, 3);
     *
     * console.log(array);
     * // => [5, 15]
     *
     * console.log(evens);
     * // => [10, 20]
     */
    var pullAt = restParam(function(array, indexes) {
      indexes = baseFlatten(indexes);

      var result = baseAt(array, indexes);
      basePullAt(array, indexes.sort(baseCompareAscending));
      return result;
    });

    /**
     * Removes all elements from `array` that `predicate` returns truthy for
     * and returns an array of the removed elements. The predicate is bound to
     * `thisArg` and invoked with three arguments: (value, index, array).
     *
     * If a property name is provided for `predicate` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `predicate` the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * **Note:** Unlike `_.filter`, this method mutates `array`.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to modify.
     * @param {Function|Object|string} [predicate=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `predicate`.
     * @returns {Array} Returns the new array of removed elements.
     * @example
     *
     * var array = [1, 2, 3, 4];
     * var evens = _.remove(array, function(n) {
     *   return n % 2 == 0;
     * });
     *
     * console.log(array);
     * // => [1, 3]
     *
     * console.log(evens);
     * // => [2, 4]
     */
    function remove(array, predicate, thisArg) {
      var result = [];
      if (!(array && array.length)) {
        return result;
      }
      var index = -1,
          indexes = [],
          length = array.length;

      predicate = getCallback(predicate, thisArg, 3);
      while (++index < length) {
        var value = array[index];
        if (predicate(value, index, array)) {
          result.push(value);
          indexes.push(index);
        }
      }
      basePullAt(array, indexes);
      return result;
    }

    /**
     * Gets all but the first element of `array`.
     *
     * @static
     * @memberOf _
     * @alias tail
     * @category Array
     * @param {Array} array The array to query.
     * @returns {Array} Returns the slice of `array`.
     * @example
     *
     * _.rest([1, 2, 3]);
     * // => [2, 3]
     */
    function rest(array) {
      return drop(array, 1);
    }

    /**
     * Creates a slice of `array` from `start` up to, but not including, `end`.
     *
     * **Note:** This method is used instead of `Array#slice` to support node
     * lists in IE < 9 and to ensure dense arrays are returned.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to slice.
     * @param {number} [start=0] The start position.
     * @param {number} [end=array.length] The end position.
     * @returns {Array} Returns the slice of `array`.
     */
    function slice(array, start, end) {
      var length = array ? array.length : 0;
      if (!length) {
        return [];
      }
      if (end && typeof end != 'number' && isIterateeCall(array, start, end)) {
        start = 0;
        end = length;
      }
      return baseSlice(array, start, end);
    }

    /**
     * Uses a binary search to determine the lowest index at which `value` should
     * be inserted into `array` in order to maintain its sort order. If an iteratee
     * function is provided it is invoked for `value` and each element of `array`
     * to compute their sort ranking. The iteratee is bound to `thisArg` and
     * invoked with one argument; (value).
     *
     * If a property name is provided for `iteratee` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `iteratee` the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The sorted array to inspect.
     * @param {*} value The value to evaluate.
     * @param {Function|Object|string} [iteratee=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {number} Returns the index at which `value` should be inserted
     *  into `array`.
     * @example
     *
     * _.sortedIndex([30, 50], 40);
     * // => 1
     *
     * _.sortedIndex([4, 4, 5, 5], 5);
     * // => 2
     *
     * var dict = { 'data': { 'thirty': 30, 'forty': 40, 'fifty': 50 } };
     *
     * // using an iteratee function
     * _.sortedIndex(['thirty', 'fifty'], 'forty', function(word) {
     *   return this.data[word];
     * }, dict);
     * // => 1
     *
     * // using the `_.property` callback shorthand
     * _.sortedIndex([{ 'x': 30 }, { 'x': 50 }], { 'x': 40 }, 'x');
     * // => 1
     */
    var sortedIndex = createSortedIndex();

    /**
     * This method is like `_.sortedIndex` except that it returns the highest
     * index at which `value` should be inserted into `array` in order to
     * maintain its sort order.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The sorted array to inspect.
     * @param {*} value The value to evaluate.
     * @param {Function|Object|string} [iteratee=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {number} Returns the index at which `value` should be inserted
     *  into `array`.
     * @example
     *
     * _.sortedLastIndex([4, 4, 5, 5], 5);
     * // => 4
     */
    var sortedLastIndex = createSortedIndex(true);

    /**
     * Creates a slice of `array` with `n` elements taken from the beginning.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to query.
     * @param {number} [n=1] The number of elements to take.
     * @param- {Object} [guard] Enables use as a callback for functions like `_.map`.
     * @returns {Array} Returns the slice of `array`.
     * @example
     *
     * _.take([1, 2, 3]);
     * // => [1]
     *
     * _.take([1, 2, 3], 2);
     * // => [1, 2]
     *
     * _.take([1, 2, 3], 5);
     * // => [1, 2, 3]
     *
     * _.take([1, 2, 3], 0);
     * // => []
     */
    function take(array, n, guard) {
      var length = array ? array.length : 0;
      if (!length) {
        return [];
      }
      if (guard ? isIterateeCall(array, n, guard) : n == null) {
        n = 1;
      }
      return baseSlice(array, 0, n < 0 ? 0 : n);
    }

    /**
     * Creates a slice of `array` with `n` elements taken from the end.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to query.
     * @param {number} [n=1] The number of elements to take.
     * @param- {Object} [guard] Enables use as a callback for functions like `_.map`.
     * @returns {Array} Returns the slice of `array`.
     * @example
     *
     * _.takeRight([1, 2, 3]);
     * // => [3]
     *
     * _.takeRight([1, 2, 3], 2);
     * // => [2, 3]
     *
     * _.takeRight([1, 2, 3], 5);
     * // => [1, 2, 3]
     *
     * _.takeRight([1, 2, 3], 0);
     * // => []
     */
    function takeRight(array, n, guard) {
      var length = array ? array.length : 0;
      if (!length) {
        return [];
      }
      if (guard ? isIterateeCall(array, n, guard) : n == null) {
        n = 1;
      }
      n = length - (+n || 0);
      return baseSlice(array, n < 0 ? 0 : n);
    }

    /**
     * Creates a slice of `array` with elements taken from the end. Elements are
     * taken until `predicate` returns falsey. The predicate is bound to `thisArg`
     * and invoked with three arguments: (value, index, array).
     *
     * If a property name is provided for `predicate` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `predicate` the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to query.
     * @param {Function|Object|string} [predicate=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `predicate`.
     * @returns {Array} Returns the slice of `array`.
     * @example
     *
     * _.takeRightWhile([1, 2, 3], function(n) {
     *   return n > 1;
     * });
     * // => [2, 3]
     *
     * var users = [
     *   { 'user': 'barney',  'active': true },
     *   { 'user': 'fred',    'active': false },
     *   { 'user': 'pebbles', 'active': false }
     * ];
     *
     * // using the `_.matches` callback shorthand
     * _.pluck(_.takeRightWhile(users, { 'user': 'pebbles', 'active': false }), 'user');
     * // => ['pebbles']
     *
     * // using the `_.matchesProperty` callback shorthand
     * _.pluck(_.takeRightWhile(users, 'active', false), 'user');
     * // => ['fred', 'pebbles']
     *
     * // using the `_.property` callback shorthand
     * _.pluck(_.takeRightWhile(users, 'active'), 'user');
     * // => []
     */
    function takeRightWhile(array, predicate, thisArg) {
      return (array && array.length)
        ? baseWhile(array, getCallback(predicate, thisArg, 3), false, true)
        : [];
    }

    /**
     * Creates a slice of `array` with elements taken from the beginning. Elements
     * are taken until `predicate` returns falsey. The predicate is bound to
     * `thisArg` and invoked with three arguments: (value, index, array).
     *
     * If a property name is provided for `predicate` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `predicate` the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to query.
     * @param {Function|Object|string} [predicate=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `predicate`.
     * @returns {Array} Returns the slice of `array`.
     * @example
     *
     * _.takeWhile([1, 2, 3], function(n) {
     *   return n < 3;
     * });
     * // => [1, 2]
     *
     * var users = [
     *   { 'user': 'barney',  'active': false },
     *   { 'user': 'fred',    'active': false},
     *   { 'user': 'pebbles', 'active': true }
     * ];
     *
     * // using the `_.matches` callback shorthand
     * _.pluck(_.takeWhile(users, { 'user': 'barney', 'active': false }), 'user');
     * // => ['barney']
     *
     * // using the `_.matchesProperty` callback shorthand
     * _.pluck(_.takeWhile(users, 'active', false), 'user');
     * // => ['barney', 'fred']
     *
     * // using the `_.property` callback shorthand
     * _.pluck(_.takeWhile(users, 'active'), 'user');
     * // => []
     */
    function takeWhile(array, predicate, thisArg) {
      return (array && array.length)
        ? baseWhile(array, getCallback(predicate, thisArg, 3))
        : [];
    }

    /**
     * Creates an array of unique values, in order, from all of the provided arrays
     * using [`SameValueZero`](http://ecma-international.org/ecma-262/6.0/#sec-samevaluezero)
     * for equality comparisons.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {...Array} [arrays] The arrays to inspect.
     * @returns {Array} Returns the new array of combined values.
     * @example
     *
     * _.union([1, 2], [4, 2], [2, 1]);
     * // => [1, 2, 4]
     */
    var union = restParam(function(arrays) {
      return baseUniq(baseFlatten(arrays, false, true));
    });

    /**
     * Creates a duplicate-free version of an array, using
     * [`SameValueZero`](http://ecma-international.org/ecma-262/6.0/#sec-samevaluezero)
     * for equality comparisons, in which only the first occurence of each element
     * is kept. Providing `true` for `isSorted` performs a faster search algorithm
     * for sorted arrays. If an iteratee function is provided it is invoked for
     * each element in the array to generate the criterion by which uniqueness
     * is computed. The `iteratee` is bound to `thisArg` and invoked with three
     * arguments: (value, index, array).
     *
     * If a property name is provided for `iteratee` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `iteratee` the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @alias unique
     * @category Array
     * @param {Array} array The array to inspect.
     * @param {boolean} [isSorted] Specify the array is sorted.
     * @param {Function|Object|string} [iteratee] The function invoked per iteration.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {Array} Returns the new duplicate-value-free array.
     * @example
     *
     * _.uniq([2, 1, 2]);
     * // => [2, 1]
     *
     * // using `isSorted`
     * _.uniq([1, 1, 2], true);
     * // => [1, 2]
     *
     * // using an iteratee function
     * _.uniq([1, 2.5, 1.5, 2], function(n) {
     *   return this.floor(n);
     * }, Math);
     * // => [1, 2.5]
     *
     * // using the `_.property` callback shorthand
     * _.uniq([{ 'x': 1 }, { 'x': 2 }, { 'x': 1 }], 'x');
     * // => [{ 'x': 1 }, { 'x': 2 }]
     */
    function uniq(array, isSorted, iteratee, thisArg) {
      var length = array ? array.length : 0;
      if (!length) {
        return [];
      }
      if (isSorted != null && typeof isSorted != 'boolean') {
        thisArg = iteratee;
        iteratee = isIterateeCall(array, isSorted, thisArg) ? undefined : isSorted;
        isSorted = false;
      }
      var callback = getCallback();
      if (!(iteratee == null && callback === baseCallback)) {
        iteratee = callback(iteratee, thisArg, 3);
      }
      return (isSorted && getIndexOf() == baseIndexOf)
        ? sortedUniq(array, iteratee)
        : baseUniq(array, iteratee);
    }

    /**
     * This method is like `_.zip` except that it accepts an array of grouped
     * elements and creates an array regrouping the elements to their pre-zip
     * configuration.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array of grouped elements to process.
     * @returns {Array} Returns the new array of regrouped elements.
     * @example
     *
     * var zipped = _.zip(['fred', 'barney'], [30, 40], [true, false]);
     * // => [['fred', 30, true], ['barney', 40, false]]
     *
     * _.unzip(zipped);
     * // => [['fred', 'barney'], [30, 40], [true, false]]
     */
    function unzip(array) {
      if (!(array && array.length)) {
        return [];
      }
      var index = -1,
          length = 0;

      array = arrayFilter(array, function(group) {
        if (isArrayLike(group)) {
          length = nativeMax(group.length, length);
          return true;
        }
      });
      var result = Array(length);
      while (++index < length) {
        result[index] = arrayMap(array, baseProperty(index));
      }
      return result;
    }

    /**
     * This method is like `_.unzip` except that it accepts an iteratee to specify
     * how regrouped values should be combined. The `iteratee` is bound to `thisArg`
     * and invoked with four arguments: (accumulator, value, index, group).
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array of grouped elements to process.
     * @param {Function} [iteratee] The function to combine regrouped values.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {Array} Returns the new array of regrouped elements.
     * @example
     *
     * var zipped = _.zip([1, 2], [10, 20], [100, 200]);
     * // => [[1, 10, 100], [2, 20, 200]]
     *
     * _.unzipWith(zipped, _.add);
     * // => [3, 30, 300]
     */
    function unzipWith(array, iteratee, thisArg) {
      var length = array ? array.length : 0;
      if (!length) {
        return [];
      }
      var result = unzip(array);
      if (iteratee == null) {
        return result;
      }
      iteratee = bindCallback(iteratee, thisArg, 4);
      return arrayMap(result, function(group) {
        return arrayReduce(group, iteratee, undefined, true);
      });
    }

    /**
     * Creates an array excluding all provided values using
     * [`SameValueZero`](http://ecma-international.org/ecma-262/6.0/#sec-samevaluezero)
     * for equality comparisons.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {Array} array The array to filter.
     * @param {...*} [values] The values to exclude.
     * @returns {Array} Returns the new array of filtered values.
     * @example
     *
     * _.without([1, 2, 1, 3], 1, 2);
     * // => [3]
     */
    var without = restParam(function(array, values) {
      return isArrayLike(array)
        ? baseDifference(array, values)
        : [];
    });

    /**
     * Creates an array of unique values that is the [symmetric difference](https://en.wikipedia.org/wiki/Symmetric_difference)
     * of the provided arrays.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {...Array} [arrays] The arrays to inspect.
     * @returns {Array} Returns the new array of values.
     * @example
     *
     * _.xor([1, 2], [4, 2]);
     * // => [1, 4]
     */
    function xor() {
      var index = -1,
          length = arguments.length;

      while (++index < length) {
        var array = arguments[index];
        if (isArrayLike(array)) {
          var result = result
            ? arrayPush(baseDifference(result, array), baseDifference(array, result))
            : array;
        }
      }
      return result ? baseUniq(result) : [];
    }

    /**
     * Creates an array of grouped elements, the first of which contains the first
     * elements of the given arrays, the second of which contains the second elements
     * of the given arrays, and so on.
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {...Array} [arrays] The arrays to process.
     * @returns {Array} Returns the new array of grouped elements.
     * @example
     *
     * _.zip(['fred', 'barney'], [30, 40], [true, false]);
     * // => [['fred', 30, true], ['barney', 40, false]]
     */
    var zip = restParam(unzip);

    /**
     * The inverse of `_.pairs`; this method returns an object composed from arrays
     * of property names and values. Provide either a single two dimensional array,
     * e.g. `[[key1, value1], [key2, value2]]` or two arrays, one of property names
     * and one of corresponding values.
     *
     * @static
     * @memberOf _
     * @alias object
     * @category Array
     * @param {Array} props The property names.
     * @param {Array} [values=[]] The property values.
     * @returns {Object} Returns the new object.
     * @example
     *
     * _.zipObject([['fred', 30], ['barney', 40]]);
     * // => { 'fred': 30, 'barney': 40 }
     *
     * _.zipObject(['fred', 'barney'], [30, 40]);
     * // => { 'fred': 30, 'barney': 40 }
     */
    function zipObject(props, values) {
      var index = -1,
          length = props ? props.length : 0,
          result = {};

      if (length && !values && !isArray(props[0])) {
        values = [];
      }
      while (++index < length) {
        var key = props[index];
        if (values) {
          result[key] = values[index];
        } else if (key) {
          result[key[0]] = key[1];
        }
      }
      return result;
    }

    /**
     * This method is like `_.zip` except that it accepts an iteratee to specify
     * how grouped values should be combined. The `iteratee` is bound to `thisArg`
     * and invoked with four arguments: (accumulator, value, index, group).
     *
     * @static
     * @memberOf _
     * @category Array
     * @param {...Array} [arrays] The arrays to process.
     * @param {Function} [iteratee] The function to combine grouped values.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {Array} Returns the new array of grouped elements.
     * @example
     *
     * _.zipWith([1, 2], [10, 20], [100, 200], _.add);
     * // => [111, 222]
     */
    var zipWith = restParam(function(arrays) {
      var length = arrays.length,
          iteratee = length > 2 ? arrays[length - 2] : undefined,
          thisArg = length > 1 ? arrays[length - 1] : undefined;

      if (length > 2 && typeof iteratee == 'function') {
        length -= 2;
      } else {
        iteratee = (length > 1 && typeof thisArg == 'function') ? (--length, thisArg) : undefined;
        thisArg = undefined;
      }
      arrays.length = length;
      return unzipWith(arrays, iteratee, thisArg);
    });

    /*------------------------------------------------------------------------*/

    /**
     * Creates a `lodash` object that wraps `value` with explicit method
     * chaining enabled.
     *
     * @static
     * @memberOf _
     * @category Chain
     * @param {*} value The value to wrap.
     * @returns {Object} Returns the new `lodash` wrapper instance.
     * @example
     *
     * var users = [
     *   { 'user': 'barney',  'age': 36 },
     *   { 'user': 'fred',    'age': 40 },
     *   { 'user': 'pebbles', 'age': 1 }
     * ];
     *
     * var youngest = _.chain(users)
     *   .sortBy('age')
     *   .map(function(chr) {
     *     return chr.user + ' is ' + chr.age;
     *   })
     *   .first()
     *   .value();
     * // => 'pebbles is 1'
     */
    function chain(value) {
      var result = lodash(value);
      result.__chain__ = true;
      return result;
    }

    /**
     * This method invokes `interceptor` and returns `value`. The interceptor is
     * bound to `thisArg` and invoked with one argument; (value). The purpose of
     * this method is to "tap into" a method chain in order to perform operations
     * on intermediate results within the chain.
     *
     * @static
     * @memberOf _
     * @category Chain
     * @param {*} value The value to provide to `interceptor`.
     * @param {Function} interceptor The function to invoke.
     * @param {*} [thisArg] The `this` binding of `interceptor`.
     * @returns {*} Returns `value`.
     * @example
     *
     * _([1, 2, 3])
     *  .tap(function(array) {
     *    array.pop();
     *  })
     *  .reverse()
     *  .value();
     * // => [2, 1]
     */
    function tap(value, interceptor, thisArg) {
      interceptor.call(thisArg, value);
      return value;
    }

    /**
     * This method is like `_.tap` except that it returns the result of `interceptor`.
     *
     * @static
     * @memberOf _
     * @category Chain
     * @param {*} value The value to provide to `interceptor`.
     * @param {Function} interceptor The function to invoke.
     * @param {*} [thisArg] The `this` binding of `interceptor`.
     * @returns {*} Returns the result of `interceptor`.
     * @example
     *
     * _('  abc  ')
     *  .chain()
     *  .trim()
     *  .thru(function(value) {
     *    return [value];
     *  })
     *  .value();
     * // => ['abc']
     */
    function thru(value, interceptor, thisArg) {
      return interceptor.call(thisArg, value);
    }

    /**
     * Enables explicit method chaining on the wrapper object.
     *
     * @name chain
     * @memberOf _
     * @category Chain
     * @returns {Object} Returns the new `lodash` wrapper instance.
     * @example
     *
     * var users = [
     *   { 'user': 'barney', 'age': 36 },
     *   { 'user': 'fred',   'age': 40 }
     * ];
     *
     * // without explicit chaining
     * _(users).first();
     * // => { 'user': 'barney', 'age': 36 }
     *
     * // with explicit chaining
     * _(users).chain()
     *   .first()
     *   .pick('user')
     *   .value();
     * // => { 'user': 'barney' }
     */
    function wrapperChain() {
      return chain(this);
    }

    /**
     * Executes the chained sequence and returns the wrapped result.
     *
     * @name commit
     * @memberOf _
     * @category Chain
     * @returns {Object} Returns the new `lodash` wrapper instance.
     * @example
     *
     * var array = [1, 2];
     * var wrapped = _(array).push(3);
     *
     * console.log(array);
     * // => [1, 2]
     *
     * wrapped = wrapped.commit();
     * console.log(array);
     * // => [1, 2, 3]
     *
     * wrapped.last();
     * // => 3
     *
     * console.log(array);
     * // => [1, 2, 3]
     */
    function wrapperCommit() {
      return new LodashWrapper(this.value(), this.__chain__);
    }

    /**
     * Creates a new array joining a wrapped array with any additional arrays
     * and/or values.
     *
     * @name concat
     * @memberOf _
     * @category Chain
     * @param {...*} [values] The values to concatenate.
     * @returns {Array} Returns the new concatenated array.
     * @example
     *
     * var array = [1];
     * var wrapped = _(array).concat(2, [3], [[4]]);
     *
     * console.log(wrapped.value());
     * // => [1, 2, 3, [4]]
     *
     * console.log(array);
     * // => [1]
     */
    var wrapperConcat = restParam(function(values) {
      values = baseFlatten(values);
      return this.thru(function(array) {
        return arrayConcat(isArray(array) ? array : [toObject(array)], values);
      });
    });

    /**
     * Creates a clone of the chained sequence planting `value` as the wrapped value.
     *
     * @name plant
     * @memberOf _
     * @category Chain
     * @returns {Object} Returns the new `lodash` wrapper instance.
     * @example
     *
     * var array = [1, 2];
     * var wrapped = _(array).map(function(value) {
     *   return Math.pow(value, 2);
     * });
     *
     * var other = [3, 4];
     * var otherWrapped = wrapped.plant(other);
     *
     * otherWrapped.value();
     * // => [9, 16]
     *
     * wrapped.value();
     * // => [1, 4]
     */
    function wrapperPlant(value) {
      var result,
          parent = this;

      while (parent instanceof baseLodash) {
        var clone = wrapperClone(parent);
        if (result) {
          previous.__wrapped__ = clone;
        } else {
          result = clone;
        }
        var previous = clone;
        parent = parent.__wrapped__;
      }
      previous.__wrapped__ = value;
      return result;
    }

    /**
     * Reverses the wrapped array so the first element becomes the last, the
     * second element becomes the second to last, and so on.
     *
     * **Note:** This method mutates the wrapped array.
     *
     * @name reverse
     * @memberOf _
     * @category Chain
     * @returns {Object} Returns the new reversed `lodash` wrapper instance.
     * @example
     *
     * var array = [1, 2, 3];
     *
     * _(array).reverse().value()
     * // => [3, 2, 1]
     *
     * console.log(array);
     * // => [3, 2, 1]
     */
    function wrapperReverse() {
      var value = this.__wrapped__;

      var interceptor = function(value) {
        return (wrapped && wrapped.__dir__ < 0) ? value : value.reverse();
      };
      if (value instanceof LazyWrapper) {
        var wrapped = value;
        if (this.__actions__.length) {
          wrapped = new LazyWrapper(this);
        }
        wrapped = wrapped.reverse();
        wrapped.__actions__.push({ 'func': thru, 'args': [interceptor], 'thisArg': undefined });
        return new LodashWrapper(wrapped, this.__chain__);
      }
      return this.thru(interceptor);
    }

    /**
     * Produces the result of coercing the unwrapped value to a string.
     *
     * @name toString
     * @memberOf _
     * @category Chain
     * @returns {string} Returns the coerced string value.
     * @example
     *
     * _([1, 2, 3]).toString();
     * // => '1,2,3'
     */
    function wrapperToString() {
      return (this.value() + '');
    }

    /**
     * Executes the chained sequence to extract the unwrapped value.
     *
     * @name value
     * @memberOf _
     * @alias run, toJSON, valueOf
     * @category Chain
     * @returns {*} Returns the resolved unwrapped value.
     * @example
     *
     * _([1, 2, 3]).value();
     * // => [1, 2, 3]
     */
    function wrapperValue() {
      return baseWrapperValue(this.__wrapped__, this.__actions__);
    }

    /*------------------------------------------------------------------------*/

    /**
     * Creates an array of elements corresponding to the given keys, or indexes,
     * of `collection`. Keys may be specified as individual arguments or as arrays
     * of keys.
     *
     * @static
     * @memberOf _
     * @category Collection
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {...(number|number[]|string|string[])} [props] The property names
     *  or indexes of elements to pick, specified individually or in arrays.
     * @returns {Array} Returns the new array of picked elements.
     * @example
     *
     * _.at(['a', 'b', 'c'], [0, 2]);
     * // => ['a', 'c']
     *
     * _.at(['barney', 'fred', 'pebbles'], 0, 2);
     * // => ['barney', 'pebbles']
     */
    var at = restParam(function(collection, props) {
      return baseAt(collection, baseFlatten(props));
    });

    /**
     * Creates an object composed of keys generated from the results of running
     * each element of `collection` through `iteratee`. The corresponding value
     * of each key is the number of times the key was returned by `iteratee`.
     * The `iteratee` is bound to `thisArg` and invoked with three arguments:
     * (value, index|key, collection).
     *
     * If a property name is provided for `iteratee` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `iteratee` the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @category Collection
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function|Object|string} [iteratee=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {Object} Returns the composed aggregate object.
     * @example
     *
     * _.countBy([4.3, 6.1, 6.4], function(n) {
     *   return Math.floor(n);
     * });
     * // => { '4': 1, '6': 2 }
     *
     * _.countBy([4.3, 6.1, 6.4], function(n) {
     *   return this.floor(n);
     * }, Math);
     * // => { '4': 1, '6': 2 }
     *
     * _.countBy(['one', 'two', 'three'], 'length');
     * // => { '3': 2, '5': 1 }
     */
    var countBy = createAggregator(function(result, value, key) {
      hasOwnProperty.call(result, key) ? ++result[key] : (result[key] = 1);
    });

    /**
     * Checks if `predicate` returns truthy for **all** elements of `collection`.
     * The predicate is bound to `thisArg` and invoked with three arguments:
     * (value, index|key, collection).
     *
     * If a property name is provided for `predicate` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `predicate` the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @alias all
     * @category Collection
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function|Object|string} [predicate=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `predicate`.
     * @returns {boolean} Returns `true` if all elements pass the predicate check,
     *  else `false`.
     * @example
     *
     * _.every([true, 1, null, 'yes'], Boolean);
     * // => false
     *
     * var users = [
     *   { 'user': 'barney', 'active': false },
     *   { 'user': 'fred',   'active': false }
     * ];
     *
     * // using the `_.matches` callback shorthand
     * _.every(users, { 'user': 'barney', 'active': false });
     * // => false
     *
     * // using the `_.matchesProperty` callback shorthand
     * _.every(users, 'active', false);
     * // => true
     *
     * // using the `_.property` callback shorthand
     * _.every(users, 'active');
     * // => false
     */
    function every(collection, predicate, thisArg) {
      var func = isArray(collection) ? arrayEvery : baseEvery;
      if (thisArg && isIterateeCall(collection, predicate, thisArg)) {
        predicate = undefined;
      }
      if (typeof predicate != 'function' || thisArg !== undefined) {
        predicate = getCallback(predicate, thisArg, 3);
      }
      return func(collection, predicate);
    }

    /**
     * Iterates over elements of `collection`, returning an array of all elements
     * `predicate` returns truthy for. The predicate is bound to `thisArg` and
     * invoked with three arguments: (value, index|key, collection).
     *
     * If a property name is provided for `predicate` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `predicate` the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @alias select
     * @category Collection
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function|Object|string} [predicate=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `predicate`.
     * @returns {Array} Returns the new filtered array.
     * @example
     *
     * _.filter([4, 5, 6], function(n) {
     *   return n % 2 == 0;
     * });
     * // => [4, 6]
     *
     * var users = [
     *   { 'user': 'barney', 'age': 36, 'active': true },
     *   { 'user': 'fred',   'age': 40, 'active': false }
     * ];
     *
     * // using the `_.matches` callback shorthand
     * _.pluck(_.filter(users, { 'age': 36, 'active': true }), 'user');
     * // => ['barney']
     *
     * // using the `_.matchesProperty` callback shorthand
     * _.pluck(_.filter(users, 'active', false), 'user');
     * // => ['fred']
     *
     * // using the `_.property` callback shorthand
     * _.pluck(_.filter(users, 'active'), 'user');
     * // => ['barney']
     */
    function filter(collection, predicate, thisArg) {
      var func = isArray(collection) ? arrayFilter : baseFilter;
      predicate = getCallback(predicate, thisArg, 3);
      return func(collection, predicate);
    }

    /**
     * Iterates over elements of `collection`, returning the first element
     * `predicate` returns truthy for. The predicate is bound to `thisArg` and
     * invoked with three arguments: (value, index|key, collection).
     *
     * If a property name is provided for `predicate` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `predicate` the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @alias detect
     * @category Collection
     * @param {Array|Object|string} collection The collection to search.
     * @param {Function|Object|string} [predicate=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `predicate`.
     * @returns {*} Returns the matched element, else `undefined`.
     * @example
     *
     * var users = [
     *   { 'user': 'barney',  'age': 36, 'active': true },
     *   { 'user': 'fred',    'age': 40, 'active': false },
     *   { 'user': 'pebbles', 'age': 1,  'active': true }
     * ];
     *
     * _.result(_.find(users, function(chr) {
     *   return chr.age < 40;
     * }), 'user');
     * // => 'barney'
     *
     * // using the `_.matches` callback shorthand
     * _.result(_.find(users, { 'age': 1, 'active': true }), 'user');
     * // => 'pebbles'
     *
     * // using the `_.matchesProperty` callback shorthand
     * _.result(_.find(users, 'active', false), 'user');
     * // => 'fred'
     *
     * // using the `_.property` callback shorthand
     * _.result(_.find(users, 'active'), 'user');
     * // => 'barney'
     */
    var find = createFind(baseEach);

    /**
     * This method is like `_.find` except that it iterates over elements of
     * `collection` from right to left.
     *
     * @static
     * @memberOf _
     * @category Collection
     * @param {Array|Object|string} collection The collection to search.
     * @param {Function|Object|string} [predicate=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `predicate`.
     * @returns {*} Returns the matched element, else `undefined`.
     * @example
     *
     * _.findLast([1, 2, 3, 4], function(n) {
     *   return n % 2 == 1;
     * });
     * // => 3
     */
    var findLast = createFind(baseEachRight, true);

    /**
     * Performs a deep comparison between each element in `collection` and the
     * source object, returning the first element that has equivalent property
     * values.
     *
     * **Note:** This method supports comparing arrays, booleans, `Date` objects,
     * numbers, `Object` objects, regexes, and strings. Objects are compared by
     * their own, not inherited, enumerable properties. For comparing a single
     * own or inherited property value see `_.matchesProperty`.
     *
     * @static
     * @memberOf _
     * @category Collection
     * @param {Array|Object|string} collection The collection to search.
     * @param {Object} source The object of property values to match.
     * @returns {*} Returns the matched element, else `undefined`.
     * @example
     *
     * var users = [
     *   { 'user': 'barney', 'age': 36, 'active': true },
     *   { 'user': 'fred',   'age': 40, 'active': false }
     * ];
     *
     * _.result(_.findWhere(users, { 'age': 36, 'active': true }), 'user');
     * // => 'barney'
     *
     * _.result(_.findWhere(users, { 'age': 40, 'active': false }), 'user');
     * // => 'fred'
     */
    function findWhere(collection, source) {
      return find(collection, baseMatches(source));
    }

    /**
     * Iterates over elements of `collection` invoking `iteratee` for each element.
     * The `iteratee` is bound to `thisArg` and invoked with three arguments:
     * (value, index|key, collection). Iteratee functions may exit iteration early
     * by explicitly returning `false`.
     *
     * **Note:** As with other "Collections" methods, objects with a "length" property
     * are iterated like arrays. To avoid this behavior `_.forIn` or `_.forOwn`
     * may be used for object iteration.
     *
     * @static
     * @memberOf _
     * @alias each
     * @category Collection
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {Array|Object|string} Returns `collection`.
     * @example
     *
     * _([1, 2]).forEach(function(n) {
     *   console.log(n);
     * }).value();
     * // => logs each value from left to right and returns the array
     *
     * _.forEach({ 'a': 1, 'b': 2 }, function(n, key) {
     *   console.log(n, key);
     * });
     * // => logs each value-key pair and returns the object (iteration order is not guaranteed)
     */
    var forEach = createForEach(arrayEach, baseEach);

    /**
     * This method is like `_.forEach` except that it iterates over elements of
     * `collection` from right to left.
     *
     * @static
     * @memberOf _
     * @alias eachRight
     * @category Collection
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {Array|Object|string} Returns `collection`.
     * @example
     *
     * _([1, 2]).forEachRight(function(n) {
     *   console.log(n);
     * }).value();
     * // => logs each value from right to left and returns the array
     */
    var forEachRight = createForEach(arrayEachRight, baseEachRight);

    /**
     * Creates an object composed of keys generated from the results of running
     * each element of `collection` through `iteratee`. The corresponding value
     * of each key is an array of the elements responsible for generating the key.
     * The `iteratee` is bound to `thisArg` and invoked with three arguments:
     * (value, index|key, collection).
     *
     * If a property name is provided for `iteratee` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `iteratee` the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @category Collection
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function|Object|string} [iteratee=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {Object} Returns the composed aggregate object.
     * @example
     *
     * _.groupBy([4.2, 6.1, 6.4], function(n) {
     *   return Math.floor(n);
     * });
     * // => { '4': [4.2], '6': [6.1, 6.4] }
     *
     * _.groupBy([4.2, 6.1, 6.4], function(n) {
     *   return this.floor(n);
     * }, Math);
     * // => { '4': [4.2], '6': [6.1, 6.4] }
     *
     * // using the `_.property` callback shorthand
     * _.groupBy(['one', 'two', 'three'], 'length');
     * // => { '3': ['one', 'two'], '5': ['three'] }
     */
    var groupBy = createAggregator(function(result, value, key) {
      if (hasOwnProperty.call(result, key)) {
        result[key].push(value);
      } else {
        result[key] = [value];
      }
    });

    /**
     * Checks if `value` is in `collection` using
     * [`SameValueZero`](http://ecma-international.org/ecma-262/6.0/#sec-samevaluezero)
     * for equality comparisons. If `fromIndex` is negative, it is used as the offset
     * from the end of `collection`.
     *
     * @static
     * @memberOf _
     * @alias contains, include
     * @category Collection
     * @param {Array|Object|string} collection The collection to search.
     * @param {*} target The value to search for.
     * @param {number} [fromIndex=0] The index to search from.
     * @param- {Object} [guard] Enables use as a callback for functions like `_.reduce`.
     * @returns {boolean} Returns `true` if a matching element is found, else `false`.
     * @example
     *
     * _.includes([1, 2, 3], 1);
     * // => true
     *
     * _.includes([1, 2, 3], 1, 2);
     * // => false
     *
     * _.includes({ 'user': 'fred', 'age': 40 }, 'fred');
     * // => true
     *
     * _.includes('pebbles', 'eb');
     * // => true
     */
    function includes(collection, target, fromIndex, guard) {
      var length = collection ? getLength(collection) : 0;
      if (!isLength(length)) {
        collection = values(collection);
        length = collection.length;
      }
      if (typeof fromIndex != 'number' || (guard && isIterateeCall(target, fromIndex, guard))) {
        fromIndex = 0;
      } else {
        fromIndex = fromIndex < 0 ? nativeMax(length + fromIndex, 0) : (fromIndex || 0);
      }
      return (typeof collection == 'string' || !isArray(collection) && isString(collection))
        ? (fromIndex <= length && collection.indexOf(target, fromIndex) > -1)
        : (!!length && getIndexOf(collection, target, fromIndex) > -1);
    }

    /**
     * Creates an object composed of keys generated from the results of running
     * each element of `collection` through `iteratee`. The corresponding value
     * of each key is the last element responsible for generating the key. The
     * iteratee function is bound to `thisArg` and invoked with three arguments:
     * (value, index|key, collection).
     *
     * If a property name is provided for `iteratee` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `iteratee` the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @category Collection
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function|Object|string} [iteratee=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {Object} Returns the composed aggregate object.
     * @example
     *
     * var keyData = [
     *   { 'dir': 'left', 'code': 97 },
     *   { 'dir': 'right', 'code': 100 }
     * ];
     *
     * _.indexBy(keyData, 'dir');
     * // => { 'left': { 'dir': 'left', 'code': 97 }, 'right': { 'dir': 'right', 'code': 100 } }
     *
     * _.indexBy(keyData, function(object) {
     *   return String.fromCharCode(object.code);
     * });
     * // => { 'a': { 'dir': 'left', 'code': 97 }, 'd': { 'dir': 'right', 'code': 100 } }
     *
     * _.indexBy(keyData, function(object) {
     *   return this.fromCharCode(object.code);
     * }, String);
     * // => { 'a': { 'dir': 'left', 'code': 97 }, 'd': { 'dir': 'right', 'code': 100 } }
     */
    var indexBy = createAggregator(function(result, value, key) {
      result[key] = value;
    });

    /**
     * Invokes the method at `path` of each element in `collection`, returning
     * an array of the results of each invoked method. Any additional arguments
     * are provided to each invoked method. If `methodName` is a function it is
     * invoked for, and `this` bound to, each element in `collection`.
     *
     * @static
     * @memberOf _
     * @category Collection
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Array|Function|string} path The path of the method to invoke or
     *  the function invoked per iteration.
     * @param {...*} [args] The arguments to invoke the method with.
     * @returns {Array} Returns the array of results.
     * @example
     *
     * _.invoke([[5, 1, 7], [3, 2, 1]], 'sort');
     * // => [[1, 5, 7], [1, 2, 3]]
     *
     * _.invoke([123, 456], String.prototype.split, '');
     * // => [['1', '2', '3'], ['4', '5', '6']]
     */
    var invoke = restParam(function(collection, path, args) {
      var index = -1,
          isFunc = typeof path == 'function',
          isProp = isKey(path),
          result = isArrayLike(collection) ? Array(collection.length) : [];

      baseEach(collection, function(value) {
        var func = isFunc ? path : ((isProp && value != null) ? value[path] : undefined);
        result[++index] = func ? func.apply(value, args) : invokePath(value, path, args);
      });
      return result;
    });

    /**
     * Creates an array of values by running each element in `collection` through
     * `iteratee`. The `iteratee` is bound to `thisArg` and invoked with three
     * arguments: (value, index|key, collection).
     *
     * If a property name is provided for `iteratee` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `iteratee` the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * Many lodash methods are guarded to work as iteratees for methods like
     * `_.every`, `_.filter`, `_.map`, `_.mapValues`, `_.reject`, and `_.some`.
     *
     * The guarded methods are:
     * `ary`, `callback`, `chunk`, `clone`, `create`, `curry`, `curryRight`,
     * `drop`, `dropRight`, `every`, `fill`, `flatten`, `invert`, `max`, `min`,
     * `parseInt`, `slice`, `sortBy`, `take`, `takeRight`, `template`, `trim`,
     * `trimLeft`, `trimRight`, `trunc`, `random`, `range`, `sample`, `some`,
     * `sum`, `uniq`, and `words`
     *
     * @static
     * @memberOf _
     * @alias collect
     * @category Collection
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function|Object|string} [iteratee=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {Array} Returns the new mapped array.
     * @example
     *
     * function timesThree(n) {
     *   return n * 3;
     * }
     *
     * _.map([1, 2], timesThree);
     * // => [3, 6]
     *
     * _.map({ 'a': 1, 'b': 2 }, timesThree);
     * // => [3, 6] (iteration order is not guaranteed)
     *
     * var users = [
     *   { 'user': 'barney' },
     *   { 'user': 'fred' }
     * ];
     *
     * // using the `_.property` callback shorthand
     * _.map(users, 'user');
     * // => ['barney', 'fred']
     */
    function map(collection, iteratee, thisArg) {
      var func = isArray(collection) ? arrayMap : baseMap;
      iteratee = getCallback(iteratee, thisArg, 3);
      return func(collection, iteratee);
    }

    /**
     * Creates an array of elements split into two groups, the first of which
     * contains elements `predicate` returns truthy for, while the second of which
     * contains elements `predicate` returns falsey for. The predicate is bound
     * to `thisArg` and invoked with three arguments: (value, index|key, collection).
     *
     * If a property name is provided for `predicate` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `predicate` the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @category Collection
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function|Object|string} [predicate=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `predicate`.
     * @returns {Array} Returns the array of grouped elements.
     * @example
     *
     * _.partition([1, 2, 3], function(n) {
     *   return n % 2;
     * });
     * // => [[1, 3], [2]]
     *
     * _.partition([1.2, 2.3, 3.4], function(n) {
     *   return this.floor(n) % 2;
     * }, Math);
     * // => [[1.2, 3.4], [2.3]]
     *
     * var users = [
     *   { 'user': 'barney',  'age': 36, 'active': false },
     *   { 'user': 'fred',    'age': 40, 'active': true },
     *   { 'user': 'pebbles', 'age': 1,  'active': false }
     * ];
     *
     * var mapper = function(array) {
     *   return _.pluck(array, 'user');
     * };
     *
     * // using the `_.matches` callback shorthand
     * _.map(_.partition(users, { 'age': 1, 'active': false }), mapper);
     * // => [['pebbles'], ['barney', 'fred']]
     *
     * // using the `_.matchesProperty` callback shorthand
     * _.map(_.partition(users, 'active', false), mapper);
     * // => [['barney', 'pebbles'], ['fred']]
     *
     * // using the `_.property` callback shorthand
     * _.map(_.partition(users, 'active'), mapper);
     * // => [['fred'], ['barney', 'pebbles']]
     */
    var partition = createAggregator(function(result, value, key) {
      result[key ? 0 : 1].push(value);
    }, function() { return [[], []]; });

    /**
     * Gets the property value of `path` from all elements in `collection`.
     *
     * @static
     * @memberOf _
     * @category Collection
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Array|string} path The path of the property to pluck.
     * @returns {Array} Returns the property values.
     * @example
     *
     * var users = [
     *   { 'user': 'barney', 'age': 36 },
     *   { 'user': 'fred',   'age': 40 }
     * ];
     *
     * _.pluck(users, 'user');
     * // => ['barney', 'fred']
     *
     * var userIndex = _.indexBy(users, 'user');
     * _.pluck(userIndex, 'age');
     * // => [36, 40] (iteration order is not guaranteed)
     */
    function pluck(collection, path) {
      return map(collection, property(path));
    }

    /**
     * Reduces `collection` to a value which is the accumulated result of running
     * each element in `collection` through `iteratee`, where each successive
     * invocation is supplied the return value of the previous. If `accumulator`
     * is not provided the first element of `collection` is used as the initial
     * value. The `iteratee` is bound to `thisArg` and invoked with four arguments:
     * (accumulator, value, index|key, collection).
     *
     * Many lodash methods are guarded to work as iteratees for methods like
     * `_.reduce`, `_.reduceRight`, and `_.transform`.
     *
     * The guarded methods are:
     * `assign`, `defaults`, `defaultsDeep`, `includes`, `merge`, `sortByAll`,
     * and `sortByOrder`
     *
     * @static
     * @memberOf _
     * @alias foldl, inject
     * @category Collection
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
     * @param {*} [accumulator] The initial value.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {*} Returns the accumulated value.
     * @example
     *
     * _.reduce([1, 2], function(total, n) {
     *   return total + n;
     * });
     * // => 3
     *
     * _.reduce({ 'a': 1, 'b': 2 }, function(result, n, key) {
     *   result[key] = n * 3;
     *   return result;
     * }, {});
     * // => { 'a': 3, 'b': 6 } (iteration order is not guaranteed)
     */
    var reduce = createReduce(arrayReduce, baseEach);

    /**
     * This method is like `_.reduce` except that it iterates over elements of
     * `collection` from right to left.
     *
     * @static
     * @memberOf _
     * @alias foldr
     * @category Collection
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
     * @param {*} [accumulator] The initial value.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {*} Returns the accumulated value.
     * @example
     *
     * var array = [[0, 1], [2, 3], [4, 5]];
     *
     * _.reduceRight(array, function(flattened, other) {
     *   return flattened.concat(other);
     * }, []);
     * // => [4, 5, 2, 3, 0, 1]
     */
    var reduceRight = createReduce(arrayReduceRight, baseEachRight);

    /**
     * The opposite of `_.filter`; this method returns the elements of `collection`
     * that `predicate` does **not** return truthy for.
     *
     * @static
     * @memberOf _
     * @category Collection
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function|Object|string} [predicate=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `predicate`.
     * @returns {Array} Returns the new filtered array.
     * @example
     *
     * _.reject([1, 2, 3, 4], function(n) {
     *   return n % 2 == 0;
     * });
     * // => [1, 3]
     *
     * var users = [
     *   { 'user': 'barney', 'age': 36, 'active': false },
     *   { 'user': 'fred',   'age': 40, 'active': true }
     * ];
     *
     * // using the `_.matches` callback shorthand
     * _.pluck(_.reject(users, { 'age': 40, 'active': true }), 'user');
     * // => ['barney']
     *
     * // using the `_.matchesProperty` callback shorthand
     * _.pluck(_.reject(users, 'active', false), 'user');
     * // => ['fred']
     *
     * // using the `_.property` callback shorthand
     * _.pluck(_.reject(users, 'active'), 'user');
     * // => ['barney']
     */
    function reject(collection, predicate, thisArg) {
      var func = isArray(collection) ? arrayFilter : baseFilter;
      predicate = getCallback(predicate, thisArg, 3);
      return func(collection, function(value, index, collection) {
        return !predicate(value, index, collection);
      });
    }

    /**
     * Gets a random element or `n` random elements from a collection.
     *
     * @static
     * @memberOf _
     * @category Collection
     * @param {Array|Object|string} collection The collection to sample.
     * @param {number} [n] The number of elements to sample.
     * @param- {Object} [guard] Enables use as a callback for functions like `_.map`.
     * @returns {*} Returns the random sample(s).
     * @example
     *
     * _.sample([1, 2, 3, 4]);
     * // => 2
     *
     * _.sample([1, 2, 3, 4], 2);
     * // => [3, 1]
     */
    function sample(collection, n, guard) {
      if (guard ? isIterateeCall(collection, n, guard) : n == null) {
        collection = toIterable(collection);
        var length = collection.length;
        return length > 0 ? collection[baseRandom(0, length - 1)] : undefined;
      }
      var index = -1,
          result = toArray(collection),
          length = result.length,
          lastIndex = length - 1;

      n = nativeMin(n < 0 ? 0 : (+n || 0), length);
      while (++index < n) {
        var rand = baseRandom(index, lastIndex),
            value = result[rand];

        result[rand] = result[index];
        result[index] = value;
      }
      result.length = n;
      return result;
    }

    /**
     * Creates an array of shuffled values, using a version of the
     * [Fisher-Yates shuffle](https://en.wikipedia.org/wiki/Fisher-Yates_shuffle).
     *
     * @static
     * @memberOf _
     * @category Collection
     * @param {Array|Object|string} collection The collection to shuffle.
     * @returns {Array} Returns the new shuffled array.
     * @example
     *
     * _.shuffle([1, 2, 3, 4]);
     * // => [4, 1, 3, 2]
     */
    function shuffle(collection) {
      return sample(collection, POSITIVE_INFINITY);
    }

    /**
     * Gets the size of `collection` by returning its length for array-like
     * values or the number of own enumerable properties for objects.
     *
     * @static
     * @memberOf _
     * @category Collection
     * @param {Array|Object|string} collection The collection to inspect.
     * @returns {number} Returns the size of `collection`.
     * @example
     *
     * _.size([1, 2, 3]);
     * // => 3
     *
     * _.size({ 'a': 1, 'b': 2 });
     * // => 2
     *
     * _.size('pebbles');
     * // => 7
     */
    function size(collection) {
      var length = collection ? getLength(collection) : 0;
      return isLength(length) ? length : keys(collection).length;
    }

    /**
     * Checks if `predicate` returns truthy for **any** element of `collection`.
     * The function returns as soon as it finds a passing value and does not iterate
     * over the entire collection. The predicate is bound to `thisArg` and invoked
     * with three arguments: (value, index|key, collection).
     *
     * If a property name is provided for `predicate` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `predicate` the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @alias any
     * @category Collection
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function|Object|string} [predicate=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `predicate`.
     * @returns {boolean} Returns `true` if any element passes the predicate check,
     *  else `false`.
     * @example
     *
     * _.some([null, 0, 'yes', false], Boolean);
     * // => true
     *
     * var users = [
     *   { 'user': 'barney', 'active': true },
     *   { 'user': 'fred',   'active': false }
     * ];
     *
     * // using the `_.matches` callback shorthand
     * _.some(users, { 'user': 'barney', 'active': false });
     * // => false
     *
     * // using the `_.matchesProperty` callback shorthand
     * _.some(users, 'active', false);
     * // => true
     *
     * // using the `_.property` callback shorthand
     * _.some(users, 'active');
     * // => true
     */
    function some(collection, predicate, thisArg) {
      var func = isArray(collection) ? arraySome : baseSome;
      if (thisArg && isIterateeCall(collection, predicate, thisArg)) {
        predicate = undefined;
      }
      if (typeof predicate != 'function' || thisArg !== undefined) {
        predicate = getCallback(predicate, thisArg, 3);
      }
      return func(collection, predicate);
    }

    /**
     * Creates an array of elements, sorted in ascending order by the results of
     * running each element in a collection through `iteratee`. This method performs
     * a stable sort, that is, it preserves the original sort order of equal elements.
     * The `iteratee` is bound to `thisArg` and invoked with three arguments:
     * (value, index|key, collection).
     *
     * If a property name is provided for `iteratee` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `iteratee` the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @category Collection
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function|Object|string} [iteratee=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {Array} Returns the new sorted array.
     * @example
     *
     * _.sortBy([1, 2, 3], function(n) {
     *   return Math.sin(n);
     * });
     * // => [3, 1, 2]
     *
     * _.sortBy([1, 2, 3], function(n) {
     *   return this.sin(n);
     * }, Math);
     * // => [3, 1, 2]
     *
     * var users = [
     *   { 'user': 'fred' },
     *   { 'user': 'pebbles' },
     *   { 'user': 'barney' }
     * ];
     *
     * // using the `_.property` callback shorthand
     * _.pluck(_.sortBy(users, 'user'), 'user');
     * // => ['barney', 'fred', 'pebbles']
     */
    function sortBy(collection, iteratee, thisArg) {
      if (collection == null) {
        return [];
      }
      if (thisArg && isIterateeCall(collection, iteratee, thisArg)) {
        iteratee = undefined;
      }
      var index = -1;
      iteratee = getCallback(iteratee, thisArg, 3);

      var result = baseMap(collection, function(value, key, collection) {
        return { 'criteria': iteratee(value, key, collection), 'index': ++index, 'value': value };
      });
      return baseSortBy(result, compareAscending);
    }

    /**
     * This method is like `_.sortBy` except that it can sort by multiple iteratees
     * or property names.
     *
     * If a property name is provided for an iteratee the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If an object is provided for an iteratee the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @category Collection
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {...(Function|Function[]|Object|Object[]|string|string[])} iteratees
     *  The iteratees to sort by, specified as individual values or arrays of values.
     * @returns {Array} Returns the new sorted array.
     * @example
     *
     * var users = [
     *   { 'user': 'fred',   'age': 48 },
     *   { 'user': 'barney', 'age': 36 },
     *   { 'user': 'fred',   'age': 42 },
     *   { 'user': 'barney', 'age': 34 }
     * ];
     *
     * _.map(_.sortByAll(users, ['user', 'age']), _.values);
     * // => [['barney', 34], ['barney', 36], ['fred', 42], ['fred', 48]]
     *
     * _.map(_.sortByAll(users, 'user', function(chr) {
     *   return Math.floor(chr.age / 10);
     * }), _.values);
     * // => [['barney', 36], ['barney', 34], ['fred', 48], ['fred', 42]]
     */
    var sortByAll = restParam(function(collection, iteratees) {
      if (collection == null) {
        return [];
      }
      var guard = iteratees[2];
      if (guard && isIterateeCall(iteratees[0], iteratees[1], guard)) {
        iteratees.length = 1;
      }
      return baseSortByOrder(collection, baseFlatten(iteratees), []);
    });

    /**
     * This method is like `_.sortByAll` except that it allows specifying the
     * sort orders of the iteratees to sort by. If `orders` is unspecified, all
     * values are sorted in ascending order. Otherwise, a value is sorted in
     * ascending order if its corresponding order is "asc", and descending if "desc".
     *
     * If a property name is provided for an iteratee the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If an object is provided for an iteratee the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @category Collection
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function[]|Object[]|string[]} iteratees The iteratees to sort by.
     * @param {boolean[]} [orders] The sort orders of `iteratees`.
     * @param- {Object} [guard] Enables use as a callback for functions like `_.reduce`.
     * @returns {Array} Returns the new sorted array.
     * @example
     *
     * var users = [
     *   { 'user': 'fred',   'age': 48 },
     *   { 'user': 'barney', 'age': 34 },
     *   { 'user': 'fred',   'age': 42 },
     *   { 'user': 'barney', 'age': 36 }
     * ];
     *
     * // sort by `user` in ascending order and by `age` in descending order
     * _.map(_.sortByOrder(users, ['user', 'age'], ['asc', 'desc']), _.values);
     * // => [['barney', 36], ['barney', 34], ['fred', 48], ['fred', 42]]
     */
    function sortByOrder(collection, iteratees, orders, guard) {
      if (collection == null) {
        return [];
      }
      if (guard && isIterateeCall(iteratees, orders, guard)) {
        orders = undefined;
      }
      if (!isArray(iteratees)) {
        iteratees = iteratees == null ? [] : [iteratees];
      }
      if (!isArray(orders)) {
        orders = orders == null ? [] : [orders];
      }
      return baseSortByOrder(collection, iteratees, orders);
    }

    /**
     * Performs a deep comparison between each element in `collection` and the
     * source object, returning an array of all elements that have equivalent
     * property values.
     *
     * **Note:** This method supports comparing arrays, booleans, `Date` objects,
     * numbers, `Object` objects, regexes, and strings. Objects are compared by
     * their own, not inherited, enumerable properties. For comparing a single
     * own or inherited property value see `_.matchesProperty`.
     *
     * @static
     * @memberOf _
     * @category Collection
     * @param {Array|Object|string} collection The collection to search.
     * @param {Object} source The object of property values to match.
     * @returns {Array} Returns the new filtered array.
     * @example
     *
     * var users = [
     *   { 'user': 'barney', 'age': 36, 'active': false, 'pets': ['hoppy'] },
     *   { 'user': 'fred',   'age': 40, 'active': true, 'pets': ['baby puss', 'dino'] }
     * ];
     *
     * _.pluck(_.where(users, { 'age': 36, 'active': false }), 'user');
     * // => ['barney']
     *
     * _.pluck(_.where(users, { 'pets': ['dino'] }), 'user');
     * // => ['fred']
     */
    function where(collection, source) {
      return filter(collection, baseMatches(source));
    }

    /*------------------------------------------------------------------------*/

    /**
     * Gets the number of milliseconds that have elapsed since the Unix epoch
     * (1 January 1970 00:00:00 UTC).
     *
     * @static
     * @memberOf _
     * @category Date
     * @example
     *
     * _.defer(function(stamp) {
     *   console.log(_.now() - stamp);
     * }, _.now());
     * // => logs the number of milliseconds it took for the deferred function to be invoked
     */
    var now = nativeNow || function() {
      return new Date().getTime();
    };

    /*------------------------------------------------------------------------*/

    /**
     * The opposite of `_.before`; this method creates a function that invokes
     * `func` once it is called `n` or more times.
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {number} n The number of calls before `func` is invoked.
     * @param {Function} func The function to restrict.
     * @returns {Function} Returns the new restricted function.
     * @example
     *
     * var saves = ['profile', 'settings'];
     *
     * var done = _.after(saves.length, function() {
     *   console.log('done saving!');
     * });
     *
     * _.forEach(saves, function(type) {
     *   asyncSave({ 'type': type, 'complete': done });
     * });
     * // => logs 'done saving!' after the two async saves have completed
     */
    function after(n, func) {
      if (typeof func != 'function') {
        if (typeof n == 'function') {
          var temp = n;
          n = func;
          func = temp;
        } else {
          throw new TypeError(FUNC_ERROR_TEXT);
        }
      }
      n = nativeIsFinite(n = +n) ? n : 0;
      return function() {
        if (--n < 1) {
          return func.apply(this, arguments);
        }
      };
    }

    /**
     * Creates a function that accepts up to `n` arguments ignoring any
     * additional arguments.
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {Function} func The function to cap arguments for.
     * @param {number} [n=func.length] The arity cap.
     * @param- {Object} [guard] Enables use as a callback for functions like `_.map`.
     * @returns {Function} Returns the new function.
     * @example
     *
     * _.map(['6', '8', '10'], _.ary(parseInt, 1));
     * // => [6, 8, 10]
     */
    function ary(func, n, guard) {
      if (guard && isIterateeCall(func, n, guard)) {
        n = undefined;
      }
      n = (func && n == null) ? func.length : nativeMax(+n || 0, 0);
      return createWrapper(func, ARY_FLAG, undefined, undefined, undefined, undefined, n);
    }

    /**
     * Creates a function that invokes `func`, with the `this` binding and arguments
     * of the created function, while it is called less than `n` times. Subsequent
     * calls to the created function return the result of the last `func` invocation.
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {number} n The number of calls at which `func` is no longer invoked.
     * @param {Function} func The function to restrict.
     * @returns {Function} Returns the new restricted function.
     * @example
     *
     * jQuery('#add').on('click', _.before(5, addContactToList));
     * // => allows adding up to 4 contacts to the list
     */
    function before(n, func) {
      var result;
      if (typeof func != 'function') {
        if (typeof n == 'function') {
          var temp = n;
          n = func;
          func = temp;
        } else {
          throw new TypeError(FUNC_ERROR_TEXT);
        }
      }
      return function() {
        if (--n > 0) {
          result = func.apply(this, arguments);
        }
        if (n <= 1) {
          func = undefined;
        }
        return result;
      };
    }

    /**
     * Creates a function that invokes `func` with the `this` binding of `thisArg`
     * and prepends any additional `_.bind` arguments to those provided to the
     * bound function.
     *
     * The `_.bind.placeholder` value, which defaults to `_` in monolithic builds,
     * may be used as a placeholder for partially applied arguments.
     *
     * **Note:** Unlike native `Function#bind` this method does not set the "length"
     * property of bound functions.
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {Function} func The function to bind.
     * @param {*} thisArg The `this` binding of `func`.
     * @param {...*} [partials] The arguments to be partially applied.
     * @returns {Function} Returns the new bound function.
     * @example
     *
     * var greet = function(greeting, punctuation) {
     *   return greeting + ' ' + this.user + punctuation;
     * };
     *
     * var object = { 'user': 'fred' };
     *
     * var bound = _.bind(greet, object, 'hi');
     * bound('!');
     * // => 'hi fred!'
     *
     * // using placeholders
     * var bound = _.bind(greet, object, _, '!');
     * bound('hi');
     * // => 'hi fred!'
     */
    var bind = restParam(function(func, thisArg, partials) {
      var bitmask = BIND_FLAG;
      if (partials.length) {
        var holders = replaceHolders(partials, bind.placeholder);
        bitmask |= PARTIAL_FLAG;
      }
      return createWrapper(func, bitmask, thisArg, partials, holders);
    });

    /**
     * Binds methods of an object to the object itself, overwriting the existing
     * method. Method names may be specified as individual arguments or as arrays
     * of method names. If no method names are provided all enumerable function
     * properties, own and inherited, of `object` are bound.
     *
     * **Note:** This method does not set the "length" property of bound functions.
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {Object} object The object to bind and assign the bound methods to.
     * @param {...(string|string[])} [methodNames] The object method names to bind,
     *  specified as individual method names or arrays of method names.
     * @returns {Object} Returns `object`.
     * @example
     *
     * var view = {
     *   'label': 'docs',
     *   'onClick': function() {
     *     console.log('clicked ' + this.label);
     *   }
     * };
     *
     * _.bindAll(view);
     * jQuery('#docs').on('click', view.onClick);
     * // => logs 'clicked docs' when the element is clicked
     */
    var bindAll = restParam(function(object, methodNames) {
      methodNames = methodNames.length ? baseFlatten(methodNames) : functions(object);

      var index = -1,
          length = methodNames.length;

      while (++index < length) {
        var key = methodNames[index];
        object[key] = createWrapper(object[key], BIND_FLAG, object);
      }
      return object;
    });

    /**
     * Creates a function that invokes the method at `object[key]` and prepends
     * any additional `_.bindKey` arguments to those provided to the bound function.
     *
     * This method differs from `_.bind` by allowing bound functions to reference
     * methods that may be redefined or don't yet exist.
     * See [Peter Michaux's article](http://peter.michaux.ca/articles/lazy-function-definition-pattern)
     * for more details.
     *
     * The `_.bindKey.placeholder` value, which defaults to `_` in monolithic
     * builds, may be used as a placeholder for partially applied arguments.
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {Object} object The object the method belongs to.
     * @param {string} key The key of the method.
     * @param {...*} [partials] The arguments to be partially applied.
     * @returns {Function} Returns the new bound function.
     * @example
     *
     * var object = {
     *   'user': 'fred',
     *   'greet': function(greeting, punctuation) {
     *     return greeting + ' ' + this.user + punctuation;
     *   }
     * };
     *
     * var bound = _.bindKey(object, 'greet', 'hi');
     * bound('!');
     * // => 'hi fred!'
     *
     * object.greet = function(greeting, punctuation) {
     *   return greeting + 'ya ' + this.user + punctuation;
     * };
     *
     * bound('!');
     * // => 'hiya fred!'
     *
     * // using placeholders
     * var bound = _.bindKey(object, 'greet', _, '!');
     * bound('hi');
     * // => 'hiya fred!'
     */
    var bindKey = restParam(function(object, key, partials) {
      var bitmask = BIND_FLAG | BIND_KEY_FLAG;
      if (partials.length) {
        var holders = replaceHolders(partials, bindKey.placeholder);
        bitmask |= PARTIAL_FLAG;
      }
      return createWrapper(key, bitmask, object, partials, holders);
    });

    /**
     * Creates a function that accepts one or more arguments of `func` that when
     * called either invokes `func` returning its result, if all `func` arguments
     * have been provided, or returns a function that accepts one or more of the
     * remaining `func` arguments, and so on. The arity of `func` may be specified
     * if `func.length` is not sufficient.
     *
     * The `_.curry.placeholder` value, which defaults to `_` in monolithic builds,
     * may be used as a placeholder for provided arguments.
     *
     * **Note:** This method does not set the "length" property of curried functions.
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {Function} func The function to curry.
     * @param {number} [arity=func.length] The arity of `func`.
     * @param- {Object} [guard] Enables use as a callback for functions like `_.map`.
     * @returns {Function} Returns the new curried function.
     * @example
     *
     * var abc = function(a, b, c) {
     *   return [a, b, c];
     * };
     *
     * var curried = _.curry(abc);
     *
     * curried(1)(2)(3);
     * // => [1, 2, 3]
     *
     * curried(1, 2)(3);
     * // => [1, 2, 3]
     *
     * curried(1, 2, 3);
     * // => [1, 2, 3]
     *
     * // using placeholders
     * curried(1)(_, 3)(2);
     * // => [1, 2, 3]
     */
    var curry = createCurry(CURRY_FLAG);

    /**
     * This method is like `_.curry` except that arguments are applied to `func`
     * in the manner of `_.partialRight` instead of `_.partial`.
     *
     * The `_.curryRight.placeholder` value, which defaults to `_` in monolithic
     * builds, may be used as a placeholder for provided arguments.
     *
     * **Note:** This method does not set the "length" property of curried functions.
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {Function} func The function to curry.
     * @param {number} [arity=func.length] The arity of `func`.
     * @param- {Object} [guard] Enables use as a callback for functions like `_.map`.
     * @returns {Function} Returns the new curried function.
     * @example
     *
     * var abc = function(a, b, c) {
     *   return [a, b, c];
     * };
     *
     * var curried = _.curryRight(abc);
     *
     * curried(3)(2)(1);
     * // => [1, 2, 3]
     *
     * curried(2, 3)(1);
     * // => [1, 2, 3]
     *
     * curried(1, 2, 3);
     * // => [1, 2, 3]
     *
     * // using placeholders
     * curried(3)(1, _)(2);
     * // => [1, 2, 3]
     */
    var curryRight = createCurry(CURRY_RIGHT_FLAG);

    /**
     * Creates a debounced function that delays invoking `func` until after `wait`
     * milliseconds have elapsed since the last time the debounced function was
     * invoked. The debounced function comes with a `cancel` method to cancel
     * delayed invocations. Provide an options object to indicate that `func`
     * should be invoked on the leading and/or trailing edge of the `wait` timeout.
     * Subsequent calls to the debounced function return the result of the last
     * `func` invocation.
     *
     * **Note:** If `leading` and `trailing` options are `true`, `func` is invoked
     * on the trailing edge of the timeout only if the the debounced function is
     * invoked more than once during the `wait` timeout.
     *
     * See [David Corbacho's article](http://drupalmotion.com/article/debounce-and-throttle-visual-explanation)
     * for details over the differences between `_.debounce` and `_.throttle`.
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {Function} func The function to debounce.
     * @param {number} [wait=0] The number of milliseconds to delay.
     * @param {Object} [options] The options object.
     * @param {boolean} [options.leading=false] Specify invoking on the leading
     *  edge of the timeout.
     * @param {number} [options.maxWait] The maximum time `func` is allowed to be
     *  delayed before it is invoked.
     * @param {boolean} [options.trailing=true] Specify invoking on the trailing
     *  edge of the timeout.
     * @returns {Function} Returns the new debounced function.
     * @example
     *
     * // avoid costly calculations while the window size is in flux
     * jQuery(window).on('resize', _.debounce(calculateLayout, 150));
     *
     * // invoke `sendMail` when the click event is fired, debouncing subsequent calls
     * jQuery('#postbox').on('click', _.debounce(sendMail, 300, {
     *   'leading': true,
     *   'trailing': false
     * }));
     *
     * // ensure `batchLog` is invoked once after 1 second of debounced calls
     * var source = new EventSource('/stream');
     * jQuery(source).on('message', _.debounce(batchLog, 250, {
     *   'maxWait': 1000
     * }));
     *
     * // cancel a debounced call
     * var todoChanges = _.debounce(batchLog, 1000);
     * Object.observe(models.todo, todoChanges);
     *
     * Object.observe(models, function(changes) {
     *   if (_.find(changes, { 'user': 'todo', 'type': 'delete'})) {
     *     todoChanges.cancel();
     *   }
     * }, ['delete']);
     *
     * // ...at some point `models.todo` is changed
     * models.todo.completed = true;
     *
     * // ...before 1 second has passed `models.todo` is deleted
     * // which cancels the debounced `todoChanges` call
     * delete models.todo;
     */
    function debounce(func, wait, options) {
      var args,
          maxTimeoutId,
          result,
          stamp,
          thisArg,
          timeoutId,
          trailingCall,
          lastCalled = 0,
          maxWait = false,
          trailing = true;

      if (typeof func != 'function') {
        throw new TypeError(FUNC_ERROR_TEXT);
      }
      wait = wait < 0 ? 0 : (+wait || 0);
      if (options === true) {
        var leading = true;
        trailing = false;
      } else if (isObject(options)) {
        leading = !!options.leading;
        maxWait = 'maxWait' in options && nativeMax(+options.maxWait || 0, wait);
        trailing = 'trailing' in options ? !!options.trailing : trailing;
      }

      function cancel() {
        if (timeoutId) {
          clearTimeout(timeoutId);
        }
        if (maxTimeoutId) {
          clearTimeout(maxTimeoutId);
        }
        lastCalled = 0;
        maxTimeoutId = timeoutId = trailingCall = undefined;
      }

      function complete(isCalled, id) {
        if (id) {
          clearTimeout(id);
        }
        maxTimeoutId = timeoutId = trailingCall = undefined;
        if (isCalled) {
          lastCalled = now();
          result = func.apply(thisArg, args);
          if (!timeoutId && !maxTimeoutId) {
            args = thisArg = undefined;
          }
        }
      }

      function delayed() {
        var remaining = wait - (now() - stamp);
        if (remaining <= 0 || remaining > wait) {
          complete(trailingCall, maxTimeoutId);
        } else {
          timeoutId = setTimeout(delayed, remaining);
        }
      }

      function maxDelayed() {
        complete(trailing, timeoutId);
      }

      function debounced() {
        args = arguments;
        stamp = now();
        thisArg = this;
        trailingCall = trailing && (timeoutId || !leading);

        if (maxWait === false) {
          var leadingCall = leading && !timeoutId;
        } else {
          if (!maxTimeoutId && !leading) {
            lastCalled = stamp;
          }
          var remaining = maxWait - (stamp - lastCalled),
              isCalled = remaining <= 0 || remaining > maxWait;

          if (isCalled) {
            if (maxTimeoutId) {
              maxTimeoutId = clearTimeout(maxTimeoutId);
            }
            lastCalled = stamp;
            result = func.apply(thisArg, args);
          }
          else if (!maxTimeoutId) {
            maxTimeoutId = setTimeout(maxDelayed, remaining);
          }
        }
        if (isCalled && timeoutId) {
          timeoutId = clearTimeout(timeoutId);
        }
        else if (!timeoutId && wait !== maxWait) {
          timeoutId = setTimeout(delayed, wait);
        }
        if (leadingCall) {
          isCalled = true;
          result = func.apply(thisArg, args);
        }
        if (isCalled && !timeoutId && !maxTimeoutId) {
          args = thisArg = undefined;
        }
        return result;
      }
      debounced.cancel = cancel;
      return debounced;
    }

    /**
     * Defers invoking the `func` until the current call stack has cleared. Any
     * additional arguments are provided to `func` when it is invoked.
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {Function} func The function to defer.
     * @param {...*} [args] The arguments to invoke the function with.
     * @returns {number} Returns the timer id.
     * @example
     *
     * _.defer(function(text) {
     *   console.log(text);
     * }, 'deferred');
     * // logs 'deferred' after one or more milliseconds
     */
    var defer = restParam(function(func, args) {
      return baseDelay(func, 1, args);
    });

    /**
     * Invokes `func` after `wait` milliseconds. Any additional arguments are
     * provided to `func` when it is invoked.
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {Function} func The function to delay.
     * @param {number} wait The number of milliseconds to delay invocation.
     * @param {...*} [args] The arguments to invoke the function with.
     * @returns {number} Returns the timer id.
     * @example
     *
     * _.delay(function(text) {
     *   console.log(text);
     * }, 1000, 'later');
     * // => logs 'later' after one second
     */
    var delay = restParam(function(func, wait, args) {
      return baseDelay(func, wait, args);
    });

    /**
     * Creates a function that returns the result of invoking the provided
     * functions with the `this` binding of the created function, where each
     * successive invocation is supplied the return value of the previous.
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {...Function} [funcs] Functions to invoke.
     * @returns {Function} Returns the new function.
     * @example
     *
     * function square(n) {
     *   return n * n;
     * }
     *
     * var addSquare = _.flow(_.add, square);
     * addSquare(1, 2);
     * // => 9
     */
    var flow = createFlow();

    /**
     * This method is like `_.flow` except that it creates a function that
     * invokes the provided functions from right to left.
     *
     * @static
     * @memberOf _
     * @alias backflow, compose
     * @category Function
     * @param {...Function} [funcs] Functions to invoke.
     * @returns {Function} Returns the new function.
     * @example
     *
     * function square(n) {
     *   return n * n;
     * }
     *
     * var addSquare = _.flowRight(square, _.add);
     * addSquare(1, 2);
     * // => 9
     */
    var flowRight = createFlow(true);

    /**
     * Creates a function that memoizes the result of `func`. If `resolver` is
     * provided it determines the cache key for storing the result based on the
     * arguments provided to the memoized function. By default, the first argument
     * provided to the memoized function is coerced to a string and used as the
     * cache key. The `func` is invoked with the `this` binding of the memoized
     * function.
     *
     * **Note:** The cache is exposed as the `cache` property on the memoized
     * function. Its creation may be customized by replacing the `_.memoize.Cache`
     * constructor with one whose instances implement the [`Map`](http://ecma-international.org/ecma-262/6.0/#sec-properties-of-the-map-prototype-object)
     * method interface of `get`, `has`, and `set`.
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {Function} func The function to have its output memoized.
     * @param {Function} [resolver] The function to resolve the cache key.
     * @returns {Function} Returns the new memoizing function.
     * @example
     *
     * var upperCase = _.memoize(function(string) {
     *   return string.toUpperCase();
     * });
     *
     * upperCase('fred');
     * // => 'FRED'
     *
     * // modifying the result cache
     * upperCase.cache.set('fred', 'BARNEY');
     * upperCase('fred');
     * // => 'BARNEY'
     *
     * // replacing `_.memoize.Cache`
     * var object = { 'user': 'fred' };
     * var other = { 'user': 'barney' };
     * var identity = _.memoize(_.identity);
     *
     * identity(object);
     * // => { 'user': 'fred' }
     * identity(other);
     * // => { 'user': 'fred' }
     *
     * _.memoize.Cache = WeakMap;
     * var identity = _.memoize(_.identity);
     *
     * identity(object);
     * // => { 'user': 'fred' }
     * identity(other);
     * // => { 'user': 'barney' }
     */
    function memoize(func, resolver) {
      if (typeof func != 'function' || (resolver && typeof resolver != 'function')) {
        throw new TypeError(FUNC_ERROR_TEXT);
      }
      var memoized = function() {
        var args = arguments,
            key = resolver ? resolver.apply(this, args) : args[0],
            cache = memoized.cache;

        if (cache.has(key)) {
          return cache.get(key);
        }
        var result = func.apply(this, args);
        memoized.cache = cache.set(key, result);
        return result;
      };
      memoized.cache = new memoize.Cache;
      return memoized;
    }

    /**
     * Creates a function that runs each argument through a corresponding
     * transform function.
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {Function} func The function to wrap.
     * @param {...(Function|Function[])} [transforms] The functions to transform
     * arguments, specified as individual functions or arrays of functions.
     * @returns {Function} Returns the new function.
     * @example
     *
     * function doubled(n) {
     *   return n * 2;
     * }
     *
     * function square(n) {
     *   return n * n;
     * }
     *
     * var modded = _.modArgs(function(x, y) {
     *   return [x, y];
     * }, square, doubled);
     *
     * modded(1, 2);
     * // => [1, 4]
     *
     * modded(5, 10);
     * // => [25, 20]
     */
    var modArgs = restParam(function(func, transforms) {
      transforms = baseFlatten(transforms);
      if (typeof func != 'function' || !arrayEvery(transforms, baseIsFunction)) {
        throw new TypeError(FUNC_ERROR_TEXT);
      }
      var length = transforms.length;
      return restParam(function(args) {
        var index = nativeMin(args.length, length);
        while (index--) {
          args[index] = transforms[index](args[index]);
        }
        return func.apply(this, args);
      });
    });

    /**
     * Creates a function that negates the result of the predicate `func`. The
     * `func` predicate is invoked with the `this` binding and arguments of the
     * created function.
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {Function} predicate The predicate to negate.
     * @returns {Function} Returns the new function.
     * @example
     *
     * function isEven(n) {
     *   return n % 2 == 0;
     * }
     *
     * _.filter([1, 2, 3, 4, 5, 6], _.negate(isEven));
     * // => [1, 3, 5]
     */
    function negate(predicate) {
      if (typeof predicate != 'function') {
        throw new TypeError(FUNC_ERROR_TEXT);
      }
      return function() {
        return !predicate.apply(this, arguments);
      };
    }

    /**
     * Creates a function that is restricted to invoking `func` once. Repeat calls
     * to the function return the value of the first call. The `func` is invoked
     * with the `this` binding and arguments of the created function.
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {Function} func The function to restrict.
     * @returns {Function} Returns the new restricted function.
     * @example
     *
     * var initialize = _.once(createApplication);
     * initialize();
     * initialize();
     * // `initialize` invokes `createApplication` once
     */
    function once(func) {
      return before(2, func);
    }

    /**
     * Creates a function that invokes `func` with `partial` arguments prepended
     * to those provided to the new function. This method is like `_.bind` except
     * it does **not** alter the `this` binding.
     *
     * The `_.partial.placeholder` value, which defaults to `_` in monolithic
     * builds, may be used as a placeholder for partially applied arguments.
     *
     * **Note:** This method does not set the "length" property of partially
     * applied functions.
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {Function} func The function to partially apply arguments to.
     * @param {...*} [partials] The arguments to be partially applied.
     * @returns {Function} Returns the new partially applied function.
     * @example
     *
     * var greet = function(greeting, name) {
     *   return greeting + ' ' + name;
     * };
     *
     * var sayHelloTo = _.partial(greet, 'hello');
     * sayHelloTo('fred');
     * // => 'hello fred'
     *
     * // using placeholders
     * var greetFred = _.partial(greet, _, 'fred');
     * greetFred('hi');
     * // => 'hi fred'
     */
    var partial = createPartial(PARTIAL_FLAG);

    /**
     * This method is like `_.partial` except that partially applied arguments
     * are appended to those provided to the new function.
     *
     * The `_.partialRight.placeholder` value, which defaults to `_` in monolithic
     * builds, may be used as a placeholder for partially applied arguments.
     *
     * **Note:** This method does not set the "length" property of partially
     * applied functions.
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {Function} func The function to partially apply arguments to.
     * @param {...*} [partials] The arguments to be partially applied.
     * @returns {Function} Returns the new partially applied function.
     * @example
     *
     * var greet = function(greeting, name) {
     *   return greeting + ' ' + name;
     * };
     *
     * var greetFred = _.partialRight(greet, 'fred');
     * greetFred('hi');
     * // => 'hi fred'
     *
     * // using placeholders
     * var sayHelloTo = _.partialRight(greet, 'hello', _);
     * sayHelloTo('fred');
     * // => 'hello fred'
     */
    var partialRight = createPartial(PARTIAL_RIGHT_FLAG);

    /**
     * Creates a function that invokes `func` with arguments arranged according
     * to the specified indexes where the argument value at the first index is
     * provided as the first argument, the argument value at the second index is
     * provided as the second argument, and so on.
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {Function} func The function to rearrange arguments for.
     * @param {...(number|number[])} indexes The arranged argument indexes,
     *  specified as individual indexes or arrays of indexes.
     * @returns {Function} Returns the new function.
     * @example
     *
     * var rearged = _.rearg(function(a, b, c) {
     *   return [a, b, c];
     * }, 2, 0, 1);
     *
     * rearged('b', 'c', 'a')
     * // => ['a', 'b', 'c']
     *
     * var map = _.rearg(_.map, [1, 0]);
     * map(function(n) {
     *   return n * 3;
     * }, [1, 2, 3]);
     * // => [3, 6, 9]
     */
    var rearg = restParam(function(func, indexes) {
      return createWrapper(func, REARG_FLAG, undefined, undefined, undefined, baseFlatten(indexes));
    });

    /**
     * Creates a function that invokes `func` with the `this` binding of the
     * created function and arguments from `start` and beyond provided as an array.
     *
     * **Note:** This method is based on the [rest parameter](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Functions/rest_parameters).
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {Function} func The function to apply a rest parameter to.
     * @param {number} [start=func.length-1] The start position of the rest parameter.
     * @returns {Function} Returns the new function.
     * @example
     *
     * var say = _.restParam(function(what, names) {
     *   return what + ' ' + _.initial(names).join(', ') +
     *     (_.size(names) > 1 ? ', & ' : '') + _.last(names);
     * });
     *
     * say('hello', 'fred', 'barney', 'pebbles');
     * // => 'hello fred, barney, & pebbles'
     */
    function restParam(func, start) {
      if (typeof func != 'function') {
        throw new TypeError(FUNC_ERROR_TEXT);
      }
      start = nativeMax(start === undefined ? (func.length - 1) : (+start || 0), 0);
      return function() {
        var args = arguments,
            index = -1,
            length = nativeMax(args.length - start, 0),
            rest = Array(length);

        while (++index < length) {
          rest[index] = args[start + index];
        }
        switch (start) {
          case 0: return func.call(this, rest);
          case 1: return func.call(this, args[0], rest);
          case 2: return func.call(this, args[0], args[1], rest);
        }
        var otherArgs = Array(start + 1);
        index = -1;
        while (++index < start) {
          otherArgs[index] = args[index];
        }
        otherArgs[start] = rest;
        return func.apply(this, otherArgs);
      };
    }

    /**
     * Creates a function that invokes `func` with the `this` binding of the created
     * function and an array of arguments much like [`Function#apply`](https://es5.github.io/#x15.3.4.3).
     *
     * **Note:** This method is based on the [spread operator](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Operators/Spread_operator).
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {Function} func The function to spread arguments over.
     * @returns {Function} Returns the new function.
     * @example
     *
     * var say = _.spread(function(who, what) {
     *   return who + ' says ' + what;
     * });
     *
     * say(['fred', 'hello']);
     * // => 'fred says hello'
     *
     * // with a Promise
     * var numbers = Promise.all([
     *   Promise.resolve(40),
     *   Promise.resolve(36)
     * ]);
     *
     * numbers.then(_.spread(function(x, y) {
     *   return x + y;
     * }));
     * // => a Promise of 76
     */
    function spread(func) {
      if (typeof func != 'function') {
        throw new TypeError(FUNC_ERROR_TEXT);
      }
      return function(array) {
        return func.apply(this, array);
      };
    }

    /**
     * Creates a throttled function that only invokes `func` at most once per
     * every `wait` milliseconds. The throttled function comes with a `cancel`
     * method to cancel delayed invocations. Provide an options object to indicate
     * that `func` should be invoked on the leading and/or trailing edge of the
     * `wait` timeout. Subsequent calls to the throttled function return the
     * result of the last `func` call.
     *
     * **Note:** If `leading` and `trailing` options are `true`, `func` is invoked
     * on the trailing edge of the timeout only if the the throttled function is
     * invoked more than once during the `wait` timeout.
     *
     * See [David Corbacho's article](http://drupalmotion.com/article/debounce-and-throttle-visual-explanation)
     * for details over the differences between `_.throttle` and `_.debounce`.
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {Function} func The function to throttle.
     * @param {number} [wait=0] The number of milliseconds to throttle invocations to.
     * @param {Object} [options] The options object.
     * @param {boolean} [options.leading=true] Specify invoking on the leading
     *  edge of the timeout.
     * @param {boolean} [options.trailing=true] Specify invoking on the trailing
     *  edge of the timeout.
     * @returns {Function} Returns the new throttled function.
     * @example
     *
     * // avoid excessively updating the position while scrolling
     * jQuery(window).on('scroll', _.throttle(updatePosition, 100));
     *
     * // invoke `renewToken` when the click event is fired, but not more than once every 5 minutes
     * jQuery('.interactive').on('click', _.throttle(renewToken, 300000, {
     *   'trailing': false
     * }));
     *
     * // cancel a trailing throttled call
     * jQuery(window).on('popstate', throttled.cancel);
     */
    function throttle(func, wait, options) {
      var leading = true,
          trailing = true;

      if (typeof func != 'function') {
        throw new TypeError(FUNC_ERROR_TEXT);
      }
      if (options === false) {
        leading = false;
      } else if (isObject(options)) {
        leading = 'leading' in options ? !!options.leading : leading;
        trailing = 'trailing' in options ? !!options.trailing : trailing;
      }
      return debounce(func, wait, { 'leading': leading, 'maxWait': +wait, 'trailing': trailing });
    }

    /**
     * Creates a function that provides `value` to the wrapper function as its
     * first argument. Any additional arguments provided to the function are
     * appended to those provided to the wrapper function. The wrapper is invoked
     * with the `this` binding of the created function.
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {*} value The value to wrap.
     * @param {Function} wrapper The wrapper function.
     * @returns {Function} Returns the new function.
     * @example
     *
     * var p = _.wrap(_.escape, function(func, text) {
     *   return '<p>' + func(text) + '</p>';
     * });
     *
     * p('fred, barney, & pebbles');
     * // => '<p>fred, barney, &amp; pebbles</p>'
     */
    function wrap(value, wrapper) {
      wrapper = wrapper == null ? identity : wrapper;
      return createWrapper(wrapper, PARTIAL_FLAG, undefined, [value], []);
    }

    /*------------------------------------------------------------------------*/

    /**
     * Creates a clone of `value`. If `isDeep` is `true` nested objects are cloned,
     * otherwise they are assigned by reference. If `customizer` is provided it is
     * invoked to produce the cloned values. If `customizer` returns `undefined`
     * cloning is handled by the method instead. The `customizer` is bound to
     * `thisArg` and invoked with two argument; (value [, index|key, object]).
     *
     * **Note:** This method is loosely based on the
     * [structured clone algorithm](http://www.w3.org/TR/html5/infrastructure.html#internal-structured-cloning-algorithm).
     * The enumerable properties of `arguments` objects and objects created by
     * constructors other than `Object` are cloned to plain `Object` objects. An
     * empty object is returned for uncloneable values such as functions, DOM nodes,
     * Maps, Sets, and WeakMaps.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to clone.
     * @param {boolean} [isDeep] Specify a deep clone.
     * @param {Function} [customizer] The function to customize cloning values.
     * @param {*} [thisArg] The `this` binding of `customizer`.
     * @returns {*} Returns the cloned value.
     * @example
     *
     * var users = [
     *   { 'user': 'barney' },
     *   { 'user': 'fred' }
     * ];
     *
     * var shallow = _.clone(users);
     * shallow[0] === users[0];
     * // => true
     *
     * var deep = _.clone(users, true);
     * deep[0] === users[0];
     * // => false
     *
     * // using a customizer callback
     * var el = _.clone(document.body, function(value) {
     *   if (_.isElement(value)) {
     *     return value.cloneNode(false);
     *   }
     * });
     *
     * el === document.body
     * // => false
     * el.nodeName
     * // => BODY
     * el.childNodes.length;
     * // => 0
     */
    function clone(value, isDeep, customizer, thisArg) {
      if (isDeep && typeof isDeep != 'boolean' && isIterateeCall(value, isDeep, customizer)) {
        isDeep = false;
      }
      else if (typeof isDeep == 'function') {
        thisArg = customizer;
        customizer = isDeep;
        isDeep = false;
      }
      return typeof customizer == 'function'
        ? baseClone(value, isDeep, bindCallback(customizer, thisArg, 1))
        : baseClone(value, isDeep);
    }

    /**
     * Creates a deep clone of `value`. If `customizer` is provided it is invoked
     * to produce the cloned values. If `customizer` returns `undefined` cloning
     * is handled by the method instead. The `customizer` is bound to `thisArg`
     * and invoked with two argument; (value [, index|key, object]).
     *
     * **Note:** This method is loosely based on the
     * [structured clone algorithm](http://www.w3.org/TR/html5/infrastructure.html#internal-structured-cloning-algorithm).
     * The enumerable properties of `arguments` objects and objects created by
     * constructors other than `Object` are cloned to plain `Object` objects. An
     * empty object is returned for uncloneable values such as functions, DOM nodes,
     * Maps, Sets, and WeakMaps.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to deep clone.
     * @param {Function} [customizer] The function to customize cloning values.
     * @param {*} [thisArg] The `this` binding of `customizer`.
     * @returns {*} Returns the deep cloned value.
     * @example
     *
     * var users = [
     *   { 'user': 'barney' },
     *   { 'user': 'fred' }
     * ];
     *
     * var deep = _.cloneDeep(users);
     * deep[0] === users[0];
     * // => false
     *
     * // using a customizer callback
     * var el = _.cloneDeep(document.body, function(value) {
     *   if (_.isElement(value)) {
     *     return value.cloneNode(true);
     *   }
     * });
     *
     * el === document.body
     * // => false
     * el.nodeName
     * // => BODY
     * el.childNodes.length;
     * // => 20
     */
    function cloneDeep(value, customizer, thisArg) {
      return typeof customizer == 'function'
        ? baseClone(value, true, bindCallback(customizer, thisArg, 1))
        : baseClone(value, true);
    }

    /**
     * Checks if `value` is greater than `other`.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to compare.
     * @param {*} other The other value to compare.
     * @returns {boolean} Returns `true` if `value` is greater than `other`, else `false`.
     * @example
     *
     * _.gt(3, 1);
     * // => true
     *
     * _.gt(3, 3);
     * // => false
     *
     * _.gt(1, 3);
     * // => false
     */
    function gt(value, other) {
      return value > other;
    }

    /**
     * Checks if `value` is greater than or equal to `other`.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to compare.
     * @param {*} other The other value to compare.
     * @returns {boolean} Returns `true` if `value` is greater than or equal to `other`, else `false`.
     * @example
     *
     * _.gte(3, 1);
     * // => true
     *
     * _.gte(3, 3);
     * // => true
     *
     * _.gte(1, 3);
     * // => false
     */
    function gte(value, other) {
      return value >= other;
    }

    /**
     * Checks if `value` is classified as an `arguments` object.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is correctly classified, else `false`.
     * @example
     *
     * _.isArguments(function() { return arguments; }());
     * // => true
     *
     * _.isArguments([1, 2, 3]);
     * // => false
     */
    function isArguments(value) {
      return isObjectLike(value) && isArrayLike(value) &&
        hasOwnProperty.call(value, 'callee') && !propertyIsEnumerable.call(value, 'callee');
    }

    /**
     * Checks if `value` is classified as an `Array` object.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is correctly classified, else `false`.
     * @example
     *
     * _.isArray([1, 2, 3]);
     * // => true
     *
     * _.isArray(function() { return arguments; }());
     * // => false
     */
    var isArray = nativeIsArray || function(value) {
      return isObjectLike(value) && isLength(value.length) && objToString.call(value) == arrayTag;
    };

    /**
     * Checks if `value` is classified as a boolean primitive or object.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is correctly classified, else `false`.
     * @example
     *
     * _.isBoolean(false);
     * // => true
     *
     * _.isBoolean(null);
     * // => false
     */
    function isBoolean(value) {
      return value === true || value === false || (isObjectLike(value) && objToString.call(value) == boolTag);
    }

    /**
     * Checks if `value` is classified as a `Date` object.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is correctly classified, else `false`.
     * @example
     *
     * _.isDate(new Date);
     * // => true
     *
     * _.isDate('Mon April 23 2012');
     * // => false
     */
    function isDate(value) {
      return isObjectLike(value) && objToString.call(value) == dateTag;
    }

    /**
     * Checks if `value` is a DOM element.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is a DOM element, else `false`.
     * @example
     *
     * _.isElement(document.body);
     * // => true
     *
     * _.isElement('<body>');
     * // => false
     */
    function isElement(value) {
      return !!value && value.nodeType === 1 && isObjectLike(value) && !isPlainObject(value);
    }

    /**
     * Checks if `value` is empty. A value is considered empty unless it is an
     * `arguments` object, array, string, or jQuery-like collection with a length
     * greater than `0` or an object with own enumerable properties.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {Array|Object|string} value The value to inspect.
     * @returns {boolean} Returns `true` if `value` is empty, else `false`.
     * @example
     *
     * _.isEmpty(null);
     * // => true
     *
     * _.isEmpty(true);
     * // => true
     *
     * _.isEmpty(1);
     * // => true
     *
     * _.isEmpty([1, 2, 3]);
     * // => false
     *
     * _.isEmpty({ 'a': 1 });
     * // => false
     */
    function isEmpty(value) {
      if (value == null) {
        return true;
      }
      if (isArrayLike(value) && (isArray(value) || isString(value) || isArguments(value) ||
          (isObjectLike(value) && isFunction(value.splice)))) {
        return !value.length;
      }
      return !keys(value).length;
    }

    /**
     * Performs a deep comparison between two values to determine if they are
     * equivalent. If `customizer` is provided it is invoked to compare values.
     * If `customizer` returns `undefined` comparisons are handled by the method
     * instead. The `customizer` is bound to `thisArg` and invoked with three
     * arguments: (value, other [, index|key]).
     *
     * **Note:** This method supports comparing arrays, booleans, `Date` objects,
     * numbers, `Object` objects, regexes, and strings. Objects are compared by
     * their own, not inherited, enumerable properties. Functions and DOM nodes
     * are **not** supported. Provide a customizer function to extend support
     * for comparing other values.
     *
     * @static
     * @memberOf _
     * @alias eq
     * @category Lang
     * @param {*} value The value to compare.
     * @param {*} other The other value to compare.
     * @param {Function} [customizer] The function to customize value comparisons.
     * @param {*} [thisArg] The `this` binding of `customizer`.
     * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
     * @example
     *
     * var object = { 'user': 'fred' };
     * var other = { 'user': 'fred' };
     *
     * object == other;
     * // => false
     *
     * _.isEqual(object, other);
     * // => true
     *
     * // using a customizer callback
     * var array = ['hello', 'goodbye'];
     * var other = ['hi', 'goodbye'];
     *
     * _.isEqual(array, other, function(value, other) {
     *   if (_.every([value, other], RegExp.prototype.test, /^h(?:i|ello)$/)) {
     *     return true;
     *   }
     * });
     * // => true
     */
    function isEqual(value, other, customizer, thisArg) {
      customizer = typeof customizer == 'function' ? bindCallback(customizer, thisArg, 3) : undefined;
      var result = customizer ? customizer(value, other) : undefined;
      return  result === undefined ? baseIsEqual(value, other, customizer) : !!result;
    }

    /**
     * Checks if `value` is an `Error`, `EvalError`, `RangeError`, `ReferenceError`,
     * `SyntaxError`, `TypeError`, or `URIError` object.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is an error object, else `false`.
     * @example
     *
     * _.isError(new Error);
     * // => true
     *
     * _.isError(Error);
     * // => false
     */
    function isError(value) {
      return isObjectLike(value) && typeof value.message == 'string' && objToString.call(value) == errorTag;
    }

    /**
     * Checks if `value` is a finite primitive number.
     *
     * **Note:** This method is based on [`Number.isFinite`](http://ecma-international.org/ecma-262/6.0/#sec-number.isfinite).
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is a finite number, else `false`.
     * @example
     *
     * _.isFinite(10);
     * // => true
     *
     * _.isFinite('10');
     * // => false
     *
     * _.isFinite(true);
     * // => false
     *
     * _.isFinite(Object(10));
     * // => false
     *
     * _.isFinite(Infinity);
     * // => false
     */
    function isFinite(value) {
      return typeof value == 'number' && nativeIsFinite(value);
    }

    /**
     * Checks if `value` is classified as a `Function` object.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is correctly classified, else `false`.
     * @example
     *
     * _.isFunction(_);
     * // => true
     *
     * _.isFunction(/abc/);
     * // => false
     */
    function isFunction(value) {
      // The use of `Object#toString` avoids issues with the `typeof` operator
      // in older versions of Chrome and Safari which return 'function' for regexes
      // and Safari 8 equivalents which return 'object' for typed array constructors.
      return isObject(value) && objToString.call(value) == funcTag;
    }

    /**
     * Checks if `value` is the [language type](https://es5.github.io/#x8) of `Object`.
     * (e.g. arrays, functions, objects, regexes, `new Number(0)`, and `new String('')`)
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is an object, else `false`.
     * @example
     *
     * _.isObject({});
     * // => true
     *
     * _.isObject([1, 2, 3]);
     * // => true
     *
     * _.isObject(1);
     * // => false
     */
    function isObject(value) {
      // Avoid a V8 JIT bug in Chrome 19-20.
      // See https://code.google.com/p/v8/issues/detail?id=2291 for more details.
      var type = typeof value;
      return !!value && (type == 'object' || type == 'function');
    }

    /**
     * Performs a deep comparison between `object` and `source` to determine if
     * `object` contains equivalent property values. If `customizer` is provided
     * it is invoked to compare values. If `customizer` returns `undefined`
     * comparisons are handled by the method instead. The `customizer` is bound
     * to `thisArg` and invoked with three arguments: (value, other, index|key).
     *
     * **Note:** This method supports comparing properties of arrays, booleans,
     * `Date` objects, numbers, `Object` objects, regexes, and strings. Functions
     * and DOM nodes are **not** supported. Provide a customizer function to extend
     * support for comparing other values.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {Object} object The object to inspect.
     * @param {Object} source The object of property values to match.
     * @param {Function} [customizer] The function to customize value comparisons.
     * @param {*} [thisArg] The `this` binding of `customizer`.
     * @returns {boolean} Returns `true` if `object` is a match, else `false`.
     * @example
     *
     * var object = { 'user': 'fred', 'age': 40 };
     *
     * _.isMatch(object, { 'age': 40 });
     * // => true
     *
     * _.isMatch(object, { 'age': 36 });
     * // => false
     *
     * // using a customizer callback
     * var object = { 'greeting': 'hello' };
     * var source = { 'greeting': 'hi' };
     *
     * _.isMatch(object, source, function(value, other) {
     *   return _.every([value, other], RegExp.prototype.test, /^h(?:i|ello)$/) || undefined;
     * });
     * // => true
     */
    function isMatch(object, source, customizer, thisArg) {
      customizer = typeof customizer == 'function' ? bindCallback(customizer, thisArg, 3) : undefined;
      return baseIsMatch(object, getMatchData(source), customizer);
    }

    /**
     * Checks if `value` is `NaN`.
     *
     * **Note:** This method is not the same as [`isNaN`](https://es5.github.io/#x15.1.2.4)
     * which returns `true` for `undefined` and other non-numeric values.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is `NaN`, else `false`.
     * @example
     *
     * _.isNaN(NaN);
     * // => true
     *
     * _.isNaN(new Number(NaN));
     * // => true
     *
     * isNaN(undefined);
     * // => true
     *
     * _.isNaN(undefined);
     * // => false
     */
    function isNaN(value) {
      // An `NaN` primitive is the only value that is not equal to itself.
      // Perform the `toStringTag` check first to avoid errors with some host objects in IE.
      return isNumber(value) && value != +value;
    }

    /**
     * Checks if `value` is a native function.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is a native function, else `false`.
     * @example
     *
     * _.isNative(Array.prototype.push);
     * // => true
     *
     * _.isNative(_);
     * // => false
     */
    function isNative(value) {
      if (value == null) {
        return false;
      }
      if (isFunction(value)) {
        return reIsNative.test(fnToString.call(value));
      }
      return isObjectLike(value) && reIsHostCtor.test(value);
    }

    /**
     * Checks if `value` is `null`.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is `null`, else `false`.
     * @example
     *
     * _.isNull(null);
     * // => true
     *
     * _.isNull(void 0);
     * // => false
     */
    function isNull(value) {
      return value === null;
    }

    /**
     * Checks if `value` is classified as a `Number` primitive or object.
     *
     * **Note:** To exclude `Infinity`, `-Infinity`, and `NaN`, which are classified
     * as numbers, use the `_.isFinite` method.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is correctly classified, else `false`.
     * @example
     *
     * _.isNumber(8.4);
     * // => true
     *
     * _.isNumber(NaN);
     * // => true
     *
     * _.isNumber('8.4');
     * // => false
     */
    function isNumber(value) {
      return typeof value == 'number' || (isObjectLike(value) && objToString.call(value) == numberTag);
    }

    /**
     * Checks if `value` is a plain object, that is, an object created by the
     * `Object` constructor or one with a `[[Prototype]]` of `null`.
     *
     * **Note:** This method assumes objects created by the `Object` constructor
     * have no inherited enumerable properties.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is a plain object, else `false`.
     * @example
     *
     * function Foo() {
     *   this.a = 1;
     * }
     *
     * _.isPlainObject(new Foo);
     * // => false
     *
     * _.isPlainObject([1, 2, 3]);
     * // => false
     *
     * _.isPlainObject({ 'x': 0, 'y': 0 });
     * // => true
     *
     * _.isPlainObject(Object.create(null));
     * // => true
     */
    function isPlainObject(value) {
      var Ctor;

      // Exit early for non `Object` objects.
      if (!(isObjectLike(value) && objToString.call(value) == objectTag && !isArguments(value)) ||
          (!hasOwnProperty.call(value, 'constructor') && (Ctor = value.constructor, typeof Ctor == 'function' && !(Ctor instanceof Ctor)))) {
        return false;
      }
      // IE < 9 iterates inherited properties before own properties. If the first
      // iterated property is an object's own property then there are no inherited
      // enumerable properties.
      var result;
      // In most environments an object's own properties are iterated before
      // its inherited properties. If the last iterated property is an object's
      // own property then there are no inherited enumerable properties.
      baseForIn(value, function(subValue, key) {
        result = key;
      });
      return result === undefined || hasOwnProperty.call(value, result);
    }

    /**
     * Checks if `value` is classified as a `RegExp` object.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is correctly classified, else `false`.
     * @example
     *
     * _.isRegExp(/abc/);
     * // => true
     *
     * _.isRegExp('/abc/');
     * // => false
     */
    function isRegExp(value) {
      return isObject(value) && objToString.call(value) == regexpTag;
    }

    /**
     * Checks if `value` is classified as a `String` primitive or object.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is correctly classified, else `false`.
     * @example
     *
     * _.isString('abc');
     * // => true
     *
     * _.isString(1);
     * // => false
     */
    function isString(value) {
      return typeof value == 'string' || (isObjectLike(value) && objToString.call(value) == stringTag);
    }

    /**
     * Checks if `value` is classified as a typed array.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is correctly classified, else `false`.
     * @example
     *
     * _.isTypedArray(new Uint8Array);
     * // => true
     *
     * _.isTypedArray([]);
     * // => false
     */
    function isTypedArray(value) {
      return isObjectLike(value) && isLength(value.length) && !!typedArrayTags[objToString.call(value)];
    }

    /**
     * Checks if `value` is `undefined`.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is `undefined`, else `false`.
     * @example
     *
     * _.isUndefined(void 0);
     * // => true
     *
     * _.isUndefined(null);
     * // => false
     */
    function isUndefined(value) {
      return value === undefined;
    }

    /**
     * Checks if `value` is less than `other`.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to compare.
     * @param {*} other The other value to compare.
     * @returns {boolean} Returns `true` if `value` is less than `other`, else `false`.
     * @example
     *
     * _.lt(1, 3);
     * // => true
     *
     * _.lt(3, 3);
     * // => false
     *
     * _.lt(3, 1);
     * // => false
     */
    function lt(value, other) {
      return value < other;
    }

    /**
     * Checks if `value` is less than or equal to `other`.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to compare.
     * @param {*} other The other value to compare.
     * @returns {boolean} Returns `true` if `value` is less than or equal to `other`, else `false`.
     * @example
     *
     * _.lte(1, 3);
     * // => true
     *
     * _.lte(3, 3);
     * // => true
     *
     * _.lte(3, 1);
     * // => false
     */
    function lte(value, other) {
      return value <= other;
    }

    /**
     * Converts `value` to an array.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to convert.
     * @returns {Array} Returns the converted array.
     * @example
     *
     * (function() {
     *   return _.toArray(arguments).slice(1);
     * }(1, 2, 3));
     * // => [2, 3]
     */
    function toArray(value) {
      var length = value ? getLength(value) : 0;
      if (!isLength(length)) {
        return values(value);
      }
      if (!length) {
        return [];
      }
      return arrayCopy(value);
    }

    /**
     * Converts `value` to a plain object flattening inherited enumerable
     * properties of `value` to own properties of the plain object.
     *
     * @static
     * @memberOf _
     * @category Lang
     * @param {*} value The value to convert.
     * @returns {Object} Returns the converted plain object.
     * @example
     *
     * function Foo() {
     *   this.b = 2;
     * }
     *
     * Foo.prototype.c = 3;
     *
     * _.assign({ 'a': 1 }, new Foo);
     * // => { 'a': 1, 'b': 2 }
     *
     * _.assign({ 'a': 1 }, _.toPlainObject(new Foo));
     * // => { 'a': 1, 'b': 2, 'c': 3 }
     */
    function toPlainObject(value) {
      return baseCopy(value, keysIn(value));
    }

    /*------------------------------------------------------------------------*/

    /**
     * Recursively merges own enumerable properties of the source object(s), that
     * don't resolve to `undefined` into the destination object. Subsequent sources
     * overwrite property assignments of previous sources. If `customizer` is
     * provided it is invoked to produce the merged values of the destination and
     * source properties. If `customizer` returns `undefined` merging is handled
     * by the method instead. The `customizer` is bound to `thisArg` and invoked
     * with five arguments: (objectValue, sourceValue, key, object, source).
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} object The destination object.
     * @param {...Object} [sources] The source objects.
     * @param {Function} [customizer] The function to customize assigned values.
     * @param {*} [thisArg] The `this` binding of `customizer`.
     * @returns {Object} Returns `object`.
     * @example
     *
     * var users = {
     *   'data': [{ 'user': 'barney' }, { 'user': 'fred' }]
     * };
     *
     * var ages = {
     *   'data': [{ 'age': 36 }, { 'age': 40 }]
     * };
     *
     * _.merge(users, ages);
     * // => { 'data': [{ 'user': 'barney', 'age': 36 }, { 'user': 'fred', 'age': 40 }] }
     *
     * // using a customizer callback
     * var object = {
     *   'fruits': ['apple'],
     *   'vegetables': ['beet']
     * };
     *
     * var other = {
     *   'fruits': ['banana'],
     *   'vegetables': ['carrot']
     * };
     *
     * _.merge(object, other, function(a, b) {
     *   if (_.isArray(a)) {
     *     return a.concat(b);
     *   }
     * });
     * // => { 'fruits': ['apple', 'banana'], 'vegetables': ['beet', 'carrot'] }
     */
    var merge = createAssigner(baseMerge);

    /**
     * Assigns own enumerable properties of source object(s) to the destination
     * object. Subsequent sources overwrite property assignments of previous sources.
     * If `customizer` is provided it is invoked to produce the assigned values.
     * The `customizer` is bound to `thisArg` and invoked with five arguments:
     * (objectValue, sourceValue, key, object, source).
     *
     * **Note:** This method mutates `object` and is based on
     * [`Object.assign`](http://ecma-international.org/ecma-262/6.0/#sec-object.assign).
     *
     * @static
     * @memberOf _
     * @alias extend
     * @category Object
     * @param {Object} object The destination object.
     * @param {...Object} [sources] The source objects.
     * @param {Function} [customizer] The function to customize assigned values.
     * @param {*} [thisArg] The `this` binding of `customizer`.
     * @returns {Object} Returns `object`.
     * @example
     *
     * _.assign({ 'user': 'barney' }, { 'age': 40 }, { 'user': 'fred' });
     * // => { 'user': 'fred', 'age': 40 }
     *
     * // using a customizer callback
     * var defaults = _.partialRight(_.assign, function(value, other) {
     *   return _.isUndefined(value) ? other : value;
     * });
     *
     * defaults({ 'user': 'barney' }, { 'age': 36 }, { 'user': 'fred' });
     * // => { 'user': 'barney', 'age': 36 }
     */
    var assign = createAssigner(function(object, source, customizer) {
      return customizer
        ? assignWith(object, source, customizer)
        : baseAssign(object, source);
    });

    /**
     * Creates an object that inherits from the given `prototype` object. If a
     * `properties` object is provided its own enumerable properties are assigned
     * to the created object.
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} prototype The object to inherit from.
     * @param {Object} [properties] The properties to assign to the object.
     * @param- {Object} [guard] Enables use as a callback for functions like `_.map`.
     * @returns {Object} Returns the new object.
     * @example
     *
     * function Shape() {
     *   this.x = 0;
     *   this.y = 0;
     * }
     *
     * function Circle() {
     *   Shape.call(this);
     * }
     *
     * Circle.prototype = _.create(Shape.prototype, {
     *   'constructor': Circle
     * });
     *
     * var circle = new Circle;
     * circle instanceof Circle;
     * // => true
     *
     * circle instanceof Shape;
     * // => true
     */
    function create(prototype, properties, guard) {
      var result = baseCreate(prototype);
      if (guard && isIterateeCall(prototype, properties, guard)) {
        properties = undefined;
      }
      return properties ? baseAssign(result, properties) : result;
    }

    /**
     * Assigns own enumerable properties of source object(s) to the destination
     * object for all destination properties that resolve to `undefined`. Once a
     * property is set, additional values of the same property are ignored.
     *
     * **Note:** This method mutates `object`.
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} object The destination object.
     * @param {...Object} [sources] The source objects.
     * @returns {Object} Returns `object`.
     * @example
     *
     * _.defaults({ 'user': 'barney' }, { 'age': 36 }, { 'user': 'fred' });
     * // => { 'user': 'barney', 'age': 36 }
     */
    var defaults = createDefaults(assign, assignDefaults);

    /**
     * This method is like `_.defaults` except that it recursively assigns
     * default properties.
     *
     * **Note:** This method mutates `object`.
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} object The destination object.
     * @param {...Object} [sources] The source objects.
     * @returns {Object} Returns `object`.
     * @example
     *
     * _.defaultsDeep({ 'user': { 'name': 'barney' } }, { 'user': { 'name': 'fred', 'age': 36 } });
     * // => { 'user': { 'name': 'barney', 'age': 36 } }
     *
     */
    var defaultsDeep = createDefaults(merge, mergeDefaults);

    /**
     * This method is like `_.find` except that it returns the key of the first
     * element `predicate` returns truthy for instead of the element itself.
     *
     * If a property name is provided for `predicate` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `predicate` the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} object The object to search.
     * @param {Function|Object|string} [predicate=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `predicate`.
     * @returns {string|undefined} Returns the key of the matched element, else `undefined`.
     * @example
     *
     * var users = {
     *   'barney':  { 'age': 36, 'active': true },
     *   'fred':    { 'age': 40, 'active': false },
     *   'pebbles': { 'age': 1,  'active': true }
     * };
     *
     * _.findKey(users, function(chr) {
     *   return chr.age < 40;
     * });
     * // => 'barney' (iteration order is not guaranteed)
     *
     * // using the `_.matches` callback shorthand
     * _.findKey(users, { 'age': 1, 'active': true });
     * // => 'pebbles'
     *
     * // using the `_.matchesProperty` callback shorthand
     * _.findKey(users, 'active', false);
     * // => 'fred'
     *
     * // using the `_.property` callback shorthand
     * _.findKey(users, 'active');
     * // => 'barney'
     */
    var findKey = createFindKey(baseForOwn);

    /**
     * This method is like `_.findKey` except that it iterates over elements of
     * a collection in the opposite order.
     *
     * If a property name is provided for `predicate` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `predicate` the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} object The object to search.
     * @param {Function|Object|string} [predicate=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `predicate`.
     * @returns {string|undefined} Returns the key of the matched element, else `undefined`.
     * @example
     *
     * var users = {
     *   'barney':  { 'age': 36, 'active': true },
     *   'fred':    { 'age': 40, 'active': false },
     *   'pebbles': { 'age': 1,  'active': true }
     * };
     *
     * _.findLastKey(users, function(chr) {
     *   return chr.age < 40;
     * });
     * // => returns `pebbles` assuming `_.findKey` returns `barney`
     *
     * // using the `_.matches` callback shorthand
     * _.findLastKey(users, { 'age': 36, 'active': true });
     * // => 'barney'
     *
     * // using the `_.matchesProperty` callback shorthand
     * _.findLastKey(users, 'active', false);
     * // => 'fred'
     *
     * // using the `_.property` callback shorthand
     * _.findLastKey(users, 'active');
     * // => 'pebbles'
     */
    var findLastKey = createFindKey(baseForOwnRight);

    /**
     * Iterates over own and inherited enumerable properties of an object invoking
     * `iteratee` for each property. The `iteratee` is bound to `thisArg` and invoked
     * with three arguments: (value, key, object). Iteratee functions may exit
     * iteration early by explicitly returning `false`.
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} object The object to iterate over.
     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {Object} Returns `object`.
     * @example
     *
     * function Foo() {
     *   this.a = 1;
     *   this.b = 2;
     * }
     *
     * Foo.prototype.c = 3;
     *
     * _.forIn(new Foo, function(value, key) {
     *   console.log(key);
     * });
     * // => logs 'a', 'b', and 'c' (iteration order is not guaranteed)
     */
    var forIn = createForIn(baseFor);

    /**
     * This method is like `_.forIn` except that it iterates over properties of
     * `object` in the opposite order.
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} object The object to iterate over.
     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {Object} Returns `object`.
     * @example
     *
     * function Foo() {
     *   this.a = 1;
     *   this.b = 2;
     * }
     *
     * Foo.prototype.c = 3;
     *
     * _.forInRight(new Foo, function(value, key) {
     *   console.log(key);
     * });
     * // => logs 'c', 'b', and 'a' assuming `_.forIn ` logs 'a', 'b', and 'c'
     */
    var forInRight = createForIn(baseForRight);

    /**
     * Iterates over own enumerable properties of an object invoking `iteratee`
     * for each property. The `iteratee` is bound to `thisArg` and invoked with
     * three arguments: (value, key, object). Iteratee functions may exit iteration
     * early by explicitly returning `false`.
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} object The object to iterate over.
     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {Object} Returns `object`.
     * @example
     *
     * function Foo() {
     *   this.a = 1;
     *   this.b = 2;
     * }
     *
     * Foo.prototype.c = 3;
     *
     * _.forOwn(new Foo, function(value, key) {
     *   console.log(key);
     * });
     * // => logs 'a' and 'b' (iteration order is not guaranteed)
     */
    var forOwn = createForOwn(baseForOwn);

    /**
     * This method is like `_.forOwn` except that it iterates over properties of
     * `object` in the opposite order.
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} object The object to iterate over.
     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {Object} Returns `object`.
     * @example
     *
     * function Foo() {
     *   this.a = 1;
     *   this.b = 2;
     * }
     *
     * Foo.prototype.c = 3;
     *
     * _.forOwnRight(new Foo, function(value, key) {
     *   console.log(key);
     * });
     * // => logs 'b' and 'a' assuming `_.forOwn` logs 'a' and 'b'
     */
    var forOwnRight = createForOwn(baseForOwnRight);

    /**
     * Creates an array of function property names from all enumerable properties,
     * own and inherited, of `object`.
     *
     * @static
     * @memberOf _
     * @alias methods
     * @category Object
     * @param {Object} object The object to inspect.
     * @returns {Array} Returns the new array of property names.
     * @example
     *
     * _.functions(_);
     * // => ['after', 'ary', 'assign', ...]
     */
    function functions(object) {
      return baseFunctions(object, keysIn(object));
    }

    /**
     * Gets the property value at `path` of `object`. If the resolved value is
     * `undefined` the `defaultValue` is used in its place.
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} object The object to query.
     * @param {Array|string} path The path of the property to get.
     * @param {*} [defaultValue] The value returned if the resolved value is `undefined`.
     * @returns {*} Returns the resolved value.
     * @example
     *
     * var object = { 'a': [{ 'b': { 'c': 3 } }] };
     *
     * _.get(object, 'a[0].b.c');
     * // => 3
     *
     * _.get(object, ['a', '0', 'b', 'c']);
     * // => 3
     *
     * _.get(object, 'a.b.c', 'default');
     * // => 'default'
     */
    function get(object, path, defaultValue) {
      var result = object == null ? undefined : baseGet(object, toPath(path), path + '');
      return result === undefined ? defaultValue : result;
    }

    /**
     * Checks if `path` is a direct property.
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} object The object to query.
     * @param {Array|string} path The path to check.
     * @returns {boolean} Returns `true` if `path` is a direct property, else `false`.
     * @example
     *
     * var object = { 'a': { 'b': { 'c': 3 } } };
     *
     * _.has(object, 'a');
     * // => true
     *
     * _.has(object, 'a.b.c');
     * // => true
     *
     * _.has(object, ['a', 'b', 'c']);
     * // => true
     */
    function has(object, path) {
      if (object == null) {
        return false;
      }
      var result = hasOwnProperty.call(object, path);
      if (!result && !isKey(path)) {
        path = toPath(path);
        object = path.length == 1 ? object : baseGet(object, baseSlice(path, 0, -1));
        if (object == null) {
          return false;
        }
        path = last(path);
        result = hasOwnProperty.call(object, path);
      }
      return result || (isLength(object.length) && isIndex(path, object.length) &&
        (isArray(object) || isArguments(object)));
    }

    /**
     * Creates an object composed of the inverted keys and values of `object`.
     * If `object` contains duplicate values, subsequent values overwrite property
     * assignments of previous values unless `multiValue` is `true`.
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} object The object to invert.
     * @param {boolean} [multiValue] Allow multiple values per key.
     * @param- {Object} [guard] Enables use as a callback for functions like `_.map`.
     * @returns {Object} Returns the new inverted object.
     * @example
     *
     * var object = { 'a': 1, 'b': 2, 'c': 1 };
     *
     * _.invert(object);
     * // => { '1': 'c', '2': 'b' }
     *
     * // with `multiValue`
     * _.invert(object, true);
     * // => { '1': ['a', 'c'], '2': ['b'] }
     */
    function invert(object, multiValue, guard) {
      if (guard && isIterateeCall(object, multiValue, guard)) {
        multiValue = undefined;
      }
      var index = -1,
          props = keys(object),
          length = props.length,
          result = {};

      while (++index < length) {
        var key = props[index],
            value = object[key];

        if (multiValue) {
          if (hasOwnProperty.call(result, value)) {
            result[value].push(key);
          } else {
            result[value] = [key];
          }
        }
        else {
          result[value] = key;
        }
      }
      return result;
    }

    /**
     * Creates an array of the own enumerable property names of `object`.
     *
     * **Note:** Non-object values are coerced to objects. See the
     * [ES spec](http://ecma-international.org/ecma-262/6.0/#sec-object.keys)
     * for more details.
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} object The object to query.
     * @returns {Array} Returns the array of property names.
     * @example
     *
     * function Foo() {
     *   this.a = 1;
     *   this.b = 2;
     * }
     *
     * Foo.prototype.c = 3;
     *
     * _.keys(new Foo);
     * // => ['a', 'b'] (iteration order is not guaranteed)
     *
     * _.keys('hi');
     * // => ['0', '1']
     */
    var keys = !nativeKeys ? shimKeys : function(object) {
      var Ctor = object == null ? undefined : object.constructor;
      if ((typeof Ctor == 'function' && Ctor.prototype === object) ||
          (typeof object != 'function' && isArrayLike(object))) {
        return shimKeys(object);
      }
      return isObject(object) ? nativeKeys(object) : [];
    };

    /**
     * Creates an array of the own and inherited enumerable property names of `object`.
     *
     * **Note:** Non-object values are coerced to objects.
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} object The object to query.
     * @returns {Array} Returns the array of property names.
     * @example
     *
     * function Foo() {
     *   this.a = 1;
     *   this.b = 2;
     * }
     *
     * Foo.prototype.c = 3;
     *
     * _.keysIn(new Foo);
     * // => ['a', 'b', 'c'] (iteration order is not guaranteed)
     */
    function keysIn(object) {
      if (object == null) {
        return [];
      }
      if (!isObject(object)) {
        object = Object(object);
      }
      var length = object.length;
      length = (length && isLength(length) &&
        (isArray(object) || isArguments(object)) && length) || 0;

      var Ctor = object.constructor,
          index = -1,
          isProto = typeof Ctor == 'function' && Ctor.prototype === object,
          result = Array(length),
          skipIndexes = length > 0;

      while (++index < length) {
        result[index] = (index + '');
      }
      for (var key in object) {
        if (!(skipIndexes && isIndex(key, length)) &&
            !(key == 'constructor' && (isProto || !hasOwnProperty.call(object, key)))) {
          result.push(key);
        }
      }
      return result;
    }

    /**
     * The opposite of `_.mapValues`; this method creates an object with the
     * same values as `object` and keys generated by running each own enumerable
     * property of `object` through `iteratee`.
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} object The object to iterate over.
     * @param {Function|Object|string} [iteratee=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {Object} Returns the new mapped object.
     * @example
     *
     * _.mapKeys({ 'a': 1, 'b': 2 }, function(value, key) {
     *   return key + value;
     * });
     * // => { 'a1': 1, 'b2': 2 }
     */
    var mapKeys = createObjectMapper(true);

    /**
     * Creates an object with the same keys as `object` and values generated by
     * running each own enumerable property of `object` through `iteratee`. The
     * iteratee function is bound to `thisArg` and invoked with three arguments:
     * (value, key, object).
     *
     * If a property name is provided for `iteratee` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `iteratee` the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} object The object to iterate over.
     * @param {Function|Object|string} [iteratee=_.identity] The function invoked
     *  per iteration.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {Object} Returns the new mapped object.
     * @example
     *
     * _.mapValues({ 'a': 1, 'b': 2 }, function(n) {
     *   return n * 3;
     * });
     * // => { 'a': 3, 'b': 6 }
     *
     * var users = {
     *   'fred':    { 'user': 'fred',    'age': 40 },
     *   'pebbles': { 'user': 'pebbles', 'age': 1 }
     * };
     *
     * // using the `_.property` callback shorthand
     * _.mapValues(users, 'age');
     * // => { 'fred': 40, 'pebbles': 1 } (iteration order is not guaranteed)
     */
    var mapValues = createObjectMapper();

    /**
     * The opposite of `_.pick`; this method creates an object composed of the
     * own and inherited enumerable properties of `object` that are not omitted.
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} object The source object.
     * @param {Function|...(string|string[])} [predicate] The function invoked per
     *  iteration or property names to omit, specified as individual property
     *  names or arrays of property names.
     * @param {*} [thisArg] The `this` binding of `predicate`.
     * @returns {Object} Returns the new object.
     * @example
     *
     * var object = { 'user': 'fred', 'age': 40 };
     *
     * _.omit(object, 'age');
     * // => { 'user': 'fred' }
     *
     * _.omit(object, _.isNumber);
     * // => { 'user': 'fred' }
     */
    var omit = restParam(function(object, props) {
      if (object == null) {
        return {};
      }
      if (typeof props[0] != 'function') {
        var props = arrayMap(baseFlatten(props), String);
        return pickByArray(object, baseDifference(keysIn(object), props));
      }
      var predicate = bindCallback(props[0], props[1], 3);
      return pickByCallback(object, function(value, key, object) {
        return !predicate(value, key, object);
      });
    });

    /**
     * Creates a two dimensional array of the key-value pairs for `object`,
     * e.g. `[[key1, value1], [key2, value2]]`.
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} object The object to query.
     * @returns {Array} Returns the new array of key-value pairs.
     * @example
     *
     * _.pairs({ 'barney': 36, 'fred': 40 });
     * // => [['barney', 36], ['fred', 40]] (iteration order is not guaranteed)
     */
    function pairs(object) {
      object = toObject(object);

      var index = -1,
          props = keys(object),
          length = props.length,
          result = Array(length);

      while (++index < length) {
        var key = props[index];
        result[index] = [key, object[key]];
      }
      return result;
    }

    /**
     * Creates an object composed of the picked `object` properties. Property
     * names may be specified as individual arguments or as arrays of property
     * names. If `predicate` is provided it is invoked for each property of `object`
     * picking the properties `predicate` returns truthy for. The predicate is
     * bound to `thisArg` and invoked with three arguments: (value, key, object).
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} object The source object.
     * @param {Function|...(string|string[])} [predicate] The function invoked per
     *  iteration or property names to pick, specified as individual property
     *  names or arrays of property names.
     * @param {*} [thisArg] The `this` binding of `predicate`.
     * @returns {Object} Returns the new object.
     * @example
     *
     * var object = { 'user': 'fred', 'age': 40 };
     *
     * _.pick(object, 'user');
     * // => { 'user': 'fred' }
     *
     * _.pick(object, _.isString);
     * // => { 'user': 'fred' }
     */
    var pick = restParam(function(object, props) {
      if (object == null) {
        return {};
      }
      return typeof props[0] == 'function'
        ? pickByCallback(object, bindCallback(props[0], props[1], 3))
        : pickByArray(object, baseFlatten(props));
    });

    /**
     * This method is like `_.get` except that if the resolved value is a function
     * it is invoked with the `this` binding of its parent object and its result
     * is returned.
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} object The object to query.
     * @param {Array|string} path The path of the property to resolve.
     * @param {*} [defaultValue] The value returned if the resolved value is `undefined`.
     * @returns {*} Returns the resolved value.
     * @example
     *
     * var object = { 'a': [{ 'b': { 'c1': 3, 'c2': _.constant(4) } }] };
     *
     * _.result(object, 'a[0].b.c1');
     * // => 3
     *
     * _.result(object, 'a[0].b.c2');
     * // => 4
     *
     * _.result(object, 'a.b.c', 'default');
     * // => 'default'
     *
     * _.result(object, 'a.b.c', _.constant('default'));
     * // => 'default'
     */
    function result(object, path, defaultValue) {
      var result = object == null ? undefined : object[path];
      if (result === undefined) {
        if (object != null && !isKey(path, object)) {
          path = toPath(path);
          object = path.length == 1 ? object : baseGet(object, baseSlice(path, 0, -1));
          result = object == null ? undefined : object[last(path)];
        }
        result = result === undefined ? defaultValue : result;
      }
      return isFunction(result) ? result.call(object) : result;
    }

    /**
     * Sets the property value of `path` on `object`. If a portion of `path`
     * does not exist it is created.
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} object The object to augment.
     * @param {Array|string} path The path of the property to set.
     * @param {*} value The value to set.
     * @returns {Object} Returns `object`.
     * @example
     *
     * var object = { 'a': [{ 'b': { 'c': 3 } }] };
     *
     * _.set(object, 'a[0].b.c', 4);
     * console.log(object.a[0].b.c);
     * // => 4
     *
     * _.set(object, 'x[0].y.z', 5);
     * console.log(object.x[0].y.z);
     * // => 5
     */
    function set(object, path, value) {
      if (object == null) {
        return object;
      }
      var pathKey = (path + '');
      path = (object[pathKey] != null || isKey(path, object)) ? [pathKey] : toPath(path);

      var index = -1,
          length = path.length,
          lastIndex = length - 1,
          nested = object;

      while (nested != null && ++index < length) {
        var key = path[index];
        if (isObject(nested)) {
          if (index == lastIndex) {
            nested[key] = value;
          } else if (nested[key] == null) {
            nested[key] = isIndex(path[index + 1]) ? [] : {};
          }
        }
        nested = nested[key];
      }
      return object;
    }

    /**
     * An alternative to `_.reduce`; this method transforms `object` to a new
     * `accumulator` object which is the result of running each of its own enumerable
     * properties through `iteratee`, with each invocation potentially mutating
     * the `accumulator` object. The `iteratee` is bound to `thisArg` and invoked
     * with four arguments: (accumulator, value, key, object). Iteratee functions
     * may exit iteration early by explicitly returning `false`.
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Array|Object} object The object to iterate over.
     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
     * @param {*} [accumulator] The custom accumulator value.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {*} Returns the accumulated value.
     * @example
     *
     * _.transform([2, 3, 4], function(result, n) {
     *   result.push(n *= n);
     *   return n % 2 == 0;
     * });
     * // => [4, 9]
     *
     * _.transform({ 'a': 1, 'b': 2 }, function(result, n, key) {
     *   result[key] = n * 3;
     * });
     * // => { 'a': 3, 'b': 6 }
     */
    function transform(object, iteratee, accumulator, thisArg) {
      var isArr = isArray(object) || isTypedArray(object);
      iteratee = getCallback(iteratee, thisArg, 4);

      if (accumulator == null) {
        if (isArr || isObject(object)) {
          var Ctor = object.constructor;
          if (isArr) {
            accumulator = isArray(object) ? new Ctor : [];
          } else {
            accumulator = baseCreate(isFunction(Ctor) ? Ctor.prototype : undefined);
          }
        } else {
          accumulator = {};
        }
      }
      (isArr ? arrayEach : baseForOwn)(object, function(value, index, object) {
        return iteratee(accumulator, value, index, object);
      });
      return accumulator;
    }

    /**
     * Creates an array of the own enumerable property values of `object`.
     *
     * **Note:** Non-object values are coerced to objects.
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} object The object to query.
     * @returns {Array} Returns the array of property values.
     * @example
     *
     * function Foo() {
     *   this.a = 1;
     *   this.b = 2;
     * }
     *
     * Foo.prototype.c = 3;
     *
     * _.values(new Foo);
     * // => [1, 2] (iteration order is not guaranteed)
     *
     * _.values('hi');
     * // => ['h', 'i']
     */
    function values(object) {
      return baseValues(object, keys(object));
    }

    /**
     * Creates an array of the own and inherited enumerable property values
     * of `object`.
     *
     * **Note:** Non-object values are coerced to objects.
     *
     * @static
     * @memberOf _
     * @category Object
     * @param {Object} object The object to query.
     * @returns {Array} Returns the array of property values.
     * @example
     *
     * function Foo() {
     *   this.a = 1;
     *   this.b = 2;
     * }
     *
     * Foo.prototype.c = 3;
     *
     * _.valuesIn(new Foo);
     * // => [1, 2, 3] (iteration order is not guaranteed)
     */
    function valuesIn(object) {
      return baseValues(object, keysIn(object));
    }

    /*------------------------------------------------------------------------*/

    /**
     * Checks if `n` is between `start` and up to but not including, `end`. If
     * `end` is not specified it is set to `start` with `start` then set to `0`.
     *
     * @static
     * @memberOf _
     * @category Number
     * @param {number} n The number to check.
     * @param {number} [start=0] The start of the range.
     * @param {number} end The end of the range.
     * @returns {boolean} Returns `true` if `n` is in the range, else `false`.
     * @example
     *
     * _.inRange(3, 2, 4);
     * // => true
     *
     * _.inRange(4, 8);
     * // => true
     *
     * _.inRange(4, 2);
     * // => false
     *
     * _.inRange(2, 2);
     * // => false
     *
     * _.inRange(1.2, 2);
     * // => true
     *
     * _.inRange(5.2, 4);
     * // => false
     */
    function inRange(value, start, end) {
      start = +start || 0;
      if (end === undefined) {
        end = start;
        start = 0;
      } else {
        end = +end || 0;
      }
      return value >= nativeMin(start, end) && value < nativeMax(start, end);
    }

    /**
     * Produces a random number between `min` and `max` (inclusive). If only one
     * argument is provided a number between `0` and the given number is returned.
     * If `floating` is `true`, or either `min` or `max` are floats, a floating-point
     * number is returned instead of an integer.
     *
     * @static
     * @memberOf _
     * @category Number
     * @param {number} [min=0] The minimum possible value.
     * @param {number} [max=1] The maximum possible value.
     * @param {boolean} [floating] Specify returning a floating-point number.
     * @returns {number} Returns the random number.
     * @example
     *
     * _.random(0, 5);
     * // => an integer between 0 and 5
     *
     * _.random(5);
     * // => also an integer between 0 and 5
     *
     * _.random(5, true);
     * // => a floating-point number between 0 and 5
     *
     * _.random(1.2, 5.2);
     * // => a floating-point number between 1.2 and 5.2
     */
    function random(min, max, floating) {
      if (floating && isIterateeCall(min, max, floating)) {
        max = floating = undefined;
      }
      var noMin = min == null,
          noMax = max == null;

      if (floating == null) {
        if (noMax && typeof min == 'boolean') {
          floating = min;
          min = 1;
        }
        else if (typeof max == 'boolean') {
          floating = max;
          noMax = true;
        }
      }
      if (noMin && noMax) {
        max = 1;
        noMax = false;
      }
      min = +min || 0;
      if (noMax) {
        max = min;
        min = 0;
      } else {
        max = +max || 0;
      }
      if (floating || min % 1 || max % 1) {
        var rand = nativeRandom();
        return nativeMin(min + (rand * (max - min + parseFloat('1e-' + ((rand + '').length - 1)))), max);
      }
      return baseRandom(min, max);
    }

    /*------------------------------------------------------------------------*/

    /**
     * Converts `string` to [camel case](https://en.wikipedia.org/wiki/CamelCase).
     *
     * @static
     * @memberOf _
     * @category String
     * @param {string} [string=''] The string to convert.
     * @returns {string} Returns the camel cased string.
     * @example
     *
     * _.camelCase('Foo Bar');
     * // => 'fooBar'
     *
     * _.camelCase('--foo-bar');
     * // => 'fooBar'
     *
     * _.camelCase('__foo_bar__');
     * // => 'fooBar'
     */
    var camelCase = createCompounder(function(result, word, index) {
      word = word.toLowerCase();
      return result + (index ? (word.charAt(0).toUpperCase() + word.slice(1)) : word);
    });

    /**
     * Capitalizes the first character of `string`.
     *
     * @static
     * @memberOf _
     * @category String
     * @param {string} [string=''] The string to capitalize.
     * @returns {string} Returns the capitalized string.
     * @example
     *
     * _.capitalize('fred');
     * // => 'Fred'
     */
    function capitalize(string) {
      string = baseToString(string);
      return string && (string.charAt(0).toUpperCase() + string.slice(1));
    }

    /**
     * Deburrs `string` by converting [latin-1 supplementary letters](https://en.wikipedia.org/wiki/Latin-1_Supplement_(Unicode_block)#Character_table)
     * to basic latin letters and removing [combining diacritical marks](https://en.wikipedia.org/wiki/Combining_Diacritical_Marks).
     *
     * @static
     * @memberOf _
     * @category String
     * @param {string} [string=''] The string to deburr.
     * @returns {string} Returns the deburred string.
     * @example
     *
     * _.deburr('déjà vu');
     * // => 'deja vu'
     */
    function deburr(string) {
      string = baseToString(string);
      return string && string.replace(reLatin1, deburrLetter).replace(reComboMark, '');
    }

    /**
     * Checks if `string` ends with the given target string.
     *
     * @static
     * @memberOf _
     * @category String
     * @param {string} [string=''] The string to search.
     * @param {string} [target] The string to search for.
     * @param {number} [position=string.length] The position to search from.
     * @returns {boolean} Returns `true` if `string` ends with `target`, else `false`.
     * @example
     *
     * _.endsWith('abc', 'c');
     * // => true
     *
     * _.endsWith('abc', 'b');
     * // => false
     *
     * _.endsWith('abc', 'b', 2);
     * // => true
     */
    function endsWith(string, target, position) {
      string = baseToString(string);
      target = (target + '');

      var length = string.length;
      position = position === undefined
        ? length
        : nativeMin(position < 0 ? 0 : (+position || 0), length);

      position -= target.length;
      return position >= 0 && string.indexOf(target, position) == position;
    }

    /**
     * Converts the characters "&", "<", ">", '"', "'", and "\`", in `string` to
     * their corresponding HTML entities.
     *
     * **Note:** No other characters are escaped. To escape additional characters
     * use a third-party library like [_he_](https://mths.be/he).
     *
     * Though the ">" character is escaped for symmetry, characters like
     * ">" and "/" don't need escaping in HTML and have no special meaning
     * unless they're part of a tag or unquoted attribute value.
     * See [Mathias Bynens's article](https://mathiasbynens.be/notes/ambiguous-ampersands)
     * (under "semi-related fun fact") for more details.
     *
     * Backticks are escaped because in Internet Explorer < 9, they can break out
     * of attribute values or HTML comments. See [#59](https://html5sec.org/#59),
     * [#102](https://html5sec.org/#102), [#108](https://html5sec.org/#108), and
     * [#133](https://html5sec.org/#133) of the [HTML5 Security Cheatsheet](https://html5sec.org/)
     * for more details.
     *
     * When working with HTML you should always [quote attribute values](http://wonko.com/post/html-escaping)
     * to reduce XSS vectors.
     *
     * @static
     * @memberOf _
     * @category String
     * @param {string} [string=''] The string to escape.
     * @returns {string} Returns the escaped string.
     * @example
     *
     * _.escape('fred, barney, & pebbles');
     * // => 'fred, barney, &amp; pebbles'
     */
    function escape(string) {
      // Reset `lastIndex` because in IE < 9 `String#replace` does not.
      string = baseToString(string);
      return (string && reHasUnescapedHtml.test(string))
        ? string.replace(reUnescapedHtml, escapeHtmlChar)
        : string;
    }

    /**
     * Escapes the `RegExp` special characters "\", "/", "^", "$", ".", "|", "?",
     * "*", "+", "(", ")", "[", "]", "{" and "}" in `string`.
     *
     * @static
     * @memberOf _
     * @category String
     * @param {string} [string=''] The string to escape.
     * @returns {string} Returns the escaped string.
     * @example
     *
     * _.escapeRegExp('[lodash](https://lodash.com/)');
     * // => '\[lodash\]\(https:\/\/lodash\.com\/\)'
     */
    function escapeRegExp(string) {
      string = baseToString(string);
      return (string && reHasRegExpChars.test(string))
        ? string.replace(reRegExpChars, escapeRegExpChar)
        : (string || '(?:)');
    }

    /**
     * Converts `string` to [kebab case](https://en.wikipedia.org/wiki/Letter_case#Special_case_styles).
     *
     * @static
     * @memberOf _
     * @category String
     * @param {string} [string=''] The string to convert.
     * @returns {string} Returns the kebab cased string.
     * @example
     *
     * _.kebabCase('Foo Bar');
     * // => 'foo-bar'
     *
     * _.kebabCase('fooBar');
     * // => 'foo-bar'
     *
     * _.kebabCase('__foo_bar__');
     * // => 'foo-bar'
     */
    var kebabCase = createCompounder(function(result, word, index) {
      return result + (index ? '-' : '') + word.toLowerCase();
    });

    /**
     * Pads `string` on the left and right sides if it's shorter than `length`.
     * Padding characters are truncated if they can't be evenly divided by `length`.
     *
     * @static
     * @memberOf _
     * @category String
     * @param {string} [string=''] The string to pad.
     * @param {number} [length=0] The padding length.
     * @param {string} [chars=' '] The string used as padding.
     * @returns {string} Returns the padded string.
     * @example
     *
     * _.pad('abc', 8);
     * // => '  abc   '
     *
     * _.pad('abc', 8, '_-');
     * // => '_-abc_-_'
     *
     * _.pad('abc', 3);
     * // => 'abc'
     */
    function pad(string, length, chars) {
      string = baseToString(string);
      length = +length;

      var strLength = string.length;
      if (strLength >= length || !nativeIsFinite(length)) {
        return string;
      }
      var mid = (length - strLength) / 2,
          leftLength = nativeFloor(mid),
          rightLength = nativeCeil(mid);

      chars = createPadding('', rightLength, chars);
      return chars.slice(0, leftLength) + string + chars;
    }

    /**
     * Pads `string` on the left side if it's shorter than `length`. Padding
     * characters are truncated if they exceed `length`.
     *
     * @static
     * @memberOf _
     * @category String
     * @param {string} [string=''] The string to pad.
     * @param {number} [length=0] The padding length.
     * @param {string} [chars=' '] The string used as padding.
     * @returns {string} Returns the padded string.
     * @example
     *
     * _.padLeft('abc', 6);
     * // => '   abc'
     *
     * _.padLeft('abc', 6, '_-');
     * // => '_-_abc'
     *
     * _.padLeft('abc', 3);
     * // => 'abc'
     */
    var padLeft = createPadDir();

    /**
     * Pads `string` on the right side if it's shorter than `length`. Padding
     * characters are truncated if they exceed `length`.
     *
     * @static
     * @memberOf _
     * @category String
     * @param {string} [string=''] The string to pad.
     * @param {number} [length=0] The padding length.
     * @param {string} [chars=' '] The string used as padding.
     * @returns {string} Returns the padded string.
     * @example
     *
     * _.padRight('abc', 6);
     * // => 'abc   '
     *
     * _.padRight('abc', 6, '_-');
     * // => 'abc_-_'
     *
     * _.padRight('abc', 3);
     * // => 'abc'
     */
    var padRight = createPadDir(true);

    /**
     * Converts `string` to an integer of the specified radix. If `radix` is
     * `undefined` or `0`, a `radix` of `10` is used unless `value` is a hexadecimal,
     * in which case a `radix` of `16` is used.
     *
     * **Note:** This method aligns with the [ES5 implementation](https://es5.github.io/#E)
     * of `parseInt`.
     *
     * @static
     * @memberOf _
     * @category String
     * @param {string} string The string to convert.
     * @param {number} [radix] The radix to interpret `value` by.
     * @param- {Object} [guard] Enables use as a callback for functions like `_.map`.
     * @returns {number} Returns the converted integer.
     * @example
     *
     * _.parseInt('08');
     * // => 8
     *
     * _.map(['6', '08', '10'], _.parseInt);
     * // => [6, 8, 10]
     */
    function parseInt(string, radix, guard) {
      // Firefox < 21 and Opera < 15 follow ES3 for `parseInt`.
      // Chrome fails to trim leading <BOM> whitespace characters.
      // See https://code.google.com/p/v8/issues/detail?id=3109 for more details.
      if (guard ? isIterateeCall(string, radix, guard) : radix == null) {
        radix = 0;
      } else if (radix) {
        radix = +radix;
      }
      string = trim(string);
      return nativeParseInt(string, radix || (reHasHexPrefix.test(string) ? 16 : 10));
    }

    /**
     * Repeats the given string `n` times.
     *
     * @static
     * @memberOf _
     * @category String
     * @param {string} [string=''] The string to repeat.
     * @param {number} [n=0] The number of times to repeat the string.
     * @returns {string} Returns the repeated string.
     * @example
     *
     * _.repeat('*', 3);
     * // => '***'
     *
     * _.repeat('abc', 2);
     * // => 'abcabc'
     *
     * _.repeat('abc', 0);
     * // => ''
     */
    function repeat(string, n) {
      var result = '';
      string = baseToString(string);
      n = +n;
      if (n < 1 || !string || !nativeIsFinite(n)) {
        return result;
      }
      // Leverage the exponentiation by squaring algorithm for a faster repeat.
      // See https://en.wikipedia.org/wiki/Exponentiation_by_squaring for more details.
      do {
        if (n % 2) {
          result += string;
        }
        n = nativeFloor(n / 2);
        string += string;
      } while (n);

      return result;
    }

    /**
     * Converts `string` to [snake case](https://en.wikipedia.org/wiki/Snake_case).
     *
     * @static
     * @memberOf _
     * @category String
     * @param {string} [string=''] The string to convert.
     * @returns {string} Returns the snake cased string.
     * @example
     *
     * _.snakeCase('Foo Bar');
     * // => 'foo_bar'
     *
     * _.snakeCase('fooBar');
     * // => 'foo_bar'
     *
     * _.snakeCase('--foo-bar');
     * // => 'foo_bar'
     */
    var snakeCase = createCompounder(function(result, word, index) {
      return result + (index ? '_' : '') + word.toLowerCase();
    });

    /**
     * Converts `string` to [start case](https://en.wikipedia.org/wiki/Letter_case#Stylistic_or_specialised_usage).
     *
     * @static
     * @memberOf _
     * @category String
     * @param {string} [string=''] The string to convert.
     * @returns {string} Returns the start cased string.
     * @example
     *
     * _.startCase('--foo-bar');
     * // => 'Foo Bar'
     *
     * _.startCase('fooBar');
     * // => 'Foo Bar'
     *
     * _.startCase('__foo_bar__');
     * // => 'Foo Bar'
     */
    var startCase = createCompounder(function(result, word, index) {
      return result + (index ? ' ' : '') + (word.charAt(0).toUpperCase() + word.slice(1));
    });

    /**
     * Checks if `string` starts with the given target string.
     *
     * @static
     * @memberOf _
     * @category String
     * @param {string} [string=''] The string to search.
     * @param {string} [target] The string to search for.
     * @param {number} [position=0] The position to search from.
     * @returns {boolean} Returns `true` if `string` starts with `target`, else `false`.
     * @example
     *
     * _.startsWith('abc', 'a');
     * // => true
     *
     * _.startsWith('abc', 'b');
     * // => false
     *
     * _.startsWith('abc', 'b', 1);
     * // => true
     */
    function startsWith(string, target, position) {
      string = baseToString(string);
      position = position == null
        ? 0
        : nativeMin(position < 0 ? 0 : (+position || 0), string.length);

      return string.lastIndexOf(target, position) == position;
    }

    /**
     * Creates a compiled template function that can interpolate data properties
     * in "interpolate" delimiters, HTML-escape interpolated data properties in
     * "escape" delimiters, and execute JavaScript in "evaluate" delimiters. Data
     * properties may be accessed as free variables in the template. If a setting
     * object is provided it takes precedence over `_.templateSettings` values.
     *
     * **Note:** In the development build `_.template` utilizes
     * [sourceURLs](http://www.html5rocks.com/en/tutorials/developertools/sourcemaps/#toc-sourceurl)
     * for easier debugging.
     *
     * For more information on precompiling templates see
     * [lodash's custom builds documentation](https://lodash.com/custom-builds).
     *
     * For more information on Chrome extension sandboxes see
     * [Chrome's extensions documentation](https://developer.chrome.com/extensions/sandboxingEval).
     *
     * @static
     * @memberOf _
     * @category String
     * @param {string} [string=''] The template string.
     * @param {Object} [options] The options object.
     * @param {RegExp} [options.escape] The HTML "escape" delimiter.
     * @param {RegExp} [options.evaluate] The "evaluate" delimiter.
     * @param {Object} [options.imports] An object to import into the template as free variables.
     * @param {RegExp} [options.interpolate] The "interpolate" delimiter.
     * @param {string} [options.sourceURL] The sourceURL of the template's compiled source.
     * @param {string} [options.variable] The data object variable name.
     * @param- {Object} [otherOptions] Enables the legacy `options` param signature.
     * @returns {Function} Returns the compiled template function.
     * @example
     *
     * // using the "interpolate" delimiter to create a compiled template
     * var compiled = _.template('hello <%= user %>!');
     * compiled({ 'user': 'fred' });
     * // => 'hello fred!'
     *
     * // using the HTML "escape" delimiter to escape data property values
     * var compiled = _.template('<b><%- value %></b>');
     * compiled({ 'value': '<script>' });
     * // => '<b>&lt;script&gt;</b>'
     *
     * // using the "evaluate" delimiter to execute JavaScript and generate HTML
     * var compiled = _.template('<% _.forEach(users, function(user) { %><li><%- user %></li><% }); %>');
     * compiled({ 'users': ['fred', 'barney'] });
     * // => '<li>fred</li><li>barney</li>'
     *
     * // using the internal `print` function in "evaluate" delimiters
     * var compiled = _.template('<% print("hello " + user); %>!');
     * compiled({ 'user': 'barney' });
     * // => 'hello barney!'
     *
     * // using the ES delimiter as an alternative to the default "interpolate" delimiter
     * var compiled = _.template('hello ${ user }!');
     * compiled({ 'user': 'pebbles' });
     * // => 'hello pebbles!'
     *
     * // using custom template delimiters
     * _.templateSettings.interpolate = /{{([\s\S]+?)}}/g;
     * var compiled = _.template('hello {{ user }}!');
     * compiled({ 'user': 'mustache' });
     * // => 'hello mustache!'
     *
     * // using backslashes to treat delimiters as plain text
     * var compiled = _.template('<%= "\\<%- value %\\>" %>');
     * compiled({ 'value': 'ignored' });
     * // => '<%- value %>'
     *
     * // using the `imports` option to import `jQuery` as `jq`
     * var text = '<% jq.each(users, function(user) { %><li><%- user %></li><% }); %>';
     * var compiled = _.template(text, { 'imports': { 'jq': jQuery } });
     * compiled({ 'users': ['fred', 'barney'] });
     * // => '<li>fred</li><li>barney</li>'
     *
     * // using the `sourceURL` option to specify a custom sourceURL for the template
     * var compiled = _.template('hello <%= user %>!', { 'sourceURL': '/basic/greeting.jst' });
     * compiled(data);
     * // => find the source of "greeting.jst" under the Sources tab or Resources panel of the web inspector
     *
     * // using the `variable` option to ensure a with-statement isn't used in the compiled template
     * var compiled = _.template('hi <%= data.user %>!', { 'variable': 'data' });
     * compiled.source;
     * // => function(data) {
     * //   var __t, __p = '';
     * //   __p += 'hi ' + ((__t = ( data.user )) == null ? '' : __t) + '!';
     * //   return __p;
     * // }
     *
     * // using the `source` property to inline compiled templates for meaningful
     * // line numbers in error messages and a stack trace
     * fs.writeFileSync(path.join(cwd, 'jst.js'), '\
     *   var JST = {\
     *     "main": ' + _.template(mainText).source + '\
     *   };\
     * ');
     */
    function template(string, options, otherOptions) {
      // Based on John Resig's `tmpl` implementation (http://ejohn.org/blog/javascript-micro-templating/)
      // and Laura Doktorova's doT.js (https://github.com/olado/doT).
      var settings = lodash.templateSettings;

      if (otherOptions && isIterateeCall(string, options, otherOptions)) {
        options = otherOptions = undefined;
      }
      string = baseToString(string);
      options = assignWith(baseAssign({}, otherOptions || options), settings, assignOwnDefaults);

      var imports = assignWith(baseAssign({}, options.imports), settings.imports, assignOwnDefaults),
          importsKeys = keys(imports),
          importsValues = baseValues(imports, importsKeys);

      var isEscaping,
          isEvaluating,
          index = 0,
          interpolate = options.interpolate || reNoMatch,
          source = "__p += '";

      // Compile the regexp to match each delimiter.
      var reDelimiters = RegExp(
        (options.escape || reNoMatch).source + '|' +
        interpolate.source + '|' +
        (interpolate === reInterpolate ? reEsTemplate : reNoMatch).source + '|' +
        (options.evaluate || reNoMatch).source + '|$'
      , 'g');

      // Use a sourceURL for easier debugging.
      var sourceURL = '//# sourceURL=' +
        ('sourceURL' in options
          ? options.sourceURL
          : ('lodash.templateSources[' + (++templateCounter) + ']')
        ) + '\n';

      string.replace(reDelimiters, function(match, escapeValue, interpolateValue, esTemplateValue, evaluateValue, offset) {
        interpolateValue || (interpolateValue = esTemplateValue);

        // Escape characters that can't be included in string literals.
        source += string.slice(index, offset).replace(reUnescapedString, escapeStringChar);

        // Replace delimiters with snippets.
        if (escapeValue) {
          isEscaping = true;
          source += "' +\n__e(" + escapeValue + ") +\n'";
        }
        if (evaluateValue) {
          isEvaluating = true;
          source += "';\n" + evaluateValue + ";\n__p += '";
        }
        if (interpolateValue) {
          source += "' +\n((__t = (" + interpolateValue + ")) == null ? '' : __t) +\n'";
        }
        index = offset + match.length;

        // The JS engine embedded in Adobe products requires returning the `match`
        // string in order to produce the correct `offset` value.
        return match;
      });

      source += "';\n";

      // If `variable` is not specified wrap a with-statement around the generated
      // code to add the data object to the top of the scope chain.
      var variable = options.variable;
      if (!variable) {
        source = 'with (obj) {\n' + source + '\n}\n';
      }
      // Cleanup code by stripping empty strings.
      source = (isEvaluating ? source.replace(reEmptyStringLeading, '') : source)
        .replace(reEmptyStringMiddle, '$1')
        .replace(reEmptyStringTrailing, '$1;');

      // Frame code as the function body.
      source = 'function(' + (variable || 'obj') + ') {\n' +
        (variable
          ? ''
          : 'obj || (obj = {});\n'
        ) +
        "var __t, __p = ''" +
        (isEscaping
           ? ', __e = _.escape'
           : ''
        ) +
        (isEvaluating
          ? ', __j = Array.prototype.join;\n' +
            "function print() { __p += __j.call(arguments, '') }\n"
          : ';\n'
        ) +
        source +
        'return __p\n}';

      var result = attempt(function() {
        return Function(importsKeys, sourceURL + 'return ' + source).apply(undefined, importsValues);
      });

      // Provide the compiled function's source by its `toString` method or
      // the `source` property as a convenience for inlining compiled templates.
      result.source = source;
      if (isError(result)) {
        throw result;
      }
      return result;
    }

    /**
     * Removes leading and trailing whitespace or specified characters from `string`.
     *
     * @static
     * @memberOf _
     * @category String
     * @param {string} [string=''] The string to trim.
     * @param {string} [chars=whitespace] The characters to trim.
     * @param- {Object} [guard] Enables use as a callback for functions like `_.map`.
     * @returns {string} Returns the trimmed string.
     * @example
     *
     * _.trim('  abc  ');
     * // => 'abc'
     *
     * _.trim('-_-abc-_-', '_-');
     * // => 'abc'
     *
     * _.map(['  foo  ', '  bar  '], _.trim);
     * // => ['foo', 'bar']
     */
    function trim(string, chars, guard) {
      var value = string;
      string = baseToString(string);
      if (!string) {
        return string;
      }
      if (guard ? isIterateeCall(value, chars, guard) : chars == null) {
        return string.slice(trimmedLeftIndex(string), trimmedRightIndex(string) + 1);
      }
      chars = (chars + '');
      return string.slice(charsLeftIndex(string, chars), charsRightIndex(string, chars) + 1);
    }

    /**
     * Removes leading whitespace or specified characters from `string`.
     *
     * @static
     * @memberOf _
     * @category String
     * @param {string} [string=''] The string to trim.
     * @param {string} [chars=whitespace] The characters to trim.
     * @param- {Object} [guard] Enables use as a callback for functions like `_.map`.
     * @returns {string} Returns the trimmed string.
     * @example
     *
     * _.trimLeft('  abc  ');
     * // => 'abc  '
     *
     * _.trimLeft('-_-abc-_-', '_-');
     * // => 'abc-_-'
     */
    function trimLeft(string, chars, guard) {
      var value = string;
      string = baseToString(string);
      if (!string) {
        return string;
      }
      if (guard ? isIterateeCall(value, chars, guard) : chars == null) {
        return string.slice(trimmedLeftIndex(string));
      }
      return string.slice(charsLeftIndex(string, (chars + '')));
    }

    /**
     * Removes trailing whitespace or specified characters from `string`.
     *
     * @static
     * @memberOf _
     * @category String
     * @param {string} [string=''] The string to trim.
     * @param {string} [chars=whitespace] The characters to trim.
     * @param- {Object} [guard] Enables use as a callback for functions like `_.map`.
     * @returns {string} Returns the trimmed string.
     * @example
     *
     * _.trimRight('  abc  ');
     * // => '  abc'
     *
     * _.trimRight('-_-abc-_-', '_-');
     * // => '-_-abc'
     */
    function trimRight(string, chars, guard) {
      var value = string;
      string = baseToString(string);
      if (!string) {
        return string;
      }
      if (guard ? isIterateeCall(value, chars, guard) : chars == null) {
        return string.slice(0, trimmedRightIndex(string) + 1);
      }
      return string.slice(0, charsRightIndex(string, (chars + '')) + 1);
    }

    /**
     * Truncates `string` if it's longer than the given maximum string length.
     * The last characters of the truncated string are replaced with the omission
     * string which defaults to "...".
     *
     * @static
     * @memberOf _
     * @category String
     * @param {string} [string=''] The string to truncate.
     * @param {Object|number} [options] The options object or maximum string length.
     * @param {number} [options.length=30] The maximum string length.
     * @param {string} [options.omission='...'] The string to indicate text is omitted.
     * @param {RegExp|string} [options.separator] The separator pattern to truncate to.
     * @param- {Object} [guard] Enables use as a callback for functions like `_.map`.
     * @returns {string} Returns the truncated string.
     * @example
     *
     * _.trunc('hi-diddly-ho there, neighborino');
     * // => 'hi-diddly-ho there, neighbo...'
     *
     * _.trunc('hi-diddly-ho there, neighborino', 24);
     * // => 'hi-diddly-ho there, n...'
     *
     * _.trunc('hi-diddly-ho there, neighborino', {
     *   'length': 24,
     *   'separator': ' '
     * });
     * // => 'hi-diddly-ho there,...'
     *
     * _.trunc('hi-diddly-ho there, neighborino', {
     *   'length': 24,
     *   'separator': /,? +/
     * });
     * // => 'hi-diddly-ho there...'
     *
     * _.trunc('hi-diddly-ho there, neighborino', {
     *   'omission': ' [...]'
     * });
     * // => 'hi-diddly-ho there, neig [...]'
     */
    function trunc(string, options, guard) {
      if (guard && isIterateeCall(string, options, guard)) {
        options = undefined;
      }
      var length = DEFAULT_TRUNC_LENGTH,
          omission = DEFAULT_TRUNC_OMISSION;

      if (options != null) {
        if (isObject(options)) {
          var separator = 'separator' in options ? options.separator : separator;
          length = 'length' in options ? (+options.length || 0) : length;
          omission = 'omission' in options ? baseToString(options.omission) : omission;
        } else {
          length = +options || 0;
        }
      }
      string = baseToString(string);
      if (length >= string.length) {
        return string;
      }
      var end = length - omission.length;
      if (end < 1) {
        return omission;
      }
      var result = string.slice(0, end);
      if (separator == null) {
        return result + omission;
      }
      if (isRegExp(separator)) {
        if (string.slice(end).search(separator)) {
          var match,
              newEnd,
              substring = string.slice(0, end);

          if (!separator.global) {
            separator = RegExp(separator.source, (reFlags.exec(separator) || '') + 'g');
          }
          separator.lastIndex = 0;
          while ((match = separator.exec(substring))) {
            newEnd = match.index;
          }
          result = result.slice(0, newEnd == null ? end : newEnd);
        }
      } else if (string.indexOf(separator, end) != end) {
        var index = result.lastIndexOf(separator);
        if (index > -1) {
          result = result.slice(0, index);
        }
      }
      return result + omission;
    }

    /**
     * The inverse of `_.escape`; this method converts the HTML entities
     * `&amp;`, `&lt;`, `&gt;`, `&quot;`, `&#39;`, and `&#96;` in `string` to their
     * corresponding characters.
     *
     * **Note:** No other HTML entities are unescaped. To unescape additional HTML
     * entities use a third-party library like [_he_](https://mths.be/he).
     *
     * @static
     * @memberOf _
     * @category String
     * @param {string} [string=''] The string to unescape.
     * @returns {string} Returns the unescaped string.
     * @example
     *
     * _.unescape('fred, barney, &amp; pebbles');
     * // => 'fred, barney, & pebbles'
     */
    function unescape(string) {
      string = baseToString(string);
      return (string && reHasEscapedHtml.test(string))
        ? string.replace(reEscapedHtml, unescapeHtmlChar)
        : string;
    }

    /**
     * Splits `string` into an array of its words.
     *
     * @static
     * @memberOf _
     * @category String
     * @param {string} [string=''] The string to inspect.
     * @param {RegExp|string} [pattern] The pattern to match words.
     * @param- {Object} [guard] Enables use as a callback for functions like `_.map`.
     * @returns {Array} Returns the words of `string`.
     * @example
     *
     * _.words('fred, barney, & pebbles');
     * // => ['fred', 'barney', 'pebbles']
     *
     * _.words('fred, barney, & pebbles', /[^, ]+/g);
     * // => ['fred', 'barney', '&', 'pebbles']
     */
    function words(string, pattern, guard) {
      if (guard && isIterateeCall(string, pattern, guard)) {
        pattern = undefined;
      }
      string = baseToString(string);
      return string.match(pattern || reWords) || [];
    }

    /*------------------------------------------------------------------------*/

    /**
     * Attempts to invoke `func`, returning either the result or the caught error
     * object. Any additional arguments are provided to `func` when it is invoked.
     *
     * @static
     * @memberOf _
     * @category Utility
     * @param {Function} func The function to attempt.
     * @returns {*} Returns the `func` result or error object.
     * @example
     *
     * // avoid throwing errors for invalid selectors
     * var elements = _.attempt(function(selector) {
     *   return document.querySelectorAll(selector);
     * }, '>_>');
     *
     * if (_.isError(elements)) {
     *   elements = [];
     * }
     */
    var attempt = restParam(function(func, args) {
      try {
        return func.apply(undefined, args);
      } catch(e) {
        return isError(e) ? e : new Error(e);
      }
    });

    /**
     * Creates a function that invokes `func` with the `this` binding of `thisArg`
     * and arguments of the created function. If `func` is a property name the
     * created callback returns the property value for a given element. If `func`
     * is an object the created callback returns `true` for elements that contain
     * the equivalent object properties, otherwise it returns `false`.
     *
     * @static
     * @memberOf _
     * @alias iteratee
     * @category Utility
     * @param {*} [func=_.identity] The value to convert to a callback.
     * @param {*} [thisArg] The `this` binding of `func`.
     * @param- {Object} [guard] Enables use as a callback for functions like `_.map`.
     * @returns {Function} Returns the callback.
     * @example
     *
     * var users = [
     *   { 'user': 'barney', 'age': 36 },
     *   { 'user': 'fred',   'age': 40 }
     * ];
     *
     * // wrap to create custom callback shorthands
     * _.callback = _.wrap(_.callback, function(callback, func, thisArg) {
     *   var match = /^(.+?)__([gl]t)(.+)$/.exec(func);
     *   if (!match) {
     *     return callback(func, thisArg);
     *   }
     *   return function(object) {
     *     return match[2] == 'gt'
     *       ? object[match[1]] > match[3]
     *       : object[match[1]] < match[3];
     *   };
     * });
     *
     * _.filter(users, 'age__gt36');
     * // => [{ 'user': 'fred', 'age': 40 }]
     */
    function callback(func, thisArg, guard) {
      if (guard && isIterateeCall(func, thisArg, guard)) {
        thisArg = undefined;
      }
      return isObjectLike(func)
        ? matches(func)
        : baseCallback(func, thisArg);
    }

    /**
     * Creates a function that returns `value`.
     *
     * @static
     * @memberOf _
     * @category Utility
     * @param {*} value The value to return from the new function.
     * @returns {Function} Returns the new function.
     * @example
     *
     * var object = { 'user': 'fred' };
     * var getter = _.constant(object);
     *
     * getter() === object;
     * // => true
     */
    function constant(value) {
      return function() {
        return value;
      };
    }

    /**
     * This method returns the first argument provided to it.
     *
     * @static
     * @memberOf _
     * @category Utility
     * @param {*} value Any value.
     * @returns {*} Returns `value`.
     * @example
     *
     * var object = { 'user': 'fred' };
     *
     * _.identity(object) === object;
     * // => true
     */
    function identity(value) {
      return value;
    }

    /**
     * Creates a function that performs a deep comparison between a given object
     * and `source`, returning `true` if the given object has equivalent property
     * values, else `false`.
     *
     * **Note:** This method supports comparing arrays, booleans, `Date` objects,
     * numbers, `Object` objects, regexes, and strings. Objects are compared by
     * their own, not inherited, enumerable properties. For comparing a single
     * own or inherited property value see `_.matchesProperty`.
     *
     * @static
     * @memberOf _
     * @category Utility
     * @param {Object} source The object of property values to match.
     * @returns {Function} Returns the new function.
     * @example
     *
     * var users = [
     *   { 'user': 'barney', 'age': 36, 'active': true },
     *   { 'user': 'fred',   'age': 40, 'active': false }
     * ];
     *
     * _.filter(users, _.matches({ 'age': 40, 'active': false }));
     * // => [{ 'user': 'fred', 'age': 40, 'active': false }]
     */
    function matches(source) {
      return baseMatches(baseClone(source, true));
    }

    /**
     * Creates a function that compares the property value of `path` on a given
     * object to `value`.
     *
     * **Note:** This method supports comparing arrays, booleans, `Date` objects,
     * numbers, `Object` objects, regexes, and strings. Objects are compared by
     * their own, not inherited, enumerable properties.
     *
     * @static
     * @memberOf _
     * @category Utility
     * @param {Array|string} path The path of the property to get.
     * @param {*} srcValue The value to match.
     * @returns {Function} Returns the new function.
     * @example
     *
     * var users = [
     *   { 'user': 'barney' },
     *   { 'user': 'fred' }
     * ];
     *
     * _.find(users, _.matchesProperty('user', 'fred'));
     * // => { 'user': 'fred' }
     */
    function matchesProperty(path, srcValue) {
      return baseMatchesProperty(path, baseClone(srcValue, true));
    }

    /**
     * Creates a function that invokes the method at `path` on a given object.
     * Any additional arguments are provided to the invoked method.
     *
     * @static
     * @memberOf _
     * @category Utility
     * @param {Array|string} path The path of the method to invoke.
     * @param {...*} [args] The arguments to invoke the method with.
     * @returns {Function} Returns the new function.
     * @example
     *
     * var objects = [
     *   { 'a': { 'b': { 'c': _.constant(2) } } },
     *   { 'a': { 'b': { 'c': _.constant(1) } } }
     * ];
     *
     * _.map(objects, _.method('a.b.c'));
     * // => [2, 1]
     *
     * _.invoke(_.sortBy(objects, _.method(['a', 'b', 'c'])), 'a.b.c');
     * // => [1, 2]
     */
    var method = restParam(function(path, args) {
      return function(object) {
        return invokePath(object, path, args);
      };
    });

    /**
     * The opposite of `_.method`; this method creates a function that invokes
     * the method at a given path on `object`. Any additional arguments are
     * provided to the invoked method.
     *
     * @static
     * @memberOf _
     * @category Utility
     * @param {Object} object The object to query.
     * @param {...*} [args] The arguments to invoke the method with.
     * @returns {Function} Returns the new function.
     * @example
     *
     * var array = _.times(3, _.constant),
     *     object = { 'a': array, 'b': array, 'c': array };
     *
     * _.map(['a[2]', 'c[0]'], _.methodOf(object));
     * // => [2, 0]
     *
     * _.map([['a', '2'], ['c', '0']], _.methodOf(object));
     * // => [2, 0]
     */
    var methodOf = restParam(function(object, args) {
      return function(path) {
        return invokePath(object, path, args);
      };
    });

    /**
     * Adds all own enumerable function properties of a source object to the
     * destination object. If `object` is a function then methods are added to
     * its prototype as well.
     *
     * **Note:** Use `_.runInContext` to create a pristine `lodash` function to
     * avoid conflicts caused by modifying the original.
     *
     * @static
     * @memberOf _
     * @category Utility
     * @param {Function|Object} [object=lodash] The destination object.
     * @param {Object} source The object of functions to add.
     * @param {Object} [options] The options object.
     * @param {boolean} [options.chain=true] Specify whether the functions added
     *  are chainable.
     * @returns {Function|Object} Returns `object`.
     * @example
     *
     * function vowels(string) {
     *   return _.filter(string, function(v) {
     *     return /[aeiou]/i.test(v);
     *   });
     * }
     *
     * _.mixin({ 'vowels': vowels });
     * _.vowels('fred');
     * // => ['e']
     *
     * _('fred').vowels().value();
     * // => ['e']
     *
     * _.mixin({ 'vowels': vowels }, { 'chain': false });
     * _('fred').vowels();
     * // => ['e']
     */
    function mixin(object, source, options) {
      if (options == null) {
        var isObj = isObject(source),
            props = isObj ? keys(source) : undefined,
            methodNames = (props && props.length) ? baseFunctions(source, props) : undefined;

        if (!(methodNames ? methodNames.length : isObj)) {
          methodNames = false;
          options = source;
          source = object;
          object = this;
        }
      }
      if (!methodNames) {
        methodNames = baseFunctions(source, keys(source));
      }
      var chain = true,
          index = -1,
          isFunc = isFunction(object),
          length = methodNames.length;

      if (options === false) {
        chain = false;
      } else if (isObject(options) && 'chain' in options) {
        chain = options.chain;
      }
      while (++index < length) {
        var methodName = methodNames[index],
            func = source[methodName];

        object[methodName] = func;
        if (isFunc) {
          object.prototype[methodName] = (function(func) {
            return function() {
              var chainAll = this.__chain__;
              if (chain || chainAll) {
                var result = object(this.__wrapped__),
                    actions = result.__actions__ = arrayCopy(this.__actions__);

                actions.push({ 'func': func, 'args': arguments, 'thisArg': object });
                result.__chain__ = chainAll;
                return result;
              }
              return func.apply(object, arrayPush([this.value()], arguments));
            };
          }(func));
        }
      }
      return object;
    }

    /**
     * Reverts the `_` variable to its previous value and returns a reference to
     * the `lodash` function.
     *
     * @static
     * @memberOf _
     * @category Utility
     * @returns {Function} Returns the `lodash` function.
     * @example
     *
     * var lodash = _.noConflict();
     */
    function noConflict() {
      root._ = oldDash;
      return this;
    }

    /**
     * A no-operation function that returns `undefined` regardless of the
     * arguments it receives.
     *
     * @static
     * @memberOf _
     * @category Utility
     * @example
     *
     * var object = { 'user': 'fred' };
     *
     * _.noop(object) === undefined;
     * // => true
     */
    function noop() {
      // No operation performed.
    }

    /**
     * Creates a function that returns the property value at `path` on a
     * given object.
     *
     * @static
     * @memberOf _
     * @category Utility
     * @param {Array|string} path The path of the property to get.
     * @returns {Function} Returns the new function.
     * @example
     *
     * var objects = [
     *   { 'a': { 'b': { 'c': 2 } } },
     *   { 'a': { 'b': { 'c': 1 } } }
     * ];
     *
     * _.map(objects, _.property('a.b.c'));
     * // => [2, 1]
     *
     * _.pluck(_.sortBy(objects, _.property(['a', 'b', 'c'])), 'a.b.c');
     * // => [1, 2]
     */
    function property(path) {
      return isKey(path) ? baseProperty(path) : basePropertyDeep(path);
    }

    /**
     * The opposite of `_.property`; this method creates a function that returns
     * the property value at a given path on `object`.
     *
     * @static
     * @memberOf _
     * @category Utility
     * @param {Object} object The object to query.
     * @returns {Function} Returns the new function.
     * @example
     *
     * var array = [0, 1, 2],
     *     object = { 'a': array, 'b': array, 'c': array };
     *
     * _.map(['a[2]', 'c[0]'], _.propertyOf(object));
     * // => [2, 0]
     *
     * _.map([['a', '2'], ['c', '0']], _.propertyOf(object));
     * // => [2, 0]
     */
    function propertyOf(object) {
      return function(path) {
        return baseGet(object, toPath(path), path + '');
      };
    }

    /**
     * Creates an array of numbers (positive and/or negative) progressing from
     * `start` up to, but not including, `end`. If `end` is not specified it is
     * set to `start` with `start` then set to `0`. If `end` is less than `start`
     * a zero-length range is created unless a negative `step` is specified.
     *
     * @static
     * @memberOf _
     * @category Utility
     * @param {number} [start=0] The start of the range.
     * @param {number} end The end of the range.
     * @param {number} [step=1] The value to increment or decrement by.
     * @returns {Array} Returns the new array of numbers.
     * @example
     *
     * _.range(4);
     * // => [0, 1, 2, 3]
     *
     * _.range(1, 5);
     * // => [1, 2, 3, 4]
     *
     * _.range(0, 20, 5);
     * // => [0, 5, 10, 15]
     *
     * _.range(0, -4, -1);
     * // => [0, -1, -2, -3]
     *
     * _.range(1, 4, 0);
     * // => [1, 1, 1]
     *
     * _.range(0);
     * // => []
     */
    function range(start, end, step) {
      if (step && isIterateeCall(start, end, step)) {
        end = step = undefined;
      }
      start = +start || 0;
      step = step == null ? 1 : (+step || 0);

      if (end == null) {
        end = start;
        start = 0;
      } else {
        end = +end || 0;
      }
      // Use `Array(length)` so engines like Chakra and V8 avoid slower modes.
      // See https://youtu.be/XAqIpGU8ZZk#t=17m25s for more details.
      var index = -1,
          length = nativeMax(nativeCeil((end - start) / (step || 1)), 0),
          result = Array(length);

      while (++index < length) {
        result[index] = start;
        start += step;
      }
      return result;
    }

    /**
     * Invokes the iteratee function `n` times, returning an array of the results
     * of each invocation. The `iteratee` is bound to `thisArg` and invoked with
     * one argument; (index).
     *
     * @static
     * @memberOf _
     * @category Utility
     * @param {number} n The number of times to invoke `iteratee`.
     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {Array} Returns the array of results.
     * @example
     *
     * var diceRolls = _.times(3, _.partial(_.random, 1, 6, false));
     * // => [3, 6, 4]
     *
     * _.times(3, function(n) {
     *   mage.castSpell(n);
     * });
     * // => invokes `mage.castSpell(n)` three times with `n` of `0`, `1`, and `2`
     *
     * _.times(3, function(n) {
     *   this.cast(n);
     * }, mage);
     * // => also invokes `mage.castSpell(n)` three times
     */
    function times(n, iteratee, thisArg) {
      n = nativeFloor(n);

      // Exit early to avoid a JSC JIT bug in Safari 8
      // where `Array(0)` is treated as `Array(1)`.
      if (n < 1 || !nativeIsFinite(n)) {
        return [];
      }
      var index = -1,
          result = Array(nativeMin(n, MAX_ARRAY_LENGTH));

      iteratee = bindCallback(iteratee, thisArg, 1);
      while (++index < n) {
        if (index < MAX_ARRAY_LENGTH) {
          result[index] = iteratee(index);
        } else {
          iteratee(index);
        }
      }
      return result;
    }

    /**
     * Generates a unique ID. If `prefix` is provided the ID is appended to it.
     *
     * @static
     * @memberOf _
     * @category Utility
     * @param {string} [prefix] The value to prefix the ID with.
     * @returns {string} Returns the unique ID.
     * @example
     *
     * _.uniqueId('contact_');
     * // => 'contact_104'
     *
     * _.uniqueId();
     * // => '105'
     */
    function uniqueId(prefix) {
      var id = ++idCounter;
      return baseToString(prefix) + id;
    }

    /*------------------------------------------------------------------------*/

    /**
     * Adds two numbers.
     *
     * @static
     * @memberOf _
     * @category Math
     * @param {number} augend The first number to add.
     * @param {number} addend The second number to add.
     * @returns {number} Returns the sum.
     * @example
     *
     * _.add(6, 4);
     * // => 10
     */
    function add(augend, addend) {
      return (+augend || 0) + (+addend || 0);
    }

    /**
     * Calculates `n` rounded up to `precision`.
     *
     * @static
     * @memberOf _
     * @category Math
     * @param {number} n The number to round up.
     * @param {number} [precision=0] The precision to round up to.
     * @returns {number} Returns the rounded up number.
     * @example
     *
     * _.ceil(4.006);
     * // => 5
     *
     * _.ceil(6.004, 2);
     * // => 6.01
     *
     * _.ceil(6040, -2);
     * // => 6100
     */
    var ceil = createRound('ceil');

    /**
     * Calculates `n` rounded down to `precision`.
     *
     * @static
     * @memberOf _
     * @category Math
     * @param {number} n The number to round down.
     * @param {number} [precision=0] The precision to round down to.
     * @returns {number} Returns the rounded down number.
     * @example
     *
     * _.floor(4.006);
     * // => 4
     *
     * _.floor(0.046, 2);
     * // => 0.04
     *
     * _.floor(4060, -2);
     * // => 4000
     */
    var floor = createRound('floor');

    /**
     * Gets the maximum value of `collection`. If `collection` is empty or falsey
     * `-Infinity` is returned. If an iteratee function is provided it is invoked
     * for each value in `collection` to generate the criterion by which the value
     * is ranked. The `iteratee` is bound to `thisArg` and invoked with three
     * arguments: (value, index, collection).
     *
     * If a property name is provided for `iteratee` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `iteratee` the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @category Math
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function|Object|string} [iteratee] The function invoked per iteration.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {*} Returns the maximum value.
     * @example
     *
     * _.max([4, 2, 8, 6]);
     * // => 8
     *
     * _.max([]);
     * // => -Infinity
     *
     * var users = [
     *   { 'user': 'barney', 'age': 36 },
     *   { 'user': 'fred',   'age': 40 }
     * ];
     *
     * _.max(users, function(chr) {
     *   return chr.age;
     * });
     * // => { 'user': 'fred', 'age': 40 }
     *
     * // using the `_.property` callback shorthand
     * _.max(users, 'age');
     * // => { 'user': 'fred', 'age': 40 }
     */
    var max = createExtremum(gt, NEGATIVE_INFINITY);

    /**
     * Gets the minimum value of `collection`. If `collection` is empty or falsey
     * `Infinity` is returned. If an iteratee function is provided it is invoked
     * for each value in `collection` to generate the criterion by which the value
     * is ranked. The `iteratee` is bound to `thisArg` and invoked with three
     * arguments: (value, index, collection).
     *
     * If a property name is provided for `iteratee` the created `_.property`
     * style callback returns the property value of the given element.
     *
     * If a value is also provided for `thisArg` the created `_.matchesProperty`
     * style callback returns `true` for elements that have a matching property
     * value, else `false`.
     *
     * If an object is provided for `iteratee` the created `_.matches` style
     * callback returns `true` for elements that have the properties of the given
     * object, else `false`.
     *
     * @static
     * @memberOf _
     * @category Math
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function|Object|string} [iteratee] The function invoked per iteration.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {*} Returns the minimum value.
     * @example
     *
     * _.min([4, 2, 8, 6]);
     * // => 2
     *
     * _.min([]);
     * // => Infinity
     *
     * var users = [
     *   { 'user': 'barney', 'age': 36 },
     *   { 'user': 'fred',   'age': 40 }
     * ];
     *
     * _.min(users, function(chr) {
     *   return chr.age;
     * });
     * // => { 'user': 'barney', 'age': 36 }
     *
     * // using the `_.property` callback shorthand
     * _.min(users, 'age');
     * // => { 'user': 'barney', 'age': 36 }
     */
    var min = createExtremum(lt, POSITIVE_INFINITY);

    /**
     * Calculates `n` rounded to `precision`.
     *
     * @static
     * @memberOf _
     * @category Math
     * @param {number} n The number to round.
     * @param {number} [precision=0] The precision to round to.
     * @returns {number} Returns the rounded number.
     * @example
     *
     * _.round(4.006);
     * // => 4
     *
     * _.round(4.006, 2);
     * // => 4.01
     *
     * _.round(4060, -2);
     * // => 4100
     */
    var round = createRound('round');

    /**
     * Gets the sum of the values in `collection`.
     *
     * @static
     * @memberOf _
     * @category Math
     * @param {Array|Object|string} collection The collection to iterate over.
     * @param {Function|Object|string} [iteratee] The function invoked per iteration.
     * @param {*} [thisArg] The `this` binding of `iteratee`.
     * @returns {number} Returns the sum.
     * @example
     *
     * _.sum([4, 6]);
     * // => 10
     *
     * _.sum({ 'a': 4, 'b': 6 });
     * // => 10
     *
     * var objects = [
     *   { 'n': 4 },
     *   { 'n': 6 }
     * ];
     *
     * _.sum(objects, function(object) {
     *   return object.n;
     * });
     * // => 10
     *
     * // using the `_.property` callback shorthand
     * _.sum(objects, 'n');
     * // => 10
     */
    function sum(collection, iteratee, thisArg) {
      if (thisArg && isIterateeCall(collection, iteratee, thisArg)) {
        iteratee = undefined;
      }
      iteratee = getCallback(iteratee, thisArg, 3);
      return iteratee.length == 1
        ? arraySum(isArray(collection) ? collection : toIterable(collection), iteratee)
        : baseSum(collection, iteratee);
    }

    /*------------------------------------------------------------------------*/

    // Ensure wrappers are instances of `baseLodash`.
    lodash.prototype = baseLodash.prototype;

    LodashWrapper.prototype = baseCreate(baseLodash.prototype);
    LodashWrapper.prototype.constructor = LodashWrapper;

    LazyWrapper.prototype = baseCreate(baseLodash.prototype);
    LazyWrapper.prototype.constructor = LazyWrapper;

    // Add functions to the `Map` cache.
    MapCache.prototype['delete'] = mapDelete;
    MapCache.prototype.get = mapGet;
    MapCache.prototype.has = mapHas;
    MapCache.prototype.set = mapSet;

    // Add functions to the `Set` cache.
    SetCache.prototype.push = cachePush;

    // Assign cache to `_.memoize`.
    memoize.Cache = MapCache;

    // Add functions that return wrapped values when chaining.
    lodash.after = after;
    lodash.ary = ary;
    lodash.assign = assign;
    lodash.at = at;
    lodash.before = before;
    lodash.bind = bind;
    lodash.bindAll = bindAll;
    lodash.bindKey = bindKey;
    lodash.callback = callback;
    lodash.chain = chain;
    lodash.chunk = chunk;
    lodash.compact = compact;
    lodash.constant = constant;
    lodash.countBy = countBy;
    lodash.create = create;
    lodash.curry = curry;
    lodash.curryRight = curryRight;
    lodash.debounce = debounce;
    lodash.defaults = defaults;
    lodash.defaultsDeep = defaultsDeep;
    lodash.defer = defer;
    lodash.delay = delay;
    lodash.difference = difference;
    lodash.drop = drop;
    lodash.dropRight = dropRight;
    lodash.dropRightWhile = dropRightWhile;
    lodash.dropWhile = dropWhile;
    lodash.fill = fill;
    lodash.filter = filter;
    lodash.flatten = flatten;
    lodash.flattenDeep = flattenDeep;
    lodash.flow = flow;
    lodash.flowRight = flowRight;
    lodash.forEach = forEach;
    lodash.forEachRight = forEachRight;
    lodash.forIn = forIn;
    lodash.forInRight = forInRight;
    lodash.forOwn = forOwn;
    lodash.forOwnRight = forOwnRight;
    lodash.functions = functions;
    lodash.groupBy = groupBy;
    lodash.indexBy = indexBy;
    lodash.initial = initial;
    lodash.intersection = intersection;
    lodash.invert = invert;
    lodash.invoke = invoke;
    lodash.keys = keys;
    lodash.keysIn = keysIn;
    lodash.map = map;
    lodash.mapKeys = mapKeys;
    lodash.mapValues = mapValues;
    lodash.matches = matches;
    lodash.matchesProperty = matchesProperty;
    lodash.memoize = memoize;
    lodash.merge = merge;
    lodash.method = method;
    lodash.methodOf = methodOf;
    lodash.mixin = mixin;
    lodash.modArgs = modArgs;
    lodash.negate = negate;
    lodash.omit = omit;
    lodash.once = once;
    lodash.pairs = pairs;
    lodash.partial = partial;
    lodash.partialRight = partialRight;
    lodash.partition = partition;
    lodash.pick = pick;
    lodash.pluck = pluck;
    lodash.property = property;
    lodash.propertyOf = propertyOf;
    lodash.pull = pull;
    lodash.pullAt = pullAt;
    lodash.range = range;
    lodash.rearg = rearg;
    lodash.reject = reject;
    lodash.remove = remove;
    lodash.rest = rest;
    lodash.restParam = restParam;
    lodash.set = set;
    lodash.shuffle = shuffle;
    lodash.slice = slice;
    lodash.sortBy = sortBy;
    lodash.sortByAll = sortByAll;
    lodash.sortByOrder = sortByOrder;
    lodash.spread = spread;
    lodash.take = take;
    lodash.takeRight = takeRight;
    lodash.takeRightWhile = takeRightWhile;
    lodash.takeWhile = takeWhile;
    lodash.tap = tap;
    lodash.throttle = throttle;
    lodash.thru = thru;
    lodash.times = times;
    lodash.toArray = toArray;
    lodash.toPlainObject = toPlainObject;
    lodash.transform = transform;
    lodash.union = union;
    lodash.uniq = uniq;
    lodash.unzip = unzip;
    lodash.unzipWith = unzipWith;
    lodash.values = values;
    lodash.valuesIn = valuesIn;
    lodash.where = where;
    lodash.without = without;
    lodash.wrap = wrap;
    lodash.xor = xor;
    lodash.zip = zip;
    lodash.zipObject = zipObject;
    lodash.zipWith = zipWith;

    // Add aliases.
    lodash.backflow = flowRight;
    lodash.collect = map;
    lodash.compose = flowRight;
    lodash.each = forEach;
    lodash.eachRight = forEachRight;
    lodash.extend = assign;
    lodash.iteratee = callback;
    lodash.methods = functions;
    lodash.object = zipObject;
    lodash.select = filter;
    lodash.tail = rest;
    lodash.unique = uniq;

    // Add functions to `lodash.prototype`.
    mixin(lodash, lodash);

    /*------------------------------------------------------------------------*/

    // Add functions that return unwrapped values when chaining.
    lodash.add = add;
    lodash.attempt = attempt;
    lodash.camelCase = camelCase;
    lodash.capitalize = capitalize;
    lodash.ceil = ceil;
    lodash.clone = clone;
    lodash.cloneDeep = cloneDeep;
    lodash.deburr = deburr;
    lodash.endsWith = endsWith;
    lodash.escape = escape;
    lodash.escapeRegExp = escapeRegExp;
    lodash.every = every;
    lodash.find = find;
    lodash.findIndex = findIndex;
    lodash.findKey = findKey;
    lodash.findLast = findLast;
    lodash.findLastIndex = findLastIndex;
    lodash.findLastKey = findLastKey;
    lodash.findWhere = findWhere;
    lodash.first = first;
    lodash.floor = floor;
    lodash.get = get;
    lodash.gt = gt;
    lodash.gte = gte;
    lodash.has = has;
    lodash.identity = identity;
    lodash.includes = includes;
    lodash.indexOf = indexOf;
    lodash.inRange = inRange;
    lodash.isArguments = isArguments;
    lodash.isArray = isArray;
    lodash.isBoolean = isBoolean;
    lodash.isDate = isDate;
    lodash.isElement = isElement;
    lodash.isEmpty = isEmpty;
    lodash.isEqual = isEqual;
    lodash.isError = isError;
    lodash.isFinite = isFinite;
    lodash.isFunction = isFunction;
    lodash.isMatch = isMatch;
    lodash.isNaN = isNaN;
    lodash.isNative = isNative;
    lodash.isNull = isNull;
    lodash.isNumber = isNumber;
    lodash.isObject = isObject;
    lodash.isPlainObject = isPlainObject;
    lodash.isRegExp = isRegExp;
    lodash.isString = isString;
    lodash.isTypedArray = isTypedArray;
    lodash.isUndefined = isUndefined;
    lodash.kebabCase = kebabCase;
    lodash.last = last;
    lodash.lastIndexOf = lastIndexOf;
    lodash.lt = lt;
    lodash.lte = lte;
    lodash.max = max;
    lodash.min = min;
    lodash.noConflict = noConflict;
    lodash.noop = noop;
    lodash.now = now;
    lodash.pad = pad;
    lodash.padLeft = padLeft;
    lodash.padRight = padRight;
    lodash.parseInt = parseInt;
    lodash.random = random;
    lodash.reduce = reduce;
    lodash.reduceRight = reduceRight;
    lodash.repeat = repeat;
    lodash.result = result;
    lodash.round = round;
    lodash.runInContext = runInContext;
    lodash.size = size;
    lodash.snakeCase = snakeCase;
    lodash.some = some;
    lodash.sortedIndex = sortedIndex;
    lodash.sortedLastIndex = sortedLastIndex;
    lodash.startCase = startCase;
    lodash.startsWith = startsWith;
    lodash.sum = sum;
    lodash.template = template;
    lodash.trim = trim;
    lodash.trimLeft = trimLeft;
    lodash.trimRight = trimRight;
    lodash.trunc = trunc;
    lodash.unescape = unescape;
    lodash.uniqueId = uniqueId;
    lodash.words = words;

    // Add aliases.
    lodash.all = every;
    lodash.any = some;
    lodash.contains = includes;
    lodash.eq = isEqual;
    lodash.detect = find;
    lodash.foldl = reduce;
    lodash.foldr = reduceRight;
    lodash.head = first;
    lodash.include = includes;
    lodash.inject = reduce;

    mixin(lodash, (function() {
      var source = {};
      baseForOwn(lodash, function(func, methodName) {
        if (!lodash.prototype[methodName]) {
          source[methodName] = func;
        }
      });
      return source;
    }()), false);

    /*------------------------------------------------------------------------*/

    // Add functions capable of returning wrapped and unwrapped values when chaining.
    lodash.sample = sample;

    lodash.prototype.sample = function(n) {
      if (!this.__chain__ && n == null) {
        return sample(this.value());
      }
      return this.thru(function(value) {
        return sample(value, n);
      });
    };

    /*------------------------------------------------------------------------*/

    /**
     * The semantic version number.
     *
     * @static
     * @memberOf _
     * @type string
     */
    lodash.VERSION = VERSION;

    // Assign default placeholders.
    arrayEach(['bind', 'bindKey', 'curry', 'curryRight', 'partial', 'partialRight'], function(methodName) {
      lodash[methodName].placeholder = lodash;
    });

    // Add `LazyWrapper` methods for `_.drop` and `_.take` variants.
    arrayEach(['drop', 'take'], function(methodName, index) {
      LazyWrapper.prototype[methodName] = function(n) {
        var filtered = this.__filtered__;
        if (filtered && !index) {
          return new LazyWrapper(this);
        }
        n = n == null ? 1 : nativeMax(nativeFloor(n) || 0, 0);

        var result = this.clone();
        if (filtered) {
          result.__takeCount__ = nativeMin(result.__takeCount__, n);
        } else {
          result.__views__.push({ 'size': n, 'type': methodName + (result.__dir__ < 0 ? 'Right' : '') });
        }
        return result;
      };

      LazyWrapper.prototype[methodName + 'Right'] = function(n) {
        return this.reverse()[methodName](n).reverse();
      };
    });

    // Add `LazyWrapper` methods that accept an `iteratee` value.
    arrayEach(['filter', 'map', 'takeWhile'], function(methodName, index) {
      var type = index + 1,
          isFilter = type != LAZY_MAP_FLAG;

      LazyWrapper.prototype[methodName] = function(iteratee, thisArg) {
        var result = this.clone();
        result.__iteratees__.push({ 'iteratee': getCallback(iteratee, thisArg, 1), 'type': type });
        result.__filtered__ = result.__filtered__ || isFilter;
        return result;
      };
    });

    // Add `LazyWrapper` methods for `_.first` and `_.last`.
    arrayEach(['first', 'last'], function(methodName, index) {
      var takeName = 'take' + (index ? 'Right' : '');

      LazyWrapper.prototype[methodName] = function() {
        return this[takeName](1).value()[0];
      };
    });

    // Add `LazyWrapper` methods for `_.initial` and `_.rest`.
    arrayEach(['initial', 'rest'], function(methodName, index) {
      var dropName = 'drop' + (index ? '' : 'Right');

      LazyWrapper.prototype[methodName] = function() {
        return this.__filtered__ ? new LazyWrapper(this) : this[dropName](1);
      };
    });

    // Add `LazyWrapper` methods for `_.pluck` and `_.where`.
    arrayEach(['pluck', 'where'], function(methodName, index) {
      var operationName = index ? 'filter' : 'map',
          createCallback = index ? baseMatches : property;

      LazyWrapper.prototype[methodName] = function(value) {
        return this[operationName](createCallback(value));
      };
    });

    LazyWrapper.prototype.compact = function() {
      return this.filter(identity);
    };

    LazyWrapper.prototype.reject = function(predicate, thisArg) {
      predicate = getCallback(predicate, thisArg, 1);
      return this.filter(function(value) {
        return !predicate(value);
      });
    };

    LazyWrapper.prototype.slice = function(start, end) {
      start = start == null ? 0 : (+start || 0);

      var result = this;
      if (result.__filtered__ && (start > 0 || end < 0)) {
        return new LazyWrapper(result);
      }
      if (start < 0) {
        result = result.takeRight(-start);
      } else if (start) {
        result = result.drop(start);
      }
      if (end !== undefined) {
        end = (+end || 0);
        result = end < 0 ? result.dropRight(-end) : result.take(end - start);
      }
      return result;
    };

    LazyWrapper.prototype.takeRightWhile = function(predicate, thisArg) {
      return this.reverse().takeWhile(predicate, thisArg).reverse();
    };

    LazyWrapper.prototype.toArray = function() {
      return this.take(POSITIVE_INFINITY);
    };

    // Add `LazyWrapper` methods to `lodash.prototype`.
    baseForOwn(LazyWrapper.prototype, function(func, methodName) {
      var checkIteratee = /^(?:filter|map|reject)|While$/.test(methodName),
          retUnwrapped = /^(?:first|last)$/.test(methodName),
          lodashFunc = lodash[retUnwrapped ? ('take' + (methodName == 'last' ? 'Right' : '')) : methodName];

      if (!lodashFunc) {
        return;
      }
      lodash.prototype[methodName] = function() {
        var args = retUnwrapped ? [1] : arguments,
            chainAll = this.__chain__,
            value = this.__wrapped__,
            isHybrid = !!this.__actions__.length,
            isLazy = value instanceof LazyWrapper,
            iteratee = args[0],
            useLazy = isLazy || isArray(value);

        if (useLazy && checkIteratee && typeof iteratee == 'function' && iteratee.length != 1) {
          // Avoid lazy use if the iteratee has a "length" value other than `1`.
          isLazy = useLazy = false;
        }
        var interceptor = function(value) {
          return (retUnwrapped && chainAll)
            ? lodashFunc(value, 1)[0]
            : lodashFunc.apply(undefined, arrayPush([value], args));
        };

        var action = { 'func': thru, 'args': [interceptor], 'thisArg': undefined },
            onlyLazy = isLazy && !isHybrid;

        if (retUnwrapped && !chainAll) {
          if (onlyLazy) {
            value = value.clone();
            value.__actions__.push(action);
            return func.call(value);
          }
          return lodashFunc.call(undefined, this.value())[0];
        }
        if (!retUnwrapped && useLazy) {
          value = onlyLazy ? value : new LazyWrapper(this);
          var result = func.apply(value, args);
          result.__actions__.push(action);
          return new LodashWrapper(result, chainAll);
        }
        return this.thru(interceptor);
      };
    });

    // Add `Array` and `String` methods to `lodash.prototype`.
    arrayEach(['join', 'pop', 'push', 'replace', 'shift', 'sort', 'splice', 'split', 'unshift'], function(methodName) {
      var func = (/^(?:replace|split)$/.test(methodName) ? stringProto : arrayProto)[methodName],
          chainName = /^(?:push|sort|unshift)$/.test(methodName) ? 'tap' : 'thru',
          retUnwrapped = /^(?:join|pop|replace|shift)$/.test(methodName);

      lodash.prototype[methodName] = function() {
        var args = arguments;
        if (retUnwrapped && !this.__chain__) {
          return func.apply(this.value(), args);
        }
        return this[chainName](function(value) {
          return func.apply(value, args);
        });
      };
    });

    // Map minified function names to their real names.
    baseForOwn(LazyWrapper.prototype, function(func, methodName) {
      var lodashFunc = lodash[methodName];
      if (lodashFunc) {
        var key = lodashFunc.name,
            names = realNames[key] || (realNames[key] = []);

        names.push({ 'name': methodName, 'func': lodashFunc });
      }
    });

    realNames[createHybridWrapper(undefined, BIND_KEY_FLAG).name] = [{ 'name': 'wrapper', 'func': undefined }];

    // Add functions to the lazy wrapper.
    LazyWrapper.prototype.clone = lazyClone;
    LazyWrapper.prototype.reverse = lazyReverse;
    LazyWrapper.prototype.value = lazyValue;

    // Add chaining functions to the `lodash` wrapper.
    lodash.prototype.chain = wrapperChain;
    lodash.prototype.commit = wrapperCommit;
    lodash.prototype.concat = wrapperConcat;
    lodash.prototype.plant = wrapperPlant;
    lodash.prototype.reverse = wrapperReverse;
    lodash.prototype.toString = wrapperToString;
    lodash.prototype.run = lodash.prototype.toJSON = lodash.prototype.valueOf = lodash.prototype.value = wrapperValue;

    // Add function aliases to the `lodash` wrapper.
    lodash.prototype.collect = lodash.prototype.map;
    lodash.prototype.head = lodash.prototype.first;
    lodash.prototype.select = lodash.prototype.filter;
    lodash.prototype.tail = lodash.prototype.rest;

    return lodash;
  }

  /*--------------------------------------------------------------------------*/

  // Export lodash.
  var _ = runInContext();

  // Some AMD build optimizers like r.js check for condition patterns like the following:
  if (typeof define == 'function' && typeof define.amd == 'object' && define.amd) {
    // Expose lodash to the global object when an AMD loader is present to avoid
    // errors in cases where lodash is loaded by a script tag and not intended
    // as an AMD module. See http://requirejs.org/docs/errors.html#mismatch for
    // more details.
    root._ = _;

    // Define as an anonymous module so, through path mapping, it can be
    // referenced as the "underscore" module.
    define('lodash',[],function() {
      return _;
    });
  }
  // Check for `exports` after `define` in case a build optimizer adds an `exports` object.
  else if (freeExports && freeModule) {
    // Export for Node.js or RingoJS.
    if (moduleExports) {
      (freeModule.exports = _)._ = _;
    }
    // Export for Rhino with CommonJS support.
    else {
      freeExports._ = _;
    }
  }
  else {
    // Export for a browser or Rhino.
    root._ = _;
  }
}.call(this));
/**
 * Implements a browser API for Chrome.  This module largely proxies Chrome's
 * API since that's what ProductivityTab was designed around.
 */
define('browser/chrome',[],function() {
	/* global chrome */
	if (typeof chrome !== "object") {
		return false;
	}

	// Many browser properties are getters and cost a few ms each time they're called.
	// If direct calls were used here it would cost about 30ms to run the script on a fast system.

	var dpr = devicePixelRatio;

	var API = {
		app: {
			id: "iccjgbbjckehppnpajnmplcccjcgbdep", // chrome.runtime.id
			version: "3.0.45.14",
			newTab: true // chrome.runtime.id === "iccjgbbjckehppnpajnmplcccjcgbdep"
		},

		environment: "chrome",

		storage: localStorage,

		// These calls add up fast, we use getters for basic properties to avoid the cost until necessary
		/* jshint ignore:start */
		get tabs() { return chrome.tabs },
		get system() { return chrome.system },
		get runtime() { return chrome.runtime },
		get windows() { return chrome.windows },
		get cookies() { return chrome.cookies },
		get sessions() { return chrome.sessions },
		get topSites() { return chrome.topSites },
		get bookmarks() { return chrome.bookmarks },
		get webRequest() { return chrome.webRequest },
		get management() { return chrome.management },
		get permissions() { return chrome.permissions },
		get syncStorage() { return chrome.storage.sync },
		get chromeLocal() { return chrome.storage.local },
		/* jshint ignore:end */

		// chrome.i18n costs as well but is always used
		language: localStorage.localeOverride || chrome.i18n.getMessage("lang_code"),


		/**
		 * Returns a favicon for given a URL
		 *
		 * @api     public
		 * @param   {String}  url     The URL to get a favicon for
		 * @return  {String}          The URL of the favicon, or an empty string if no URL was provided
		 */
		getFavicon: function(url) {
			if (!url) {
				return "";
			}

			return "chrome://favicon/size/16@" + dpr + "x/" + url;
		}
	};

	return API;
});

/**
 * Implements a cross-browser core API
 */
define('browser/api',["browser/chrome"], function(Chrome) {
	// Browser API modules return false if an invalid environment is detected
	if (Chrome) {
		return Object.freeze(Chrome);
	}
	else {
		throw new Error("Unknown environment");
	}
});
/*
 * The Apps widget.
 */
define('w/apps',["jquery", "lodash", "browser/api"], function($, _, Browser) {
	return {
		id: 11,
		sort: 180,
		size: 2,
		order: 25,
		nicename: "apps",
		sizes: ["variable"],
		environments: ["chrome"],
		permissions: ["management"],
		settings: [
			{
				type: "text",
				nicename: "title",
				label: "i18n.settings.title",
				placeholder: "i18n.settings.title_placeholder"
			},
			{
				type: "select",
				nicename: "view",
				label: "i18n.settings.format",
				options: {
					tiles: "i18n.settings.format_options.tiles",
					list: "i18n.settings.format_options.list"
				}
			},
			{
				type: "radio",
				nicename: "show",
				label: "i18n.settings.display",
				options: {
					all: "i18n.settings.display_options.all",
					enabled: "i18n.settings.display_options.enabled"
				}
			},
			{
				type: "select",
				nicename: "sort",
				label: "i18n.settings.sort",
				options: {
					id: "i18n.settings.sort_options.id",
					alpha: "i18n.settings.sort_options.alphabetically",
					offline: "i18n.settings.sort_options.offline",
					available: "i18n.settings.sort_options.available"
				}
			},
			{
				type: "radio",
				nicename: "target",
				label: "i18n.settings.open",
				options: {
					_self: "i18n.settings.open_options.current",
					_blank: "i18n.settings.open_options.blank"
				}
			}
		],
		config: {
			title: "",
			sort: "id",
			show: "all",
			view: "list",
			target: "_self",
			size: "variable"
		},

		syncData: {},

		refresh: function() {
			this.render();
		},


		/**
		 * Gets, filters and sorts the listing of apps
		 *
		 * @api     private
		 * @param   {Function}  cb
		 */
		getApps: function(cb) {
			Browser.management.getAll(function(d) {
				var list = d.filter(function(e) {
						return e.type !== "extension" && e.type !== "theme";
					}),
					apps = [],
					all = this.config.show === "all";

				list.unshift({
					enabled: true,
					offlineEnabled: false,
					id: "ahfgeienlihckogmohjhadlkjgocpleb",
					shortName: this.utils.translate("store_app"),
					appLaunchUrl: "https://chrome.google.com/webstore?utm_source=iChrome-apps-widget"
				});

				switch (this.config.sort) {
					case "alpha":
						list.sort(function(a, b) {
							var c = a.shortName.toLowerCase(),
								d = b.shortName.toLowerCase();

							return c < d ? -1 : c > d;
						});
					break;
					case "offline":
						list.sort(function(a) {
							return a.offlineEnabled;
						});
					break;
					case "available":
						list.sort(function(a, b) {
							return ((!navigator.onLine && a.offlineEnabled) + a.enabled) - ((!navigator.onLine && b.offlineEnabled) + b.enabled);
						});
					break;
				}

				list.forEach(function(e) {
					if (e.id !== Browser.app.id && (all || e.enabled)) {
						apps.push({
							name: e.shortName,
							id: e.id,
							thumb: "chrome://extension-icon/" + e.id + "/64/1",
							available: (navigator.onLine && e.enabled) || (!navigator.onLine && e.offlineEnabled)
						});
					}
				});

				if (this.syncData && this.syncData.order) {
					// This creates an hash that can be used to look up the
					// _.sortBy compatible sort value of a given app id.
					//
					// This method with negative reversed indexes causes apps
					// that are sorted to stay in position while new apps get
					// appended to the end of the list in their original order.
					var order = this.syncData.order.slice().reverse();

					order = _.zipObject(order, order.map(function(e, i) {
						return -i;
					}));

					apps = _.sortBy(apps, function(e) {
						return order[e.id] || 1;
					});
				}

				cb.call(this, {
					items: apps
				});
			}.bind(this));
		},

		render: function(demo) {
			if (demo) {
				return this.utils.render({
					items: [
						{
							"name": this.utils.translate("store_app"),
							"id": "ahfgeienlihckogmohjhadlkjgocpleb",
							"thumb": "chrome://extension-icon/ahfgeienlihckogmohjhadlkjgocpleb/64/1",
							"available": true
						},
						{
							"name": "Google Drive",
							"id": "apdfllckaahabafndbhieahigkjlhalf",
							"thumb": "chrome://extension-icon/apdfllckaahabafndbhieahigkjlhalf/64/1",
							"available": true
						},
						{
							"name": "YouTube",
							"id": "blpcfgokakmgnkcojhhkbfbldkacnbeo",
							"thumb": "chrome://extension-icon/blpcfgokakmgnkcojhhkbfbldkacnbeo/64/1",
							"available": true
						},
						{
							"name": "Google Search",
							"id": "coobgpohoikkiipiblmjeljniedjpjpf",
							"thumb": "chrome://extension-icon/coobgpohoikkiipiblmjeljniedjpjpf/64/1",
							"available": true
						}
					]
				});
			}
			else if (!Browser.management.getAll) {
				return;
			}

			this.getApps(function(apps) {
				if (this.config.title && this.config.title !== "") {
					apps.title = this.config.title;
				}

				if (this.config.view === "tiles") {
					apps.tiles = true;
				}

				this.utils.render(apps);


				var that = this,
					self = this.config.target === "_self";

				this.sortable = this.elm.off("click.apps").on("click.apps", ".app", function(e) {
					e.preventDefault();

					var id = this.getAttribute("data-id");

					Browser.management.launchApp(id, function() {
						if (self) {
							Browser.tabs.getCurrent(function(d) {
								Browser.tabs.remove(d.id);
							});
						}
					});
				}).find(".list, .tiles").sortable({
					distance: 20,
					itemSelector: ".app",
					placeholder: "<div class=\"app holder\"/>",
					onDragStart: function(item) {
						var width = item.outerWidth(),
							height = item.outerHeight();

						item.css({
							width: width,
							height: height,
							transform: "translate(-" + width / 2 + "px, -" + height / 2 + "px)"
						});

						item.addClass("dragged");
					},
					onDrop: function(item, container, _super) {
						_super(item, container);

						that.syncData.order = that.sortable.sortable("serialize").get();

						that.utils.save();
					},
					serialize: function(item, children, isContainer) {
						if (isContainer) {
							return children;
						}
						else {
							return item.attr("data-id");
						}
					},
				});

				$(window).one("offline.apps online.apps", function() {
					this.render();
				}.bind(this));
			});
		}
	};
});

//     Backbone.js 1.1.2

//     PATCHED: Collection.set() is patched to fix discrepancies in collection lengths

//     (c) 2010-2014 Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
//     Backbone may be freely distributed under the MIT license.
//     For all details and documentation:
//     http://backbonejs.org

(function(root, factory) {

  // Set up Backbone appropriately for the environment. Start with AMD.
  if (typeof define === 'function' && define.amd) {
    define('backbone',['underscore', 'jquery', 'exports'], function(_, $, exports) {
      // Export global even in AMD case in case this script is loaded with
      // others that may still expect a global Backbone.
      root.Backbone = factory(root, exports, _, $);
    });

  // Next for Node.js or CommonJS. jQuery may not be needed as a module.
  } else if (typeof exports !== 'undefined') {
    var _ = require('underscore');
    factory(root, exports, _);

  // Finally, as a browser global.
  } else {
    root.Backbone = factory(root, {}, root._, (root.jQuery || root.Zepto || root.ender || root.$));
  }

}(this, function(root, Backbone, _, $) {

  // Initial Setup
  // -------------

  // Save the previous value of the `Backbone` variable, so that it can be
  // restored later on, if `noConflict` is used.
  var previousBackbone = root.Backbone;

  // Create local references to array methods we'll want to use later.
  var array = [];
  var push = array.push;
  var slice = array.slice;
  var splice = array.splice;

  // Current version of the library. Keep in sync with `package.json`.
  Backbone.VERSION = '1.1.2';

  // For Backbone's purposes, jQuery, Zepto, Ender, or My Library (kidding) owns
  // the `$` variable.
  Backbone.$ = $;

  // Runs Backbone.js in *noConflict* mode, returning the `Backbone` variable
  // to its previous owner. Returns a reference to this Backbone object.
  Backbone.noConflict = function() {
    root.Backbone = previousBackbone;
    return this;
  };

  // Turn on `emulateHTTP` to support legacy HTTP servers. Setting this option
  // will fake `"PATCH"`, `"PUT"` and `"DELETE"` requests via the `_method` parameter and
  // set a `X-Http-Method-Override` header.
  Backbone.emulateHTTP = false;

  // Turn on `emulateJSON` to support legacy servers that can't deal with direct
  // `application/json` requests ... will encode the body as
  // `application/x-www-form-urlencoded` instead and will send the model in a
  // form param named `model`.
  Backbone.emulateJSON = false;

  // Backbone.Events
  // ---------------

  // A module that can be mixed in to *any object* in order to provide it with
  // custom events. You may bind with `on` or remove with `off` callback
  // functions to an event; `trigger`-ing an event fires all callbacks in
  // succession.
  //
  //     var object = {};
  //     _.extend(object, Backbone.Events);
  //     object.on('expand', function(){ alert('expanded'); });
  //     object.trigger('expand');
  //
  var Events = Backbone.Events = {

    // Bind an event to a `callback` function. Passing `"all"` will bind
    // the callback to all events fired.
    on: function(name, callback, context) {
      if (!eventsApi(this, 'on', name, [callback, context]) || !callback) return this;
      this._events || (this._events = {});
      var events = this._events[name] || (this._events[name] = []);
      events.push({callback: callback, context: context, ctx: context || this});
      return this;
    },

    // Bind an event to only be triggered a single time. After the first time
    // the callback is invoked, it will be removed.
    once: function(name, callback, context) {
      if (!eventsApi(this, 'once', name, [callback, context]) || !callback) return this;
      var self = this;
      var once = _.once(function() {
        self.off(name, once);
        callback.apply(this, arguments);
      });
      once._callback = callback;
      return this.on(name, once, context);
    },

    // Remove one or many callbacks. If `context` is null, removes all
    // callbacks with that function. If `callback` is null, removes all
    // callbacks for the event. If `name` is null, removes all bound
    // callbacks for all events.
    off: function(name, callback, context) {
      var retain, ev, events, names, i, l, j, k;
      if (!this._events || !eventsApi(this, 'off', name, [callback, context])) return this;
      if (!name && !callback && !context) {
        this._events = void 0;
        return this;
      }
      names = name ? [name] : _.keys(this._events);
      for (i = 0, l = names.length; i < l; i++) {
        name = names[i];
        if (events = this._events[name]) {
          this._events[name] = retain = [];
          if (callback || context) {
            for (j = 0, k = events.length; j < k; j++) {
              ev = events[j];
              if ((callback && callback !== ev.callback && callback !== ev.callback._callback) ||
                  (context && context !== ev.context)) {
                retain.push(ev);
              }
            }
          }
          if (!retain.length) delete this._events[name];
        }
      }

      return this;
    },

    // Trigger one or many events, firing all bound callbacks. Callbacks are
    // passed the same arguments as `trigger` is, apart from the event name
    // (unless you're listening on `"all"`, which will cause your callback to
    // receive the true name of the event as the first argument).
    trigger: function(name) {
      if (!this._events) return this;
      var args = slice.call(arguments, 1);
      if (!eventsApi(this, 'trigger', name, args)) return this;
      var events = this._events[name];
      var allEvents = this._events.all;
      if (events) triggerEvents(events, args);
      if (allEvents) triggerEvents(allEvents, arguments);
      return this;
    },

    // Tell this object to stop listening to either specific events ... or
    // to every object it's currently listening to.
    stopListening: function(obj, name, callback) {
      var listeningTo = this._listeningTo;
      if (!listeningTo) return this;
      var remove = !name && !callback;
      if (!callback && typeof name === 'object') callback = this;
      if (obj) (listeningTo = {})[obj._listenId] = obj;
      for (var id in listeningTo) {
        obj = listeningTo[id];
        obj.off(name, callback, this);
        if (remove || _.isEmpty(obj._events)) delete this._listeningTo[id];
      }
      return this;
    }

  };

  // Regular expression used to split event strings.
  var eventSplitter = /\s+/;

  // Implement fancy features of the Events API such as multiple event
  // names `"change blur"` and jQuery-style event maps `{change: action}`
  // in terms of the existing API.
  var eventsApi = function(obj, action, name, rest) {
    if (!name) return true;

    // Handle event maps.
    if (typeof name === 'object') {
      for (var key in name) {
        obj[action].apply(obj, [key, name[key]].concat(rest));
      }
      return false;
    }

    // Handle space separated event names.
    if (eventSplitter.test(name)) {
      var names = name.split(eventSplitter);
      for (var i = 0, l = names.length; i < l; i++) {
        obj[action].apply(obj, [names[i]].concat(rest));
      }
      return false;
    }

    return true;
  };

  // A difficult-to-believe, but optimized internal dispatch function for
  // triggering events. Tries to keep the usual cases speedy (most internal
  // Backbone events have 3 arguments).
  var triggerEvents = function(events, args) {
    var ev, i = -1, l = events.length, a1 = args[0], a2 = args[1], a3 = args[2];
    switch (args.length) {
      case 0: while (++i < l) (ev = events[i]).callback.call(ev.ctx); return;
      case 1: while (++i < l) (ev = events[i]).callback.call(ev.ctx, a1); return;
      case 2: while (++i < l) (ev = events[i]).callback.call(ev.ctx, a1, a2); return;
      case 3: while (++i < l) (ev = events[i]).callback.call(ev.ctx, a1, a2, a3); return;
      default: while (++i < l) (ev = events[i]).callback.apply(ev.ctx, args); return;
    }
  };

  var listenMethods = {listenTo: 'on', listenToOnce: 'once'};

  // Inversion-of-control versions of `on` and `once`. Tell *this* object to
  // listen to an event in another object ... keeping track of what it's
  // listening to.
  _.each(listenMethods, function(implementation, method) {
    Events[method] = function(obj, name, callback) {
      var listeningTo = this._listeningTo || (this._listeningTo = {});
      var id = obj._listenId || (obj._listenId = _.uniqueId('l'));
      listeningTo[id] = obj;
      if (!callback && typeof name === 'object') callback = this;
      obj[implementation](name, callback, this);
      return this;
    };
  });

  // Aliases for backwards compatibility.
  Events.bind   = Events.on;
  Events.unbind = Events.off;

  // Allow the `Backbone` object to serve as a global event bus, for folks who
  // want global "pubsub" in a convenient place.
  _.extend(Backbone, Events);

  // Backbone.Model
  // --------------

  // Backbone **Models** are the basic data object in the framework --
  // frequently representing a row in a table in a database on your server.
  // A discrete chunk of data and a bunch of useful, related methods for
  // performing computations and transformations on that data.

  // Create a new model with the specified attributes. A client id (`cid`)
  // is automatically generated and assigned for you.
  var Model = Backbone.Model = function(attributes, options) {
    var attrs = attributes || {};
    options || (options = {});
    this.cid = _.uniqueId('c');
    this.attributes = {};
    if (options.collection) this.collection = options.collection;
    if (options.parse) attrs = this.parse(attrs, options) || {};
    attrs = _.defaults({}, attrs, _.result(this, 'defaults'));
    this.set(attrs, options);
    this.changed = {};
    this.initialize.apply(this, arguments);
  };

  // Attach all inheritable methods to the Model prototype.
  _.extend(Model.prototype, Events, {

    // A hash of attributes whose current and previous value differ.
    changed: null,

    // The value returned during the last failed validation.
    validationError: null,

    // The default name for the JSON `id` attribute is `"id"`. MongoDB and
    // CouchDB users may want to set this to `"_id"`.
    idAttribute: 'id',

    // Initialize is an empty function by default. Override it with your own
    // initialization logic.
    initialize: function(){},

    // Return a copy of the model's `attributes` object.
    toJSON: function(options) {
      return _.clone(this.attributes);
    },

    // Proxy `Backbone.sync` by default -- but override this if you need
    // custom syncing semantics for *this* particular model.
    sync: function() {
      return Backbone.sync.apply(this, arguments);
    },

    // Get the value of an attribute.
    get: function(attr) {
      return this.attributes[attr];
    },

    // Get the HTML-escaped value of an attribute.
    escape: function(attr) {
      return _.escape(this.get(attr));
    },

    // Returns `true` if the attribute contains a value that is not null
    // or undefined.
    has: function(attr) {
      return this.get(attr) != null;
    },

    // Set a hash of model attributes on the object, firing `"change"`. This is
    // the core primitive operation of a model, updating the data and notifying
    // anyone who needs to know about the change in state. The heart of the beast.
    set: function(key, val, options) {
      var attr, attrs, unset, changes, silent, changing, prev, current;
      if (key == null) return this;

      // Handle both `"key", value` and `{key: value}` -style arguments.
      if (typeof key === 'object') {
        attrs = key;
        options = val;
      } else {
        (attrs = {})[key] = val;
      }

      options || (options = {});

      // Run validation.
      if (!this._validate(attrs, options)) return false;

      // Extract attributes and options.
      unset           = options.unset;
      silent          = options.silent;
      changes         = [];
      changing        = this._changing;
      this._changing  = true;

      if (!changing) {
        this._previousAttributes = _.clone(this.attributes);
        this.changed = {};
      }
      current = this.attributes, prev = this._previousAttributes;

      // Check for changes of `id`.
      if (this.idAttribute in attrs) this.id = attrs[this.idAttribute];

      // For each `set` attribute, update or delete the current value.
      for (attr in attrs) {
        val = attrs[attr];
        if (!_.isEqual(current[attr], val)) changes.push(attr);
        if (!_.isEqual(prev[attr], val)) {
          this.changed[attr] = val;
        } else {
          delete this.changed[attr];
        }
        unset ? delete current[attr] : current[attr] = val;
      }

      // Trigger all relevant attribute changes.
      if (!silent) {
        if (changes.length) this._pending = options;
        for (var i = 0, l = changes.length; i < l; i++) {
          this.trigger('change:' + changes[i], this, current[changes[i]], options);
        }
      }

      // You might be wondering why there's a `while` loop here. Changes can
      // be recursively nested within `"change"` events.
      if (changing) return this;
      if (!silent) {
        while (this._pending) {
          options = this._pending;
          this._pending = false;
          this.trigger('change', this, options);
        }
      }
      this._pending = false;
      this._changing = false;
      return this;
    },

    // Remove an attribute from the model, firing `"change"`. `unset` is a noop
    // if the attribute doesn't exist.
    unset: function(attr, options) {
      return this.set(attr, void 0, _.extend({}, options, {unset: true}));
    },

    // Clear all attributes on the model, firing `"change"`.
    clear: function(options) {
      var attrs = {};
      for (var key in this.attributes) attrs[key] = void 0;
      return this.set(attrs, _.extend({}, options, {unset: true}));
    },

    // Determine if the model has changed since the last `"change"` event.
    // If you specify an attribute name, determine if that attribute has changed.
    hasChanged: function(attr) {
      if (attr == null) return !_.isEmpty(this.changed);
      return _.has(this.changed, attr);
    },

    // Return an object containing all the attributes that have changed, or
    // false if there are no changed attributes. Useful for determining what
    // parts of a view need to be updated and/or what attributes need to be
    // persisted to the server. Unset attributes will be set to undefined.
    // You can also pass an attributes object to diff against the model,
    // determining if there *would be* a change.
    changedAttributes: function(diff) {
      if (!diff) return this.hasChanged() ? _.clone(this.changed) : false;
      var val, changed = false;
      var old = this._changing ? this._previousAttributes : this.attributes;
      for (var attr in diff) {
        if (_.isEqual(old[attr], (val = diff[attr]))) continue;
        (changed || (changed = {}))[attr] = val;
      }
      return changed;
    },

    // Get the previous value of an attribute, recorded at the time the last
    // `"change"` event was fired.
    previous: function(attr) {
      if (attr == null || !this._previousAttributes) return null;
      return this._previousAttributes[attr];
    },

    // Get all of the attributes of the model at the time of the previous
    // `"change"` event.
    previousAttributes: function() {
      return _.clone(this._previousAttributes);
    },

    // Fetch the model from the server. If the server's representation of the
    // model differs from its current attributes, they will be overridden,
    // triggering a `"change"` event.
    fetch: function(options) {
      options = options ? _.clone(options) : {};
      if (options.parse === void 0) options.parse = true;
      var model = this;
      var success = options.success;
      options.success = function(resp) {
        if (!model.set(model.parse(resp, options), options)) return false;
        if (success) success(model, resp, options);
        model.trigger('sync', model, resp, options);
      };
      wrapError(this, options);
      return this.sync('read', this, options);
    },

    // Set a hash of model attributes, and sync the model to the server.
    // If the server returns an attributes hash that differs, the model's
    // state will be `set` again.
    save: function(key, val, options) {
      var attrs, method, xhr, attributes = this.attributes;

      // Handle both `"key", value` and `{key: value}` -style arguments.
      if (key == null || typeof key === 'object') {
        attrs = key;
        options = val;
      } else {
        (attrs = {})[key] = val;
      }

      options = _.extend({validate: true}, options);

      // If we're not waiting and attributes exist, save acts as
      // `set(attr).save(null, opts)` with validation. Otherwise, check if
      // the model will be valid when the attributes, if any, are set.
      if (attrs && !options.wait) {
        if (!this.set(attrs, options)) return false;
      } else {
        if (!this._validate(attrs, options)) return false;
      }

      // Set temporary attributes if `{wait: true}`.
      if (attrs && options.wait) {
        this.attributes = _.extend({}, attributes, attrs);
      }

      // After a successful server-side save, the client is (optionally)
      // updated with the server-side state.
      if (options.parse === void 0) options.parse = true;
      var model = this;
      var success = options.success;
      options.success = function(resp) {
        // Ensure attributes are restored during synchronous saves.
        model.attributes = attributes;
        var serverAttrs = model.parse(resp, options);
        if (options.wait) serverAttrs = _.extend(attrs || {}, serverAttrs);
        if (_.isObject(serverAttrs) && !model.set(serverAttrs, options)) {
          return false;
        }
        if (success) success(model, resp, options);
        model.trigger('sync', model, resp, options);
      };
      wrapError(this, options);

      method = this.isNew() ? 'create' : (options.patch ? 'patch' : 'update');
      if (method === 'patch') options.attrs = attrs;
      xhr = this.sync(method, this, options);

      // Restore attributes.
      if (attrs && options.wait) this.attributes = attributes;

      return xhr;
    },

    // Destroy this model on the server if it was already persisted.
    // Optimistically removes the model from its collection, if it has one.
    // If `wait: true` is passed, waits for the server to respond before removal.
    destroy: function(options) {
      options = options ? _.clone(options) : {};
      var model = this;
      var success = options.success;

      var destroy = function() {
        model.trigger('destroy', model, model.collection, options);
      };

      options.success = function(resp) {
        if (options.wait || model.isNew()) destroy();
        if (success) success(model, resp, options);
        if (!model.isNew()) model.trigger('sync', model, resp, options);
      };

      if (this.isNew()) {
        options.success();
        return false;
      }
      wrapError(this, options);

      var xhr = this.sync('delete', this, options);
      if (!options.wait) destroy();
      return xhr;
    },

    // Default URL for the model's representation on the server -- if you're
    // using Backbone's restful methods, override this to change the endpoint
    // that will be called.
    url: function() {
      var base =
        _.result(this, 'urlRoot') ||
        _.result(this.collection, 'url') ||
        urlError();
      if (this.isNew()) return base;
      return base.replace(/([^\/])$/, '$1/') + encodeURIComponent(this.id);
    },

    // **parse** converts a response into the hash of attributes to be `set` on
    // the model. The default implementation is just to pass the response along.
    parse: function(resp, options) {
      return resp;
    },

    // Create a new model with identical attributes to this one.
    clone: function() {
      return new this.constructor(this.attributes);
    },

    // A model is new if it has never been saved to the server, and lacks an id.
    isNew: function() {
      return !this.has(this.idAttribute);
    },

    // Check if the model is currently in a valid state.
    isValid: function(options) {
      return this._validate({}, _.extend(options || {}, { validate: true }));
    },

    // Run validation against the next complete set of model attributes,
    // returning `true` if all is well. Otherwise, fire an `"invalid"` event.
    _validate: function(attrs, options) {
      if (!options.validate || !this.validate) return true;
      attrs = _.extend({}, this.attributes, attrs);
      var error = this.validationError = this.validate(attrs, options) || null;
      if (!error) return true;
      this.trigger('invalid', this, error, _.extend(options, {validationError: error}));
      return false;
    }

  });

  // Underscore methods that we want to implement on the Model.
  var modelMethods = ['keys', 'values', 'pairs', 'invert', 'pick', 'omit'];

  // Mix in each Underscore method as a proxy to `Model#attributes`.
  _.each(modelMethods, function(method) {
    Model.prototype[method] = function() {
      var args = slice.call(arguments);
      args.unshift(this.attributes);
      return _[method].apply(_, args);
    };
  });

  // Backbone.Collection
  // -------------------

  // If models tend to represent a single row of data, a Backbone Collection is
  // more analagous to a table full of data ... or a small slice or page of that
  // table, or a collection of rows that belong together for a particular reason
  // -- all of the messages in this particular folder, all of the documents
  // belonging to this particular author, and so on. Collections maintain
  // indexes of their models, both in order, and for lookup by `id`.

  // Create a new **Collection**, perhaps to contain a specific type of `model`.
  // If a `comparator` is specified, the Collection will maintain
  // its models in sort order, as they're added and removed.
  var Collection = Backbone.Collection = function(models, options) {
    options || (options = {});
    if (options.model) this.model = options.model;
    if (options.comparator !== void 0) this.comparator = options.comparator;
    this._reset();
    this.initialize.apply(this, arguments);
    if (models) this.reset(models, _.extend({silent: true}, options));
  };

  // Default options for `Collection#set`.
  var setOptions = {add: true, remove: true, merge: true};
  var addOptions = {add: true, remove: false};

  // Define the Collection's inheritable methods.
  _.extend(Collection.prototype, Events, {

    // The default model for a collection is just a **Backbone.Model**.
    // This should be overridden in most cases.
    model: Model,

    // Initialize is an empty function by default. Override it with your own
    // initialization logic.
    initialize: function(){},

    // The JSON representation of a Collection is an array of the
    // models' attributes.
    toJSON: function(options) {
      return this.map(function(model){ return model.toJSON(options); });
    },

    // Proxy `Backbone.sync` by default.
    sync: function() {
      return Backbone.sync.apply(this, arguments);
    },

    // Add a model, or list of models to the set.
    add: function(models, options) {
      return this.set(models, _.extend({merge: false}, options, addOptions));
    },

    // Remove a model, or a list of models from the set.
    remove: function(models, options) {
      var singular = !_.isArray(models);
      models = singular ? [models] : _.clone(models);
      options || (options = {});
      var i, l, index, model;
      for (i = 0, l = models.length; i < l; i++) {
        model = models[i] = this.get(models[i]);
        if (!model) continue;
        delete this._byId[model.id];
        delete this._byId[model.cid];
        index = this.indexOf(model);
        this.models.splice(index, 1);
        this.length--;
        if (!options.silent) {
          options.index = index;
          model.trigger('remove', model, this, options);
        }
        this._removeReference(model, options);
      }
      return singular ? models[0] : models;
    },

    // Update a collection by `set`-ing a new list of models, adding new ones,
    // removing models that are no longer present, and merging models that
    // already exist in the collection, as necessary. Similar to **Model#set**,
    // the core operation for updating the data contained by the collection.
    set: function(models, options) {
      options = _.defaults({}, options, setOptions);
      if (options.parse) models = this.parse(models, options);
      var singular = !_.isArray(models);
      models = singular ? (models ? [models] : []) : _.clone(models);
      var i, l, id, model, attrs, existing, sort;
      var at = options.at;
      var targetModel = this.model;
      var sortable = this.comparator && (at == null) && options.sort !== false;
      var sortAttr = _.isString(this.comparator) ? this.comparator : null;
      var toAdd = [], toRemove = [], modelMap = {};
      var add = options.add, merge = options.merge, remove = options.remove;
      var order = !sortable && add && remove ? [] : false;

      // Turn bare objects into model references, and prevent invalid models
      // from being added.
      for (i = 0, l = models.length; i < l; i++) {
        attrs = models[i] || {};
        if (attrs instanceof Model) {
          id = model = attrs;
        } else {
          id = attrs[targetModel.prototype.idAttribute || 'id'];
        }

        // If a duplicate is found, prevent it from being added and
        // optionally merge it into the existing model.
        if (existing = this.get(id)) {
          if (remove) modelMap[existing.cid] = true;
          if (merge) {
            attrs = attrs === model ? model.attributes : attrs;
            if (options.parse) attrs = existing.parse(attrs, options);
            existing.set(attrs, options);
            if (sortable && !sort && existing.hasChanged(sortAttr)) sort = true;
          }
          models[i] = existing;

        // If this is a new, valid model, push it to the `toAdd` list.
        } else if (add) {
          model = models[i] = this._prepareModel(attrs, options);
          if (!model) continue;
          toAdd.push(model);
          this._addReference(model, options);
        }

        // Do not add multiple models with the same `id`.
        model = existing || model;
        if (order && (model.isNew() || !modelMap[model.id])) order.push(model);
        modelMap[model.id] = true;
      }

      // PATCH: This makes sure the length is accurate before the loop runs
      this.length = this.models.length;

      // Remove nonexistent models if appropriate.
      if (remove) {
        for (i = 0, l = this.length; i < l; ++i) {
          if (!modelMap[(model = this.models[i]).cid]) toRemove.push(model);
        }
        if (toRemove.length) this.remove(toRemove, options);
      }

      // See if sorting is needed, update `length` and splice in new models.
      if (toAdd.length || (order && order.length)) {
        if (sortable) sort = true;
        this.length += toAdd.length;
        if (at != null) {
          for (i = 0, l = toAdd.length; i < l; i++) {
            this.models.splice(at + i, 0, toAdd[i]);
          }
        } else {
          if (order) this.models.length = 0;
          var orderedModels = order || toAdd;
          for (i = 0, l = orderedModels.length; i < l; i++) {
            this.models.push(orderedModels[i]);
          }
        }
      }

      // Silently sort the collection if appropriate.
      if (sort) this.sort({silent: true});

      // PATCH: This fixes discrepancies caused by duplicate models being set.
      this.length = this.models.length;

      // Unless silenced, it's time to fire all appropriate add/sort events.
      if (!options.silent) {
        for (i = 0, l = toAdd.length; i < l; i++) {
          (model = toAdd[i]).trigger('add', model, this, options);
        }
        if (sort || (order && order.length)) this.trigger('sort', this, options);
      }

      // Return the added (or merged) model (or models).
      return singular ? models[0] : models;
    },

    // When you have more items than you want to add or remove individually,
    // you can reset the entire set with a new list of models, without firing
    // any granular `add` or `remove` events. Fires `reset` when finished.
    // Useful for bulk operations and optimizations.
    reset: function(models, options) {
      options || (options = {});
      for (var i = 0, l = this.models.length; i < l; i++) {
        this._removeReference(this.models[i], options);
      }
      options.previousModels = this.models;
      this._reset();
      models = this.add(models, _.extend({silent: true}, options));
      if (!options.silent) this.trigger('reset', this, options);
      return models;
    },

    // Add a model to the end of the collection.
    push: function(model, options) {
      return this.add(model, _.extend({at: this.length}, options));
    },

    // Remove a model from the end of the collection.
    pop: function(options) {
      var model = this.at(this.length - 1);
      this.remove(model, options);
      return model;
    },

    // Add a model to the beginning of the collection.
    unshift: function(model, options) {
      return this.add(model, _.extend({at: 0}, options));
    },

    // Remove a model from the beginning of the collection.
    shift: function(options) {
      var model = this.at(0);
      this.remove(model, options);
      return model;
    },

    // Slice out a sub-array of models from the collection.
    slice: function() {
      return slice.apply(this.models, arguments);
    },

    // Get a model from the set by id.
    get: function(obj) {
      if (obj == null) return void 0;
      return this._byId[obj] || this._byId[obj.id] || this._byId[obj.cid];
    },

    // Get the model at the given index.
    at: function(index) {
      return this.models[index];
    },

    // Return models with matching attributes. Useful for simple cases of
    // `filter`.
    where: function(attrs, first) {
      if (_.isEmpty(attrs)) return first ? void 0 : [];
      return this[first ? 'find' : 'filter'](function(model) {
        for (var key in attrs) {
          if (attrs[key] !== model.get(key)) return false;
        }
        return true;
      });
    },

    // Return the first model with matching attributes. Useful for simple cases
    // of `find`.
    findWhere: function(attrs) {
      return this.where(attrs, true);
    },

    // Force the collection to re-sort itself. You don't need to call this under
    // normal circumstances, as the set will maintain sort order as each item
    // is added.
    sort: function(options) {
      if (!this.comparator) throw new Error('Cannot sort a set without a comparator');
      options || (options = {});

      // Run sort based on type of `comparator`.
      if (_.isString(this.comparator) || this.comparator.length === 1) {
        this.models = this.sortBy(this.comparator, this);
      } else {
        this.models.sort(_.bind(this.comparator, this));
      }

      if (!options.silent) this.trigger('sort', this, options);
      return this;
    },

    // Pluck an attribute from each model in the collection.
    pluck: function(attr) {
      return _.invoke(this.models, 'get', attr);
    },

    // Fetch the default set of models for this collection, resetting the
    // collection when they arrive. If `reset: true` is passed, the response
    // data will be passed through the `reset` method instead of `set`.
    fetch: function(options) {
      options = options ? _.clone(options) : {};
      if (options.parse === void 0) options.parse = true;
      var success = options.success;
      var collection = this;
      options.success = function(resp) {
        var method = options.reset ? 'reset' : 'set';
        collection[method](resp, options);
        if (success) success(collection, resp, options);
        collection.trigger('sync', collection, resp, options);
      };
      wrapError(this, options);
      return this.sync('read', this, options);
    },

    // Create a new instance of a model in this collection. Add the model to the
    // collection immediately, unless `wait: true` is passed, in which case we
    // wait for the server to agree.
    create: function(model, options) {
      options = options ? _.clone(options) : {};
      if (!(model = this._prepareModel(model, options))) return false;
      if (!options.wait) this.add(model, options);
      var collection = this;
      var success = options.success;
      options.success = function(model, resp) {
        if (options.wait) collection.add(model, options);
        if (success) success(model, resp, options);
      };
      model.save(null, options);
      return model;
    },

    // **parse** converts a response into a list of models to be added to the
    // collection. The default implementation is just to pass it through.
    parse: function(resp, options) {
      return resp;
    },

    // Create a new collection with an identical list of models as this one.
    clone: function() {
      return new this.constructor(this.models);
    },

    // Private method to reset all internal state. Called when the collection
    // is first initialized or reset.
    _reset: function() {
      this.length = 0;
      this.models = [];
      this._byId  = {};
    },

    // Prepare a hash of attributes (or other model) to be added to this
    // collection.
    _prepareModel: function(attrs, options) {
      if (attrs instanceof Model) return attrs;
      options = options ? _.clone(options) : {};
      options.collection = this;
      var model = new this.model(attrs, options);
      if (!model.validationError) return model;
      this.trigger('invalid', this, model.validationError, options);
      return false;
    },

    // Internal method to create a model's ties to a collection.
    _addReference: function(model, options) {
      this._byId[model.cid] = model;
      if (model.id != null) this._byId[model.id] = model;
      if (!model.collection) model.collection = this;
      model.on('all', this._onModelEvent, this);
    },

    // Internal method to sever a model's ties to a collection.
    _removeReference: function(model, options) {
      if (this === model.collection) delete model.collection;
      model.off('all', this._onModelEvent, this);
    },

    // Internal method called every time a model in the set fires an event.
    // Sets need to update their indexes when models change ids. All other
    // events simply proxy through. "add" and "remove" events that originate
    // in other collections are ignored.
    _onModelEvent: function(event, model, collection, options) {
      if ((event === 'add' || event === 'remove') && collection !== this) return;
      if (event === 'destroy') this.remove(model, options);
      if (model && event === 'change:' + model.idAttribute) {
        delete this._byId[model.previous(model.idAttribute)];
        if (model.id != null) this._byId[model.id] = model;
      }
      this.trigger.apply(this, arguments);
    }

  });

  // Underscore methods that we want to implement on the Collection.
  // 90% of the core usefulness of Backbone Collections is actually implemented
  // right here:
  var methods = ['forEach', 'each', 'map', 'collect', 'reduce', 'foldl',
    'inject', 'reduceRight', 'foldr', 'find', 'detect', 'filter', 'select',
    'reject', 'every', 'all', 'some', 'any', 'include', 'contains', 'invoke',
    'max', 'min', 'toArray', 'size', 'first', 'head', 'take', 'initial', 'rest',
    'tail', 'drop', 'last', 'without', 'difference', 'indexOf', 'shuffle',
    'lastIndexOf', 'isEmpty', 'chain', 'sample'];

  // Mix in each Underscore method as a proxy to `Collection#models`.
  _.each(methods, function(method) {
    Collection.prototype[method] = function() {
      var args = slice.call(arguments);
      args.unshift(this.models);
      return _[method].apply(_, args);
    };
  });

  // Underscore methods that take a property name as an argument.
  var attributeMethods = ['groupBy', 'countBy', 'sortBy', 'indexBy'];

  // Use attributes instead of properties.
  _.each(attributeMethods, function(method) {
    Collection.prototype[method] = function(value, context) {
      var iterator = _.isFunction(value) ? value : function(model) {
        return model.get(value);
      };
      return _[method](this.models, iterator, context);
    };
  });

  // Backbone.View
  // -------------

  // Backbone Views are almost more convention than they are actual code. A View
  // is simply a JavaScript object that represents a logical chunk of UI in the
  // DOM. This might be a single item, an entire list, a sidebar or panel, or
  // even the surrounding frame which wraps your whole app. Defining a chunk of
  // UI as a **View** allows you to define your DOM events declaratively, without
  // having to worry about render order ... and makes it easy for the view to
  // react to specific changes in the state of your models.

  // Creating a Backbone.View creates its initial element outside of the DOM,
  // if an existing element is not provided...
  var View = Backbone.View = function(options) {
    this.cid = _.uniqueId('view');
    options || (options = {});
    _.extend(this, _.pick(options, viewOptions));
    this._ensureElement();
    this.initialize.apply(this, arguments);
    this.delegateEvents();
  };

  // Cached regex to split keys for `delegate`.
  var delegateEventSplitter = /^(\S+)\s*(.*)$/;

  // List of view options to be merged as properties.
  var viewOptions = ['model', 'collection', 'el', 'id', 'attributes', 'className', 'tagName', 'events'];

  // Set up all inheritable **Backbone.View** properties and methods.
  _.extend(View.prototype, Events, {

    // The default `tagName` of a View's element is `"div"`.
    tagName: 'div',

    // jQuery delegate for element lookup, scoped to DOM elements within the
    // current view. This should be preferred to global lookups where possible.
    $: function(selector) {
      return this.$el.find(selector);
    },

    // Initialize is an empty function by default. Override it with your own
    // initialization logic.
    initialize: function(){},

    // **render** is the core function that your view should override, in order
    // to populate its element (`this.el`), with the appropriate HTML. The
    // convention is for **render** to always return `this`.
    render: function() {
      return this;
    },

    // Remove this view by taking the element out of the DOM, and removing any
    // applicable Backbone.Events listeners.
    remove: function() {
      this.$el.remove();
      this.stopListening();
      return this;
    },

    // Change the view's element (`this.el` property), including event
    // re-delegation.
    setElement: function(element, delegate) {
      if (this.$el) this.undelegateEvents();
      this.$el = element instanceof Backbone.$ ? element : Backbone.$(element);
      this.el = this.$el[0];
      if (delegate !== false) this.delegateEvents();
      return this;
    },

    // Set callbacks, where `this.events` is a hash of
    //
    // *{"event selector": "callback"}*
    //
    //     {
    //       'mousedown .title':  'edit',
    //       'click .button':     'save',
    //       'click .open':       function(e) { ... }
    //     }
    //
    // pairs. Callbacks will be bound to the view, with `this` set properly.
    // Uses event delegation for efficiency.
    // Omitting the selector binds the event to `this.el`.
    // This only works for delegate-able events: not `focus`, `blur`, and
    // not `change`, `submit`, and `reset` in Internet Explorer.
    delegateEvents: function(events) {
      if (!(events || (events = _.result(this, 'events')))) return this;
      this.undelegateEvents();
      for (var key in events) {
        var method = events[key];
        if (!_.isFunction(method)) method = this[events[key]];
        if (!method) continue;

        var match = key.match(delegateEventSplitter);
        var eventName = match[1], selector = match[2];
        method = _.bind(method, this);
        eventName += '.delegateEvents' + this.cid;
        if (selector === '') {
          this.$el.on(eventName, method);
        } else {
          this.$el.on(eventName, selector, method);
        }
      }
      return this;
    },

    // Clears all callbacks previously bound to the view with `delegateEvents`.
    // You usually don't need to use this, but may wish to if you have multiple
    // Backbone views attached to the same DOM element.
    undelegateEvents: function() {
      this.$el.off('.delegateEvents' + this.cid);
      return this;
    },

    // Ensure that the View has a DOM element to render into.
    // If `this.el` is a string, pass it through `$()`, take the first
    // matching element, and re-assign it to `el`. Otherwise, create
    // an element from the `id`, `className` and `tagName` properties.
    _ensureElement: function() {
      if (!this.el) {
        var attrs = _.extend({}, _.result(this, 'attributes'));
        if (this.id) attrs.id = _.result(this, 'id');
        if (this.className) attrs['class'] = _.result(this, 'className');
        var $el = Backbone.$('<' + _.result(this, 'tagName') + '>').attr(attrs);
        this.setElement($el, false);
      } else {
        this.setElement(_.result(this, 'el'), false);
      }
    }

  });

  // Backbone.sync
  // -------------

  // Override this function to change the manner in which Backbone persists
  // models to the server. You will be passed the type of request, and the
  // model in question. By default, makes a RESTful Ajax request
  // to the model's `url()`. Some possible customizations could be:
  //
  // * Use `setTimeout` to batch rapid-fire updates into a single request.
  // * Send up the models as XML instead of JSON.
  // * Persist models via WebSockets instead of Ajax.
  //
  // Turn on `Backbone.emulateHTTP` in order to send `PUT` and `DELETE` requests
  // as `POST`, with a `_method` parameter containing the true HTTP method,
  // as well as all requests with the body as `application/x-www-form-urlencoded`
  // instead of `application/json` with the model in a param named `model`.
  // Useful when interfacing with server-side languages like **PHP** that make
  // it difficult to read the body of `PUT` requests.
  Backbone.sync = function(method, model, options) {
    var type = methodMap[method];

    // Default options, unless specified.
    _.defaults(options || (options = {}), {
      emulateHTTP: Backbone.emulateHTTP,
      emulateJSON: Backbone.emulateJSON
    });

    // Default JSON-request options.
    var params = {type: type, dataType: 'json'};

    // Ensure that we have a URL.
    if (!options.url) {
      params.url = _.result(model, 'url') || urlError();
    }

    // Ensure that we have the appropriate request data.
    if (options.data == null && model && (method === 'create' || method === 'update' || method === 'patch')) {
      params.contentType = 'application/json';
      params.data = JSON.stringify(options.attrs || model.toJSON(options));
    }

    // For older servers, emulate JSON by encoding the request into an HTML-form.
    if (options.emulateJSON) {
      params.contentType = 'application/x-www-form-urlencoded';
      params.data = params.data ? {model: params.data} : {};
    }

    // For older servers, emulate HTTP by mimicking the HTTP method with `_method`
    // And an `X-HTTP-Method-Override` header.
    if (options.emulateHTTP && (type === 'PUT' || type === 'DELETE' || type === 'PATCH')) {
      params.type = 'POST';
      if (options.emulateJSON) params.data._method = type;
      var beforeSend = options.beforeSend;
      options.beforeSend = function(xhr) {
        xhr.setRequestHeader('X-HTTP-Method-Override', type);
        if (beforeSend) return beforeSend.apply(this, arguments);
      };
    }

    // Don't process data on a non-GET request.
    if (params.type !== 'GET' && !options.emulateJSON) {
      params.processData = false;
    }

    // If we're sending a `PATCH` request, and we're in an old Internet Explorer
    // that still has ActiveX enabled by default, override jQuery to use that
    // for XHR instead. Remove this line when jQuery supports `PATCH` on IE8.
    if (params.type === 'PATCH' && noXhrPatch) {
      params.xhr = function() {
        return new ActiveXObject("Microsoft.XMLHTTP");
      };
    }

    // Make the request, allowing the user to override any Ajax options.
    var xhr = options.xhr = Backbone.ajax(_.extend(params, options));
    model.trigger('request', model, xhr, options);
    return xhr;
  };

  var noXhrPatch =
    typeof window !== 'undefined' && !!window.ActiveXObject &&
      !(window.XMLHttpRequest && (new XMLHttpRequest).dispatchEvent);

  // Map from CRUD to HTTP for our default `Backbone.sync` implementation.
  var methodMap = {
    'create': 'POST',
    'update': 'PUT',
    'patch':  'PATCH',
    'delete': 'DELETE',
    'read':   'GET'
  };

  // Set the default implementation of `Backbone.ajax` to proxy through to `$`.
  // Override this if you'd like to use a different library.
  Backbone.ajax = function() {
    return Backbone.$.ajax.apply(Backbone.$, arguments);
  };

  // Backbone.Router
  // ---------------

  // Routers map faux-URLs to actions, and fire events when routes are
  // matched. Creating a new one sets its `routes` hash, if not set statically.
  var Router = Backbone.Router = function(options) {
    options || (options = {});
    if (options.routes) this.routes = options.routes;
    this._bindRoutes();
    this.initialize.apply(this, arguments);
  };

  // Cached regular expressions for matching named param parts and splatted
  // parts of route strings.
  var optionalParam = /\((.*?)\)/g;
  var namedParam    = /(\(\?)?:\w+/g;
  var splatParam    = /\*\w+/g;
  var escapeRegExp  = /[\-{}\[\]+?.,\\\^$|#\s]/g;

  // Set up all inheritable **Backbone.Router** properties and methods.
  _.extend(Router.prototype, Events, {

    // Initialize is an empty function by default. Override it with your own
    // initialization logic.
    initialize: function(){},

    // Manually bind a single named route to a callback. For example:
    //
    //     this.route('search/:query/p:num', 'search', function(query, num) {
    //       ...
    //     });
    //
    route: function(route, name, callback) {
      if (!_.isRegExp(route)) route = this._routeToRegExp(route);
      if (_.isFunction(name)) {
        callback = name;
        name = '';
      }
      if (!callback) callback = this[name];
      var router = this;
      Backbone.history.route(route, function(fragment) {
        var args = router._extractParameters(route, fragment);
        router.execute(callback, args);
        router.trigger.apply(router, ['route:' + name].concat(args));
        router.trigger('route', name, args);
        Backbone.history.trigger('route', router, name, args);
      });
      return this;
    },

    // Execute a route handler with the provided parameters.  This is an
    // excellent place to do pre-route setup or post-route cleanup.
    execute: function(callback, args) {
      if (callback) callback.apply(this, args);
    },

    // Simple proxy to `Backbone.history` to save a fragment into the history.
    navigate: function(fragment, options) {
      Backbone.history.navigate(fragment, options);
      return this;
    },

    // Bind all defined routes to `Backbone.history`. We have to reverse the
    // order of the routes here to support behavior where the most general
    // routes can be defined at the bottom of the route map.
    _bindRoutes: function() {
      if (!this.routes) return;
      this.routes = _.result(this, 'routes');
      var route, routes = _.keys(this.routes);
      while ((route = routes.pop()) != null) {
        this.route(route, this.routes[route]);
      }
    },

    // Convert a route string into a regular expression, suitable for matching
    // against the current location hash.
    _routeToRegExp: function(route) {
      route = route.replace(escapeRegExp, '\\$&')
                   .replace(optionalParam, '(?:$1)?')
                   .replace(namedParam, function(match, optional) {
                     return optional ? match : '([^/?]+)';
                   })
                   .replace(splatParam, '([^?]*?)');
      return new RegExp('^' + route + '(?:\\?([\\s\\S]*))?$');
    },

    // Given a route, and a URL fragment that it matches, return the array of
    // extracted decoded parameters. Empty or unmatched parameters will be
    // treated as `null` to normalize cross-browser behavior.
    _extractParameters: function(route, fragment) {
      var params = route.exec(fragment).slice(1);
      return _.map(params, function(param, i) {
        // Don't decode the search params.
        if (i === params.length - 1) return param || null;
        return param ? decodeURIComponent(param) : null;
      });
    }

  });

  // Backbone.History
  // ----------------

  // Handles cross-browser history management, based on either
  // [pushState](http://diveintohtml5.info/history.html) and real URLs, or
  // [onhashchange](https://developer.mozilla.org/en-US/docs/DOM/window.onhashchange)
  // and URL fragments. If the browser supports neither (old IE, natch),
  // falls back to polling.
  var History = Backbone.History = function() {
    this.handlers = [];
    _.bindAll(this, 'checkUrl');

    // Ensure that `History` can be used outside of the browser.
    if (typeof window !== 'undefined') {
      this.location = window.location;
      this.history = window.history;
    }
  };

  // Cached regex for stripping a leading hash/slash and trailing space.
  var routeStripper = /^[#\/]|\s+$/g;

  // Cached regex for stripping leading and trailing slashes.
  var rootStripper = /^\/+|\/+$/g;

  // Cached regex for detecting MSIE.
  var isExplorer = /msie [\w.]+/;

  // Cached regex for removing a trailing slash.
  var trailingSlash = /\/$/;

  // Cached regex for stripping urls of hash.
  var pathStripper = /#.*$/;

  // Has the history handling already been started?
  History.started = false;

  // Set up all inheritable **Backbone.History** properties and methods.
  _.extend(History.prototype, Events, {

    // The default interval to poll for hash changes, if necessary, is
    // twenty times a second.
    interval: 50,

    // Are we at the app root?
    atRoot: function() {
      return this.location.pathname.replace(/[^\/]$/, '$&/') === this.root;
    },

    // Gets the true hash value. Cannot use location.hash directly due to bug
    // in Firefox where location.hash will always be decoded.
    getHash: function(window) {
      var match = (window || this).location.href.match(/#(.*)$/);
      return match ? match[1] : '';
    },

    // Get the cross-browser normalized URL fragment, either from the URL,
    // the hash, or the override.
    getFragment: function(fragment, forcePushState) {
      if (fragment == null) {
        if (this._hasPushState || !this._wantsHashChange || forcePushState) {
          fragment = decodeURI(this.location.pathname + this.location.search);
          var root = this.root.replace(trailingSlash, '');
          if (!fragment.indexOf(root)) fragment = fragment.slice(root.length);
        } else {
          fragment = this.getHash();
        }
      }
      return fragment.replace(routeStripper, '');
    },

    // Start the hash change handling, returning `true` if the current URL matches
    // an existing route, and `false` otherwise.
    start: function(options) {
      if (History.started) throw new Error("Backbone.history has already been started");
      History.started = true;

      // Figure out the initial configuration. Do we need an iframe?
      // Is pushState desired ... is it available?
      this.options          = _.extend({root: '/'}, this.options, options);
      this.root             = this.options.root;
      this._wantsHashChange = this.options.hashChange !== false;
      this._wantsPushState  = !!this.options.pushState;
      this._hasPushState    = !!(this.options.pushState && this.history && this.history.pushState);
      var fragment          = this.getFragment();
      var docMode           = document.documentMode;
      var oldIE             = (isExplorer.exec(navigator.userAgent.toLowerCase()) && (!docMode || docMode <= 7));

      // Normalize root to always include a leading and trailing slash.
      this.root = ('/' + this.root + '/').replace(rootStripper, '/');

      if (oldIE && this._wantsHashChange) {
        var frame = Backbone.$('<iframe src="javascript:0" tabindex="-1">');
        this.iframe = frame.hide().appendTo('body')[0].contentWindow;
        this.navigate(fragment);
      }

      // Depending on whether we're using pushState or hashes, and whether
      // 'onhashchange' is supported, determine how we check the URL state.
      if (this._hasPushState) {
        Backbone.$(window).on('popstate', this.checkUrl);
      } else if (this._wantsHashChange && ('onhashchange' in window) && !oldIE) {
        Backbone.$(window).on('hashchange', this.checkUrl);
      } else if (this._wantsHashChange) {
        this._checkUrlInterval = setInterval(this.checkUrl, this.interval);
      }

      // Determine if we need to change the base url, for a pushState link
      // opened by a non-pushState browser.
      this.fragment = fragment;
      var loc = this.location;

      // Transition from hashChange to pushState or vice versa if both are
      // requested.
      if (this._wantsHashChange && this._wantsPushState) {

        // If we've started off with a route from a `pushState`-enabled
        // browser, but we're currently in a browser that doesn't support it...
        if (!this._hasPushState && !this.atRoot()) {
          this.fragment = this.getFragment(null, true);
          this.location.replace(this.root + '#' + this.fragment);
          // Return immediately as browser will do redirect to new url
          return true;

        // Or if we've started out with a hash-based route, but we're currently
        // in a browser where it could be `pushState`-based instead...
        } else if (this._hasPushState && this.atRoot() && loc.hash) {
          this.fragment = this.getHash().replace(routeStripper, '');
          this.history.replaceState({}, document.title, this.root + this.fragment);
        }

      }

      if (!this.options.silent) return this.loadUrl();
    },

    // Disable Backbone.history, perhaps temporarily. Not useful in a real app,
    // but possibly useful for unit testing Routers.
    stop: function() {
      Backbone.$(window).off('popstate', this.checkUrl).off('hashchange', this.checkUrl);
      if (this._checkUrlInterval) clearInterval(this._checkUrlInterval);
      History.started = false;
    },

    // Add a route to be tested when the fragment changes. Routes added later
    // may override previous routes.
    route: function(route, callback) {
      this.handlers.unshift({route: route, callback: callback});
    },

    // Checks the current URL to see if it has changed, and if it has,
    // calls `loadUrl`, normalizing across the hidden iframe.
    checkUrl: function(e) {
      var current = this.getFragment();
      if (current === this.fragment && this.iframe) {
        current = this.getFragment(this.getHash(this.iframe));
      }
      if (current === this.fragment) return false;
      if (this.iframe) this.navigate(current);
      this.loadUrl();
    },

    // Attempt to load the current URL fragment. If a route succeeds with a
    // match, returns `true`. If no defined routes matches the fragment,
    // returns `false`.
    loadUrl: function(fragment) {
      fragment = this.fragment = this.getFragment(fragment);
      return _.any(this.handlers, function(handler) {
        if (handler.route.test(fragment)) {
          handler.callback(fragment);
          return true;
        }
      });
    },

    // Save a fragment into the hash history, or replace the URL state if the
    // 'replace' option is passed. You are responsible for properly URL-encoding
    // the fragment in advance.
    //
    // The options object can contain `trigger: true` if you wish to have the
    // route callback be fired (not usually desirable), or `replace: true`, if
    // you wish to modify the current URL without adding an entry to the history.
    navigate: function(fragment, options) {
      if (!History.started) return false;
      if (!options || options === true) options = {trigger: !!options};

      var url = this.root + (fragment = this.getFragment(fragment || ''));

      // Strip the hash for matching.
      fragment = fragment.replace(pathStripper, '');

      if (this.fragment === fragment) return;
      this.fragment = fragment;

      // Don't include a trailing slash on the root.
      if (fragment === '' && url !== '/') url = url.slice(0, -1);

      // If pushState is available, we use it to set the fragment as a real URL.
      if (this._hasPushState) {
        this.history[options.replace ? 'replaceState' : 'pushState']({}, document.title, url);

      // If hash changes haven't been explicitly disabled, update the hash
      // fragment to store history.
      } else if (this._wantsHashChange) {
        this._updateHash(this.location, fragment, options.replace);
        if (this.iframe && (fragment !== this.getFragment(this.getHash(this.iframe)))) {
          // Opening and closing the iframe tricks IE7 and earlier to push a
          // history entry on hash-tag change.  When replace is true, we don't
          // want this.
          if(!options.replace) this.iframe.document.open().close();
          this._updateHash(this.iframe.location, fragment, options.replace);
        }

      // If you've told us that you explicitly don't want fallback hashchange-
      // based history, then `navigate` becomes a page refresh.
      } else {
        return this.location.assign(url);
      }
      if (options.trigger) return this.loadUrl(fragment);
    },

    // Update the hash location, either replacing the current entry, or adding
    // a new one to the browser history.
    _updateHash: function(location, fragment, replace) {
      if (replace) {
        var href = location.href.replace(/(javascript:|#).*$/, '');
        location.replace(href + '#' + fragment);
      } else {
        // Some browsers require that `hash` contains a leading #.
        location.hash = '#' + fragment;
      }
    }

  });

  // Create the default Backbone.history.
  Backbone.history = new History;

  // Helpers
  // -------

  // Helper function to correctly set up the prototype chain, for subclasses.
  // Similar to `goog.inherits`, but uses a hash of prototype properties and
  // class properties to be extended.
  var extend = function(protoProps, staticProps) {
    var parent = this;
    var child;

    // The constructor function for the new subclass is either defined by you
    // (the "constructor" property in your `extend` definition), or defaulted
    // by us to simply call the parent's constructor.
    if (protoProps && _.has(protoProps, 'constructor')) {
      child = protoProps.constructor;
    } else {
      child = function(){ return parent.apply(this, arguments); };
    }

    // Add static properties to the constructor function, if supplied.
    _.extend(child, parent, staticProps);

    // Set the prototype chain to inherit from `parent`, without calling
    // `parent`'s constructor function.
    var Surrogate = function(){ this.constructor = child; };
    Surrogate.prototype = parent.prototype;
    child.prototype = new Surrogate;

    // Add prototype properties (instance properties) to the subclass,
    // if supplied.
    if (protoProps) _.extend(child.prototype, protoProps);

    // Set a convenience property in case the parent's prototype is needed
    // later.
    child.__super__ = parent.prototype;

    return child;
  };

  // Set up inheritance for the model, collection, router, view and history.
  Model.extend = Collection.extend = Router.extend = View.extend = History.extend = extend;

  // Throw an error when a URL is needed, and none is supplied.
  var urlError = function() {
    throw new Error('A "url" property or function must be specified');
  };

  // Wrap an optional error callback with a fallback error event.
  var wrapError = function(model, options) {
    var error = options.error;
    options.error = function(resp) {
      if (error) error(model, resp, options);
      model.trigger('error', model, resp, options);
    };
  };

  return Backbone;

}));

/**
 * This is the modal dialog base view.
 *
 * Because it has so many methods of its own, it needs to be created and then have its element set as a base element for the actual modal content (i.e. the store).
 *
 * See modals/updated for a simple usage example.
 */
define('modals/modals',["jquery", "backbone"], function($, Backbone) {
	var Modal = Backbone.View.extend({
		el: '<div class="modal" tabindex="-1"><div class="close"></div><div class="content"></div></div>',
		overlay: '<div class="modal-overlay" tabindex="-1"></div>',

		/**
		 * Whether or not to destroy the modal when it's hidden.  Used to clean up temporary modals.
		 *
		 * @type  {Boolean}
		 */
		destroyOnHide: false,

		show: function() {
			this.trigger("show");

			this.mo.addClass("visible").end().focus();

			return this;
		},
		hide: function() {
			this.trigger("hide");

			this.mo.removeClass("visible");

			if (this.destroyOnHide) {
				setTimeout(this.destroy.bind(this), 400);
			}

			return this;
		},
		close: function() { // This is an overridable close method that is called from event handlers, it lets the content intercept closes.
			return this.hide();
		},
		destroy: function() {
			this.trigger("destroy");

			this.mo.off().remove();

			this.stopListening();

			return this;
		},
		initialize: function() {
			// The overlay has to be created for each individual modal instead of once
			this.overlay = $(this.overlay);

			// Set this.(modal + overlay = mo) shortcut
			this.mo = this.overlay.add(this.$el);


			// Construct an object of CSS properties based on the options passed
			var css = {};

			if (this.width) {
				css.width = this.width;
			}

			if (this.height) {
				css.maxHeight = this.height;
			}

			if (this.realHeight) {
				css.height = this.realHeight;
			}

			this.$el.css(css);


			// Add any classes that have been defined
			if (this.classes) {
				// Classes should also be set on the overlays so things like the Getting Started guide can position themselves over everything else
				this.mo.addClass(this.classes);
			}


			// If the modal is less than 700px wide, add a small class
			if (this.width && this.width <= 700) {
				this.$el.addClass("small");
			}


			// Attach close handlers
			this.overlay.add(this.$(".close")).on("click", this.close.bind(this));

			/*
				This isn't perfect since it relies on the modal having focus, but it should be pretty good.

				It can't be attached in "events" since it has to be triggered for both the modal and the overlay.
			*/
			this.mo.on("keydown", function(e) {
				if (e.keyCode === 27) {
					this.close(e);
				}
			}.bind(this));

			// This is used by most of the actual modals as their $el
			this.content = this.$(".content");
		}
	});

	return Modal;
});
define('lib/parseurl',[],function() {
	/**
	 * Converts a given string to a URL
	 *
	 * @param   {String}  str  The string to convert to a URL
	 * @return  {String}       The converted URL
	 */
	return function(str) {
		if (typeof str !== "string") {
			return str;
		}

		if (str.indexOf("://") === 0) {
			return "https" + str;
		}
		else if (str.indexOf("data:") === 0 || str.indexOf("filesystem:") === 0 || str.indexOf("blob:") === 0) {
			return str;
		}
		else if (str.indexOf("://") === -1) {
			return "http://" + str;
		}
		else {
			return str;
		}
	};
});
/*
 * The Bookmarks widget.
 */
define('w/bookmarks',["jquery", "lodash", "browser/api", "modals/modals", "lib/parseurl"], function($, _, Browser, Modal, parseUrl) {
	return {
		id: 16,
		sort: 440,
		size: 2,
		order: 12,
		unlisted: true,
		nicename: "bookmarks",
		sizes: ["tiny", "variable"],
		settings: [
			{
				type: "text",
				nicename: "title",
				label: "i18n.settings.title",
				placeholder: "i18n.settings.title_placeholder"
			},
			{
				type: "size"
			},
			{
				type: "select",
				nicename: "columns",
				label: "i18n.settings.layout",
				options: {
					one: "i18n.settings.layout_options.single",
					two: "i18n.settings.layout_options.double"
				},
				sizes: ["variable"]
			},
			{
				type: "radio",
				nicename: "target",
				label: "i18n.settings.open",
				options: {
					_self: "i18n.settings.open_options.current",
					_blank: "i18n.settings.open_options.blank"
				}
			}
		],
		config: {
			title: "i18n.name",
			size: "variable",
			columns: "one",
			target: "_self"
		},
		syncData: {
			bookmarks: [
				{
					title: "Google",
					url: "https://www.google.com/"
				},
				{
					title: "Facebook",
					url: "https://www.facebook.com/"
				},
				{
					title: "Youtube",
					url: "https://www.youtube.com/"
				},
				{
					title: "Amazon",
					url: "https://www.amazon.com/"
				},
				{
					title: "Wikipedia",
					url: "https://www.wikipedia.org/"
				}
			]
		},
		save: function() {
			this.syncData.bookmarks = this.sortable.sortable("serialize").get();

			this.utils.saveData(this.syncData);
		},
		addItem: function(data) {
			var html = '<a class="link drag" href="' + data.url + '"><img class="favicon" src="' + Browser.getFavicon(data.url) +
				'" /><span class="title">' + data.title + '</span><div class="tools"><span class="' +
				'edit">	&#xE606;</span><span class="delete">&#xE678;</span><span class="move">&#xE693;</span></div>';

			this.editItem($(html).appendTo(this.sortable));

			this.save();
		},
		editItem: function(item) {
			var modal = this.modal;

			modal.url.val(item.attr("href"));
			modal.title.val(item.find(".title").text());

			modal.save = function(e) {
				e.preventDefault();

				this.adding = false;

				modal.hide();

				item.attr("href", parseUrl(modal.url.val().trim()))
					.find(".title").text(modal.title.val().trim()).end()
					.find(".favicon").attr("src", Browser.getFavicon(parseUrl(modal.url.val().trim())));

				this.save();
			}.bind(this);

			modal.show();
		},
		adding: false,
		render: function() {
			if (this.data) {
				this.syncData = _.cloneDeep(this.data);

				delete this.data;
			}

			var data = _.clone(this.syncData);

			data.bookmarks = data.bookmarks.map(function(e) {
				e = _.clone(e);

				e.favicon = Browser.getFavicon(e.url);

				return e;
			});

			if (this.config.title && this.config.title !== "") {
				data.title = this.config.title;
			}

			if (this.config.columns && this.config.columns !== "one" && this.config.size !== "tiny") {
				data.two = true;
			}

			if (this.config.target && this.config.target === "_blank") {
				data.newTab = true;
			}

			this.utils.render(data, {
				listing: this.utils.getTemplate("listing")
			});


			var modalHTML = '<h2 class="title">' + this.utils.translate("edit.dialog_title") + '</h2>' +
				'<form>' +
					'<div class="form-group">' +
						'<label for="bookmark-title">' + this.utils.translate("edit.title") + '</label>' +
						'<input type="text" class="form-control" id="bookmark-title" maxlength="255" placeholder="' + this.utils.translate("edit.title_placeholder") + '" />' +
					'</div>' +

					'<div class="form-group">' +
						'<label for="bookmark-url">' + this.utils.translate("edit.url") + '</label>' +
						'<input type="text" class="form-control" id="bookmark-url" maxlength="500" placeholder="' + this.utils.translate("edit.url_placeholder") + '" />' +
					'</div>' +

				'</form>' +

				'<button class="btn btn-primary">' + this.utils.translate("edit.save") + '</button>';

			this.modal = new (Modal.extend({
				width: 400,
				height: 290,
				classes: "bookmarks-modal",
				close: function() {
					this.adding = false;

					this.modal.hide();
				}.bind(this)
			}))();

			this.modal.mo.appendTo(document.body);

			this.modal.content.html(modalHTML);

			this.modal.save = function() {};

			this.modal.title = this.modal.$("#bookmark-title");
			this.modal.url = this.modal.$("#bookmark-url");
			this.modal.btn = this.modal.$(".btn").click(function(e) {
				this.modal.save(e);
			}.bind(this));

			this.modal.title.add(this.modal.url).on("keydown", function(e) {
				if (e.which === 13) {
					this.modal.save(e);
				}
			}.bind(this));

			var that = this;

			this.sortable = this.elm.on("click", "a.link", function(e) {
				var href = this.getAttribute("href");

				if (href.indexOf("chrome") === 0 && !$(e.target).is(".tools span")) { // chrome:// links can't be opened directly for security reasons, this bypasses that feature.
					e.preventDefault();

					Browser.tabs.getCurrent(function(d) {
						if (e.which === 2 || (e.currentTarget.target || $("base").attr("target")) === "_blank") {
							Browser.tabs.create({
								url: href,
								index: d.index + 1
							});
						}
						else {
							Browser.tabs.update(d.id, {
								url: href
							});
						}
					});
				}
			}).on("click", ".link .delete", function(e) {
				e.preventDefault();

				$(this).parent().parent().slideUp(function() {
					$(this).remove();

					that.save.call(that);
				});
			}).on("click", ".link .edit", function(e) {
				e.preventDefault();

				that.editItem.call(that, $(this).parent().parent());
			}).on("click", ".folder", function(e) {
				if ($(e.target).is(".folder, .name")) {
					e.preventDefault();
					e.stopPropagation();

					$(this).toggleClass("active");
				}
			}).on("click", ".folder > .tools .delete", function(e) {
				e.preventDefault();

				$(this).parents(".folder").first().slideUp(function() {
					$(this).remove();

					that.save.call(that);
				});
			}).on("click", ".folder > .tools .edit", function(e) {
				e.preventDefault();

				$(this).parents(".folder")
					.first()
					.children(".name")
					.attr("disabled", false)
					.focus()
					.on("click", function(e) {
						e.stopPropagation();
					}).one("focusout", function() {
						$(this).attr("disabled", true);

						that.save.call(that);
					}).on("keydown", function(e) {
						if (e.which === 13) {
							$(this).off("click keydown").focusout();
						}
					});
			}).on("dragenter dragover", function() {

				$(this).find(".drop").addClass("active");

			}).on("dragleave dragexit", ".drop", function() {

				$(this).removeClass("active");

			}).on("input", ".catch", function(e) {
				e.preventDefault();

				var link = $(this).find("a").first();

				if (link.length) {
					that.addItem.call(that, {
						title: link.text(),
						url: link.attr("href")
					});
				}

				link.end().end().html("").parent().removeClass("active");
			}).on("click", ".new > a", function() {
				if (!that.adding) {
					if ($(this).attr("data-type") === "folder") {
						var html = '<div class="folder drag"><input type="text" class="name" disabled /><div class="tools"><span class="' +
							'edit">	&#xE606;</span><span class="delete">&#xE678;</span><span class="move">&#xE693;</span><div class="items"></div></div>';

						$(html).appendTo(that.sortable).find(".edit").click();

						that.save.call(that);
					}
					else {
						that.adding = true;

						that.addItem.call(that, {
							title: "",
							url: ""
						});
					}
				}
			}).find(".list").sortable({
				handle: ".move",
				group: "bookmarks",
				itemSelector: ".drag",
				dynamicDimensions: true,
				containerSelector: ".folder .items, .list",
				placeholder: "<a class=\"link holder\"/>",
				onDragStart: function(item) {
					item.css({
						height: item.outerHeight(),
						width: item.outerWidth()
					});

					item.addClass("dragged");
				},
				onDrag: function(item, position) {
					var ctx = $(item.context),
						ctp = ctx.position(),
						ctpp = ctx.parent().position();

					position.top -= ctp.top + ctpp.top + 10;
					position.left -= ctp.left + ctpp.left + 10;

					item.css(position);
				},
				onDrop: function(item, container, _super) {
					that.save.call(that);

					_super(item, container);
				},
				serialize: function(item, children, isContainer) {
					if (isContainer) {
						return children;
					}
					else {
						if (item.hasClass("folder")) {
							return {
								name: item.find(".name").val().trim().slice(0, 255),
								items: children[0] ? children : []
							};
						}
						else {
							return {
								title: item.find(".title").text().trim().slice(0, 255),
								url: item.attr("href").trim().slice(0, 500)
							};
						}
					}
				},
			});
		}
	};
});
/*
 * The Calculator widget.
 */
define('w/calc',[],function() {
	return {
		id: 28,
		sort: 230,
		size: 4,
		order: 20,
		nicename: "calc",
		sizes: ["tiny", "small", "medium"],
		settings: [
			{
				type: "size"
			}
		],
		config: {
			size: "medium"
		},
		render: function() {
			/*
				This calculator works for the most part, but can't really be expanded.

				If it needs to be it should be rewritten so problems are stored as an array, like so:

					["2", " x ", "3.14", " + ", ["2", " x ", ["sqrt", ["2", " + ", "3"]]]]

				That would be rendered as: 2 x 3.14 + (2 x √(2 + 3)).

				The syntax can be easily expanded so the calculator supports sin, cos, tan, square roots, exponents, etc.

				This also makes decimal point validation easier, and makes sure there are no missing parentheses or consecutive operators.

				But, right now it's unnecessary.
			*/

			this.utils.render();

			var btns = this.elm.find("button"),
				display = this.elm.find(".display"),
				d0 = display[0],
				overwrite = false,
				nums = ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
				f;

			var calculate = function() {
				var problem = d0.value
					.replace(/×/g, "*") // Multiplication symbol with *
					.replace(/x/gi, "*") // x with *
					.replace(/÷/g, "/") // Division symbol with /
					.replace(/[^ +\-()1234567890*\/\.]|[\-+\/\*\.]{2}/g, "") // Replace all invalid characters
					.replace(/ {1,}/g, " ") // Multiple spaces
					.replace(/([0-9]) ([0-9])/g, "$1$2") // Spaces in numbers
					.replace(/[0-9\.]+/g, function(match) { // Handle multiple decimal places within a number
						f = true;

						return " " + match.replace(/\./g, function() { return (f && !(f = false)) ? "." : ""; }) + " ";
					})
					.replace(/ {1,}/g, " ") // Multiple spaces
					.replace(/([0-9]) ?\(/g, "$1 * (") // Handle parentheses adjacent to numbers by multiplying them
					.replace(/\) ?([0-9])/g, ") * $1") // Again
					.trim();

				if (problem.indexOf("(") !== -1 || problem.indexOf(")") !== -1) {
					// Modified from: http://stackoverflow.com/a/14369329/900747
					var check = function(str) {
						var s;

						str = str.replace(/[^()]/g, "");

						while (s !== str) {
							s = str;

							str = str.replace(/\(\)/g, "");
						}

						return !str;
					};

					while ((problem.match(/\(/g) || "").length > (problem.match(/\)/g) || "").length) {
						problem += ")";
					}

					while ((problem.match(/\)/g) || "").length > (problem.match(/\(/g) || "").length) {
						problem = "(" + problem;
					}

					if (!check(problem)) {
						d0.value = this.utils.translate("mismatch");
					}
				}

				try {
					var answer = eval(problem); // jshint ignore:line

					if (typeof answer !== "number" || isNaN(answer)) {
						d0.value = this.utils.translate("error");
					}
					else if (answer === Infinity || answer === -Infinity) {
						d0.value = this.utils.translate("infinity");
					}
					else {
						d0.value = +answer.toFixed(8); // Maximum of 8 decimal places
					}
				}
				catch(e) {
					d0.value = this.utils.translate("error");
				}

				overwrite = true;
			};

			btns.on("click", function(e) {
				e.preventDefault();

				var which = this.getAttribute("data-id"),
					value,
					num = false;

				if (nums.indexOf(which) !== -1) {
					value = which;

					num = true;
				}
				else {
					switch (which) {
						case "oparen":
							value = "(";
						break;
						case "cparen":
							value = ")";
						break;
						case "plus":
							value = " + ";
						break;
						case "minus":
							value = " - ";
						break;
						case "multiply":
							value = " × ";
						break;
						case "divide":
							value = " ÷ ";
						break;
						case "decimal":
							value = ".";
						break;
						case "clear":
							d0.value = "";
						break;
						case "equals":
							calculate();
						break;
					}
				}

				if (value) {
					if ((overwrite && !num) || !overwrite) {
						/*var start = d0.selectionStart;

						d0.value = d0.value.slice(0, start) + value + d0.value.slice(d0.selectionEnd);

						d0.setSelectionRange(start, start);*/

						d0.value += value;
					}
					else {
						d0.value = value;
					}

					overwrite = false;

					d0.focus();
				}
			});

			display.on("keydown", function(e) {
				if (e.which === 13) {
					calculate();
				}
			}).on("input", function() {
				var val = d0.value.replace(/[^ +\-()1234567890*\/×x\.÷]/g, "");

				if (d0.value !== val) {
					var start = d0.selectionStart - 1, // These are -1 since the cursor is just after the entered text and we want to be before
						end = d0.selectionEnd - 1;

					d0.value = val;

					d0.setSelectionRange(start, end);
				}
			}).on("focusout", function() {
				d0.value = d0.value // See calculate() for comments
					.replace(/[^ +\-()1234567890*\/x\.×÷]|[\-+\/\*\.]{2}/g, "")
					.replace(/[0-9\.]+/g, function(match) {
						f = true;

						return " " + match.replace(/\./g, function() { return (f && !(f = false)) ? "." : ""; }) + " ";
					})
					.replace(/ {1,}/g, " ")
					.replace(/\( /g, "(")
					.replace(/ \)/g, ")")
					.replace(/([+\-x×÷*\/])(\()|(\))([+\-x×÷*\/])/g, "$1 $2")
					.trim();
			});
		}
	};
});
;(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
	typeof define === 'function' && define.amd ? define('moment',factory) :
	global.moment = factory()
}(this, function () { 'use strict';

	var hookCallback;

	function utils_hooks__hooks () {
		return hookCallback.apply(null, arguments);
	}

	// This is done to register the method called with moment()
	// without creating circular dependencies.
	function setHookCallback (callback) {
		hookCallback = callback;
	}

	function isArray(input) {
		return Object.prototype.toString.call(input) === '[object Array]';
	}

	function isDate(input) {
		return input instanceof Date || Object.prototype.toString.call(input) === '[object Date]';
	}

	function map(arr, fn) {
		var res = [], i;
		for (i = 0; i < arr.length; ++i) {
			res.push(fn(arr[i], i));
		}
		return res;
	}

	function hasOwnProp(a, b) {
		return Object.prototype.hasOwnProperty.call(a, b);
	}

	function extend(a, b) {
		for (var i in b) {
			if (hasOwnProp(b, i)) {
				a[i] = b[i];
			}
		}

		if (hasOwnProp(b, 'toString')) {
			a.toString = b.toString;
		}

		if (hasOwnProp(b, 'valueOf')) {
			a.valueOf = b.valueOf;
		}

		return a;
	}

	function create_utc__createUTC (input, format, locale, strict) {
		return createLocalOrUTC(input, format, locale, strict, true).utc();
	}

	function defaultParsingFlags() {
		// We need to deep clone this object.
		return {
			empty           : false,
			unusedTokens    : [],
			unusedInput     : [],
			overflow        : -2,
			charsLeftOver   : 0,
			nullInput       : false,
			invalidMonth    : null,
			invalidFormat   : false,
			userInvalidated : false,
			iso             : false
		};
	}

	function getParsingFlags(m) {
		if (m._pf == null) {
			m._pf = defaultParsingFlags();
		}
		return m._pf;
	}

	function valid__isValid(m) {
		if (m._isValid == null) {
			var flags = getParsingFlags(m);
			m._isValid = !isNaN(m._d.getTime()) &&
				flags.overflow < 0 &&
				!flags.empty &&
				!flags.invalidMonth &&
				!flags.invalidWeekday &&
				!flags.nullInput &&
				!flags.invalidFormat &&
				!flags.userInvalidated;

			if (m._strict) {
				m._isValid = m._isValid &&
					flags.charsLeftOver === 0 &&
					flags.unusedTokens.length === 0 &&
					flags.bigHour === undefined;
			}
		}
		return m._isValid;
	}

	function valid__createInvalid (flags) {
		var m = create_utc__createUTC(NaN);
		if (flags != null) {
			extend(getParsingFlags(m), flags);
		}
		else {
			getParsingFlags(m).userInvalidated = true;
		}

		return m;
	}

	function isUndefined(input) {
		return input === void 0;
	}

	// Plugins that add properties should also add the key here (null value),
	// so we can properly clone ourselves.
	var momentProperties = utils_hooks__hooks.momentProperties = [];

	function copyConfig(to, from) {
		var i, prop, val;

		if (!isUndefined(from._isAMomentObject)) {
			to._isAMomentObject = from._isAMomentObject;
		}
		if (!isUndefined(from._i)) {
			to._i = from._i;
		}
		if (!isUndefined(from._f)) {
			to._f = from._f;
		}
		if (!isUndefined(from._l)) {
			to._l = from._l;
		}
		if (!isUndefined(from._strict)) {
			to._strict = from._strict;
		}
		if (!isUndefined(from._tzm)) {
			to._tzm = from._tzm;
		}
		if (!isUndefined(from._isUTC)) {
			to._isUTC = from._isUTC;
		}
		if (!isUndefined(from._offset)) {
			to._offset = from._offset;
		}
		if (!isUndefined(from._pf)) {
			to._pf = getParsingFlags(from);
		}
		if (!isUndefined(from._locale)) {
			to._locale = from._locale;
		}

		if (momentProperties.length > 0) {
			for (i in momentProperties) {
				prop = momentProperties[i];
				val = from[prop];
				if (!isUndefined(val)) {
					to[prop] = val;
				}
			}
		}

		return to;
	}

	var updateInProgress = false;

	// Moment prototype object
	function Moment(config) {
		copyConfig(this, config);
		this._d = new Date(config._d != null ? config._d.getTime() : NaN);
		// Prevent infinite loop in case updateOffset creates new moment
		// objects.
		if (updateInProgress === false) {
			updateInProgress = true;
			utils_hooks__hooks.updateOffset(this);
			updateInProgress = false;
		}
	}

	function isMoment (obj) {
		return obj instanceof Moment || (obj != null && obj._isAMomentObject != null);
	}

	function absFloor (number) {
		if (number < 0) {
			return Math.ceil(number);
		} else {
			return Math.floor(number);
		}
	}

	function toInt(argumentForCoercion) {
		var coercedNumber = +argumentForCoercion,
			value = 0;

		if (coercedNumber !== 0 && isFinite(coercedNumber)) {
			value = absFloor(coercedNumber);
		}

		return value;
	}

	// compare two arrays, return the number of differences
	function compareArrays(array1, array2, dontConvert) {
		var len = Math.min(array1.length, array2.length),
			lengthDiff = Math.abs(array1.length - array2.length),
			diffs = 0,
			i;
		for (i = 0; i < len; i++) {
			if ((dontConvert && array1[i] !== array2[i]) ||
				(!dontConvert && toInt(array1[i]) !== toInt(array2[i]))) {
				diffs++;
			}
		}
		return diffs + lengthDiff;
	}

	function Locale() {
	}

	// internal storage for locale config files
	var locales = {};
	var globalLocale;

	function normalizeLocale(key) {
		return key ? key.toLowerCase().replace('_', '-') : key;
	}

	// pick the locale from the array
	// try ['en-au', 'en-gb'] as 'en-au', 'en-gb', 'en', as in move through the list trying each
	// substring from most specific to least, but move to the next array item if it's a more specific variant than the current root
	function chooseLocale(names) {
		var i = 0, j, next, locale, split;

		while (i < names.length) {
			split = normalizeLocale(names[i]).split('-');
			j = split.length;
			next = normalizeLocale(names[i + 1]);
			next = next ? next.split('-') : null;
			while (j > 0) {
				locale = loadLocale(split.slice(0, j).join('-'));
				if (locale) {
					return locale;
				}
				if (next && next.length >= j && compareArrays(split, next, true) >= j - 1) {
					//the next array item is better than a shallower substring of this one
					break;
				}
				j--;
			}
			i++;
		}
		return null;
	}

	function loadLocale(name) {
		var oldLocale = null;
		// TODO: Find a better way to register and load all the locales in Node
		if (!locales[name] && (typeof module !== 'undefined') &&
				module && module.exports) {
			try {
				oldLocale = globalLocale._abbr;
				require('./locale/' + name);
				// because defineLocale currently also sets the global locale, we
				// want to undo that for lazy loaded locales
				locale_locales__getSetGlobalLocale(oldLocale);
			} catch (e) { }
		}
		return locales[name];
	}

	// This function will load locale and then set the global locale.  If
	// no arguments are passed in, it will simply return the current global
	// locale key.
	function locale_locales__getSetGlobalLocale (key, values) {
		var data;
		if (key) {
			if (isUndefined(values)) {
				data = locale_locales__getLocale(key);
			}
			else {
				data = defineLocale(key, values);
			}

			if (data) {
				// moment.duration._locale = moment._locale = data;
				globalLocale = data;
			}
		}

		return globalLocale._abbr;
	}

	function defineLocale (name, values) {
		if (values !== null) {
			values.abbr = name;
			locales[name] = locales[name] || new Locale();
			locales[name].set(values);

			// backwards compat for now: also set the locale
			locale_locales__getSetGlobalLocale(name);

			return locales[name];
		} else {
			// useful for testing
			delete locales[name];
			return null;
		}
	}

	// returns locale data
	function locale_locales__getLocale (key) {
		var locale;

		if (key && key._locale && key._locale._abbr) {
			key = key._locale._abbr;
		}

		if (!key) {
			return globalLocale;
		}

		if (!isArray(key)) {
			//short-circuit everything else
			locale = loadLocale(key);
			if (locale) {
				return locale;
			}
			key = [key];
		}

		return chooseLocale(key);
	}

	var aliases = {};

	function addUnitAlias (unit, shorthand) {
		var lowerCase = unit.toLowerCase();
		aliases[lowerCase] = aliases[lowerCase + 's'] = aliases[shorthand] = unit;
	}

	function normalizeUnits(units) {
		return typeof units === 'string' ? aliases[units] || aliases[units.toLowerCase()] : undefined;
	}

	function normalizeObjectUnits(inputObject) {
		var normalizedInput = {},
			normalizedProp,
			prop;

		for (prop in inputObject) {
			if (hasOwnProp(inputObject, prop)) {
				normalizedProp = normalizeUnits(prop);
				if (normalizedProp) {
					normalizedInput[normalizedProp] = inputObject[prop];
				}
			}
		}

		return normalizedInput;
	}

	function isFunction(input) {
		return input instanceof Function || Object.prototype.toString.call(input) === '[object Function]';
	}

	function makeGetSet (unit, keepTime) {
		return function (value) {
			if (value != null) {
				get_set__set(this, unit, value);
				utils_hooks__hooks.updateOffset(this, keepTime);
				return this;
			} else {
				return get_set__get(this, unit);
			}
		};
	}

	function get_set__get (mom, unit) {
		return mom.isValid() ?
			mom._d['get' + (mom._isUTC ? 'UTC' : '') + unit]() : NaN;
	}

	function get_set__set (mom, unit, value) {
		if (mom.isValid()) {
			mom._d['set' + (mom._isUTC ? 'UTC' : '') + unit](value);
		}
	}

	// MOMENTS

	function getSet (units, value) {
		var unit;
		if (typeof units === 'object') {
			for (unit in units) {
				this.set(unit, units[unit]);
			}
		} else {
			units = normalizeUnits(units);
			if (isFunction(this[units])) {
				return this[units](value);
			}
		}
		return this;
	}

	function zeroFill(number, targetLength, forceSign) {
		var absNumber = '' + Math.abs(number),
			zerosToFill = targetLength - absNumber.length,
			sign = number >= 0;
		return (sign ? (forceSign ? '+' : '') : '-') +
			Math.pow(10, Math.max(0, zerosToFill)).toString().substr(1) + absNumber;
	}

	var formattingTokens = /(\[[^\[]*\])|(\\)?([Hh]mm(ss)?|Mo|MM?M?M?|Do|DDDo|DD?D?D?|ddd?d?|do?|w[o|w]?|W[o|W]?|Qo?|YYYYYY|YYYYY|YYYY|YY|gg(ggg?)?|GG(GGG?)?|e|E|a|A|hh?|HH?|mm?|ss?|S{1,9}|x|X|zz?|ZZ?|.)/g;

	var localFormattingTokens = /(\[[^\[]*\])|(\\)?(LTS|LT|LL?L?L?|l{1,4})/g;

	var formatFunctions = {};

	var formatTokenFunctions = {};

	// token:    'M'
	// padded:   ['MM', 2]
	// ordinal:  'Mo'
	// callback: function () { this.month() + 1 }
	function addFormatToken (token, padded, ordinal, callback) {
		var func = callback;
		if (typeof callback === 'string') {
			func = function () {
				return this[callback]();
			};
		}
		if (token) {
			formatTokenFunctions[token] = func;
		}
		if (padded) {
			formatTokenFunctions[padded[0]] = function () {
				return zeroFill(func.apply(this, arguments), padded[1], padded[2]);
			};
		}
		if (ordinal) {
			formatTokenFunctions[ordinal] = function () {
				return this.localeData().ordinal(func.apply(this, arguments), token);
			};
		}
	}

	function removeFormattingTokens(input) {
		if (input.match(/\[[\s\S]/)) {
			return input.replace(/^\[|\]$/g, '');
		}
		return input.replace(/\\/g, '');
	}

	function makeFormatFunction(format) {
		var array = format.match(formattingTokens), i, length;

		for (i = 0, length = array.length; i < length; i++) {
			if (formatTokenFunctions[array[i]]) {
				array[i] = formatTokenFunctions[array[i]];
			} else {
				array[i] = removeFormattingTokens(array[i]);
			}
		}

		return function (mom) {
			var output = '';
			for (i = 0; i < length; i++) {
				output += array[i] instanceof Function ? array[i].call(mom, format) : array[i];
			}
			return output;
		};
	}

	// format date using native date object
	function formatMoment(m, format) {
		if (!m.isValid()) {
			return m.localeData().invalidDate();
		}

		format = expandFormat(format, m.localeData());
		formatFunctions[format] = formatFunctions[format] || makeFormatFunction(format);

		return formatFunctions[format](m);
	}

	function expandFormat(format, locale) {
		var i = 5;

		function replaceLongDateFormatTokens(input) {
			return locale.longDateFormat(input) || input;
		}

		localFormattingTokens.lastIndex = 0;
		while (i >= 0 && localFormattingTokens.test(format)) {
			format = format.replace(localFormattingTokens, replaceLongDateFormatTokens);
			localFormattingTokens.lastIndex = 0;
			i -= 1;
		}

		return format;
	}

	var match1         = /\d/;            //       0 - 9
	var match2         = /\d\d/;          //      00 - 99
	var match3         = /\d{3}/;         //     000 - 999
	var match4         = /\d{4}/;         //    0000 - 9999
	var match6         = /[+-]?\d{6}/;    // -999999 - 999999
	var match1to2      = /\d\d?/;         //       0 - 99
	var match3to4      = /\d\d\d\d?/;     //     999 - 9999
	var match5to6      = /\d\d\d\d\d\d?/; //   99999 - 999999
	var match1to3      = /\d{1,3}/;       //       0 - 999
	var match1to4      = /\d{1,4}/;       //       0 - 9999
	var match1to6      = /[+-]?\d{1,6}/;  // -999999 - 999999

	var matchUnsigned  = /\d+/;           //       0 - inf
	var matchSigned    = /[+-]?\d+/;      //    -inf - inf

	var matchOffset    = /Z|[+-]\d\d:?\d\d/gi; // +00:00 -00:00 +0000 -0000 or Z
	var matchShortOffset = /Z|[+-]\d\d(?::?\d\d)?/gi; // +00 -00 +00:00 -00:00 +0000 -0000 or Z

	var matchTimestamp = /[+-]?\d+(\.\d{1,3})?/; // 123456789 123456789.123

	// any word (or two) characters or numbers including two/three word month in arabic.
	// includes scottish gaelic two word and hyphenated months
	var matchWord = /[0-9]*['a-z\u00A0-\u05FF\u0700-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]+|[\u0600-\u06FF\/]+(\s*?[\u0600-\u06FF]+){1,2}/i;


	var regexes = {};

	function addRegexToken (token, regex, strictRegex) {
		regexes[token] = isFunction(regex) ? regex : function (isStrict, localeData) {
			return (isStrict && strictRegex) ? strictRegex : regex;
		};
	}

	function getParseRegexForToken (token, config) {
		if (!hasOwnProp(regexes, token)) {
			return new RegExp(unescapeFormat(token));
		}

		return regexes[token](config._strict, config._locale);
	}

	// Code from http://stackoverflow.com/questions/3561493/is-there-a-regexp-escape-function-in-javascript
	function unescapeFormat(s) {
		return regexEscape(s.replace('\\', '').replace(/\\(\[)|\\(\])|\[([^\]\[]*)\]|\\(.)/g, function (matched, p1, p2, p3, p4) {
			return p1 || p2 || p3 || p4;
		}));
	}

	function regexEscape(s) {
		return s.replace(/[-\/\\^$*+?.()|[\]{}]/g, '\\$&');
	}

	var tokens = {};

	function addParseToken (token, callback) {
		var i, func = callback;
		if (typeof token === 'string') {
			token = [token];
		}
		if (typeof callback === 'number') {
			func = function (input, array) {
				array[callback] = toInt(input);
			};
		}
		for (i = 0; i < token.length; i++) {
			tokens[token[i]] = func;
		}
	}

	function addWeekParseToken (token, callback) {
		addParseToken(token, function (input, array, config, token) {
			config._w = config._w || {};
			callback(input, config._w, config, token);
		});
	}

	function addTimeToArrayFromToken(token, input, config) {
		if (input != null && hasOwnProp(tokens, token)) {
			tokens[token](input, config._a, config, token);
		}
	}

	var YEAR = 0;
	var MONTH = 1;
	var DATE = 2;
	var HOUR = 3;
	var MINUTE = 4;
	var SECOND = 5;
	var MILLISECOND = 6;
	var WEEK = 7;
	var WEEKDAY = 8;

	function daysInMonth(year, month) {
		return new Date(Date.UTC(year, month + 1, 0)).getUTCDate();
	}

	// FORMATTING

	addFormatToken('M', ['MM', 2], 'Mo', function () {
		return this.month() + 1;
	});

	addFormatToken('MMM', 0, 0, function (format) {
		return this.localeData().monthsShort(this, format);
	});

	addFormatToken('MMMM', 0, 0, function (format) {
		return this.localeData().months(this, format);
	});

	// ALIASES

	addUnitAlias('month', 'M');

	// PARSING

	addRegexToken('M',    match1to2);
	addRegexToken('MM',   match1to2, match2);
	addRegexToken('MMM',  function (isStrict, locale) {
		return locale.monthsShortRegex(isStrict);
	});
	addRegexToken('MMMM', function (isStrict, locale) {
		return locale.monthsRegex(isStrict);
	});

	addParseToken(['M', 'MM'], function (input, array) {
		array[MONTH] = toInt(input) - 1;
	});

	addParseToken(['MMM', 'MMMM'], function (input, array, config, token) {
		var month = config._locale.monthsParse(input, token, config._strict);
		// if we didn't find a month name, mark the date as invalid.
		if (month != null) {
			array[MONTH] = month;
		} else {
			getParsingFlags(config).invalidMonth = input;
		}
	});

	// LOCALES

	var MONTHS_IN_FORMAT = /D[oD]?(\[[^\[\]]*\]|\s+)+MMMM?/;
	var defaultLocaleMonths = 'January_February_March_April_May_June_July_August_September_October_November_December'.split('_');
	function localeMonths (m, format) {
		return isArray(this._months) ? this._months[m.month()] :
			this._months[MONTHS_IN_FORMAT.test(format) ? 'format' : 'standalone'][m.month()];
	}

	var defaultLocaleMonthsShort = 'Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec'.split('_');
	function localeMonthsShort (m, format) {
		return isArray(this._monthsShort) ? this._monthsShort[m.month()] :
			this._monthsShort[MONTHS_IN_FORMAT.test(format) ? 'format' : 'standalone'][m.month()];
	}

	function localeMonthsParse (monthName, format, strict) {
		var i, mom, regex;

		if (!this._monthsParse) {
			this._monthsParse = [];
			this._longMonthsParse = [];
			this._shortMonthsParse = [];
		}

		for (i = 0; i < 12; i++) {
			// make the regex if we don't have it already
			mom = create_utc__createUTC([2000, i]);
			if (strict && !this._longMonthsParse[i]) {
				this._longMonthsParse[i] = new RegExp('^' + this.months(mom, '').replace('.', '') + '$', 'i');
				this._shortMonthsParse[i] = new RegExp('^' + this.monthsShort(mom, '').replace('.', '') + '$', 'i');
			}
			if (!strict && !this._monthsParse[i]) {
				regex = '^' + this.months(mom, '') + '|^' + this.monthsShort(mom, '');
				this._monthsParse[i] = new RegExp(regex.replace('.', ''), 'i');
			}
			// test the regex
			if (strict && format === 'MMMM' && this._longMonthsParse[i].test(monthName)) {
				return i;
			} else if (strict && format === 'MMM' && this._shortMonthsParse[i].test(monthName)) {
				return i;
			} else if (!strict && this._monthsParse[i].test(monthName)) {
				return i;
			}
		}
	}

	// MOMENTS

	function setMonth (mom, value) {
		var dayOfMonth;

		if (!mom.isValid()) {
			// No op
			return mom;
		}

		// TODO: Move this out of here!
		if (typeof value === 'string') {
			value = mom.localeData().monthsParse(value);
			// TODO: Another silent failure?
			if (typeof value !== 'number') {
				return mom;
			}
		}

		dayOfMonth = Math.min(mom.date(), daysInMonth(mom.year(), value));
		mom._d['set' + (mom._isUTC ? 'UTC' : '') + 'Month'](value, dayOfMonth);
		return mom;
	}

	function getSetMonth (value) {
		if (value != null) {
			setMonth(this, value);
			utils_hooks__hooks.updateOffset(this, true);
			return this;
		} else {
			return get_set__get(this, 'Month');
		}
	}

	function getDaysInMonth () {
		return daysInMonth(this.year(), this.month());
	}

	var defaultMonthsShortRegex = matchWord;
	function monthsShortRegex (isStrict) {
		if (this._monthsParseExact) {
			if (!hasOwnProp(this, '_monthsRegex')) {
				computeMonthsParse.call(this);
			}
			if (isStrict) {
				return this._monthsShortStrictRegex;
			} else {
				return this._monthsShortRegex;
			}
		} else {
			return this._monthsShortStrictRegex && isStrict ?
				this._monthsShortStrictRegex : this._monthsShortRegex;
		}
	}

	var defaultMonthsRegex = matchWord;
	function monthsRegex (isStrict) {
		if (this._monthsParseExact) {
			if (!hasOwnProp(this, '_monthsRegex')) {
				computeMonthsParse.call(this);
			}
			if (isStrict) {
				return this._monthsStrictRegex;
			} else {
				return this._monthsRegex;
			}
		} else {
			return this._monthsStrictRegex && isStrict ?
				this._monthsStrictRegex : this._monthsRegex;
		}
	}

	function computeMonthsParse () {
		function cmpLenRev(a, b) {
			return b.length - a.length;
		}

		var shortPieces = [], longPieces = [], mixedPieces = [],
			i, mom;
		for (i = 0; i < 12; i++) {
			// make the regex if we don't have it already
			mom = create_utc__createUTC([2000, i]);
			shortPieces.push(this.monthsShort(mom, ''));
			longPieces.push(this.months(mom, ''));
			mixedPieces.push(this.months(mom, ''));
			mixedPieces.push(this.monthsShort(mom, ''));
		}
		// Sorting makes sure if one month (or abbr) is a prefix of another it
		// will match the longer piece.
		shortPieces.sort(cmpLenRev);
		longPieces.sort(cmpLenRev);
		mixedPieces.sort(cmpLenRev);
		for (i = 0; i < 12; i++) {
			shortPieces[i] = regexEscape(shortPieces[i]);
			longPieces[i] = regexEscape(longPieces[i]);
			mixedPieces[i] = regexEscape(mixedPieces[i]);
		}

		this._monthsRegex = new RegExp('^(' + mixedPieces.join('|') + ')', 'i');
		this._monthsShortRegex = this._monthsRegex;
		this._monthsStrictRegex = new RegExp('^(' + longPieces.join('|') + ')$', 'i');
		this._monthsShortStrictRegex = new RegExp('^(' + shortPieces.join('|') + ')$', 'i');
	}

	function checkOverflow (m) {
		var overflow;
		var a = m._a;

		if (a && getParsingFlags(m).overflow === -2) {
			overflow =
				a[MONTH]       < 0 || a[MONTH]       > 11  ? MONTH :
				a[DATE]        < 1 || a[DATE]        > daysInMonth(a[YEAR], a[MONTH]) ? DATE :
				a[HOUR]        < 0 || a[HOUR]        > 24 || (a[HOUR] === 24 && (a[MINUTE] !== 0 || a[SECOND] !== 0 || a[MILLISECOND] !== 0)) ? HOUR :
				a[MINUTE]      < 0 || a[MINUTE]      > 59  ? MINUTE :
				a[SECOND]      < 0 || a[SECOND]      > 59  ? SECOND :
				a[MILLISECOND] < 0 || a[MILLISECOND] > 999 ? MILLISECOND :
				-1;

			if (getParsingFlags(m)._overflowDayOfYear && (overflow < YEAR || overflow > DATE)) {
				overflow = DATE;
			}
			if (getParsingFlags(m)._overflowWeeks && overflow === -1) {
				overflow = WEEK;
			}
			if (getParsingFlags(m)._overflowWeekday && overflow === -1) {
				overflow = WEEKDAY;
			}

			getParsingFlags(m).overflow = overflow;
		}

		return m;
	}

	function warn(msg) {
		if (utils_hooks__hooks.suppressDeprecationWarnings === false &&
				(typeof console !==  'undefined') && console.warn) {
			console.warn('Deprecation warning: ' + msg);
		}
	}

	function deprecate(msg, fn) {
		var firstTime = true;

		return extend(function () {
			if (firstTime) {
				warn(msg + '\nArguments: ' + Array.prototype.slice.call(arguments).join(', ') + '\n' + (new Error()).stack);
				firstTime = false;
			}
			return fn.apply(this, arguments);
		}, fn);
	}

	var deprecations = {};

	function deprecateSimple(name, msg) {
		if (!deprecations[name]) {
			warn(msg);
			deprecations[name] = true;
		}
	}

	utils_hooks__hooks.suppressDeprecationWarnings = false;

	// iso 8601 regex
	// 0000-00-00 0000-W00 or 0000-W00-0 + T + 00 or 00:00 or 00:00:00 or 00:00:00.000 + +00:00 or +0000 or +00)
	var extendedIsoRegex = /^\s*((?:[+-]\d{6}|\d{4})-(?:\d\d-\d\d|W\d\d-\d|W\d\d|\d\d\d|\d\d))(?:(T| )(\d\d(?::\d\d(?::\d\d(?:[.,]\d+)?)?)?)([\+\-]\d\d(?::?\d\d)?|\s*Z)?)?/;
	var basicIsoRegex = /^\s*((?:[+-]\d{6}|\d{4})(?:\d\d\d\d|W\d\d\d|W\d\d|\d\d\d|\d\d))(?:(T| )(\d\d(?:\d\d(?:\d\d(?:[.,]\d+)?)?)?)([\+\-]\d\d(?::?\d\d)?|\s*Z)?)?/;

	var tzRegex = /Z|[+-]\d\d(?::?\d\d)?/;

	var isoDates = [
		['YYYYYY-MM-DD', /[+-]\d{6}-\d\d-\d\d/],
		['YYYY-MM-DD', /\d{4}-\d\d-\d\d/],
		['GGGG-[W]WW-E', /\d{4}-W\d\d-\d/],
		['GGGG-[W]WW', /\d{4}-W\d\d/, false],
		['YYYY-DDD', /\d{4}-\d{3}/],
		['YYYY-MM', /\d{4}-\d\d/, false],
		['YYYYYYMMDD', /[+-]\d{10}/],
		['YYYYMMDD', /\d{8}/],
		// YYYYMM is NOT allowed by the standard
		['GGGG[W]WWE', /\d{4}W\d{3}/],
		['GGGG[W]WW', /\d{4}W\d{2}/, false],
		['YYYYDDD', /\d{7}/]
	];

	// iso time formats and regexes
	var isoTimes = [
		['HH:mm:ss.SSSS', /\d\d:\d\d:\d\d\.\d+/],
		['HH:mm:ss,SSSS', /\d\d:\d\d:\d\d,\d+/],
		['HH:mm:ss', /\d\d:\d\d:\d\d/],
		['HH:mm', /\d\d:\d\d/],
		['HHmmss.SSSS', /\d\d\d\d\d\d\.\d+/],
		['HHmmss,SSSS', /\d\d\d\d\d\d,\d+/],
		['HHmmss', /\d\d\d\d\d\d/],
		['HHmm', /\d\d\d\d/],
		['HH', /\d\d/]
	];

	var aspNetJsonRegex = /^\/?Date\((\-?\d+)/i;

	// date from iso format
	function configFromISO(config) {
		var i, l,
			string = config._i,
			match = extendedIsoRegex.exec(string) || basicIsoRegex.exec(string),
			allowTime, dateFormat, timeFormat, tzFormat;

		if (match) {
			getParsingFlags(config).iso = true;

			for (i = 0, l = isoDates.length; i < l; i++) {
				if (isoDates[i][1].exec(match[1])) {
					dateFormat = isoDates[i][0];
					allowTime = isoDates[i][2] !== false;
					break;
				}
			}
			if (dateFormat == null) {
				config._isValid = false;
				return;
			}
			if (match[3]) {
				for (i = 0, l = isoTimes.length; i < l; i++) {
					if (isoTimes[i][1].exec(match[3])) {
						// match[2] should be 'T' or space
						timeFormat = (match[2] || ' ') + isoTimes[i][0];
						break;
					}
				}
				if (timeFormat == null) {
					config._isValid = false;
					return;
				}
			}
			if (!allowTime && timeFormat != null) {
				config._isValid = false;
				return;
			}
			if (match[4]) {
				if (tzRegex.exec(match[4])) {
					tzFormat = 'Z';
				} else {
					config._isValid = false;
					return;
				}
			}
			config._f = dateFormat + (timeFormat || '') + (tzFormat || '');
			configFromStringAndFormat(config);
		} else {
			config._isValid = false;
		}
	}

	// date from iso format or fallback
	function configFromString(config) {
		var matched = aspNetJsonRegex.exec(config._i);

		if (matched !== null) {
			config._d = new Date(+matched[1]);
			return;
		}

		configFromISO(config);
		if (config._isValid === false) {
			delete config._isValid;
			utils_hooks__hooks.createFromInputFallback(config);
		}
	}

	utils_hooks__hooks.createFromInputFallback = deprecate(
		'moment construction falls back to js Date. This is ' +
		'discouraged and will be removed in upcoming major ' +
		'release. Please refer to ' +
		'https://github.com/moment/moment/issues/1407 for more info.',
		function (config) {
			config._d = new Date(config._i + (config._useUTC ? ' UTC' : ''));
		}
	);

	function createDate (y, m, d, h, M, s, ms) {
		//can't just apply() to create a date:
		//http://stackoverflow.com/questions/181348/instantiating-a-javascript-object-by-calling-prototype-constructor-apply
		var date = new Date(y, m, d, h, M, s, ms);

		//the date constructor remaps years 0-99 to 1900-1999
		if (y < 100 && y >= 0 && isFinite(date.getFullYear())) {
			date.setFullYear(y);
		}
		return date;
	}

	function createUTCDate (y) {
		var date = new Date(Date.UTC.apply(null, arguments));

		//the Date.UTC function remaps years 0-99 to 1900-1999
		if (y < 100 && y >= 0 && isFinite(date.getUTCFullYear())) {
			date.setUTCFullYear(y);
		}
		return date;
	}

	// FORMATTING

	addFormatToken('Y', 0, 0, function () {
		var y = this.year();
		return y <= 9999 ? '' + y : '+' + y;
	});

	addFormatToken(0, ['YY', 2], 0, function () {
		return this.year() % 100;
	});

	addFormatToken(0, ['YYYY',   4],       0, 'year');
	addFormatToken(0, ['YYYYY',  5],       0, 'year');
	addFormatToken(0, ['YYYYYY', 6, true], 0, 'year');

	// ALIASES

	addUnitAlias('year', 'y');

	// PARSING

	addRegexToken('Y',      matchSigned);
	addRegexToken('YY',     match1to2, match2);
	addRegexToken('YYYY',   match1to4, match4);
	addRegexToken('YYYYY',  match1to6, match6);
	addRegexToken('YYYYYY', match1to6, match6);

	addParseToken(['YYYYY', 'YYYYYY'], YEAR);
	addParseToken('YYYY', function (input, array) {
		array[YEAR] = input.length === 2 ? utils_hooks__hooks.parseTwoDigitYear(input) : toInt(input);
	});
	addParseToken('YY', function (input, array) {
		array[YEAR] = utils_hooks__hooks.parseTwoDigitYear(input);
	});
	addParseToken('Y', function (input, array) {
		array[YEAR] = parseInt(input, 10);
	});

	// HELPERS

	function daysInYear(year) {
		return isLeapYear(year) ? 366 : 365;
	}

	function isLeapYear(year) {
		return (year % 4 === 0 && year % 100 !== 0) || year % 400 === 0;
	}

	// HOOKS

	utils_hooks__hooks.parseTwoDigitYear = function (input) {
		return toInt(input) + (toInt(input) > 68 ? 1900 : 2000);
	};

	// MOMENTS

	var getSetYear = makeGetSet('FullYear', false);

	function getIsLeapYear () {
		return isLeapYear(this.year());
	}

	// start-of-first-week - start-of-year
	function firstWeekOffset(year, dow, doy) {
		var // first-week day -- which january is always in the first week (4 for iso, 1 for other)
			fwd = 7 + dow - doy,
			// first-week day local weekday -- which local weekday is fwd
			fwdlw = (7 + createUTCDate(year, 0, fwd).getUTCDay() - dow) % 7;

		return -fwdlw + fwd - 1;
	}

	//http://en.wikipedia.org/wiki/ISO_week_date#Calculating_a_date_given_the_year.2C_week_number_and_weekday
	function dayOfYearFromWeeks(year, week, weekday, dow, doy) {
		var localWeekday = (7 + weekday - dow) % 7,
			weekOffset = firstWeekOffset(year, dow, doy),
			dayOfYear = 1 + 7 * (week - 1) + localWeekday + weekOffset,
			resYear, resDayOfYear;

		if (dayOfYear <= 0) {
			resYear = year - 1;
			resDayOfYear = daysInYear(resYear) + dayOfYear;
		} else if (dayOfYear > daysInYear(year)) {
			resYear = year + 1;
			resDayOfYear = dayOfYear - daysInYear(year);
		} else {
			resYear = year;
			resDayOfYear = dayOfYear;
		}

		return {
			year: resYear,
			dayOfYear: resDayOfYear
		};
	}

	function weekOfYear(mom, dow, doy) {
		var weekOffset = firstWeekOffset(mom.year(), dow, doy),
			week = Math.floor((mom.dayOfYear() - weekOffset - 1) / 7) + 1,
			resWeek, resYear;

		if (week < 1) {
			resYear = mom.year() - 1;
			resWeek = week + weeksInYear(resYear, dow, doy);
		} else if (week > weeksInYear(mom.year(), dow, doy)) {
			resWeek = week - weeksInYear(mom.year(), dow, doy);
			resYear = mom.year() + 1;
		} else {
			resYear = mom.year();
			resWeek = week;
		}

		return {
			week: resWeek,
			year: resYear
		};
	}

	function weeksInYear(year, dow, doy) {
		var weekOffset = firstWeekOffset(year, dow, doy),
			weekOffsetNext = firstWeekOffset(year + 1, dow, doy);
		return (daysInYear(year) - weekOffset + weekOffsetNext) / 7;
	}

	// Pick the first defined of two or three arguments.
	function defaults(a, b, c) {
		if (a != null) {
			return a;
		}
		if (b != null) {
			return b;
		}
		return c;
	}

	function currentDateArray(config) {
		// hooks is actually the exported moment object
		var nowValue = new Date(utils_hooks__hooks.now());
		if (config._useUTC) {
			return [nowValue.getUTCFullYear(), nowValue.getUTCMonth(), nowValue.getUTCDate()];
		}
		return [nowValue.getFullYear(), nowValue.getMonth(), nowValue.getDate()];
	}

	// convert an array to a date.
	// the array should mirror the parameters below
	// note: all values past the year are optional and will default to the lowest possible value.
	// [year, month, day , hour, minute, second, millisecond]
	function configFromArray (config) {
		var i, date, input = [], currentDate, yearToUse;

		if (config._d) {
			return;
		}

		currentDate = currentDateArray(config);

		//compute day of the year from weeks and weekdays
		if (config._w && config._a[DATE] == null && config._a[MONTH] == null) {
			dayOfYearFromWeekInfo(config);
		}

		//if the day of the year is set, figure out what it is
		if (config._dayOfYear) {
			yearToUse = defaults(config._a[YEAR], currentDate[YEAR]);

			if (config._dayOfYear > daysInYear(yearToUse)) {
				getParsingFlags(config)._overflowDayOfYear = true;
			}

			date = createUTCDate(yearToUse, 0, config._dayOfYear);
			config._a[MONTH] = date.getUTCMonth();
			config._a[DATE] = date.getUTCDate();
		}

		// Default to current date.
		// * if no year, month, day of month are given, default to today
		// * if day of month is given, default month and year
		// * if month is given, default only year
		// * if year is given, don't default anything
		for (i = 0; i < 3 && config._a[i] == null; ++i) {
			config._a[i] = input[i] = currentDate[i];
		}

		// Zero out whatever was not defaulted, including time
		for (; i < 7; i++) {
			config._a[i] = input[i] = (config._a[i] == null) ? (i === 2 ? 1 : 0) : config._a[i];
		}

		// Check for 24:00:00.000
		if (config._a[HOUR] === 24 &&
				config._a[MINUTE] === 0 &&
				config._a[SECOND] === 0 &&
				config._a[MILLISECOND] === 0) {
			config._nextDay = true;
			config._a[HOUR] = 0;
		}

		config._d = (config._useUTC ? createUTCDate : createDate).apply(null, input);
		// Apply timezone offset from input. The actual utcOffset can be changed
		// with parseZone.
		if (config._tzm != null) {
			config._d.setUTCMinutes(config._d.getUTCMinutes() - config._tzm);
		}

		if (config._nextDay) {
			config._a[HOUR] = 24;
		}
	}

	function dayOfYearFromWeekInfo(config) {
		var w, weekYear, week, weekday, dow, doy, temp, weekdayOverflow;

		w = config._w;
		if (w.GG != null || w.W != null || w.E != null) {
			dow = 1;
			doy = 4;

			// TODO: We need to take the current isoWeekYear, but that depends on
			// how we interpret now (local, utc, fixed offset). So create
			// a now version of current config (take local/utc/offset flags, and
			// create now).
			weekYear = defaults(w.GG, config._a[YEAR], weekOfYear(local__createLocal(), 1, 4).year);
			week = defaults(w.W, 1);
			weekday = defaults(w.E, 1);
			if (weekday < 1 || weekday > 7) {
				weekdayOverflow = true;
			}
		} else {
			dow = config._locale._week.dow;
			doy = config._locale._week.doy;

			weekYear = defaults(w.gg, config._a[YEAR], weekOfYear(local__createLocal(), dow, doy).year);
			week = defaults(w.w, 1);

			if (w.d != null) {
				// weekday -- low day numbers are considered next week
				weekday = w.d;
				if (weekday < 0 || weekday > 6) {
					weekdayOverflow = true;
				}
			} else if (w.e != null) {
				// local weekday -- counting starts from begining of week
				weekday = w.e + dow;
				if (w.e < 0 || w.e > 6) {
					weekdayOverflow = true;
				}
			} else {
				// default to begining of week
				weekday = dow;
			}
		}
		if (week < 1 || week > weeksInYear(weekYear, dow, doy)) {
			getParsingFlags(config)._overflowWeeks = true;
		} else if (weekdayOverflow != null) {
			getParsingFlags(config)._overflowWeekday = true;
		} else {
			temp = dayOfYearFromWeeks(weekYear, week, weekday, dow, doy);
			config._a[YEAR] = temp.year;
			config._dayOfYear = temp.dayOfYear;
		}
	}

	// constant that refers to the ISO standard
	utils_hooks__hooks.ISO_8601 = function () {};

	// date from string and format string
	function configFromStringAndFormat(config) {
		// TODO: Move this to another part of the creation flow to prevent circular deps
		if (config._f === utils_hooks__hooks.ISO_8601) {
			configFromISO(config);
			return;
		}

		config._a = [];
		getParsingFlags(config).empty = true;

		// This array is used to make a Date, either with `new Date` or `Date.UTC`
		var string = '' + config._i,
			i, parsedInput, tokens, token, skipped,
			stringLength = string.length,
			totalParsedInputLength = 0;

		tokens = expandFormat(config._f, config._locale).match(formattingTokens) || [];

		for (i = 0; i < tokens.length; i++) {
			token = tokens[i];
			parsedInput = (string.match(getParseRegexForToken(token, config)) || [])[0];
			// console.log('token', token, 'parsedInput', parsedInput,
			//         'regex', getParseRegexForToken(token, config));
			if (parsedInput) {
				skipped = string.substr(0, string.indexOf(parsedInput));
				if (skipped.length > 0) {
					getParsingFlags(config).unusedInput.push(skipped);
				}
				string = string.slice(string.indexOf(parsedInput) + parsedInput.length);
				totalParsedInputLength += parsedInput.length;
			}
			// don't parse if it's not a known token
			if (formatTokenFunctions[token]) {
				if (parsedInput) {
					getParsingFlags(config).empty = false;
				}
				else {
					getParsingFlags(config).unusedTokens.push(token);
				}
				addTimeToArrayFromToken(token, parsedInput, config);
			}
			else if (config._strict && !parsedInput) {
				getParsingFlags(config).unusedTokens.push(token);
			}
		}

		// add remaining unparsed input length to the string
		getParsingFlags(config).charsLeftOver = stringLength - totalParsedInputLength;
		if (string.length > 0) {
			getParsingFlags(config).unusedInput.push(string);
		}

		// clear _12h flag if hour is <= 12
		if (getParsingFlags(config).bigHour === true &&
				config._a[HOUR] <= 12 &&
				config._a[HOUR] > 0) {
			getParsingFlags(config).bigHour = undefined;
		}
		// handle meridiem
		config._a[HOUR] = meridiemFixWrap(config._locale, config._a[HOUR], config._meridiem);

		configFromArray(config);
		checkOverflow(config);
	}


	function meridiemFixWrap (locale, hour, meridiem) {
		var isPm;

		if (meridiem == null) {
			// nothing to do
			return hour;
		}
		if (locale.meridiemHour != null) {
			return locale.meridiemHour(hour, meridiem);
		} else if (locale.isPM != null) {
			// Fallback
			isPm = locale.isPM(meridiem);
			if (isPm && hour < 12) {
				hour += 12;
			}
			if (!isPm && hour === 12) {
				hour = 0;
			}
			return hour;
		} else {
			// this is not supposed to happen
			return hour;
		}
	}

	// date from string and array of format strings
	function configFromStringAndArray(config) {
		var tempConfig,
			bestMoment,

			scoreToBeat,
			i,
			currentScore;

		if (config._f.length === 0) {
			getParsingFlags(config).invalidFormat = true;
			config._d = new Date(NaN);
			return;
		}

		for (i = 0; i < config._f.length; i++) {
			currentScore = 0;
			tempConfig = copyConfig({}, config);
			if (config._useUTC != null) {
				tempConfig._useUTC = config._useUTC;
			}
			tempConfig._f = config._f[i];
			configFromStringAndFormat(tempConfig);

			if (!valid__isValid(tempConfig)) {
				continue;
			}

			// if there is any input that was not parsed add a penalty for that format
			currentScore += getParsingFlags(tempConfig).charsLeftOver;

			//or tokens
			currentScore += getParsingFlags(tempConfig).unusedTokens.length * 10;

			getParsingFlags(tempConfig).score = currentScore;

			if (scoreToBeat == null || currentScore < scoreToBeat) {
				scoreToBeat = currentScore;
				bestMoment = tempConfig;
			}
		}

		extend(config, bestMoment || tempConfig);
	}

	function configFromObject(config) {
		if (config._d) {
			return;
		}

		var i = normalizeObjectUnits(config._i);
		config._a = map([i.year, i.month, i.day || i.date, i.hour, i.minute, i.second, i.millisecond], function (obj) {
			return obj && parseInt(obj, 10);
		});

		configFromArray(config);
	}

	function createFromConfig (config) {
		var res = new Moment(checkOverflow(prepareConfig(config)));
		if (res._nextDay) {
			// Adding is smart enough around DST
			res.add(1, 'd');
			res._nextDay = undefined;
		}

		return res;
	}

	function prepareConfig (config) {
		var input = config._i,
			format = config._f;

		config._locale = config._locale || locale_locales__getLocale(config._l);

		if (input === null || (format === undefined && input === '')) {
			return valid__createInvalid({nullInput: true});
		}

		if (typeof input === 'string') {
			config._i = input = config._locale.preparse(input);
		}

		if (isMoment(input)) {
			return new Moment(checkOverflow(input));
		} else if (isArray(format)) {
			configFromStringAndArray(config);
		} else if (format) {
			configFromStringAndFormat(config);
		} else if (isDate(input)) {
			config._d = input;
		} else {
			configFromInput(config);
		}

		if (!valid__isValid(config)) {
			config._d = null;
		}

		return config;
	}

	function configFromInput(config) {
		var input = config._i;
		if (input === undefined) {
			config._d = new Date(utils_hooks__hooks.now());
		} else if (isDate(input)) {
			config._d = new Date(+input);
		} else if (typeof input === 'string') {
			configFromString(config);
		} else if (isArray(input)) {
			config._a = map(input.slice(0), function (obj) {
				return parseInt(obj, 10);
			});
			configFromArray(config);
		} else if (typeof(input) === 'object') {
			configFromObject(config);
		} else if (typeof(input) === 'number') {
			// from milliseconds
			config._d = new Date(input);
		} else {
			utils_hooks__hooks.createFromInputFallback(config);
		}
	}

	function createLocalOrUTC (input, format, locale, strict, isUTC) {
		var c = {};

		if (typeof(locale) === 'boolean') {
			strict = locale;
			locale = undefined;
		}
		// object construction must be done this way.
		// https://github.com/moment/moment/issues/1423
		c._isAMomentObject = true;
		c._useUTC = c._isUTC = isUTC;
		c._l = locale;
		c._i = input;
		c._f = format;
		c._strict = strict;

		return createFromConfig(c);
	}

	function local__createLocal (input, format, locale, strict) {
		return createLocalOrUTC(input, format, locale, strict, false);
	}

	var prototypeMin = deprecate(
		 'moment().min is deprecated, use moment.min instead. https://github.com/moment/moment/issues/1548',
		 function () {
			 var other = local__createLocal.apply(null, arguments);
			 if (this.isValid() && other.isValid()) {
				 return other < this ? this : other;
			 } else {
				 return valid__createInvalid();
			 }
		 }
	 );

	var prototypeMax = deprecate(
		'moment().max is deprecated, use moment.max instead. https://github.com/moment/moment/issues/1548',
		function () {
			var other = local__createLocal.apply(null, arguments);
			if (this.isValid() && other.isValid()) {
				return other > this ? this : other;
			} else {
				return valid__createInvalid();
			}
		}
	);

	// Pick a moment m from moments so that m[fn](other) is true for all
	// other. This relies on the function fn to be transitive.
	//
	// moments should either be an array of moment objects or an array, whose
	// first element is an array of moment objects.
	function pickBy(fn, moments) {
		var res, i;
		if (moments.length === 1 && isArray(moments[0])) {
			moments = moments[0];
		}
		if (!moments.length) {
			return local__createLocal();
		}
		res = moments[0];
		for (i = 1; i < moments.length; ++i) {
			if (!moments[i].isValid() || moments[i][fn](res)) {
				res = moments[i];
			}
		}
		return res;
	}

	// TODO: Use [].sort instead?
	function min () {
		var args = [].slice.call(arguments, 0);

		return pickBy('isBefore', args);
	}

	function max () {
		var args = [].slice.call(arguments, 0);

		return pickBy('isAfter', args);
	}

	var now = function () {
		return Date.now ? Date.now() : +(new Date());
	};

	function Duration (duration) {
		var normalizedInput = normalizeObjectUnits(duration),
			years = normalizedInput.year || 0,
			quarters = normalizedInput.quarter || 0,
			months = normalizedInput.month || 0,
			weeks = normalizedInput.week || 0,
			days = normalizedInput.day || 0,
			hours = normalizedInput.hour || 0,
			minutes = normalizedInput.minute || 0,
			seconds = normalizedInput.second || 0,
			milliseconds = normalizedInput.millisecond || 0;

		// representation for dateAddRemove
		this._milliseconds = +milliseconds +
			seconds * 1e3 + // 1000
			minutes * 6e4 + // 1000 * 60
			hours * 36e5; // 1000 * 60 * 60
		// Because of dateAddRemove treats 24 hours as different from a
		// day when working around DST, we need to store them separately
		this._days = +days +
			weeks * 7;
		// It is impossible translate months into days without knowing
		// which months you are are talking about, so we have to store
		// it separately.
		this._months = +months +
			quarters * 3 +
			years * 12;

		this._data = {};

		this._locale = locale_locales__getLocale();

		this._bubble();
	}

	function isDuration (obj) {
		return obj instanceof Duration;
	}

	// FORMATTING

	function offset (token, separator) {
		addFormatToken(token, 0, 0, function () {
			var offset = this.utcOffset();
			var sign = '+';
			if (offset < 0) {
				offset = -offset;
				sign = '-';
			}
			return sign + zeroFill(~~(offset / 60), 2) + separator + zeroFill(~~(offset) % 60, 2);
		});
	}

	offset('Z', ':');
	offset('ZZ', '');

	// PARSING

	addRegexToken('Z',  matchShortOffset);
	addRegexToken('ZZ', matchShortOffset);
	addParseToken(['Z', 'ZZ'], function (input, array, config) {
		config._useUTC = true;
		config._tzm = offsetFromString(matchShortOffset, input);
	});

	// HELPERS

	// timezone chunker
	// '+10:00' > ['10',  '00']
	// '-1530'  > ['-15', '30']
	var chunkOffset = /([\+\-]|\d\d)/gi;

	function offsetFromString(matcher, string) {
		var matches = ((string || '').match(matcher) || []);
		var chunk   = matches[matches.length - 1] || [];
		var parts   = (chunk + '').match(chunkOffset) || ['-', 0, 0];
		var minutes = +(parts[1] * 60) + toInt(parts[2]);

		return parts[0] === '+' ? minutes : -minutes;
	}

	// Return a moment from input, that is local/utc/zone equivalent to model.
	function cloneWithOffset(input, model) {
		var res, diff;
		if (model._isUTC) {
			res = model.clone();
			diff = (isMoment(input) || isDate(input) ? +input : +local__createLocal(input)) - (+res);
			// Use low-level api, because this fn is low-level api.
			res._d.setTime(+res._d + diff);
			utils_hooks__hooks.updateOffset(res, false);
			return res;
		} else {
			return local__createLocal(input).local();
		}
	}

	function getDateOffset (m) {
		// On Firefox.24 Date#getTimezoneOffset returns a floating point.
		// https://github.com/moment/moment/pull/1871
		return -Math.round(m._d.getTimezoneOffset() / 15) * 15;
	}

	// HOOKS

	// This function will be called whenever a moment is mutated.
	// It is intended to keep the offset in sync with the timezone.
	utils_hooks__hooks.updateOffset = function () {};

	// MOMENTS

	// keepLocalTime = true means only change the timezone, without
	// affecting the local hour. So 5:31:26 +0300 --[utcOffset(2, true)]-->
	// 5:31:26 +0200 It is possible that 5:31:26 doesn't exist with offset
	// +0200, so we adjust the time as needed, to be valid.
	//
	// Keeping the time actually adds/subtracts (one hour)
	// from the actual represented time. That is why we call updateOffset
	// a second time. In case it wants us to change the offset again
	// _changeInProgress == true case, then we have to adjust, because
	// there is no such time in the given timezone.
	function getSetOffset (input, keepLocalTime) {
		var offset = this._offset || 0,
			localAdjust;
		if (!this.isValid()) {
			return input != null ? this : NaN;
		}
		if (input != null) {
			if (typeof input === 'string') {
				input = offsetFromString(matchShortOffset, input);
			} else if (Math.abs(input) < 16) {
				input = input * 60;
			}
			if (!this._isUTC && keepLocalTime) {
				localAdjust = getDateOffset(this);
			}
			this._offset = input;
			this._isUTC = true;
			if (localAdjust != null) {
				this.add(localAdjust, 'm');
			}
			if (offset !== input) {
				if (!keepLocalTime || this._changeInProgress) {
					add_subtract__addSubtract(this, create__createDuration(input - offset, 'm'), 1, false);
				} else if (!this._changeInProgress) {
					this._changeInProgress = true;
					utils_hooks__hooks.updateOffset(this, true);
					this._changeInProgress = null;
				}
			}
			return this;
		} else {
			return this._isUTC ? offset : getDateOffset(this);
		}
	}

	function getSetZone (input, keepLocalTime) {
		if (input != null) {
			if (typeof input !== 'string') {
				input = -input;
			}

			this.utcOffset(input, keepLocalTime);

			return this;
		} else {
			return -this.utcOffset();
		}
	}

	function setOffsetToUTC (keepLocalTime) {
		return this.utcOffset(0, keepLocalTime);
	}

	function setOffsetToLocal (keepLocalTime) {
		if (this._isUTC) {
			this.utcOffset(0, keepLocalTime);
			this._isUTC = false;

			if (keepLocalTime) {
				this.subtract(getDateOffset(this), 'm');
			}
		}
		return this;
	}

	function setOffsetToParsedOffset () {
		if (this._tzm) {
			this.utcOffset(this._tzm);
		} else if (typeof this._i === 'string') {
			this.utcOffset(offsetFromString(matchOffset, this._i));
		}
		return this;
	}

	function hasAlignedHourOffset (input) {
		if (!this.isValid()) {
			return false;
		}
		input = input ? local__createLocal(input).utcOffset() : 0;

		return (this.utcOffset() - input) % 60 === 0;
	}

	function isDaylightSavingTime () {
		return (
			this.utcOffset() > this.clone().month(0).utcOffset() ||
			this.utcOffset() > this.clone().month(5).utcOffset()
		);
	}

	function isDaylightSavingTimeShifted () {
		if (!isUndefined(this._isDSTShifted)) {
			return this._isDSTShifted;
		}

		var c = {};

		copyConfig(c, this);
		c = prepareConfig(c);

		if (c._a) {
			var other = c._isUTC ? create_utc__createUTC(c._a) : local__createLocal(c._a);
			this._isDSTShifted = this.isValid() &&
				compareArrays(c._a, other.toArray()) > 0;
		} else {
			this._isDSTShifted = false;
		}

		return this._isDSTShifted;
	}

	function isLocal () {
		return this.isValid() ? !this._isUTC : false;
	}

	function isUtcOffset () {
		return this.isValid() ? this._isUTC : false;
	}

	function isUtc () {
		return this.isValid() ? this._isUTC && this._offset === 0 : false;
	}

	// ASP.NET json date format regex
	var aspNetRegex = /^(\-)?(?:(\d*)[. ])?(\d+)\:(\d+)(?:\:(\d+)\.?(\d{3})?\d*)?$/;

	// from http://docs.closure-library.googlecode.com/git/closure_goog_date_date.js.source.html
	// somewhat more in line with 4.4.3.2 2004 spec, but allows decimal anywhere
	var isoRegex = /^(-)?P(?:(?:([0-9,.]*)Y)?(?:([0-9,.]*)M)?(?:([0-9,.]*)D)?(?:T(?:([0-9,.]*)H)?(?:([0-9,.]*)M)?(?:([0-9,.]*)S)?)?|([0-9,.]*)W)$/;

	function create__createDuration (input, key) {
		var duration = input,
			// matching against regexp is expensive, do it on demand
			match = null,
			sign,
			ret,
			diffRes;

		if (isDuration(input)) {
			duration = {
				ms : input._milliseconds,
				d  : input._days,
				M  : input._months
			};
		} else if (typeof input === 'number') {
			duration = {};
			if (key) {
				duration[key] = input;
			} else {
				duration.milliseconds = input;
			}
		} else if (!!(match = aspNetRegex.exec(input))) {
			sign = (match[1] === '-') ? -1 : 1;
			duration = {
				y  : 0,
				d  : toInt(match[DATE])        * sign,
				h  : toInt(match[HOUR])        * sign,
				m  : toInt(match[MINUTE])      * sign,
				s  : toInt(match[SECOND])      * sign,
				ms : toInt(match[MILLISECOND]) * sign
			};
		} else if (!!(match = isoRegex.exec(input))) {
			sign = (match[1] === '-') ? -1 : 1;
			duration = {
				y : parseIso(match[2], sign),
				M : parseIso(match[3], sign),
				d : parseIso(match[4], sign),
				h : parseIso(match[5], sign),
				m : parseIso(match[6], sign),
				s : parseIso(match[7], sign),
				w : parseIso(match[8], sign)
			};
		} else if (duration == null) {// checks for null or undefined
			duration = {};
		} else if (typeof duration === 'object' && ('from' in duration || 'to' in duration)) {
			diffRes = momentsDifference(local__createLocal(duration.from), local__createLocal(duration.to));

			duration = {};
			duration.ms = diffRes.milliseconds;
			duration.M = diffRes.months;
		}

		ret = new Duration(duration);

		if (isDuration(input) && hasOwnProp(input, '_locale')) {
			ret._locale = input._locale;
		}

		return ret;
	}

	create__createDuration.fn = Duration.prototype;

	function parseIso (inp, sign) {
		// We'd normally use ~~inp for this, but unfortunately it also
		// converts floats to ints.
		// inp may be undefined, so careful calling replace on it.
		var res = inp && parseFloat(inp.replace(',', '.'));
		// apply sign while we're at it
		return (isNaN(res) ? 0 : res) * sign;
	}

	function positiveMomentsDifference(base, other) {
		var res = {milliseconds: 0, months: 0};

		res.months = other.month() - base.month() +
			(other.year() - base.year()) * 12;
		if (base.clone().add(res.months, 'M').isAfter(other)) {
			--res.months;
		}

		res.milliseconds = +other - +(base.clone().add(res.months, 'M'));

		return res;
	}

	function momentsDifference(base, other) {
		var res;
		if (!(base.isValid() && other.isValid())) {
			return {milliseconds: 0, months: 0};
		}

		other = cloneWithOffset(other, base);
		if (base.isBefore(other)) {
			res = positiveMomentsDifference(base, other);
		} else {
			res = positiveMomentsDifference(other, base);
			res.milliseconds = -res.milliseconds;
			res.months = -res.months;
		}

		return res;
	}

	// TODO: remove 'name' arg after deprecation is removed
	function createAdder(direction, name) {
		return function (val, period) {
			var dur, tmp;
			//invert the arguments, but complain about it
			if (period !== null && !isNaN(+period)) {
				deprecateSimple(name, 'moment().' + name  + '(period, number) is deprecated. Please use moment().' + name + '(number, period).');
				tmp = val; val = period; period = tmp;
			}

			val = typeof val === 'string' ? +val : val;
			dur = create__createDuration(val, period);
			add_subtract__addSubtract(this, dur, direction);
			return this;
		};
	}

	function add_subtract__addSubtract (mom, duration, isAdding, updateOffset) {
		var milliseconds = duration._milliseconds,
			days = duration._days,
			months = duration._months;

		if (!mom.isValid()) {
			// No op
			return;
		}

		updateOffset = updateOffset == null ? true : updateOffset;

		if (milliseconds) {
			mom._d.setTime(+mom._d + milliseconds * isAdding);
		}
		if (days) {
			get_set__set(mom, 'Date', get_set__get(mom, 'Date') + days * isAdding);
		}
		if (months) {
			setMonth(mom, get_set__get(mom, 'Month') + months * isAdding);
		}
		if (updateOffset) {
			utils_hooks__hooks.updateOffset(mom, days || months);
		}
	}

	var add_subtract__add      = createAdder(1, 'add');
	var add_subtract__subtract = createAdder(-1, 'subtract');

	function moment_calendar__calendar (time, formats) {
		// We want to compare the start of today, vs this.
		// Getting start-of-today depends on whether we're local/utc/offset or not.
		var now = time || local__createLocal(),
			sod = cloneWithOffset(now, this).startOf('day'),
			diff = this.diff(sod, 'days', true),
			format = diff < -6 ? 'sameElse' :
				diff < -1 ? 'lastWeek' :
				diff < 0 ? 'lastDay' :
				diff < 1 ? 'sameDay' :
				diff < 2 ? 'nextDay' :
				diff < 7 ? 'nextWeek' : 'sameElse';

		var output = formats && (isFunction(formats[format]) ? formats[format]() : formats[format]);

		return this.format(output || this.localeData().calendar(format, this, local__createLocal(now)));
	}

	function clone () {
		return new Moment(this);
	}

	function isAfter (input, units) {
		var localInput = isMoment(input) ? input : local__createLocal(input);
		if (!(this.isValid() && localInput.isValid())) {
			return false;
		}
		units = normalizeUnits(!isUndefined(units) ? units : 'millisecond');
		if (units === 'millisecond') {
			return +this > +localInput;
		} else {
			return +localInput < +this.clone().startOf(units);
		}
	}

	function isBefore (input, units) {
		var localInput = isMoment(input) ? input : local__createLocal(input);
		if (!(this.isValid() && localInput.isValid())) {
			return false;
		}
		units = normalizeUnits(!isUndefined(units) ? units : 'millisecond');
		if (units === 'millisecond') {
			return +this < +localInput;
		} else {
			return +this.clone().endOf(units) < +localInput;
		}
	}

	function isBetween (from, to, units) {
		return this.isAfter(from, units) && this.isBefore(to, units);
	}

	function isSame (input, units) {
		var localInput = isMoment(input) ? input : local__createLocal(input),
			inputMs;
		if (!(this.isValid() && localInput.isValid())) {
			return false;
		}
		units = normalizeUnits(units || 'millisecond');
		if (units === 'millisecond') {
			return +this === +localInput;
		} else {
			inputMs = +localInput;
			return +(this.clone().startOf(units)) <= inputMs && inputMs <= +(this.clone().endOf(units));
		}
	}

	function isSameOrAfter (input, units) {
		return this.isSame(input, units) || this.isAfter(input,units);
	}

	function isSameOrBefore (input, units) {
		return this.isSame(input, units) || this.isBefore(input,units);
	}

	function diff (input, units, asFloat) {
		var that,
			zoneDelta,
			delta, output;

		if (!this.isValid()) {
			return NaN;
		}

		that = cloneWithOffset(input, this);

		if (!that.isValid()) {
			return NaN;
		}

		zoneDelta = (that.utcOffset() - this.utcOffset()) * 6e4;

		units = normalizeUnits(units);

		if (units === 'year' || units === 'month' || units === 'quarter') {
			output = monthDiff(this, that);
			if (units === 'quarter') {
				output = output / 3;
			} else if (units === 'year') {
				output = output / 12;
			}
		} else {
			delta = this - that;
			output = units === 'second' ? delta / 1e3 : // 1000
				units === 'minute' ? delta / 6e4 : // 1000 * 60
				units === 'hour' ? delta / 36e5 : // 1000 * 60 * 60
				units === 'day' ? (delta - zoneDelta) / 864e5 : // 1000 * 60 * 60 * 24, negate dst
				units === 'week' ? (delta - zoneDelta) / 6048e5 : // 1000 * 60 * 60 * 24 * 7, negate dst
				delta;
		}
		return asFloat ? output : absFloor(output);
	}

	function monthDiff (a, b) {
		// difference in months
		var wholeMonthDiff = ((b.year() - a.year()) * 12) + (b.month() - a.month()),
			// b is in (anchor - 1 month, anchor + 1 month)
			anchor = a.clone().add(wholeMonthDiff, 'months'),
			anchor2, adjust;

		if (b - anchor < 0) {
			anchor2 = a.clone().add(wholeMonthDiff - 1, 'months');
			// linear across the month
			adjust = (b - anchor) / (anchor - anchor2);
		} else {
			anchor2 = a.clone().add(wholeMonthDiff + 1, 'months');
			// linear across the month
			adjust = (b - anchor) / (anchor2 - anchor);
		}

		return -(wholeMonthDiff + adjust);
	}

	utils_hooks__hooks.defaultFormat = 'YYYY-MM-DDTHH:mm:ssZ';

	function toString () {
		return this.clone().locale('en').format('ddd MMM DD YYYY HH:mm:ss [GMT]ZZ');
	}

	function moment_format__toISOString () {
		var m = this.clone().utc();
		if (0 < m.year() && m.year() <= 9999) {
			if (isFunction(Date.prototype.toISOString)) {
				// native implementation is ~50x faster, use it when we can
				return this.toDate().toISOString();
			} else {
				return formatMoment(m, 'YYYY-MM-DD[T]HH:mm:ss.SSS[Z]');
			}
		} else {
			return formatMoment(m, 'YYYYYY-MM-DD[T]HH:mm:ss.SSS[Z]');
		}
	}

	function moment_format__format (inputString) {
		var output = formatMoment(this, inputString || utils_hooks__hooks.defaultFormat);
		return this.localeData().postformat(output);
	}

	function from (time, withoutSuffix) {
		if (this.isValid() &&
				((isMoment(time) && time.isValid()) ||
				 local__createLocal(time).isValid())) {
			return create__createDuration({to: this, from: time}).locale(this.locale()).humanize(!withoutSuffix);
		} else {
			return this.localeData().invalidDate();
		}
	}

	function fromNow (withoutSuffix) {
		return this.from(local__createLocal(), withoutSuffix);
	}

	function to (time, withoutSuffix) {
		if (this.isValid() &&
				((isMoment(time) && time.isValid()) ||
				 local__createLocal(time).isValid())) {
			return create__createDuration({from: this, to: time}).locale(this.locale()).humanize(!withoutSuffix);
		} else {
			return this.localeData().invalidDate();
		}
	}

	function toNow (withoutSuffix) {
		return this.to(local__createLocal(), withoutSuffix);
	}

	// If passed a locale key, it will set the locale for this
	// instance.  Otherwise, it will return the locale configuration
	// variables for this instance.
	function locale (key) {
		var newLocaleData;

		if (key === undefined) {
			return this._locale._abbr;
		} else {
			newLocaleData = locale_locales__getLocale(key);
			if (newLocaleData != null) {
				this._locale = newLocaleData;
			}
			return this;
		}
	}

	var lang = deprecate(
		'moment().lang() is deprecated. Instead, use moment().localeData() to get the language configuration. Use moment().locale() to change languages.',
		function (key) {
			if (key === undefined) {
				return this.localeData();
			} else {
				return this.locale(key);
			}
		}
	);

	function localeData () {
		return this._locale;
	}

	function startOf (units) {
		units = normalizeUnits(units);
		// the following switch intentionally omits break keywords
		// to utilize falling through the cases.
		switch (units) {
		case 'year':
			this.month(0);
			/* falls through */
		case 'quarter':
		case 'month':
			this.date(1);
			/* falls through */
		case 'week':
		case 'isoWeek':
		case 'day':
			this.hours(0);
			/* falls through */
		case 'hour':
			this.minutes(0);
			/* falls through */
		case 'minute':
			this.seconds(0);
			/* falls through */
		case 'second':
			this.milliseconds(0);
		}

		// weeks are a special case
		if (units === 'week') {
			this.weekday(0);
		}
		if (units === 'isoWeek') {
			this.isoWeekday(1);
		}

		// quarters are also special
		if (units === 'quarter') {
			this.month(Math.floor(this.month() / 3) * 3);
		}

		return this;
	}

	function endOf (units) {
		units = normalizeUnits(units);
		if (units === undefined || units === 'millisecond') {
			return this;
		}
		return this.startOf(units).add(1, (units === 'isoWeek' ? 'week' : units)).subtract(1, 'ms');
	}

	function to_type__valueOf () {
		return +this._d - ((this._offset || 0) * 60000);
	}

	function unix () {
		return Math.floor(+this / 1000);
	}

	function toDate () {
		return this._offset ? new Date(+this) : this._d;
	}

	function toArray () {
		var m = this;
		return [m.year(), m.month(), m.date(), m.hour(), m.minute(), m.second(), m.millisecond()];
	}

	function toObject () {
		var m = this;
		return {
			years: m.year(),
			months: m.month(),
			date: m.date(),
			hours: m.hours(),
			minutes: m.minutes(),
			seconds: m.seconds(),
			milliseconds: m.milliseconds()
		};
	}

	function toJSON () {
		// JSON.stringify(new Date(NaN)) === 'null'
		return this.isValid() ? this.toISOString() : 'null';
	}

	function moment_valid__isValid () {
		return valid__isValid(this);
	}

	function parsingFlags () {
		return extend({}, getParsingFlags(this));
	}

	function invalidAt () {
		return getParsingFlags(this).overflow;
	}

	function creationData() {
		return {
			input: this._i,
			format: this._f,
			locale: this._locale,
			isUTC: this._isUTC,
			strict: this._strict
		};
	}

	// FORMATTING

	addFormatToken(0, ['gg', 2], 0, function () {
		return this.weekYear() % 100;
	});

	addFormatToken(0, ['GG', 2], 0, function () {
		return this.isoWeekYear() % 100;
	});

	function addWeekYearFormatToken (token, getter) {
		addFormatToken(0, [token, token.length], 0, getter);
	}

	addWeekYearFormatToken('gggg',     'weekYear');
	addWeekYearFormatToken('ggggg',    'weekYear');
	addWeekYearFormatToken('GGGG',  'isoWeekYear');
	addWeekYearFormatToken('GGGGG', 'isoWeekYear');

	// ALIASES

	addUnitAlias('weekYear', 'gg');
	addUnitAlias('isoWeekYear', 'GG');

	// PARSING

	addRegexToken('G',      matchSigned);
	addRegexToken('g',      matchSigned);
	addRegexToken('GG',     match1to2, match2);
	addRegexToken('gg',     match1to2, match2);
	addRegexToken('GGGG',   match1to4, match4);
	addRegexToken('gggg',   match1to4, match4);
	addRegexToken('GGGGG',  match1to6, match6);
	addRegexToken('ggggg',  match1to6, match6);

	addWeekParseToken(['gggg', 'ggggg', 'GGGG', 'GGGGG'], function (input, week, config, token) {
		week[token.substr(0, 2)] = toInt(input);
	});

	addWeekParseToken(['gg', 'GG'], function (input, week, config, token) {
		week[token] = utils_hooks__hooks.parseTwoDigitYear(input);
	});

	// MOMENTS

	function getSetWeekYear (input) {
		return getSetWeekYearHelper.call(this,
				input,
				this.week(),
				this.weekday(),
				this.localeData()._week.dow,
				this.localeData()._week.doy);
	}

	function getSetISOWeekYear (input) {
		return getSetWeekYearHelper.call(this,
				input, this.isoWeek(), this.isoWeekday(), 1, 4);
	}

	function getISOWeeksInYear () {
		return weeksInYear(this.year(), 1, 4);
	}

	function getWeeksInYear () {
		var weekInfo = this.localeData()._week;
		return weeksInYear(this.year(), weekInfo.dow, weekInfo.doy);
	}

	function getSetWeekYearHelper(input, week, weekday, dow, doy) {
		var weeksTarget;
		if (input == null) {
			return weekOfYear(this, dow, doy).year;
		} else {
			weeksTarget = weeksInYear(input, dow, doy);
			if (week > weeksTarget) {
				week = weeksTarget;
			}
			return setWeekAll.call(this, input, week, weekday, dow, doy);
		}
	}

	function setWeekAll(weekYear, week, weekday, dow, doy) {
		var dayOfYearData = dayOfYearFromWeeks(weekYear, week, weekday, dow, doy),
			date = createUTCDate(dayOfYearData.year, 0, dayOfYearData.dayOfYear);

		// console.log("got", weekYear, week, weekday, "set", date.toISOString());
		this.year(date.getUTCFullYear());
		this.month(date.getUTCMonth());
		this.date(date.getUTCDate());
		return this;
	}

	// FORMATTING

	addFormatToken('Q', 0, 'Qo', 'quarter');

	// ALIASES

	addUnitAlias('quarter', 'Q');

	// PARSING

	addRegexToken('Q', match1);
	addParseToken('Q', function (input, array) {
		array[MONTH] = (toInt(input) - 1) * 3;
	});

	// MOMENTS

	function getSetQuarter (input) {
		return input == null ? Math.ceil((this.month() + 1) / 3) : this.month((input - 1) * 3 + this.month() % 3);
	}

	// FORMATTING

	addFormatToken('w', ['ww', 2], 'wo', 'week');
	addFormatToken('W', ['WW', 2], 'Wo', 'isoWeek');

	// ALIASES

	addUnitAlias('week', 'w');
	addUnitAlias('isoWeek', 'W');

	// PARSING

	addRegexToken('w',  match1to2);
	addRegexToken('ww', match1to2, match2);
	addRegexToken('W',  match1to2);
	addRegexToken('WW', match1to2, match2);

	addWeekParseToken(['w', 'ww', 'W', 'WW'], function (input, week, config, token) {
		week[token.substr(0, 1)] = toInt(input);
	});

	// HELPERS

	// LOCALES

	function localeWeek (mom) {
		return weekOfYear(mom, this._week.dow, this._week.doy).week;
	}

	var defaultLocaleWeek = {
		dow : 0, // Sunday is the first day of the week.
		doy : 6  // The week that contains Jan 1st is the first week of the year.
	};

	function localeFirstDayOfWeek () {
		return this._week.dow;
	}

	function localeFirstDayOfYear () {
		return this._week.doy;
	}

	// MOMENTS

	function getSetWeek (input) {
		var week = this.localeData().week(this);
		return input == null ? week : this.add((input - week) * 7, 'd');
	}

	function getSetISOWeek (input) {
		var week = weekOfYear(this, 1, 4).week;
		return input == null ? week : this.add((input - week) * 7, 'd');
	}

	// FORMATTING

	addFormatToken('D', ['DD', 2], 'Do', 'date');

	// ALIASES

	addUnitAlias('date', 'D');

	// PARSING

	addRegexToken('D',  match1to2);
	addRegexToken('DD', match1to2, match2);
	addRegexToken('Do', function (isStrict, locale) {
		return isStrict ? locale._ordinalParse : locale._ordinalParseLenient;
	});

	addParseToken(['D', 'DD'], DATE);
	addParseToken('Do', function (input, array) {
		array[DATE] = toInt(input.match(match1to2)[0], 10);
	});

	// MOMENTS

	var getSetDayOfMonth = makeGetSet('Date', true);

	// FORMATTING

	addFormatToken('d', 0, 'do', 'day');

	addFormatToken('dd', 0, 0, function (format) {
		return this.localeData().weekdaysMin(this, format);
	});

	addFormatToken('ddd', 0, 0, function (format) {
		return this.localeData().weekdaysShort(this, format);
	});

	addFormatToken('dddd', 0, 0, function (format) {
		return this.localeData().weekdays(this, format);
	});

	addFormatToken('e', 0, 0, 'weekday');
	addFormatToken('E', 0, 0, 'isoWeekday');

	// ALIASES

	addUnitAlias('day', 'd');
	addUnitAlias('weekday', 'e');
	addUnitAlias('isoWeekday', 'E');

	// PARSING

	addRegexToken('d',    match1to2);
	addRegexToken('e',    match1to2);
	addRegexToken('E',    match1to2);
	addRegexToken('dd',   matchWord);
	addRegexToken('ddd',  matchWord);
	addRegexToken('dddd', matchWord);

	addWeekParseToken(['dd', 'ddd', 'dddd'], function (input, week, config, token) {
		var weekday = config._locale.weekdaysParse(input, token, config._strict);
		// if we didn't get a weekday name, mark the date as invalid
		if (weekday != null) {
			week.d = weekday;
		} else {
			getParsingFlags(config).invalidWeekday = input;
		}
	});

	addWeekParseToken(['d', 'e', 'E'], function (input, week, config, token) {
		week[token] = toInt(input);
	});

	// HELPERS

	function parseWeekday(input, locale) {
		if (typeof input !== 'string') {
			return input;
		}

		if (!isNaN(input)) {
			return parseInt(input, 10);
		}

		input = locale.weekdaysParse(input);
		if (typeof input === 'number') {
			return input;
		}

		return null;
	}

	// LOCALES

	var defaultLocaleWeekdays = 'Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday'.split('_');
	function localeWeekdays (m, format) {
		return isArray(this._weekdays) ? this._weekdays[m.day()] :
			this._weekdays[this._weekdays.isFormat.test(format) ? 'format' : 'standalone'][m.day()];
	}

	var defaultLocaleWeekdaysShort = 'Sun_Mon_Tue_Wed_Thu_Fri_Sat'.split('_');
	function localeWeekdaysShort (m) {
		return this._weekdaysShort[m.day()];
	}

	var defaultLocaleWeekdaysMin = 'Su_Mo_Tu_We_Th_Fr_Sa'.split('_');
	function localeWeekdaysMin (m) {
		return this._weekdaysMin[m.day()];
	}

	function localeWeekdaysParse (weekdayName, format, strict) {
		var i, mom, regex;

		if (!this._weekdaysParse) {
			this._weekdaysParse = [];
			this._minWeekdaysParse = [];
			this._shortWeekdaysParse = [];
			this._fullWeekdaysParse = [];
		}

		for (i = 0; i < 7; i++) {
			// make the regex if we don't have it already

			mom = local__createLocal([2000, 1]).day(i);
			if (strict && !this._fullWeekdaysParse[i]) {
				this._fullWeekdaysParse[i] = new RegExp('^' + this.weekdays(mom, '').replace('.', '\.?') + '$', 'i');
				this._shortWeekdaysParse[i] = new RegExp('^' + this.weekdaysShort(mom, '').replace('.', '\.?') + '$', 'i');
				this._minWeekdaysParse[i] = new RegExp('^' + this.weekdaysMin(mom, '').replace('.', '\.?') + '$', 'i');
			}
			if (!this._weekdaysParse[i]) {
				regex = '^' + this.weekdays(mom, '') + '|^' + this.weekdaysShort(mom, '') + '|^' + this.weekdaysMin(mom, '');
				this._weekdaysParse[i] = new RegExp(regex.replace('.', ''), 'i');
			}
			// test the regex
			if (strict && format === 'dddd' && this._fullWeekdaysParse[i].test(weekdayName)) {
				return i;
			} else if (strict && format === 'ddd' && this._shortWeekdaysParse[i].test(weekdayName)) {
				return i;
			} else if (strict && format === 'dd' && this._minWeekdaysParse[i].test(weekdayName)) {
				return i;
			} else if (!strict && this._weekdaysParse[i].test(weekdayName)) {
				return i;
			}
		}
	}

	// MOMENTS

	function getSetDayOfWeek (input) {
		if (!this.isValid()) {
			return input != null ? this : NaN;
		}
		var day = this._isUTC ? this._d.getUTCDay() : this._d.getDay();
		if (input != null) {
			input = parseWeekday(input, this.localeData());
			return this.add(input - day, 'd');
		} else {
			return day;
		}
	}

	function getSetLocaleDayOfWeek (input) {
		if (!this.isValid()) {
			return input != null ? this : NaN;
		}
		var weekday = (this.day() + 7 - this.localeData()._week.dow) % 7;
		return input == null ? weekday : this.add(input - weekday, 'd');
	}

	function getSetISODayOfWeek (input) {
		if (!this.isValid()) {
			return input != null ? this : NaN;
		}
		// behaves the same as moment#day except
		// as a getter, returns 7 instead of 0 (1-7 range instead of 0-6)
		// as a setter, sunday should belong to the previous week.
		return input == null ? this.day() || 7 : this.day(this.day() % 7 ? input : input - 7);
	}

	// FORMATTING

	addFormatToken('DDD', ['DDDD', 3], 'DDDo', 'dayOfYear');

	// ALIASES

	addUnitAlias('dayOfYear', 'DDD');

	// PARSING

	addRegexToken('DDD',  match1to3);
	addRegexToken('DDDD', match3);
	addParseToken(['DDD', 'DDDD'], function (input, array, config) {
		config._dayOfYear = toInt(input);
	});

	// HELPERS

	// MOMENTS

	function getSetDayOfYear (input) {
		var dayOfYear = Math.round((this.clone().startOf('day') - this.clone().startOf('year')) / 864e5) + 1;
		return input == null ? dayOfYear : this.add((input - dayOfYear), 'd');
	}

	// FORMATTING

	function hFormat() {
		return this.hours() % 12 || 12;
	}

	addFormatToken('H', ['HH', 2], 0, 'hour');
	addFormatToken('h', ['hh', 2], 0, hFormat);

	addFormatToken('hmm', 0, 0, function () {
		return '' + hFormat.apply(this) + zeroFill(this.minutes(), 2);
	});

	addFormatToken('hmmss', 0, 0, function () {
		return '' + hFormat.apply(this) + zeroFill(this.minutes(), 2) +
			zeroFill(this.seconds(), 2);
	});

	addFormatToken('Hmm', 0, 0, function () {
		return '' + this.hours() + zeroFill(this.minutes(), 2);
	});

	addFormatToken('Hmmss', 0, 0, function () {
		return '' + this.hours() + zeroFill(this.minutes(), 2) +
			zeroFill(this.seconds(), 2);
	});

	function meridiem (token, lowercase) {
		addFormatToken(token, 0, 0, function () {
			return this.localeData().meridiem(this.hours(), this.minutes(), lowercase);
		});
	}

	meridiem('a', true);
	meridiem('A', false);

	// ALIASES

	addUnitAlias('hour', 'h');

	// PARSING

	function matchMeridiem (isStrict, locale) {
		return locale._meridiemParse;
	}

	addRegexToken('a',  matchMeridiem);
	addRegexToken('A',  matchMeridiem);
	addRegexToken('H',  match1to2);
	addRegexToken('h',  match1to2);
	addRegexToken('HH', match1to2, match2);
	addRegexToken('hh', match1to2, match2);

	addRegexToken('hmm', match3to4);
	addRegexToken('hmmss', match5to6);
	addRegexToken('Hmm', match3to4);
	addRegexToken('Hmmss', match5to6);

	addParseToken(['H', 'HH'], HOUR);
	addParseToken(['a', 'A'], function (input, array, config) {
		config._isPm = config._locale.isPM(input);
		config._meridiem = input;
	});
	addParseToken(['h', 'hh'], function (input, array, config) {
		array[HOUR] = toInt(input);
		getParsingFlags(config).bigHour = true;
	});
	addParseToken('hmm', function (input, array, config) {
		var pos = input.length - 2;
		array[HOUR] = toInt(input.substr(0, pos));
		array[MINUTE] = toInt(input.substr(pos));
		getParsingFlags(config).bigHour = true;
	});
	addParseToken('hmmss', function (input, array, config) {
		var pos1 = input.length - 4;
		var pos2 = input.length - 2;
		array[HOUR] = toInt(input.substr(0, pos1));
		array[MINUTE] = toInt(input.substr(pos1, 2));
		array[SECOND] = toInt(input.substr(pos2));
		getParsingFlags(config).bigHour = true;
	});
	addParseToken('Hmm', function (input, array, config) {
		var pos = input.length - 2;
		array[HOUR] = toInt(input.substr(0, pos));
		array[MINUTE] = toInt(input.substr(pos));
	});
	addParseToken('Hmmss', function (input, array, config) {
		var pos1 = input.length - 4;
		var pos2 = input.length - 2;
		array[HOUR] = toInt(input.substr(0, pos1));
		array[MINUTE] = toInt(input.substr(pos1, 2));
		array[SECOND] = toInt(input.substr(pos2));
	});

	// LOCALES

	function localeIsPM (input) {
		// IE8 Quirks Mode & IE7 Standards Mode do not allow accessing strings like arrays
		// Using charAt should be more compatible.
		return ((input + '').toLowerCase().charAt(0) === 'p');
	}

	var defaultLocaleMeridiemParse = /[ap]\.?m?\.?/i;
	function localeMeridiem (hours, minutes, isLower) {
		if (hours > 11) {
			return isLower ? 'pm' : 'PM';
		} else {
			return isLower ? 'am' : 'AM';
		}
	}


	// MOMENTS

	// Setting the hour should keep the time, because the user explicitly
	// specified which hour he wants. So trying to maintain the same hour (in
	// a new timezone) makes sense. Adding/subtracting hours does not follow
	// this rule.
	var getSetHour = makeGetSet('Hours', true);

	// FORMATTING

	addFormatToken('m', ['mm', 2], 0, 'minute');

	// ALIASES

	addUnitAlias('minute', 'm');

	// PARSING

	addRegexToken('m',  match1to2);
	addRegexToken('mm', match1to2, match2);
	addParseToken(['m', 'mm'], MINUTE);

	// MOMENTS

	var getSetMinute = makeGetSet('Minutes', false);

	// FORMATTING

	addFormatToken('s', ['ss', 2], 0, 'second');

	// ALIASES

	addUnitAlias('second', 's');

	// PARSING

	addRegexToken('s',  match1to2);
	addRegexToken('ss', match1to2, match2);
	addParseToken(['s', 'ss'], SECOND);

	// MOMENTS

	var getSetSecond = makeGetSet('Seconds', false);

	// FORMATTING

	addFormatToken('S', 0, 0, function () {
		return ~~(this.millisecond() / 100);
	});

	addFormatToken(0, ['SS', 2], 0, function () {
		return ~~(this.millisecond() / 10);
	});

	addFormatToken(0, ['SSS', 3], 0, 'millisecond');
	addFormatToken(0, ['SSSS', 4], 0, function () {
		return this.millisecond() * 10;
	});
	addFormatToken(0, ['SSSSS', 5], 0, function () {
		return this.millisecond() * 100;
	});
	addFormatToken(0, ['SSSSSS', 6], 0, function () {
		return this.millisecond() * 1000;
	});
	addFormatToken(0, ['SSSSSSS', 7], 0, function () {
		return this.millisecond() * 10000;
	});
	addFormatToken(0, ['SSSSSSSS', 8], 0, function () {
		return this.millisecond() * 100000;
	});
	addFormatToken(0, ['SSSSSSSSS', 9], 0, function () {
		return this.millisecond() * 1000000;
	});


	// ALIASES

	addUnitAlias('millisecond', 'ms');

	// PARSING

	addRegexToken('S',    match1to3, match1);
	addRegexToken('SS',   match1to3, match2);
	addRegexToken('SSS',  match1to3, match3);

	var token;
	for (token = 'SSSS'; token.length <= 9; token += 'S') {
		addRegexToken(token, matchUnsigned);
	}

	function parseMs(input, array) {
		array[MILLISECOND] = toInt(('0.' + input) * 1000);
	}

	for (token = 'S'; token.length <= 9; token += 'S') {
		addParseToken(token, parseMs);
	}
	// MOMENTS

	var getSetMillisecond = makeGetSet('Milliseconds', false);

	// FORMATTING

	addFormatToken('z',  0, 0, 'zoneAbbr');
	addFormatToken('zz', 0, 0, 'zoneName');

	// MOMENTS

	function getZoneAbbr () {
		return this._isUTC ? 'UTC' : '';
	}

	function getZoneName () {
		return this._isUTC ? 'Coordinated Universal Time' : '';
	}

	var momentPrototype__proto = Moment.prototype;

	momentPrototype__proto.add               = add_subtract__add;
	momentPrototype__proto.calendar          = moment_calendar__calendar;
	momentPrototype__proto.clone             = clone;
	momentPrototype__proto.diff              = diff;
	momentPrototype__proto.endOf             = endOf;
	momentPrototype__proto.format            = moment_format__format;
	momentPrototype__proto.from              = from;
	momentPrototype__proto.fromNow           = fromNow;
	momentPrototype__proto.to                = to;
	momentPrototype__proto.toNow             = toNow;
	momentPrototype__proto.get               = getSet;
	momentPrototype__proto.invalidAt         = invalidAt;
	momentPrototype__proto.isAfter           = isAfter;
	momentPrototype__proto.isBefore          = isBefore;
	momentPrototype__proto.isBetween         = isBetween;
	momentPrototype__proto.isSame            = isSame;
	momentPrototype__proto.isSameOrAfter     = isSameOrAfter;
	momentPrototype__proto.isSameOrBefore    = isSameOrBefore;
	momentPrototype__proto.isValid           = moment_valid__isValid;
	momentPrototype__proto.lang              = lang;
	momentPrototype__proto.locale            = locale;
	momentPrototype__proto.localeData        = localeData;
	momentPrototype__proto.max               = prototypeMax;
	momentPrototype__proto.min               = prototypeMin;
	momentPrototype__proto.parsingFlags      = parsingFlags;
	momentPrototype__proto.set               = getSet;
	momentPrototype__proto.startOf           = startOf;
	momentPrototype__proto.subtract          = add_subtract__subtract;
	momentPrototype__proto.toArray           = toArray;
	momentPrototype__proto.toObject          = toObject;
	momentPrototype__proto.toDate            = toDate;
	momentPrototype__proto.toISOString       = moment_format__toISOString;
	momentPrototype__proto.toJSON            = toJSON;
	momentPrototype__proto.toString          = toString;
	momentPrototype__proto.unix              = unix;
	momentPrototype__proto.valueOf           = to_type__valueOf;
	momentPrototype__proto.creationData      = creationData;

	// Year
	momentPrototype__proto.year       = getSetYear;
	momentPrototype__proto.isLeapYear = getIsLeapYear;

	// Week Year
	momentPrototype__proto.weekYear    = getSetWeekYear;
	momentPrototype__proto.isoWeekYear = getSetISOWeekYear;

	// Quarter
	momentPrototype__proto.quarter = momentPrototype__proto.quarters = getSetQuarter;

	// Month
	momentPrototype__proto.month       = getSetMonth;
	momentPrototype__proto.daysInMonth = getDaysInMonth;

	// Week
	momentPrototype__proto.week           = momentPrototype__proto.weeks        = getSetWeek;
	momentPrototype__proto.isoWeek        = momentPrototype__proto.isoWeeks     = getSetISOWeek;
	momentPrototype__proto.weeksInYear    = getWeeksInYear;
	momentPrototype__proto.isoWeeksInYear = getISOWeeksInYear;

	// Day
	momentPrototype__proto.date       = getSetDayOfMonth;
	momentPrototype__proto.day        = momentPrototype__proto.days             = getSetDayOfWeek;
	momentPrototype__proto.weekday    = getSetLocaleDayOfWeek;
	momentPrototype__proto.isoWeekday = getSetISODayOfWeek;
	momentPrototype__proto.dayOfYear  = getSetDayOfYear;

	// Hour
	momentPrototype__proto.hour = momentPrototype__proto.hours = getSetHour;

	// Minute
	momentPrototype__proto.minute = momentPrototype__proto.minutes = getSetMinute;

	// Second
	momentPrototype__proto.second = momentPrototype__proto.seconds = getSetSecond;

	// Millisecond
	momentPrototype__proto.millisecond = momentPrototype__proto.milliseconds = getSetMillisecond;

	// Offset
	momentPrototype__proto.utcOffset            = getSetOffset;
	momentPrototype__proto.utc                  = setOffsetToUTC;
	momentPrototype__proto.local                = setOffsetToLocal;
	momentPrototype__proto.parseZone            = setOffsetToParsedOffset;
	momentPrototype__proto.hasAlignedHourOffset = hasAlignedHourOffset;
	momentPrototype__proto.isDST                = isDaylightSavingTime;
	momentPrototype__proto.isDSTShifted         = isDaylightSavingTimeShifted;
	momentPrototype__proto.isLocal              = isLocal;
	momentPrototype__proto.isUtcOffset          = isUtcOffset;
	momentPrototype__proto.isUtc                = isUtc;
	momentPrototype__proto.isUTC                = isUtc;

	// Timezone
	momentPrototype__proto.zoneAbbr = getZoneAbbr;
	momentPrototype__proto.zoneName = getZoneName;

	// Deprecations
	momentPrototype__proto.dates  = deprecate('dates accessor is deprecated. Use date instead.', getSetDayOfMonth);
	momentPrototype__proto.months = deprecate('months accessor is deprecated. Use month instead', getSetMonth);
	momentPrototype__proto.years  = deprecate('years accessor is deprecated. Use year instead', getSetYear);
	momentPrototype__proto.zone   = deprecate('moment().zone is deprecated, use moment().utcOffset instead. https://github.com/moment/moment/issues/1779', getSetZone);

	var momentPrototype = momentPrototype__proto;

	function moment_moment__createUnix (input) {
		return local__createLocal(input * 1000);
	}

	function moment_moment__createInZone () {
		return local__createLocal.apply(null, arguments).parseZone();
	}

	var defaultCalendar = {
		sameDay : '[Today at] LT',
		nextDay : '[Tomorrow at] LT',
		nextWeek : 'dddd [at] LT',
		lastDay : '[Yesterday at] LT',
		lastWeek : '[Last] dddd [at] LT',
		sameElse : 'L'
	};

	function locale_calendar__calendar (key, mom, now) {
		var output = this._calendar[key];
		return isFunction(output) ? output.call(mom, now) : output;
	}

	var defaultLongDateFormat = {
		LTS  : 'h:mm:ss A',
		LT   : 'h:mm A',
		L    : 'MM/DD/YYYY',
		LL   : 'MMMM D, YYYY',
		LLL  : 'MMMM D, YYYY h:mm A',
		LLLL : 'dddd, MMMM D, YYYY h:mm A'
	};

	function longDateFormat (key) {
		var format = this._longDateFormat[key],
			formatUpper = this._longDateFormat[key.toUpperCase()];

		if (format || !formatUpper) {
			return format;
		}

		this._longDateFormat[key] = formatUpper.replace(/MMMM|MM|DD|dddd/g, function (val) {
			return val.slice(1);
		});

		return this._longDateFormat[key];
	}

	var defaultInvalidDate = 'Invalid date';

	function invalidDate () {
		return this._invalidDate;
	}

	var defaultOrdinal = '%d';
	var defaultOrdinalParse = /\d{1,2}/;

	function ordinal (number) {
		return this._ordinal.replace('%d', number);
	}

	function preParsePostFormat (string) {
		return string;
	}

	var defaultRelativeTime = {
		future : 'in %s',
		past   : '%s ago',
		s  : 'a few seconds',
		m  : 'a minute',
		mm : '%d minutes',
		h  : 'an hour',
		hh : '%d hours',
		d  : 'a day',
		dd : '%d days',
		M  : 'a month',
		MM : '%d months',
		y  : 'a year',
		yy : '%d years'
	};

	function relative__relativeTime (number, withoutSuffix, string, isFuture) {
		var output = this._relativeTime[string];
		return (isFunction(output)) ?
			output(number, withoutSuffix, string, isFuture) :
			output.replace(/%d/i, number);
	}

	function pastFuture (diff, output) {
		var format = this._relativeTime[diff > 0 ? 'future' : 'past'];
		return isFunction(format) ? format(output) : format.replace(/%s/i, output);
	}

	function locale_set__set (config) {
		var prop, i;
		for (i in config) {
			prop = config[i];
			if (isFunction(prop)) {
				this[i] = prop;
			} else {
				this['_' + i] = prop;
			}
		}
		// Lenient ordinal parsing accepts just a number in addition to
		// number + (possibly) stuff coming from _ordinalParseLenient.
		this._ordinalParseLenient = new RegExp(this._ordinalParse.source + '|' + (/\d{1,2}/).source);
	}

	var prototype__proto = Locale.prototype;

	prototype__proto._calendar       = defaultCalendar;
	prototype__proto.calendar        = locale_calendar__calendar;
	prototype__proto._longDateFormat = defaultLongDateFormat;
	prototype__proto.longDateFormat  = longDateFormat;
	prototype__proto._invalidDate    = defaultInvalidDate;
	prototype__proto.invalidDate     = invalidDate;
	prototype__proto._ordinal        = defaultOrdinal;
	prototype__proto.ordinal         = ordinal;
	prototype__proto._ordinalParse   = defaultOrdinalParse;
	prototype__proto.preparse        = preParsePostFormat;
	prototype__proto.postformat      = preParsePostFormat;
	prototype__proto._relativeTime   = defaultRelativeTime;
	prototype__proto.relativeTime    = relative__relativeTime;
	prototype__proto.pastFuture      = pastFuture;
	prototype__proto.set             = locale_set__set;

	// Month
	prototype__proto.months            =        localeMonths;
	prototype__proto._months           = defaultLocaleMonths;
	prototype__proto.monthsShort       =        localeMonthsShort;
	prototype__proto._monthsShort      = defaultLocaleMonthsShort;
	prototype__proto.monthsParse       =        localeMonthsParse;
	prototype__proto._monthsRegex      = defaultMonthsRegex;
	prototype__proto.monthsRegex       = monthsRegex;
	prototype__proto._monthsShortRegex = defaultMonthsShortRegex;
	prototype__proto.monthsShortRegex  = monthsShortRegex;

	// Week
	prototype__proto.week = localeWeek;
	prototype__proto._week = defaultLocaleWeek;
	prototype__proto.firstDayOfYear = localeFirstDayOfYear;
	prototype__proto.firstDayOfWeek = localeFirstDayOfWeek;

	// Day of Week
	prototype__proto.weekdays       =        localeWeekdays;
	prototype__proto._weekdays      = defaultLocaleWeekdays;
	prototype__proto.weekdaysMin    =        localeWeekdaysMin;
	prototype__proto._weekdaysMin   = defaultLocaleWeekdaysMin;
	prototype__proto.weekdaysShort  =        localeWeekdaysShort;
	prototype__proto._weekdaysShort = defaultLocaleWeekdaysShort;
	prototype__proto.weekdaysParse  =        localeWeekdaysParse;

	// Hours
	prototype__proto.isPM = localeIsPM;
	prototype__proto._meridiemParse = defaultLocaleMeridiemParse;
	prototype__proto.meridiem = localeMeridiem;

	function lists__get (format, index, field, setter) {
		var locale = locale_locales__getLocale();
		var utc = create_utc__createUTC().set(setter, index);
		return locale[field](utc, format);
	}

	function list (format, index, field, count, setter) {
		if (typeof format === 'number') {
			index = format;
			format = undefined;
		}

		format = format || '';

		if (index != null) {
			return lists__get(format, index, field, setter);
		}

		var i;
		var out = [];
		for (i = 0; i < count; i++) {
			out[i] = lists__get(format, i, field, setter);
		}
		return out;
	}

	function lists__listMonths (format, index) {
		return list(format, index, 'months', 12, 'month');
	}

	function lists__listMonthsShort (format, index) {
		return list(format, index, 'monthsShort', 12, 'month');
	}

	function lists__listWeekdays (format, index) {
		return list(format, index, 'weekdays', 7, 'day');
	}

	function lists__listWeekdaysShort (format, index) {
		return list(format, index, 'weekdaysShort', 7, 'day');
	}

	function lists__listWeekdaysMin (format, index) {
		return list(format, index, 'weekdaysMin', 7, 'day');
	}

	locale_locales__getSetGlobalLocale('en', {
		ordinalParse: /\d{1,2}(th|st|nd|rd)/,
		ordinal : function (number) {
			var b = number % 10,
				output = (toInt(number % 100 / 10) === 1) ? 'th' :
				(b === 1) ? 'st' :
				(b === 2) ? 'nd' :
				(b === 3) ? 'rd' : 'th';
			return number + output;
		}
	});

	// Side effect imports
	utils_hooks__hooks.lang = deprecate('moment.lang is deprecated. Use moment.locale instead.', locale_locales__getSetGlobalLocale);
	utils_hooks__hooks.langData = deprecate('moment.langData is deprecated. Use moment.localeData instead.', locale_locales__getLocale);

	var mathAbs = Math.abs;

	function duration_abs__abs () {
		var data           = this._data;

		this._milliseconds = mathAbs(this._milliseconds);
		this._days         = mathAbs(this._days);
		this._months       = mathAbs(this._months);

		data.milliseconds  = mathAbs(data.milliseconds);
		data.seconds       = mathAbs(data.seconds);
		data.minutes       = mathAbs(data.minutes);
		data.hours         = mathAbs(data.hours);
		data.months        = mathAbs(data.months);
		data.years         = mathAbs(data.years);

		return this;
	}

	function duration_add_subtract__addSubtract (duration, input, value, direction) {
		var other = create__createDuration(input, value);

		duration._milliseconds += direction * other._milliseconds;
		duration._days         += direction * other._days;
		duration._months       += direction * other._months;

		return duration._bubble();
	}

	// supports only 2.0-style add(1, 's') or add(duration)
	function duration_add_subtract__add (input, value) {
		return duration_add_subtract__addSubtract(this, input, value, 1);
	}

	// supports only 2.0-style subtract(1, 's') or subtract(duration)
	function duration_add_subtract__subtract (input, value) {
		return duration_add_subtract__addSubtract(this, input, value, -1);
	}

	function absCeil (number) {
		if (number < 0) {
			return Math.floor(number);
		} else {
			return Math.ceil(number);
		}
	}

	function bubble () {
		var milliseconds = this._milliseconds;
		var days         = this._days;
		var months       = this._months;
		var data         = this._data;
		var seconds, minutes, hours, years, monthsFromDays;

		// if we have a mix of positive and negative values, bubble down first
		// check: https://github.com/moment/moment/issues/2166
		if (!((milliseconds >= 0 && days >= 0 && months >= 0) ||
				(milliseconds <= 0 && days <= 0 && months <= 0))) {
			milliseconds += absCeil(monthsToDays(months) + days) * 864e5;
			days = 0;
			months = 0;
		}

		// The following code bubbles up values, see the tests for
		// examples of what that means.
		data.milliseconds = milliseconds % 1000;

		seconds           = absFloor(milliseconds / 1000);
		data.seconds      = seconds % 60;

		minutes           = absFloor(seconds / 60);
		data.minutes      = minutes % 60;

		hours             = absFloor(minutes / 60);
		data.hours        = hours % 24;

		days += absFloor(hours / 24);

		// convert days to months
		monthsFromDays = absFloor(daysToMonths(days));
		months += monthsFromDays;
		days -= absCeil(monthsToDays(monthsFromDays));

		// 12 months -> 1 year
		years = absFloor(months / 12);
		months %= 12;

		data.days   = days;
		data.months = months;
		data.years  = years;

		return this;
	}

	function daysToMonths (days) {
		// 400 years have 146097 days (taking into account leap year rules)
		// 400 years have 12 months === 4800
		return days * 4800 / 146097;
	}

	function monthsToDays (months) {
		// the reverse of daysToMonths
		return months * 146097 / 4800;
	}

	function as (units) {
		var days;
		var months;
		var milliseconds = this._milliseconds;

		units = normalizeUnits(units);

		if (units === 'month' || units === 'year') {
			days   = this._days   + milliseconds / 864e5;
			months = this._months + daysToMonths(days);
			return units === 'month' ? months : months / 12;
		} else {
			// handle milliseconds separately because of floating point math errors (issue #1867)
			days = this._days + Math.round(monthsToDays(this._months));
			switch (units) {
				case 'week'   : return days / 7     + milliseconds / 6048e5;
				case 'day'    : return days         + milliseconds / 864e5;
				case 'hour'   : return days * 24    + milliseconds / 36e5;
				case 'minute' : return days * 1440  + milliseconds / 6e4;
				case 'second' : return days * 86400 + milliseconds / 1000;
				// Math.floor prevents floating point math errors here
				case 'millisecond': return Math.floor(days * 864e5) + milliseconds;
				default: throw new Error('Unknown unit ' + units);
			}
		}
	}

	// TODO: Use this.as('ms')?
	function duration_as__valueOf () {
		return (
			this._milliseconds +
			this._days * 864e5 +
			(this._months % 12) * 2592e6 +
			toInt(this._months / 12) * 31536e6
		);
	}

	function makeAs (alias) {
		return function () {
			return this.as(alias);
		};
	}

	var asMilliseconds = makeAs('ms');
	var asSeconds      = makeAs('s');
	var asMinutes      = makeAs('m');
	var asHours        = makeAs('h');
	var asDays         = makeAs('d');
	var asWeeks        = makeAs('w');
	var asMonths       = makeAs('M');
	var asYears        = makeAs('y');

	function duration_get__get (units) {
		units = normalizeUnits(units);
		return this[units + 's']();
	}

	function makeGetter(name) {
		return function () {
			return this._data[name];
		};
	}

	var milliseconds = makeGetter('milliseconds');
	var seconds      = makeGetter('seconds');
	var minutes      = makeGetter('minutes');
	var hours        = makeGetter('hours');
	var days         = makeGetter('days');
	var duration_get__months       = makeGetter('months');
	var years        = makeGetter('years');

	function weeks () {
		return absFloor(this.days() / 7);
	}

	var round = Math.round;
	var thresholds = {
		s: 45,  // seconds to minute
		m: 45,  // minutes to hour
		h: 22,  // hours to day
		d: 26,  // days to month
		M: 11   // months to year
	};

	// helper function for moment.fn.from, moment.fn.fromNow, and moment.duration.fn.humanize
	function substituteTimeAgo(string, number, withoutSuffix, isFuture, locale) {
		return locale.relativeTime(number || 1, !!withoutSuffix, string, isFuture);
	}

	function duration_humanize__relativeTime (posNegDuration, withoutSuffix, locale) {
		var duration = create__createDuration(posNegDuration).abs();
		var seconds  = round(duration.as('s'));
		var minutes  = round(duration.as('m'));
		var hours    = round(duration.as('h'));
		var days     = round(duration.as('d'));
		var months   = round(duration.as('M'));
		var years    = round(duration.as('y'));

		var a = seconds < thresholds.s && ['s', seconds]  ||
				minutes <= 1           && ['m']           ||
				minutes < thresholds.m && ['mm', minutes] ||
				hours   <= 1           && ['h']           ||
				hours   < thresholds.h && ['hh', hours]   ||
				days    <= 1           && ['d']           ||
				days    < thresholds.d && ['dd', days]    ||
				months  <= 1           && ['M']           ||
				months  < thresholds.M && ['MM', months]  ||
				years   <= 1           && ['y']           || ['yy', years];

		a[2] = withoutSuffix;
		a[3] = +posNegDuration > 0;
		a[4] = locale;
		return substituteTimeAgo.apply(null, a);
	}

	// This function allows you to set a threshold for relative time strings
	function duration_humanize__getSetRelativeTimeThreshold (threshold, limit) {
		if (thresholds[threshold] === undefined) {
			return false;
		}
		if (limit === undefined) {
			return thresholds[threshold];
		}
		thresholds[threshold] = limit;
		return true;
	}

	function humanize (withSuffix) {
		var locale = this.localeData();
		var output = duration_humanize__relativeTime(this, !withSuffix, locale);

		if (withSuffix) {
			output = locale.pastFuture(+this, output);
		}

		return locale.postformat(output);
	}

	var iso_string__abs = Math.abs;

	function iso_string__toISOString() {
		// for ISO strings we do not use the normal bubbling rules:
		//  * milliseconds bubble up until they become hours
		//  * days do not bubble at all
		//  * months bubble up until they become years
		// This is because there is no context-free conversion between hours and days
		// (think of clock changes)
		// and also not between days and months (28-31 days per month)
		var seconds = iso_string__abs(this._milliseconds) / 1000;
		var days         = iso_string__abs(this._days);
		var months       = iso_string__abs(this._months);
		var minutes, hours, years;

		// 3600 seconds -> 60 minutes -> 1 hour
		minutes           = absFloor(seconds / 60);
		hours             = absFloor(minutes / 60);
		seconds %= 60;
		minutes %= 60;

		// 12 months -> 1 year
		years  = absFloor(months / 12);
		months %= 12;


		// inspired by https://github.com/dordille/moment-isoduration/blob/master/moment.isoduration.js
		var Y = years;
		var M = months;
		var D = days;
		var h = hours;
		var m = minutes;
		var s = seconds;
		var total = this.asSeconds();

		if (!total) {
			// this is the same as C#'s (Noda) and python (isodate)...
			// but not other JS (goog.date)
			return 'P0D';
		}

		return (total < 0 ? '-' : '') +
			'P' +
			(Y ? Y + 'Y' : '') +
			(M ? M + 'M' : '') +
			(D ? D + 'D' : '') +
			((h || m || s) ? 'T' : '') +
			(h ? h + 'H' : '') +
			(m ? m + 'M' : '') +
			(s ? s + 'S' : '');
	}

	var duration_prototype__proto = Duration.prototype;

	duration_prototype__proto.abs            = duration_abs__abs;
	duration_prototype__proto.add            = duration_add_subtract__add;
	duration_prototype__proto.subtract       = duration_add_subtract__subtract;
	duration_prototype__proto.as             = as;
	duration_prototype__proto.asMilliseconds = asMilliseconds;
	duration_prototype__proto.asSeconds      = asSeconds;
	duration_prototype__proto.asMinutes      = asMinutes;
	duration_prototype__proto.asHours        = asHours;
	duration_prototype__proto.asDays         = asDays;
	duration_prototype__proto.asWeeks        = asWeeks;
	duration_prototype__proto.asMonths       = asMonths;
	duration_prototype__proto.asYears        = asYears;
	duration_prototype__proto.valueOf        = duration_as__valueOf;
	duration_prototype__proto._bubble        = bubble;
	duration_prototype__proto.get            = duration_get__get;
	duration_prototype__proto.milliseconds   = milliseconds;
	duration_prototype__proto.seconds        = seconds;
	duration_prototype__proto.minutes        = minutes;
	duration_prototype__proto.hours          = hours;
	duration_prototype__proto.days           = days;
	duration_prototype__proto.weeks          = weeks;
	duration_prototype__proto.months         = duration_get__months;
	duration_prototype__proto.years          = years;
	duration_prototype__proto.humanize       = humanize;
	duration_prototype__proto.toISOString    = iso_string__toISOString;
	duration_prototype__proto.toString       = iso_string__toISOString;
	duration_prototype__proto.toJSON         = iso_string__toISOString;
	duration_prototype__proto.locale         = locale;
	duration_prototype__proto.localeData     = localeData;

	// Deprecations
	duration_prototype__proto.toIsoString = deprecate('toIsoString() is deprecated. Please use toISOString() instead (notice the capitals)', iso_string__toISOString);
	duration_prototype__proto.lang = lang;

	// Side effect imports

	// FORMATTING

	addFormatToken('X', 0, 0, 'unix');
	addFormatToken('x', 0, 0, 'valueOf');

	// PARSING

	addRegexToken('x', matchSigned);
	addRegexToken('X', matchTimestamp);
	addParseToken('X', function (input, array, config) {
		config._d = new Date(parseFloat(input, 10) * 1000);
	});
	addParseToken('x', function (input, array, config) {
		config._d = new Date(toInt(input));
	});

	// Side effect imports

	;

	//! moment.js
	//! version : 2.11.2
	//! authors : Tim Wood, Iskren Chernev, Moment.js contributors
	//! license : MIT
	//! momentjs.com

	utils_hooks__hooks.version = '2.11.2';

	setHookCallback(local__createLocal);

	utils_hooks__hooks.fn                    = momentPrototype;
	utils_hooks__hooks.min                   = min;
	utils_hooks__hooks.max                   = max;
	utils_hooks__hooks.now                   = now;
	utils_hooks__hooks.utc                   = create_utc__createUTC;
	utils_hooks__hooks.unix                  = moment_moment__createUnix;
	utils_hooks__hooks.months                = lists__listMonths;
	utils_hooks__hooks.isDate                = isDate;
	utils_hooks__hooks.locale                = locale_locales__getSetGlobalLocale;
	utils_hooks__hooks.invalid               = valid__createInvalid;
	utils_hooks__hooks.duration              = create__createDuration;
	utils_hooks__hooks.isMoment              = isMoment;
	utils_hooks__hooks.weekdays              = lists__listWeekdays;
	utils_hooks__hooks.parseZone             = moment_moment__createInZone;
	utils_hooks__hooks.localeData            = locale_locales__getLocale;
	utils_hooks__hooks.isDuration            = isDuration;
	utils_hooks__hooks.monthsShort           = lists__listMonthsShort;
	utils_hooks__hooks.weekdaysMin           = lists__listWeekdaysMin;
	utils_hooks__hooks.defineLocale          = defineLocale;
	utils_hooks__hooks.weekdaysShort         = lists__listWeekdaysShort;
	utils_hooks__hooks.normalizeUnits        = normalizeUnits;
	utils_hooks__hooks.relativeTimeThreshold = duration_humanize__getSetRelativeTimeThreshold;
	utils_hooks__hooks.prototype             = momentPrototype;

	var moment__default = utils_hooks__hooks;

	//! moment.js locale configuration
	//! locale : afrikaans (af)
	//! author : Werner Mollentze : https://github.com/wernerm

	var af = moment__default.defineLocale('af', {
		months : 'Januarie_Februarie_Maart_April_Mei_Junie_Julie_Augustus_September_Oktober_November_Desember'.split('_'),
		monthsShort : 'Jan_Feb_Mar_Apr_Mei_Jun_Jul_Aug_Sep_Okt_Nov_Des'.split('_'),
		weekdays : 'Sondag_Maandag_Dinsdag_Woensdag_Donderdag_Vrydag_Saterdag'.split('_'),
		weekdaysShort : 'Son_Maa_Din_Woe_Don_Vry_Sat'.split('_'),
		weekdaysMin : 'So_Ma_Di_Wo_Do_Vr_Sa'.split('_'),
		meridiemParse: /vm|nm/i,
		isPM : function (input) {
			return /^nm$/i.test(input);
		},
		meridiem : function (hours, minutes, isLower) {
			if (hours < 12) {
				return isLower ? 'vm' : 'VM';
			} else {
				return isLower ? 'nm' : 'NM';
			}
		},
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd, D MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay : '[Vandag om] LT',
			nextDay : '[Môre om] LT',
			nextWeek : 'dddd [om] LT',
			lastDay : '[Gister om] LT',
			lastWeek : '[Laas] dddd [om] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'oor %s',
			past : '%s gelede',
			s : '\'n paar sekondes',
			m : '\'n minuut',
			mm : '%d minute',
			h : '\'n uur',
			hh : '%d ure',
			d : '\'n dag',
			dd : '%d dae',
			M : '\'n maand',
			MM : '%d maande',
			y : '\'n jaar',
			yy : '%d jaar'
		},
		ordinalParse: /\d{1,2}(ste|de)/,
		ordinal : function (number) {
			return number + ((number === 1 || number === 8 || number >= 20) ? 'ste' : 'de'); // Thanks to Joris Röling : https://github.com/jjupiter
		},
		week : {
			dow : 1, // Maandag is die eerste dag van die week.
			doy : 4  // Die week wat die 4de Januarie bevat is die eerste week van die jaar.
		}
	});

	//! moment.js locale configuration
	//! locale : Moroccan Arabic (ar-ma)
	//! author : ElFadili Yassine : https://github.com/ElFadiliY
	//! author : Abdel Said : https://github.com/abdelsaid

	var ar_ma = moment__default.defineLocale('ar-ma', {
		months : 'يناير_فبراير_مارس_أبريل_ماي_يونيو_يوليوز_غشت_شتنبر_أكتوبر_نونبر_دجنبر'.split('_'),
		monthsShort : 'يناير_فبراير_مارس_أبريل_ماي_يونيو_يوليوز_غشت_شتنبر_أكتوبر_نونبر_دجنبر'.split('_'),
		weekdays : 'الأحد_الإتنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت'.split('_'),
		weekdaysShort : 'احد_اتنين_ثلاثاء_اربعاء_خميس_جمعة_سبت'.split('_'),
		weekdaysMin : 'ح_ن_ث_ر_خ_ج_س'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd D MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay: '[اليوم على الساعة] LT',
			nextDay: '[غدا على الساعة] LT',
			nextWeek: 'dddd [على الساعة] LT',
			lastDay: '[أمس على الساعة] LT',
			lastWeek: 'dddd [على الساعة] LT',
			sameElse: 'L'
		},
		relativeTime : {
			future : 'في %s',
			past : 'منذ %s',
			s : 'ثوان',
			m : 'دقيقة',
			mm : '%d دقائق',
			h : 'ساعة',
			hh : '%d ساعات',
			d : 'يوم',
			dd : '%d أيام',
			M : 'شهر',
			MM : '%d أشهر',
			y : 'سنة',
			yy : '%d سنوات'
		},
		week : {
			dow : 6, // Saturday is the first day of the week.
			doy : 12  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : Arabic Saudi Arabia (ar-sa)
	//! author : Suhail Alkowaileet : https://github.com/xsoh

	var ar_sa__symbolMap = {
		'1': '١',
		'2': '٢',
		'3': '٣',
		'4': '٤',
		'5': '٥',
		'6': '٦',
		'7': '٧',
		'8': '٨',
		'9': '٩',
		'0': '٠'
	}, ar_sa__numberMap = {
		'١': '1',
		'٢': '2',
		'٣': '3',
		'٤': '4',
		'٥': '5',
		'٦': '6',
		'٧': '7',
		'٨': '8',
		'٩': '9',
		'٠': '0'
	};

	var ar_sa = moment__default.defineLocale('ar-sa', {
		months : 'يناير_فبراير_مارس_أبريل_مايو_يونيو_يوليو_أغسطس_سبتمبر_أكتوبر_نوفمبر_ديسمبر'.split('_'),
		monthsShort : 'يناير_فبراير_مارس_أبريل_مايو_يونيو_يوليو_أغسطس_سبتمبر_أكتوبر_نوفمبر_ديسمبر'.split('_'),
		weekdays : 'الأحد_الإثنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت'.split('_'),
		weekdaysShort : 'أحد_إثنين_ثلاثاء_أربعاء_خميس_جمعة_سبت'.split('_'),
		weekdaysMin : 'ح_ن_ث_ر_خ_ج_س'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd D MMMM YYYY HH:mm'
		},
		meridiemParse: /ص|م/,
		isPM : function (input) {
			return 'م' === input;
		},
		meridiem : function (hour, minute, isLower) {
			if (hour < 12) {
				return 'ص';
			} else {
				return 'م';
			}
		},
		calendar : {
			sameDay: '[اليوم على الساعة] LT',
			nextDay: '[غدا على الساعة] LT',
			nextWeek: 'dddd [على الساعة] LT',
			lastDay: '[أمس على الساعة] LT',
			lastWeek: 'dddd [على الساعة] LT',
			sameElse: 'L'
		},
		relativeTime : {
			future : 'في %s',
			past : 'منذ %s',
			s : 'ثوان',
			m : 'دقيقة',
			mm : '%d دقائق',
			h : 'ساعة',
			hh : '%d ساعات',
			d : 'يوم',
			dd : '%d أيام',
			M : 'شهر',
			MM : '%d أشهر',
			y : 'سنة',
			yy : '%d سنوات'
		},
		preparse: function (string) {
			return string.replace(/[١٢٣٤٥٦٧٨٩٠]/g, function (match) {
				return ar_sa__numberMap[match];
			}).replace(/،/g, ',');
		},
		postformat: function (string) {
			return string.replace(/\d/g, function (match) {
				return ar_sa__symbolMap[match];
			}).replace(/,/g, '،');
		},
		week : {
			dow : 6, // Saturday is the first day of the week.
			doy : 12  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale  : Tunisian Arabic (ar-tn)

	var ar_tn = moment__default.defineLocale('ar-tn', {
		months: 'جانفي_فيفري_مارس_أفريل_ماي_جوان_جويلية_أوت_سبتمبر_أكتوبر_نوفمبر_ديسمبر'.split('_'),
		monthsShort: 'جانفي_فيفري_مارس_أفريل_ماي_جوان_جويلية_أوت_سبتمبر_أكتوبر_نوفمبر_ديسمبر'.split('_'),
		weekdays: 'الأحد_الإثنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت'.split('_'),
		weekdaysShort: 'أحد_إثنين_ثلاثاء_أربعاء_خميس_جمعة_سبت'.split('_'),
		weekdaysMin: 'ح_ن_ث_ر_خ_ج_س'.split('_'),
		longDateFormat: {
			LT: 'HH:mm',
			LTS: 'HH:mm:ss',
			L: 'DD/MM/YYYY',
			LL: 'D MMMM YYYY',
			LLL: 'D MMMM YYYY HH:mm',
			LLLL: 'dddd D MMMM YYYY HH:mm'
		},
		calendar: {
			sameDay: '[اليوم على الساعة] LT',
			nextDay: '[غدا على الساعة] LT',
			nextWeek: 'dddd [على الساعة] LT',
			lastDay: '[أمس على الساعة] LT',
			lastWeek: 'dddd [على الساعة] LT',
			sameElse: 'L'
		},
		relativeTime: {
			future: 'في %s',
			past: 'منذ %s',
			s: 'ثوان',
			m: 'دقيقة',
			mm: '%d دقائق',
			h: 'ساعة',
			hh: '%d ساعات',
			d: 'يوم',
			dd: '%d أيام',
			M: 'شهر',
			MM: '%d أشهر',
			y: 'سنة',
			yy: '%d سنوات'
		},
		week: {
			dow: 1, // Monday is the first day of the week.
			doy: 4 // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! Locale: Arabic (ar)
	//! Author: Abdel Said: https://github.com/abdelsaid
	//! Changes in months, weekdays: Ahmed Elkhatib
	//! Native plural forms: forabi https://github.com/forabi

	var ar__symbolMap = {
		'1': '١',
		'2': '٢',
		'3': '٣',
		'4': '٤',
		'5': '٥',
		'6': '٦',
		'7': '٧',
		'8': '٨',
		'9': '٩',
		'0': '٠'
	}, ar__numberMap = {
		'١': '1',
		'٢': '2',
		'٣': '3',
		'٤': '4',
		'٥': '5',
		'٦': '6',
		'٧': '7',
		'٨': '8',
		'٩': '9',
		'٠': '0'
	}, pluralForm = function (n) {
		return n === 0 ? 0 : n === 1 ? 1 : n === 2 ? 2 : n % 100 >= 3 && n % 100 <= 10 ? 3 : n % 100 >= 11 ? 4 : 5;
	}, plurals = {
		s : ['أقل من ثانية', 'ثانية واحدة', ['ثانيتان', 'ثانيتين'], '%d ثوان', '%d ثانية', '%d ثانية'],
		m : ['أقل من دقيقة', 'دقيقة واحدة', ['دقيقتان', 'دقيقتين'], '%d دقائق', '%d دقيقة', '%d دقيقة'],
		h : ['أقل من ساعة', 'ساعة واحدة', ['ساعتان', 'ساعتين'], '%d ساعات', '%d ساعة', '%d ساعة'],
		d : ['أقل من يوم', 'يوم واحد', ['يومان', 'يومين'], '%d أيام', '%d يومًا', '%d يوم'],
		M : ['أقل من شهر', 'شهر واحد', ['شهران', 'شهرين'], '%d أشهر', '%d شهرا', '%d شهر'],
		y : ['أقل من عام', 'عام واحد', ['عامان', 'عامين'], '%d أعوام', '%d عامًا', '%d عام']
	}, pluralize = function (u) {
		return function (number, withoutSuffix, string, isFuture) {
			var f = pluralForm(number),
				str = plurals[u][pluralForm(number)];
			if (f === 2) {
				str = str[withoutSuffix ? 0 : 1];
			}
			return str.replace(/%d/i, number);
		};
	}, ar__months = [
		'كانون الثاني يناير',
		'شباط فبراير',
		'آذار مارس',
		'نيسان أبريل',
		'أيار مايو',
		'حزيران يونيو',
		'تموز يوليو',
		'آب أغسطس',
		'أيلول سبتمبر',
		'تشرين الأول أكتوبر',
		'تشرين الثاني نوفمبر',
		'كانون الأول ديسمبر'
	];

	var ar = moment__default.defineLocale('ar', {
		months : ar__months,
		monthsShort : ar__months,
		weekdays : 'الأحد_الإثنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت'.split('_'),
		weekdaysShort : 'أحد_إثنين_ثلاثاء_أربعاء_خميس_جمعة_سبت'.split('_'),
		weekdaysMin : 'ح_ن_ث_ر_خ_ج_س'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'D/\u200FM/\u200FYYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd D MMMM YYYY HH:mm'
		},
		meridiemParse: /ص|م/,
		isPM : function (input) {
			return 'م' === input;
		},
		meridiem : function (hour, minute, isLower) {
			if (hour < 12) {
				return 'ص';
			} else {
				return 'م';
			}
		},
		calendar : {
			sameDay: '[اليوم عند الساعة] LT',
			nextDay: '[غدًا عند الساعة] LT',
			nextWeek: 'dddd [عند الساعة] LT',
			lastDay: '[أمس عند الساعة] LT',
			lastWeek: 'dddd [عند الساعة] LT',
			sameElse: 'L'
		},
		relativeTime : {
			future : 'بعد %s',
			past : 'منذ %s',
			s : pluralize('s'),
			m : pluralize('m'),
			mm : pluralize('m'),
			h : pluralize('h'),
			hh : pluralize('h'),
			d : pluralize('d'),
			dd : pluralize('d'),
			M : pluralize('M'),
			MM : pluralize('M'),
			y : pluralize('y'),
			yy : pluralize('y')
		},
		preparse: function (string) {
			return string.replace(/\u200f/g, '').replace(/[١٢٣٤٥٦٧٨٩٠]/g, function (match) {
				return ar__numberMap[match];
			}).replace(/،/g, ',');
		},
		postformat: function (string) {
			return string.replace(/\d/g, function (match) {
				return ar__symbolMap[match];
			}).replace(/,/g, '،');
		},
		week : {
			dow : 6, // Saturday is the first day of the week.
			doy : 12  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : azerbaijani (az)
	//! author : topchiyev : https://github.com/topchiyev

	var az__suffixes = {
		1: '-inci',
		5: '-inci',
		8: '-inci',
		70: '-inci',
		80: '-inci',
		2: '-nci',
		7: '-nci',
		20: '-nci',
		50: '-nci',
		3: '-üncü',
		4: '-üncü',
		100: '-üncü',
		6: '-ncı',
		9: '-uncu',
		10: '-uncu',
		30: '-uncu',
		60: '-ıncı',
		90: '-ıncı'
	};

	var az = moment__default.defineLocale('az', {
		months : 'yanvar_fevral_mart_aprel_may_iyun_iyul_avqust_sentyabr_oktyabr_noyabr_dekabr'.split('_'),
		monthsShort : 'yan_fev_mar_apr_may_iyn_iyl_avq_sen_okt_noy_dek'.split('_'),
		weekdays : 'Bazar_Bazar ertəsi_Çərşənbə axşamı_Çərşənbə_Cümə axşamı_Cümə_Şənbə'.split('_'),
		weekdaysShort : 'Baz_BzE_ÇAx_Çər_CAx_Cüm_Şən'.split('_'),
		weekdaysMin : 'Bz_BE_ÇA_Çə_CA_Cü_Şə'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD.MM.YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd, D MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay : '[bugün saat] LT',
			nextDay : '[sabah saat] LT',
			nextWeek : '[gələn həftə] dddd [saat] LT',
			lastDay : '[dünən] LT',
			lastWeek : '[keçən həftə] dddd [saat] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : '%s sonra',
			past : '%s əvvəl',
			s : 'birneçə saniyyə',
			m : 'bir dəqiqə',
			mm : '%d dəqiqə',
			h : 'bir saat',
			hh : '%d saat',
			d : 'bir gün',
			dd : '%d gün',
			M : 'bir ay',
			MM : '%d ay',
			y : 'bir il',
			yy : '%d il'
		},
		meridiemParse: /gecə|səhər|gündüz|axşam/,
		isPM : function (input) {
			return /^(gündüz|axşam)$/.test(input);
		},
		meridiem : function (hour, minute, isLower) {
			if (hour < 4) {
				return 'gecə';
			} else if (hour < 12) {
				return 'səhər';
			} else if (hour < 17) {
				return 'gündüz';
			} else {
				return 'axşam';
			}
		},
		ordinalParse: /\d{1,2}-(ıncı|inci|nci|üncü|ncı|uncu)/,
		ordinal : function (number) {
			if (number === 0) {  // special case for zero
				return number + '-ıncı';
			}
			var a = number % 10,
				b = number % 100 - a,
				c = number >= 100 ? 100 : null;
			return number + (az__suffixes[a] || az__suffixes[b] || az__suffixes[c]);
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : belarusian (be)
	//! author : Dmitry Demidov : https://github.com/demidov91
	//! author: Praleska: http://praleska.pro/
	//! Author : Menelion Elensúle : https://github.com/Oire

	function be__plural(word, num) {
		var forms = word.split('_');
		return num % 10 === 1 && num % 100 !== 11 ? forms[0] : (num % 10 >= 2 && num % 10 <= 4 && (num % 100 < 10 || num % 100 >= 20) ? forms[1] : forms[2]);
	}
	function be__relativeTimeWithPlural(number, withoutSuffix, key) {
		var format = {
			'mm': withoutSuffix ? 'хвіліна_хвіліны_хвілін' : 'хвіліну_хвіліны_хвілін',
			'hh': withoutSuffix ? 'гадзіна_гадзіны_гадзін' : 'гадзіну_гадзіны_гадзін',
			'dd': 'дзень_дні_дзён',
			'MM': 'месяц_месяцы_месяцаў',
			'yy': 'год_гады_гадоў'
		};
		if (key === 'm') {
			return withoutSuffix ? 'хвіліна' : 'хвіліну';
		}
		else if (key === 'h') {
			return withoutSuffix ? 'гадзіна' : 'гадзіну';
		}
		else {
			return number + ' ' + be__plural(format[key], +number);
		}
	}

	var be = moment__default.defineLocale('be', {
		months : {
			format: 'студзеня_лютага_сакавіка_красавіка_траўня_чэрвеня_ліпеня_жніўня_верасня_кастрычніка_лістапада_снежня'.split('_'),
			standalone: 'студзень_люты_сакавік_красавік_травень_чэрвень_ліпень_жнівень_верасень_кастрычнік_лістапад_снежань'.split('_')
		},
		monthsShort : 'студ_лют_сак_крас_трав_чэрв_ліп_жнів_вер_каст_ліст_снеж'.split('_'),
		weekdays : {
			format: 'нядзелю_панядзелак_аўторак_сераду_чацвер_пятніцу_суботу'.split('_'),
			standalone: 'нядзеля_панядзелак_аўторак_серада_чацвер_пятніца_субота'.split('_'),
			isFormat: /\[ ?[Вв] ?(?:мінулую|наступную)? ?\] ?dddd/
		},
		weekdaysShort : 'нд_пн_ат_ср_чц_пт_сб'.split('_'),
		weekdaysMin : 'нд_пн_ат_ср_чц_пт_сб'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD.MM.YYYY',
			LL : 'D MMMM YYYY г.',
			LLL : 'D MMMM YYYY г., HH:mm',
			LLLL : 'dddd, D MMMM YYYY г., HH:mm'
		},
		calendar : {
			sameDay: '[Сёння ў] LT',
			nextDay: '[Заўтра ў] LT',
			lastDay: '[Учора ў] LT',
			nextWeek: function () {
				return '[У] dddd [ў] LT';
			},
			lastWeek: function () {
				switch (this.day()) {
				case 0:
				case 3:
				case 5:
				case 6:
					return '[У мінулую] dddd [ў] LT';
				case 1:
				case 2:
				case 4:
					return '[У мінулы] dddd [ў] LT';
				}
			},
			sameElse: 'L'
		},
		relativeTime : {
			future : 'праз %s',
			past : '%s таму',
			s : 'некалькі секунд',
			m : be__relativeTimeWithPlural,
			mm : be__relativeTimeWithPlural,
			h : be__relativeTimeWithPlural,
			hh : be__relativeTimeWithPlural,
			d : 'дзень',
			dd : be__relativeTimeWithPlural,
			M : 'месяц',
			MM : be__relativeTimeWithPlural,
			y : 'год',
			yy : be__relativeTimeWithPlural
		},
		meridiemParse: /ночы|раніцы|дня|вечара/,
		isPM : function (input) {
			return /^(дня|вечара)$/.test(input);
		},
		meridiem : function (hour, minute, isLower) {
			if (hour < 4) {
				return 'ночы';
			} else if (hour < 12) {
				return 'раніцы';
			} else if (hour < 17) {
				return 'дня';
			} else {
				return 'вечара';
			}
		},
		ordinalParse: /\d{1,2}-(і|ы|га)/,
		ordinal: function (number, period) {
			switch (period) {
			case 'M':
			case 'd':
			case 'DDD':
			case 'w':
			case 'W':
				return (number % 10 === 2 || number % 10 === 3) && (number % 100 !== 12 && number % 100 !== 13) ? number + '-і' : number + '-ы';
			case 'D':
				return number + '-га';
			default:
				return number;
			}
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : bulgarian (bg)
	//! author : Krasen Borisov : https://github.com/kraz

	var bg = moment__default.defineLocale('bg', {
		months : 'януари_февруари_март_април_май_юни_юли_август_септември_октомври_ноември_декември'.split('_'),
		monthsShort : 'янр_фев_мар_апр_май_юни_юли_авг_сеп_окт_ное_дек'.split('_'),
		weekdays : 'неделя_понеделник_вторник_сряда_четвъртък_петък_събота'.split('_'),
		weekdaysShort : 'нед_пон_вто_сря_чет_пет_съб'.split('_'),
		weekdaysMin : 'нд_пн_вт_ср_чт_пт_сб'.split('_'),
		longDateFormat : {
			LT : 'H:mm',
			LTS : 'H:mm:ss',
			L : 'D.MM.YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY H:mm',
			LLLL : 'dddd, D MMMM YYYY H:mm'
		},
		calendar : {
			sameDay : '[Днес в] LT',
			nextDay : '[Утре в] LT',
			nextWeek : 'dddd [в] LT',
			lastDay : '[Вчера в] LT',
			lastWeek : function () {
				switch (this.day()) {
				case 0:
				case 3:
				case 6:
					return '[В изминалата] dddd [в] LT';
				case 1:
				case 2:
				case 4:
				case 5:
					return '[В изминалия] dddd [в] LT';
				}
			},
			sameElse : 'L'
		},
		relativeTime : {
			future : 'след %s',
			past : 'преди %s',
			s : 'няколко секунди',
			m : 'минута',
			mm : '%d минути',
			h : 'час',
			hh : '%d часа',
			d : 'ден',
			dd : '%d дни',
			M : 'месец',
			MM : '%d месеца',
			y : 'година',
			yy : '%d години'
		},
		ordinalParse: /\d{1,2}-(ев|ен|ти|ви|ри|ми)/,
		ordinal : function (number) {
			var lastDigit = number % 10,
				last2Digits = number % 100;
			if (number === 0) {
				return number + '-ев';
			} else if (last2Digits === 0) {
				return number + '-ен';
			} else if (last2Digits > 10 && last2Digits < 20) {
				return number + '-ти';
			} else if (lastDigit === 1) {
				return number + '-ви';
			} else if (lastDigit === 2) {
				return number + '-ри';
			} else if (lastDigit === 7 || lastDigit === 8) {
				return number + '-ми';
			} else {
				return number + '-ти';
			}
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : Bengali (bn)
	//! author : Kaushik Gandhi : https://github.com/kaushikgandhi

	var bn__symbolMap = {
		'1': '১',
		'2': '২',
		'3': '৩',
		'4': '৪',
		'5': '৫',
		'6': '৬',
		'7': '৭',
		'8': '৮',
		'9': '৯',
		'0': '০'
	},
	bn__numberMap = {
		'১': '1',
		'২': '2',
		'৩': '3',
		'৪': '4',
		'৫': '5',
		'৬': '6',
		'৭': '7',
		'৮': '8',
		'৯': '9',
		'০': '0'
	};

	var bn = moment__default.defineLocale('bn', {
		months : 'জানুয়ারী_ফেবুয়ারী_মার্চ_এপ্রিল_মে_জুন_জুলাই_অগাস্ট_সেপ্টেম্বর_অক্টোবর_নভেম্বর_ডিসেম্বর'.split('_'),
		monthsShort : 'জানু_ফেব_মার্চ_এপর_মে_জুন_জুল_অগ_সেপ্ট_অক্টো_নভ_ডিসেম্'.split('_'),
		weekdays : 'রবিবার_সোমবার_মঙ্গলবার_বুধবার_বৃহস্পত্তিবার_শুক্রবার_শনিবার'.split('_'),
		weekdaysShort : 'রবি_সোম_মঙ্গল_বুধ_বৃহস্পত্তি_শুক্র_শনি'.split('_'),
		weekdaysMin : 'রব_সম_মঙ্গ_বু_ব্রিহ_শু_শনি'.split('_'),
		longDateFormat : {
			LT : 'A h:mm সময়',
			LTS : 'A h:mm:ss সময়',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY, A h:mm সময়',
			LLLL : 'dddd, D MMMM YYYY, A h:mm সময়'
		},
		calendar : {
			sameDay : '[আজ] LT',
			nextDay : '[আগামীকাল] LT',
			nextWeek : 'dddd, LT',
			lastDay : '[গতকাল] LT',
			lastWeek : '[গত] dddd, LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : '%s পরে',
			past : '%s আগে',
			s : 'কয়েক সেকেন্ড',
			m : 'এক মিনিট',
			mm : '%d মিনিট',
			h : 'এক ঘন্টা',
			hh : '%d ঘন্টা',
			d : 'এক দিন',
			dd : '%d দিন',
			M : 'এক মাস',
			MM : '%d মাস',
			y : 'এক বছর',
			yy : '%d বছর'
		},
		preparse: function (string) {
			return string.replace(/[১২৩৪৫৬৭৮৯০]/g, function (match) {
				return bn__numberMap[match];
			});
		},
		postformat: function (string) {
			return string.replace(/\d/g, function (match) {
				return bn__symbolMap[match];
			});
		},
		meridiemParse: /রাত|সকাল|দুপুর|বিকাল|রাত/,
		isPM: function (input) {
			return /^(দুপুর|বিকাল|রাত)$/.test(input);
		},
		//Bengali is a vast language its spoken
		//in different forms in various parts of the world.
		//I have just generalized with most common one used
		meridiem : function (hour, minute, isLower) {
			if (hour < 4) {
				return 'রাত';
			} else if (hour < 10) {
				return 'সকাল';
			} else if (hour < 17) {
				return 'দুপুর';
			} else if (hour < 20) {
				return 'বিকাল';
			} else {
				return 'রাত';
			}
		},
		week : {
			dow : 0, // Sunday is the first day of the week.
			doy : 6  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : tibetan (bo)
	//! author : Thupten N. Chakrishar : https://github.com/vajradog

	var bo__symbolMap = {
		'1': '༡',
		'2': '༢',
		'3': '༣',
		'4': '༤',
		'5': '༥',
		'6': '༦',
		'7': '༧',
		'8': '༨',
		'9': '༩',
		'0': '༠'
	},
	bo__numberMap = {
		'༡': '1',
		'༢': '2',
		'༣': '3',
		'༤': '4',
		'༥': '5',
		'༦': '6',
		'༧': '7',
		'༨': '8',
		'༩': '9',
		'༠': '0'
	};

	var bo = moment__default.defineLocale('bo', {
		months : 'ཟླ་བ་དང་པོ_ཟླ་བ་གཉིས་པ_ཟླ་བ་གསུམ་པ_ཟླ་བ་བཞི་པ_ཟླ་བ་ལྔ་པ_ཟླ་བ་དྲུག་པ_ཟླ་བ་བདུན་པ_ཟླ་བ་བརྒྱད་པ_ཟླ་བ་དགུ་པ_ཟླ་བ་བཅུ་པ_ཟླ་བ་བཅུ་གཅིག་པ_ཟླ་བ་བཅུ་གཉིས་པ'.split('_'),
		monthsShort : 'ཟླ་བ་དང་པོ_ཟླ་བ་གཉིས་པ_ཟླ་བ་གསུམ་པ_ཟླ་བ་བཞི་པ_ཟླ་བ་ལྔ་པ_ཟླ་བ་དྲུག་པ_ཟླ་བ་བདུན་པ_ཟླ་བ་བརྒྱད་པ_ཟླ་བ་དགུ་པ_ཟླ་བ་བཅུ་པ_ཟླ་བ་བཅུ་གཅིག་པ_ཟླ་བ་བཅུ་གཉིས་པ'.split('_'),
		weekdays : 'གཟའ་ཉི་མ་_གཟའ་ཟླ་བ་_གཟའ་མིག་དམར་_གཟའ་ལྷག་པ་_གཟའ་ཕུར་བུ_གཟའ་པ་སངས་_གཟའ་སྤེན་པ་'.split('_'),
		weekdaysShort : 'ཉི་མ་_ཟླ་བ་_མིག་དམར་_ལྷག་པ་_ཕུར་བུ_པ་སངས་_སྤེན་པ་'.split('_'),
		weekdaysMin : 'ཉི་མ་_ཟླ་བ་_མིག་དམར་_ལྷག་པ་_ཕུར་བུ_པ་སངས་_སྤེན་པ་'.split('_'),
		longDateFormat : {
			LT : 'A h:mm',
			LTS : 'A h:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY, A h:mm',
			LLLL : 'dddd, D MMMM YYYY, A h:mm'
		},
		calendar : {
			sameDay : '[དི་རིང] LT',
			nextDay : '[སང་ཉིན] LT',
			nextWeek : '[བདུན་ཕྲག་རྗེས་མ], LT',
			lastDay : '[ཁ་སང] LT',
			lastWeek : '[བདུན་ཕྲག་མཐའ་མ] dddd, LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : '%s ལ་',
			past : '%s སྔན་ལ',
			s : 'ལམ་སང',
			m : 'སྐར་མ་གཅིག',
			mm : '%d སྐར་མ',
			h : 'ཆུ་ཚོད་གཅིག',
			hh : '%d ཆུ་ཚོད',
			d : 'ཉིན་གཅིག',
			dd : '%d ཉིན་',
			M : 'ཟླ་བ་གཅིག',
			MM : '%d ཟླ་བ',
			y : 'ལོ་གཅིག',
			yy : '%d ལོ'
		},
		preparse: function (string) {
			return string.replace(/[༡༢༣༤༥༦༧༨༩༠]/g, function (match) {
				return bo__numberMap[match];
			});
		},
		postformat: function (string) {
			return string.replace(/\d/g, function (match) {
				return bo__symbolMap[match];
			});
		},
		meridiemParse: /མཚན་མོ|ཞོགས་ཀས|ཉིན་གུང|དགོང་དག|མཚན་མོ/,
		isPM: function (input) {
			return /^(ཉིན་གུང|དགོང་དག|མཚན་མོ)$/.test(input);
		},
		meridiem : function (hour, minute, isLower) {
			if (hour < 4) {
				return 'མཚན་མོ';
			} else if (hour < 10) {
				return 'ཞོགས་ཀས';
			} else if (hour < 17) {
				return 'ཉིན་གུང';
			} else if (hour < 20) {
				return 'དགོང་དག';
			} else {
				return 'མཚན་མོ';
			}
		},
		week : {
			dow : 0, // Sunday is the first day of the week.
			doy : 6  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : breton (br)
	//! author : Jean-Baptiste Le Duigou : https://github.com/jbleduigou

	function relativeTimeWithMutation(number, withoutSuffix, key) {
		var format = {
			'mm': 'munutenn',
			'MM': 'miz',
			'dd': 'devezh'
		};
		return number + ' ' + mutation(format[key], number);
	}
	function specialMutationForYears(number) {
		switch (lastNumber(number)) {
		case 1:
		case 3:
		case 4:
		case 5:
		case 9:
			return number + ' bloaz';
		default:
			return number + ' vloaz';
		}
	}
	function lastNumber(number) {
		if (number > 9) {
			return lastNumber(number % 10);
		}
		return number;
	}
	function mutation(text, number) {
		if (number === 2) {
			return softMutation(text);
		}
		return text;
	}
	function softMutation(text) {
		var mutationTable = {
			'm': 'v',
			'b': 'v',
			'd': 'z'
		};
		if (mutationTable[text.charAt(0)] === undefined) {
			return text;
		}
		return mutationTable[text.charAt(0)] + text.substring(1);
	}

	var br = moment__default.defineLocale('br', {
		months : 'Genver_C\'hwevrer_Meurzh_Ebrel_Mae_Mezheven_Gouere_Eost_Gwengolo_Here_Du_Kerzu'.split('_'),
		monthsShort : 'Gen_C\'hwe_Meu_Ebr_Mae_Eve_Gou_Eos_Gwe_Her_Du_Ker'.split('_'),
		weekdays : 'Sul_Lun_Meurzh_Merc\'her_Yaou_Gwener_Sadorn'.split('_'),
		weekdaysShort : 'Sul_Lun_Meu_Mer_Yao_Gwe_Sad'.split('_'),
		weekdaysMin : 'Su_Lu_Me_Mer_Ya_Gw_Sa'.split('_'),
		longDateFormat : {
			LT : 'h[e]mm A',
			LTS : 'h[e]mm:ss A',
			L : 'DD/MM/YYYY',
			LL : 'D [a viz] MMMM YYYY',
			LLL : 'D [a viz] MMMM YYYY h[e]mm A',
			LLLL : 'dddd, D [a viz] MMMM YYYY h[e]mm A'
		},
		calendar : {
			sameDay : '[Hiziv da] LT',
			nextDay : '[Warc\'hoazh da] LT',
			nextWeek : 'dddd [da] LT',
			lastDay : '[Dec\'h da] LT',
			lastWeek : 'dddd [paset da] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'a-benn %s',
			past : '%s \'zo',
			s : 'un nebeud segondennoù',
			m : 'ur vunutenn',
			mm : relativeTimeWithMutation,
			h : 'un eur',
			hh : '%d eur',
			d : 'un devezh',
			dd : relativeTimeWithMutation,
			M : 'ur miz',
			MM : relativeTimeWithMutation,
			y : 'ur bloaz',
			yy : specialMutationForYears
		},
		ordinalParse: /\d{1,2}(añ|vet)/,
		ordinal : function (number) {
			var output = (number === 1) ? 'añ' : 'vet';
			return number + output;
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : bosnian (bs)
	//! author : Nedim Cholich : https://github.com/frontyard
	//! based on (hr) translation by Bojan Marković

	function bs__translate(number, withoutSuffix, key) {
		var result = number + ' ';
		switch (key) {
		case 'm':
			return withoutSuffix ? 'jedna minuta' : 'jedne minute';
		case 'mm':
			if (number === 1) {
				result += 'minuta';
			} else if (number === 2 || number === 3 || number === 4) {
				result += 'minute';
			} else {
				result += 'minuta';
			}
			return result;
		case 'h':
			return withoutSuffix ? 'jedan sat' : 'jednog sata';
		case 'hh':
			if (number === 1) {
				result += 'sat';
			} else if (number === 2 || number === 3 || number === 4) {
				result += 'sata';
			} else {
				result += 'sati';
			}
			return result;
		case 'dd':
			if (number === 1) {
				result += 'dan';
			} else {
				result += 'dana';
			}
			return result;
		case 'MM':
			if (number === 1) {
				result += 'mjesec';
			} else if (number === 2 || number === 3 || number === 4) {
				result += 'mjeseca';
			} else {
				result += 'mjeseci';
			}
			return result;
		case 'yy':
			if (number === 1) {
				result += 'godina';
			} else if (number === 2 || number === 3 || number === 4) {
				result += 'godine';
			} else {
				result += 'godina';
			}
			return result;
		}
	}

	var bs = moment__default.defineLocale('bs', {
		months : 'januar_februar_mart_april_maj_juni_juli_august_septembar_oktobar_novembar_decembar'.split('_'),
		monthsShort : 'jan._feb._mar._apr._maj._jun._jul._aug._sep._okt._nov._dec.'.split('_'),
		weekdays : 'nedjelja_ponedjeljak_utorak_srijeda_četvrtak_petak_subota'.split('_'),
		weekdaysShort : 'ned._pon._uto._sri._čet._pet._sub.'.split('_'),
		weekdaysMin : 'ne_po_ut_sr_če_pe_su'.split('_'),
		longDateFormat : {
			LT : 'H:mm',
			LTS : 'H:mm:ss',
			L : 'DD. MM. YYYY',
			LL : 'D. MMMM YYYY',
			LLL : 'D. MMMM YYYY H:mm',
			LLLL : 'dddd, D. MMMM YYYY H:mm'
		},
		calendar : {
			sameDay  : '[danas u] LT',
			nextDay  : '[sutra u] LT',
			nextWeek : function () {
				switch (this.day()) {
				case 0:
					return '[u] [nedjelju] [u] LT';
				case 3:
					return '[u] [srijedu] [u] LT';
				case 6:
					return '[u] [subotu] [u] LT';
				case 1:
				case 2:
				case 4:
				case 5:
					return '[u] dddd [u] LT';
				}
			},
			lastDay  : '[jučer u] LT',
			lastWeek : function () {
				switch (this.day()) {
				case 0:
				case 3:
					return '[prošlu] dddd [u] LT';
				case 6:
					return '[prošle] [subote] [u] LT';
				case 1:
				case 2:
				case 4:
				case 5:
					return '[prošli] dddd [u] LT';
				}
			},
			sameElse : 'L'
		},
		relativeTime : {
			future : 'za %s',
			past   : 'prije %s',
			s      : 'par sekundi',
			m      : bs__translate,
			mm     : bs__translate,
			h      : bs__translate,
			hh     : bs__translate,
			d      : 'dan',
			dd     : bs__translate,
			M      : 'mjesec',
			MM     : bs__translate,
			y      : 'godinu',
			yy     : bs__translate
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : catalan (ca)
	//! author : Juan G. Hurtado : https://github.com/juanghurtado

	var ca = moment__default.defineLocale('ca', {
		months : 'gener_febrer_març_abril_maig_juny_juliol_agost_setembre_octubre_novembre_desembre'.split('_'),
		monthsShort : 'gen._febr._mar._abr._mai._jun._jul._ag._set._oct._nov._des.'.split('_'),
		weekdays : 'diumenge_dilluns_dimarts_dimecres_dijous_divendres_dissabte'.split('_'),
		weekdaysShort : 'dg._dl._dt._dc._dj._dv._ds.'.split('_'),
		weekdaysMin : 'Dg_Dl_Dt_Dc_Dj_Dv_Ds'.split('_'),
		longDateFormat : {
			LT : 'H:mm',
			LTS : 'H:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY H:mm',
			LLLL : 'dddd D MMMM YYYY H:mm'
		},
		calendar : {
			sameDay : function () {
				return '[avui a ' + ((this.hours() !== 1) ? 'les' : 'la') + '] LT';
			},
			nextDay : function () {
				return '[demà a ' + ((this.hours() !== 1) ? 'les' : 'la') + '] LT';
			},
			nextWeek : function () {
				return 'dddd [a ' + ((this.hours() !== 1) ? 'les' : 'la') + '] LT';
			},
			lastDay : function () {
				return '[ahir a ' + ((this.hours() !== 1) ? 'les' : 'la') + '] LT';
			},
			lastWeek : function () {
				return '[el] dddd [passat a ' + ((this.hours() !== 1) ? 'les' : 'la') + '] LT';
			},
			sameElse : 'L'
		},
		relativeTime : {
			future : 'en %s',
			past : 'fa %s',
			s : 'uns segons',
			m : 'un minut',
			mm : '%d minuts',
			h : 'una hora',
			hh : '%d hores',
			d : 'un dia',
			dd : '%d dies',
			M : 'un mes',
			MM : '%d mesos',
			y : 'un any',
			yy : '%d anys'
		},
		ordinalParse: /\d{1,2}(r|n|t|è|a)/,
		ordinal : function (number, period) {
			var output = (number === 1) ? 'r' :
				(number === 2) ? 'n' :
				(number === 3) ? 'r' :
				(number === 4) ? 't' : 'è';
			if (period === 'w' || period === 'W') {
				output = 'a';
			}
			return number + output;
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : czech (cs)
	//! author : petrbela : https://github.com/petrbela

	var cs__months = 'leden_únor_březen_duben_květen_červen_červenec_srpen_září_říjen_listopad_prosinec'.split('_'),
		cs__monthsShort = 'led_úno_bře_dub_kvě_čvn_čvc_srp_zář_říj_lis_pro'.split('_');
	function cs__plural(n) {
		return (n > 1) && (n < 5) && (~~(n / 10) !== 1);
	}
	function cs__translate(number, withoutSuffix, key, isFuture) {
		var result = number + ' ';
		switch (key) {
		case 's':  // a few seconds / in a few seconds / a few seconds ago
			return (withoutSuffix || isFuture) ? 'pár sekund' : 'pár sekundami';
		case 'm':  // a minute / in a minute / a minute ago
			return withoutSuffix ? 'minuta' : (isFuture ? 'minutu' : 'minutou');
		case 'mm': // 9 minutes / in 9 minutes / 9 minutes ago
			if (withoutSuffix || isFuture) {
				return result + (cs__plural(number) ? 'minuty' : 'minut');
			} else {
				return result + 'minutami';
			}
			break;
		case 'h':  // an hour / in an hour / an hour ago
			return withoutSuffix ? 'hodina' : (isFuture ? 'hodinu' : 'hodinou');
		case 'hh': // 9 hours / in 9 hours / 9 hours ago
			if (withoutSuffix || isFuture) {
				return result + (cs__plural(number) ? 'hodiny' : 'hodin');
			} else {
				return result + 'hodinami';
			}
			break;
		case 'd':  // a day / in a day / a day ago
			return (withoutSuffix || isFuture) ? 'den' : 'dnem';
		case 'dd': // 9 days / in 9 days / 9 days ago
			if (withoutSuffix || isFuture) {
				return result + (cs__plural(number) ? 'dny' : 'dní');
			} else {
				return result + 'dny';
			}
			break;
		case 'M':  // a month / in a month / a month ago
			return (withoutSuffix || isFuture) ? 'měsíc' : 'měsícem';
		case 'MM': // 9 months / in 9 months / 9 months ago
			if (withoutSuffix || isFuture) {
				return result + (cs__plural(number) ? 'měsíce' : 'měsíců');
			} else {
				return result + 'měsíci';
			}
			break;
		case 'y':  // a year / in a year / a year ago
			return (withoutSuffix || isFuture) ? 'rok' : 'rokem';
		case 'yy': // 9 years / in 9 years / 9 years ago
			if (withoutSuffix || isFuture) {
				return result + (cs__plural(number) ? 'roky' : 'let');
			} else {
				return result + 'lety';
			}
			break;
		}
	}

	var cs = moment__default.defineLocale('cs', {
		months : cs__months,
		monthsShort : cs__monthsShort,
		monthsParse : (function (months, monthsShort) {
			var i, _monthsParse = [];
			for (i = 0; i < 12; i++) {
				// use custom parser to solve problem with July (červenec)
				_monthsParse[i] = new RegExp('^' + months[i] + '$|^' + monthsShort[i] + '$', 'i');
			}
			return _monthsParse;
		}(cs__months, cs__monthsShort)),
		shortMonthsParse : (function (monthsShort) {
			var i, _shortMonthsParse = [];
			for (i = 0; i < 12; i++) {
				_shortMonthsParse[i] = new RegExp('^' + monthsShort[i] + '$', 'i');
			}
			return _shortMonthsParse;
		}(cs__monthsShort)),
		longMonthsParse : (function (months) {
			var i, _longMonthsParse = [];
			for (i = 0; i < 12; i++) {
				_longMonthsParse[i] = new RegExp('^' + months[i] + '$', 'i');
			}
			return _longMonthsParse;
		}(cs__months)),
		weekdays : 'neděle_pondělí_úterý_středa_čtvrtek_pátek_sobota'.split('_'),
		weekdaysShort : 'ne_po_út_st_čt_pá_so'.split('_'),
		weekdaysMin : 'ne_po_út_st_čt_pá_so'.split('_'),
		longDateFormat : {
			LT: 'H:mm',
			LTS : 'H:mm:ss',
			L : 'DD.MM.YYYY',
			LL : 'D. MMMM YYYY',
			LLL : 'D. MMMM YYYY H:mm',
			LLLL : 'dddd D. MMMM YYYY H:mm'
		},
		calendar : {
			sameDay: '[dnes v] LT',
			nextDay: '[zítra v] LT',
			nextWeek: function () {
				switch (this.day()) {
				case 0:
					return '[v neděli v] LT';
				case 1:
				case 2:
					return '[v] dddd [v] LT';
				case 3:
					return '[ve středu v] LT';
				case 4:
					return '[ve čtvrtek v] LT';
				case 5:
					return '[v pátek v] LT';
				case 6:
					return '[v sobotu v] LT';
				}
			},
			lastDay: '[včera v] LT',
			lastWeek: function () {
				switch (this.day()) {
				case 0:
					return '[minulou neděli v] LT';
				case 1:
				case 2:
					return '[minulé] dddd [v] LT';
				case 3:
					return '[minulou středu v] LT';
				case 4:
				case 5:
					return '[minulý] dddd [v] LT';
				case 6:
					return '[minulou sobotu v] LT';
				}
			},
			sameElse: 'L'
		},
		relativeTime : {
			future : 'za %s',
			past : 'před %s',
			s : cs__translate,
			m : cs__translate,
			mm : cs__translate,
			h : cs__translate,
			hh : cs__translate,
			d : cs__translate,
			dd : cs__translate,
			M : cs__translate,
			MM : cs__translate,
			y : cs__translate,
			yy : cs__translate
		},
		ordinalParse : /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : chuvash (cv)
	//! author : Anatoly Mironov : https://github.com/mirontoli

	var cv = moment__default.defineLocale('cv', {
		months : 'кӑрлач_нарӑс_пуш_ака_май_ҫӗртме_утӑ_ҫурла_авӑн_юпа_чӳк_раштав'.split('_'),
		monthsShort : 'кӑр_нар_пуш_ака_май_ҫӗр_утӑ_ҫур_авн_юпа_чӳк_раш'.split('_'),
		weekdays : 'вырсарникун_тунтикун_ытларикун_юнкун_кӗҫнерникун_эрнекун_шӑматкун'.split('_'),
		weekdaysShort : 'выр_тун_ытл_юн_кӗҫ_эрн_шӑм'.split('_'),
		weekdaysMin : 'вр_тн_ыт_юн_кҫ_эр_шм'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD-MM-YYYY',
			LL : 'YYYY [ҫулхи] MMMM [уйӑхӗн] D[-мӗшӗ]',
			LLL : 'YYYY [ҫулхи] MMMM [уйӑхӗн] D[-мӗшӗ], HH:mm',
			LLLL : 'dddd, YYYY [ҫулхи] MMMM [уйӑхӗн] D[-мӗшӗ], HH:mm'
		},
		calendar : {
			sameDay: '[Паян] LT [сехетре]',
			nextDay: '[Ыран] LT [сехетре]',
			lastDay: '[Ӗнер] LT [сехетре]',
			nextWeek: '[Ҫитес] dddd LT [сехетре]',
			lastWeek: '[Иртнӗ] dddd LT [сехетре]',
			sameElse: 'L'
		},
		relativeTime : {
			future : function (output) {
				var affix = /сехет$/i.exec(output) ? 'рен' : /ҫул$/i.exec(output) ? 'тан' : 'ран';
				return output + affix;
			},
			past : '%s каялла',
			s : 'пӗр-ик ҫеккунт',
			m : 'пӗр минут',
			mm : '%d минут',
			h : 'пӗр сехет',
			hh : '%d сехет',
			d : 'пӗр кун',
			dd : '%d кун',
			M : 'пӗр уйӑх',
			MM : '%d уйӑх',
			y : 'пӗр ҫул',
			yy : '%d ҫул'
		},
		ordinalParse: /\d{1,2}-мӗш/,
		ordinal : '%d-мӗш',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : Welsh (cy)
	//! author : Robert Allen

	var cy = moment__default.defineLocale('cy', {
		months: 'Ionawr_Chwefror_Mawrth_Ebrill_Mai_Mehefin_Gorffennaf_Awst_Medi_Hydref_Tachwedd_Rhagfyr'.split('_'),
		monthsShort: 'Ion_Chwe_Maw_Ebr_Mai_Meh_Gor_Aws_Med_Hyd_Tach_Rhag'.split('_'),
		weekdays: 'Dydd Sul_Dydd Llun_Dydd Mawrth_Dydd Mercher_Dydd Iau_Dydd Gwener_Dydd Sadwrn'.split('_'),
		weekdaysShort: 'Sul_Llun_Maw_Mer_Iau_Gwe_Sad'.split('_'),
		weekdaysMin: 'Su_Ll_Ma_Me_Ia_Gw_Sa'.split('_'),
		// time formats are the same as en-gb
		longDateFormat: {
			LT: 'HH:mm',
			LTS : 'HH:mm:ss',
			L: 'DD/MM/YYYY',
			LL: 'D MMMM YYYY',
			LLL: 'D MMMM YYYY HH:mm',
			LLLL: 'dddd, D MMMM YYYY HH:mm'
		},
		calendar: {
			sameDay: '[Heddiw am] LT',
			nextDay: '[Yfory am] LT',
			nextWeek: 'dddd [am] LT',
			lastDay: '[Ddoe am] LT',
			lastWeek: 'dddd [diwethaf am] LT',
			sameElse: 'L'
		},
		relativeTime: {
			future: 'mewn %s',
			past: '%s yn ôl',
			s: 'ychydig eiliadau',
			m: 'munud',
			mm: '%d munud',
			h: 'awr',
			hh: '%d awr',
			d: 'diwrnod',
			dd: '%d diwrnod',
			M: 'mis',
			MM: '%d mis',
			y: 'blwyddyn',
			yy: '%d flynedd'
		},
		ordinalParse: /\d{1,2}(fed|ain|af|il|ydd|ed|eg)/,
		// traditional ordinal numbers above 31 are not commonly used in colloquial Welsh
		ordinal: function (number) {
			var b = number,
				output = '',
				lookup = [
					'', 'af', 'il', 'ydd', 'ydd', 'ed', 'ed', 'ed', 'fed', 'fed', 'fed', // 1af to 10fed
					'eg', 'fed', 'eg', 'eg', 'fed', 'eg', 'eg', 'fed', 'eg', 'fed' // 11eg to 20fed
				];
			if (b > 20) {
				if (b === 40 || b === 50 || b === 60 || b === 80 || b === 100) {
					output = 'fed'; // not 30ain, 70ain or 90ain
				} else {
					output = 'ain';
				}
			} else if (b > 0) {
				output = lookup[b];
			}
			return number + output;
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : danish (da)
	//! author : Ulrik Nielsen : https://github.com/mrbase

	var da = moment__default.defineLocale('da', {
		months : 'januar_februar_marts_april_maj_juni_juli_august_september_oktober_november_december'.split('_'),
		monthsShort : 'jan_feb_mar_apr_maj_jun_jul_aug_sep_okt_nov_dec'.split('_'),
		weekdays : 'søndag_mandag_tirsdag_onsdag_torsdag_fredag_lørdag'.split('_'),
		weekdaysShort : 'søn_man_tir_ons_tor_fre_lør'.split('_'),
		weekdaysMin : 'sø_ma_ti_on_to_fr_lø'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D. MMMM YYYY',
			LLL : 'D. MMMM YYYY HH:mm',
			LLLL : 'dddd [d.] D. MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay : '[I dag kl.] LT',
			nextDay : '[I morgen kl.] LT',
			nextWeek : 'dddd [kl.] LT',
			lastDay : '[I går kl.] LT',
			lastWeek : '[sidste] dddd [kl] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'om %s',
			past : '%s siden',
			s : 'få sekunder',
			m : 'et minut',
			mm : '%d minutter',
			h : 'en time',
			hh : '%d timer',
			d : 'en dag',
			dd : '%d dage',
			M : 'en måned',
			MM : '%d måneder',
			y : 'et år',
			yy : '%d år'
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : austrian german (de-at)
	//! author : lluchs : https://github.com/lluchs
	//! author: Menelion Elensúle: https://github.com/Oire
	//! author : Martin Groller : https://github.com/MadMG
	//! author : Mikolaj Dadela : https://github.com/mik01aj

	function de_at__processRelativeTime(number, withoutSuffix, key, isFuture) {
		var format = {
			'm': ['eine Minute', 'einer Minute'],
			'h': ['eine Stunde', 'einer Stunde'],
			'd': ['ein Tag', 'einem Tag'],
			'dd': [number + ' Tage', number + ' Tagen'],
			'M': ['ein Monat', 'einem Monat'],
			'MM': [number + ' Monate', number + ' Monaten'],
			'y': ['ein Jahr', 'einem Jahr'],
			'yy': [number + ' Jahre', number + ' Jahren']
		};
		return withoutSuffix ? format[key][0] : format[key][1];
	}

	var de_at = moment__default.defineLocale('de-at', {
		months : 'Jänner_Februar_März_April_Mai_Juni_Juli_August_September_Oktober_November_Dezember'.split('_'),
		monthsShort : 'Jän._Febr._Mrz._Apr._Mai_Jun._Jul._Aug._Sept._Okt._Nov._Dez.'.split('_'),
		weekdays : 'Sonntag_Montag_Dienstag_Mittwoch_Donnerstag_Freitag_Samstag'.split('_'),
		weekdaysShort : 'So._Mo._Di._Mi._Do._Fr._Sa.'.split('_'),
		weekdaysMin : 'So_Mo_Di_Mi_Do_Fr_Sa'.split('_'),
		longDateFormat : {
			LT: 'HH:mm',
			LTS: 'HH:mm:ss',
			L : 'DD.MM.YYYY',
			LL : 'D. MMMM YYYY',
			LLL : 'D. MMMM YYYY HH:mm',
			LLLL : 'dddd, D. MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay: '[heute um] LT [Uhr]',
			sameElse: 'L',
			nextDay: '[morgen um] LT [Uhr]',
			nextWeek: 'dddd [um] LT [Uhr]',
			lastDay: '[gestern um] LT [Uhr]',
			lastWeek: '[letzten] dddd [um] LT [Uhr]'
		},
		relativeTime : {
			future : 'in %s',
			past : 'vor %s',
			s : 'ein paar Sekunden',
			m : de_at__processRelativeTime,
			mm : '%d Minuten',
			h : de_at__processRelativeTime,
			hh : '%d Stunden',
			d : de_at__processRelativeTime,
			dd : de_at__processRelativeTime,
			M : de_at__processRelativeTime,
			MM : de_at__processRelativeTime,
			y : de_at__processRelativeTime,
			yy : de_at__processRelativeTime
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : german (de)
	//! author : lluchs : https://github.com/lluchs
	//! author: Menelion Elensúle: https://github.com/Oire
	//! author : Mikolaj Dadela : https://github.com/mik01aj

	function de__processRelativeTime(number, withoutSuffix, key, isFuture) {
		var format = {
			'm': ['eine Minute', 'einer Minute'],
			'h': ['eine Stunde', 'einer Stunde'],
			'd': ['ein Tag', 'einem Tag'],
			'dd': [number + ' Tage', number + ' Tagen'],
			'M': ['ein Monat', 'einem Monat'],
			'MM': [number + ' Monate', number + ' Monaten'],
			'y': ['ein Jahr', 'einem Jahr'],
			'yy': [number + ' Jahre', number + ' Jahren']
		};
		return withoutSuffix ? format[key][0] : format[key][1];
	}

	var de = moment__default.defineLocale('de', {
		months : 'Januar_Februar_März_April_Mai_Juni_Juli_August_September_Oktober_November_Dezember'.split('_'),
		monthsShort : 'Jan._Febr._Mrz._Apr._Mai_Jun._Jul._Aug._Sept._Okt._Nov._Dez.'.split('_'),
		weekdays : 'Sonntag_Montag_Dienstag_Mittwoch_Donnerstag_Freitag_Samstag'.split('_'),
		weekdaysShort : 'So._Mo._Di._Mi._Do._Fr._Sa.'.split('_'),
		weekdaysMin : 'So_Mo_Di_Mi_Do_Fr_Sa'.split('_'),
		longDateFormat : {
			LT: 'HH:mm',
			LTS: 'HH:mm:ss',
			L : 'DD.MM.YYYY',
			LL : 'D. MMMM YYYY',
			LLL : 'D. MMMM YYYY HH:mm',
			LLLL : 'dddd, D. MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay: '[heute um] LT [Uhr]',
			sameElse: 'L',
			nextDay: '[morgen um] LT [Uhr]',
			nextWeek: 'dddd [um] LT [Uhr]',
			lastDay: '[gestern um] LT [Uhr]',
			lastWeek: '[letzten] dddd [um] LT [Uhr]'
		},
		relativeTime : {
			future : 'in %s',
			past : 'vor %s',
			s : 'ein paar Sekunden',
			m : de__processRelativeTime,
			mm : '%d Minuten',
			h : de__processRelativeTime,
			hh : '%d Stunden',
			d : de__processRelativeTime,
			dd : de__processRelativeTime,
			M : de__processRelativeTime,
			MM : de__processRelativeTime,
			y : de__processRelativeTime,
			yy : de__processRelativeTime
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : dhivehi (dv)
	//! author : Jawish Hameed : https://github.com/jawish

	var dv__months = [
		'ޖެނުއަރީ',
		'ފެބްރުއަރީ',
		'މާރިޗު',
		'އޭޕްރީލު',
		'މޭ',
		'ޖޫން',
		'ޖުލައި',
		'އޯގަސްޓު',
		'ސެޕްޓެމްބަރު',
		'އޮކްޓޯބަރު',
		'ނޮވެމްބަރު',
		'ޑިސެމްބަރު'
	], dv__weekdays = [
		'އާދިއްތަ',
		'ހޯމަ',
		'އަންގާރަ',
		'ބުދަ',
		'ބުރާސްފަތި',
		'ހުކުރު',
		'ހޮނިހިރު'
	];

	var dv = moment__default.defineLocale('dv', {
		months : dv__months,
		monthsShort : dv__months,
		weekdays : dv__weekdays,
		weekdaysShort : dv__weekdays,
		weekdaysMin : 'އާދި_ހޯމަ_އަން_ބުދަ_ބުރާ_ހުކު_ހޮނި'.split('_'),
		longDateFormat : {

			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'D/M/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd D MMMM YYYY HH:mm'
		},
		meridiemParse: /މކ|މފ/,
		isPM : function (input) {
			return '' === input;
		},
		meridiem : function (hour, minute, isLower) {
			if (hour < 12) {
				return 'މކ';
			} else {
				return 'މފ';
			}
		},
		calendar : {
			sameDay : '[މިއަދު] LT',
			nextDay : '[މާދަމާ] LT',
			nextWeek : 'dddd LT',
			lastDay : '[އިއްޔެ] LT',
			lastWeek : '[ފާއިތުވި] dddd LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'ތެރޭގައި %s',
			past : 'ކުރިން %s',
			s : 'ސިކުންތުކޮޅެއް',
			m : 'މިނިޓެއް',
			mm : 'މިނިޓު %d',
			h : 'ގަޑިއިރެއް',
			hh : 'ގަޑިއިރު %d',
			d : 'ދުވަހެއް',
			dd : 'ދުވަސް %d',
			M : 'މަހެއް',
			MM : 'މަސް %d',
			y : 'އަހަރެއް',
			yy : 'އަހަރު %d'
		},
		preparse: function (string) {
			return string.replace(/،/g, ',');
		},
		postformat: function (string) {
			return string.replace(/,/g, '،');
		},
		week : {
			dow : 7,  // Sunday is the first day of the week.
			doy : 12  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : modern greek (el)
	//! author : Aggelos Karalias : https://github.com/mehiel

	var el = moment__default.defineLocale('el', {
		monthsNominativeEl : 'Ιανουάριος_Φεβρουάριος_Μάρτιος_Απρίλιος_Μάιος_Ιούνιος_Ιούλιος_Αύγουστος_Σεπτέμβριος_Οκτώβριος_Νοέμβριος_Δεκέμβριος'.split('_'),
		monthsGenitiveEl : 'Ιανουαρίου_Φεβρουαρίου_Μαρτίου_Απριλίου_Μαΐου_Ιουνίου_Ιουλίου_Αυγούστου_Σεπτεμβρίου_Οκτωβρίου_Νοεμβρίου_Δεκεμβρίου'.split('_'),
		months : function (momentToFormat, format) {
			if (/D/.test(format.substring(0, format.indexOf('MMMM')))) { // if there is a day number before 'MMMM'
				return this._monthsGenitiveEl[momentToFormat.month()];
			} else {
				return this._monthsNominativeEl[momentToFormat.month()];
			}
		},
		monthsShort : 'Ιαν_Φεβ_Μαρ_Απρ_Μαϊ_Ιουν_Ιουλ_Αυγ_Σεπ_Οκτ_Νοε_Δεκ'.split('_'),
		weekdays : 'Κυριακή_Δευτέρα_Τρίτη_Τετάρτη_Πέμπτη_Παρασκευή_Σάββατο'.split('_'),
		weekdaysShort : 'Κυρ_Δευ_Τρι_Τετ_Πεμ_Παρ_Σαβ'.split('_'),
		weekdaysMin : 'Κυ_Δε_Τρ_Τε_Πε_Πα_Σα'.split('_'),
		meridiem : function (hours, minutes, isLower) {
			if (hours > 11) {
				return isLower ? 'μμ' : 'ΜΜ';
			} else {
				return isLower ? 'πμ' : 'ΠΜ';
			}
		},
		isPM : function (input) {
			return ((input + '').toLowerCase()[0] === 'μ');
		},
		meridiemParse : /[ΠΜ]\.?Μ?\.?/i,
		longDateFormat : {
			LT : 'h:mm A',
			LTS : 'h:mm:ss A',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY h:mm A',
			LLLL : 'dddd, D MMMM YYYY h:mm A'
		},
		calendarEl : {
			sameDay : '[Σήμερα {}] LT',
			nextDay : '[Αύριο {}] LT',
			nextWeek : 'dddd [{}] LT',
			lastDay : '[Χθες {}] LT',
			lastWeek : function () {
				switch (this.day()) {
					case 6:
						return '[το προηγούμενο] dddd [{}] LT';
					default:
						return '[την προηγούμενη] dddd [{}] LT';
				}
			},
			sameElse : 'L'
		},
		calendar : function (key, mom) {
			var output = this._calendarEl[key],
				hours = mom && mom.hours();
			if (isFunction(output)) {
				output = output.apply(mom);
			}
			return output.replace('{}', (hours % 12 === 1 ? 'στη' : 'στις'));
		},
		relativeTime : {
			future : 'σε %s',
			past : '%s πριν',
			s : 'λίγα δευτερόλεπτα',
			m : 'ένα λεπτό',
			mm : '%d λεπτά',
			h : 'μία ώρα',
			hh : '%d ώρες',
			d : 'μία μέρα',
			dd : '%d μέρες',
			M : 'ένας μήνας',
			MM : '%d μήνες',
			y : 'ένας χρόνος',
			yy : '%d χρόνια'
		},
		ordinalParse: /\d{1,2}η/,
		ordinal: '%dη',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : australian english (en-au)

	var en_au = moment__default.defineLocale('en-au', {
		months : 'January_February_March_April_May_June_July_August_September_October_November_December'.split('_'),
		monthsShort : 'Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec'.split('_'),
		weekdays : 'Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday'.split('_'),
		weekdaysShort : 'Sun_Mon_Tue_Wed_Thu_Fri_Sat'.split('_'),
		weekdaysMin : 'Su_Mo_Tu_We_Th_Fr_Sa'.split('_'),
		longDateFormat : {
			LT : 'h:mm A',
			LTS : 'h:mm:ss A',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY h:mm A',
			LLLL : 'dddd, D MMMM YYYY h:mm A'
		},
		calendar : {
			sameDay : '[Today at] LT',
			nextDay : '[Tomorrow at] LT',
			nextWeek : 'dddd [at] LT',
			lastDay : '[Yesterday at] LT',
			lastWeek : '[Last] dddd [at] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'in %s',
			past : '%s ago',
			s : 'a few seconds',
			m : 'a minute',
			mm : '%d minutes',
			h : 'an hour',
			hh : '%d hours',
			d : 'a day',
			dd : '%d days',
			M : 'a month',
			MM : '%d months',
			y : 'a year',
			yy : '%d years'
		},
		ordinalParse: /\d{1,2}(st|nd|rd|th)/,
		ordinal : function (number) {
			var b = number % 10,
				output = (~~(number % 100 / 10) === 1) ? 'th' :
				(b === 1) ? 'st' :
				(b === 2) ? 'nd' :
				(b === 3) ? 'rd' : 'th';
			return number + output;
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : canadian english (en-ca)
	//! author : Jonathan Abourbih : https://github.com/jonbca

	var en_ca = moment__default.defineLocale('en-ca', {
		months : 'January_February_March_April_May_June_July_August_September_October_November_December'.split('_'),
		monthsShort : 'Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec'.split('_'),
		weekdays : 'Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday'.split('_'),
		weekdaysShort : 'Sun_Mon_Tue_Wed_Thu_Fri_Sat'.split('_'),
		weekdaysMin : 'Su_Mo_Tu_We_Th_Fr_Sa'.split('_'),
		longDateFormat : {
			LT : 'h:mm A',
			LTS : 'h:mm:ss A',
			L : 'YYYY-MM-DD',
			LL : 'D MMMM, YYYY',
			LLL : 'D MMMM, YYYY h:mm A',
			LLLL : 'dddd, D MMMM, YYYY h:mm A'
		},
		calendar : {
			sameDay : '[Today at] LT',
			nextDay : '[Tomorrow at] LT',
			nextWeek : 'dddd [at] LT',
			lastDay : '[Yesterday at] LT',
			lastWeek : '[Last] dddd [at] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'in %s',
			past : '%s ago',
			s : 'a few seconds',
			m : 'a minute',
			mm : '%d minutes',
			h : 'an hour',
			hh : '%d hours',
			d : 'a day',
			dd : '%d days',
			M : 'a month',
			MM : '%d months',
			y : 'a year',
			yy : '%d years'
		},
		ordinalParse: /\d{1,2}(st|nd|rd|th)/,
		ordinal : function (number) {
			var b = number % 10,
				output = (~~(number % 100 / 10) === 1) ? 'th' :
				(b === 1) ? 'st' :
				(b === 2) ? 'nd' :
				(b === 3) ? 'rd' : 'th';
			return number + output;
		}
	});

	//! moment.js locale configuration
	//! locale : great britain english (en-gb)
	//! author : Chris Gedrim : https://github.com/chrisgedrim

	var en_gb = moment__default.defineLocale('en-gb', {
		months : 'January_February_March_April_May_June_July_August_September_October_November_December'.split('_'),
		monthsShort : 'Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec'.split('_'),
		weekdays : 'Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday'.split('_'),
		weekdaysShort : 'Sun_Mon_Tue_Wed_Thu_Fri_Sat'.split('_'),
		weekdaysMin : 'Su_Mo_Tu_We_Th_Fr_Sa'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd, D MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay : '[Today at] LT',
			nextDay : '[Tomorrow at] LT',
			nextWeek : 'dddd [at] LT',
			lastDay : '[Yesterday at] LT',
			lastWeek : '[Last] dddd [at] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'in %s',
			past : '%s ago',
			s : 'a few seconds',
			m : 'a minute',
			mm : '%d minutes',
			h : 'an hour',
			hh : '%d hours',
			d : 'a day',
			dd : '%d days',
			M : 'a month',
			MM : '%d months',
			y : 'a year',
			yy : '%d years'
		},
		ordinalParse: /\d{1,2}(st|nd|rd|th)/,
		ordinal : function (number) {
			var b = number % 10,
				output = (~~(number % 100 / 10) === 1) ? 'th' :
				(b === 1) ? 'st' :
				(b === 2) ? 'nd' :
				(b === 3) ? 'rd' : 'th';
			return number + output;
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : Irish english (en-ie)
	//! author : Chris Cartlidge : https://github.com/chriscartlidge

	var en_ie = moment__default.defineLocale('en-ie', {
		months : 'January_February_March_April_May_June_July_August_September_October_November_December'.split('_'),
		monthsShort : 'Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec'.split('_'),
		weekdays : 'Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday'.split('_'),
		weekdaysShort : 'Sun_Mon_Tue_Wed_Thu_Fri_Sat'.split('_'),
		weekdaysMin : 'Su_Mo_Tu_We_Th_Fr_Sa'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD-MM-YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd D MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay : '[Today at] LT',
			nextDay : '[Tomorrow at] LT',
			nextWeek : 'dddd [at] LT',
			lastDay : '[Yesterday at] LT',
			lastWeek : '[Last] dddd [at] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'in %s',
			past : '%s ago',
			s : 'a few seconds',
			m : 'a minute',
			mm : '%d minutes',
			h : 'an hour',
			hh : '%d hours',
			d : 'a day',
			dd : '%d days',
			M : 'a month',
			MM : '%d months',
			y : 'a year',
			yy : '%d years'
		},
		ordinalParse: /\d{1,2}(st|nd|rd|th)/,
		ordinal : function (number) {
			var b = number % 10,
				output = (~~(number % 100 / 10) === 1) ? 'th' :
				(b === 1) ? 'st' :
				(b === 2) ? 'nd' :
				(b === 3) ? 'rd' : 'th';
			return number + output;
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : New Zealand english (en-nz)

	var en_nz = moment__default.defineLocale('en-nz', {
		months : 'January_February_March_April_May_June_July_August_September_October_November_December'.split('_'),
		monthsShort : 'Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec'.split('_'),
		weekdays : 'Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday'.split('_'),
		weekdaysShort : 'Sun_Mon_Tue_Wed_Thu_Fri_Sat'.split('_'),
		weekdaysMin : 'Su_Mo_Tu_We_Th_Fr_Sa'.split('_'),
		longDateFormat : {
			LT : 'h:mm A',
			LTS : 'h:mm:ss A',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY h:mm A',
			LLLL : 'dddd, D MMMM YYYY h:mm A'
		},
		calendar : {
			sameDay : '[Today at] LT',
			nextDay : '[Tomorrow at] LT',
			nextWeek : 'dddd [at] LT',
			lastDay : '[Yesterday at] LT',
			lastWeek : '[Last] dddd [at] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'in %s',
			past : '%s ago',
			s : 'a few seconds',
			m : 'a minute',
			mm : '%d minutes',
			h : 'an hour',
			hh : '%d hours',
			d : 'a day',
			dd : '%d days',
			M : 'a month',
			MM : '%d months',
			y : 'a year',
			yy : '%d years'
		},
		ordinalParse: /\d{1,2}(st|nd|rd|th)/,
		ordinal : function (number) {
			var b = number % 10,
				output = (~~(number % 100 / 10) === 1) ? 'th' :
				(b === 1) ? 'st' :
				(b === 2) ? 'nd' :
				(b === 3) ? 'rd' : 'th';
			return number + output;
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : esperanto (eo)
	//! author : Colin Dean : https://github.com/colindean
	//! komento: Mi estas malcerta se mi korekte traktis akuzativojn en tiu traduko.
	//!          Se ne, bonvolu korekti kaj avizi min por ke mi povas lerni!

	var eo = moment__default.defineLocale('eo', {
		months : 'januaro_februaro_marto_aprilo_majo_junio_julio_aŭgusto_septembro_oktobro_novembro_decembro'.split('_'),
		monthsShort : 'jan_feb_mar_apr_maj_jun_jul_aŭg_sep_okt_nov_dec'.split('_'),
		weekdays : 'Dimanĉo_Lundo_Mardo_Merkredo_Ĵaŭdo_Vendredo_Sabato'.split('_'),
		weekdaysShort : 'Dim_Lun_Mard_Merk_Ĵaŭ_Ven_Sab'.split('_'),
		weekdaysMin : 'Di_Lu_Ma_Me_Ĵa_Ve_Sa'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'YYYY-MM-DD',
			LL : 'D[-an de] MMMM, YYYY',
			LLL : 'D[-an de] MMMM, YYYY HH:mm',
			LLLL : 'dddd, [la] D[-an de] MMMM, YYYY HH:mm'
		},
		meridiemParse: /[ap]\.t\.m/i,
		isPM: function (input) {
			return input.charAt(0).toLowerCase() === 'p';
		},
		meridiem : function (hours, minutes, isLower) {
			if (hours > 11) {
				return isLower ? 'p.t.m.' : 'P.T.M.';
			} else {
				return isLower ? 'a.t.m.' : 'A.T.M.';
			}
		},
		calendar : {
			sameDay : '[Hodiaŭ je] LT',
			nextDay : '[Morgaŭ je] LT',
			nextWeek : 'dddd [je] LT',
			lastDay : '[Hieraŭ je] LT',
			lastWeek : '[pasinta] dddd [je] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'je %s',
			past : 'antaŭ %s',
			s : 'sekundoj',
			m : 'minuto',
			mm : '%d minutoj',
			h : 'horo',
			hh : '%d horoj',
			d : 'tago',//ne 'diurno', ĉar estas uzita por proksimumo
			dd : '%d tagoj',
			M : 'monato',
			MM : '%d monatoj',
			y : 'jaro',
			yy : '%d jaroj'
		},
		ordinalParse: /\d{1,2}a/,
		ordinal : '%da',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : spanish (es)
	//! author : Julio Napurí : https://github.com/julionc

	var monthsShortDot = 'ene._feb._mar._abr._may._jun._jul._ago._sep._oct._nov._dic.'.split('_'),
		es__monthsShort = 'ene_feb_mar_abr_may_jun_jul_ago_sep_oct_nov_dic'.split('_');

	var es = moment__default.defineLocale('es', {
		months : 'enero_febrero_marzo_abril_mayo_junio_julio_agosto_septiembre_octubre_noviembre_diciembre'.split('_'),
		monthsShort : function (m, format) {
			if (/-MMM-/.test(format)) {
				return es__monthsShort[m.month()];
			} else {
				return monthsShortDot[m.month()];
			}
		},
		weekdays : 'domingo_lunes_martes_miércoles_jueves_viernes_sábado'.split('_'),
		weekdaysShort : 'dom._lun._mar._mié._jue._vie._sáb.'.split('_'),
		weekdaysMin : 'do_lu_ma_mi_ju_vi_sá'.split('_'),
		longDateFormat : {
			LT : 'H:mm',
			LTS : 'H:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D [de] MMMM [de] YYYY',
			LLL : 'D [de] MMMM [de] YYYY H:mm',
			LLLL : 'dddd, D [de] MMMM [de] YYYY H:mm'
		},
		calendar : {
			sameDay : function () {
				return '[hoy a la' + ((this.hours() !== 1) ? 's' : '') + '] LT';
			},
			nextDay : function () {
				return '[mañana a la' + ((this.hours() !== 1) ? 's' : '') + '] LT';
			},
			nextWeek : function () {
				return 'dddd [a la' + ((this.hours() !== 1) ? 's' : '') + '] LT';
			},
			lastDay : function () {
				return '[ayer a la' + ((this.hours() !== 1) ? 's' : '') + '] LT';
			},
			lastWeek : function () {
				return '[el] dddd [pasado a la' + ((this.hours() !== 1) ? 's' : '') + '] LT';
			},
			sameElse : 'L'
		},
		relativeTime : {
			future : 'en %s',
			past : 'hace %s',
			s : 'unos segundos',
			m : 'un minuto',
			mm : '%d minutos',
			h : 'una hora',
			hh : '%d horas',
			d : 'un día',
			dd : '%d días',
			M : 'un mes',
			MM : '%d meses',
			y : 'un año',
			yy : '%d años'
		},
		ordinalParse : /\d{1,2}º/,
		ordinal : '%dº',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : estonian (et)
	//! author : Henry Kehlmann : https://github.com/madhenry
	//! improvements : Illimar Tambek : https://github.com/ragulka

	function et__processRelativeTime(number, withoutSuffix, key, isFuture) {
		var format = {
			's' : ['mõne sekundi', 'mõni sekund', 'paar sekundit'],
			'm' : ['ühe minuti', 'üks minut'],
			'mm': [number + ' minuti', number + ' minutit'],
			'h' : ['ühe tunni', 'tund aega', 'üks tund'],
			'hh': [number + ' tunni', number + ' tundi'],
			'd' : ['ühe päeva', 'üks päev'],
			'M' : ['kuu aja', 'kuu aega', 'üks kuu'],
			'MM': [number + ' kuu', number + ' kuud'],
			'y' : ['ühe aasta', 'aasta', 'üks aasta'],
			'yy': [number + ' aasta', number + ' aastat']
		};
		if (withoutSuffix) {
			return format[key][2] ? format[key][2] : format[key][1];
		}
		return isFuture ? format[key][0] : format[key][1];
	}

	var et = moment__default.defineLocale('et', {
		months        : 'jaanuar_veebruar_märts_aprill_mai_juuni_juuli_august_september_oktoober_november_detsember'.split('_'),
		monthsShort   : 'jaan_veebr_märts_apr_mai_juuni_juuli_aug_sept_okt_nov_dets'.split('_'),
		weekdays      : 'pühapäev_esmaspäev_teisipäev_kolmapäev_neljapäev_reede_laupäev'.split('_'),
		weekdaysShort : 'P_E_T_K_N_R_L'.split('_'),
		weekdaysMin   : 'P_E_T_K_N_R_L'.split('_'),
		longDateFormat : {
			LT   : 'H:mm',
			LTS : 'H:mm:ss',
			L    : 'DD.MM.YYYY',
			LL   : 'D. MMMM YYYY',
			LLL  : 'D. MMMM YYYY H:mm',
			LLLL : 'dddd, D. MMMM YYYY H:mm'
		},
		calendar : {
			sameDay  : '[Täna,] LT',
			nextDay  : '[Homme,] LT',
			nextWeek : '[Järgmine] dddd LT',
			lastDay  : '[Eile,] LT',
			lastWeek : '[Eelmine] dddd LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : '%s pärast',
			past   : '%s tagasi',
			s      : et__processRelativeTime,
			m      : et__processRelativeTime,
			mm     : et__processRelativeTime,
			h      : et__processRelativeTime,
			hh     : et__processRelativeTime,
			d      : et__processRelativeTime,
			dd     : '%d päeva',
			M      : et__processRelativeTime,
			MM     : et__processRelativeTime,
			y      : et__processRelativeTime,
			yy     : et__processRelativeTime
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : euskara (eu)
	//! author : Eneko Illarramendi : https://github.com/eillarra

	var eu = moment__default.defineLocale('eu', {
		months : 'urtarrila_otsaila_martxoa_apirila_maiatza_ekaina_uztaila_abuztua_iraila_urria_azaroa_abendua'.split('_'),
		monthsShort : 'urt._ots._mar._api._mai._eka._uzt._abu._ira._urr._aza._abe.'.split('_'),
		weekdays : 'igandea_astelehena_asteartea_asteazkena_osteguna_ostirala_larunbata'.split('_'),
		weekdaysShort : 'ig._al._ar._az._og._ol._lr.'.split('_'),
		weekdaysMin : 'ig_al_ar_az_og_ol_lr'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'YYYY-MM-DD',
			LL : 'YYYY[ko] MMMM[ren] D[a]',
			LLL : 'YYYY[ko] MMMM[ren] D[a] HH:mm',
			LLLL : 'dddd, YYYY[ko] MMMM[ren] D[a] HH:mm',
			l : 'YYYY-M-D',
			ll : 'YYYY[ko] MMM D[a]',
			lll : 'YYYY[ko] MMM D[a] HH:mm',
			llll : 'ddd, YYYY[ko] MMM D[a] HH:mm'
		},
		calendar : {
			sameDay : '[gaur] LT[etan]',
			nextDay : '[bihar] LT[etan]',
			nextWeek : 'dddd LT[etan]',
			lastDay : '[atzo] LT[etan]',
			lastWeek : '[aurreko] dddd LT[etan]',
			sameElse : 'L'
		},
		relativeTime : {
			future : '%s barru',
			past : 'duela %s',
			s : 'segundo batzuk',
			m : 'minutu bat',
			mm : '%d minutu',
			h : 'ordu bat',
			hh : '%d ordu',
			d : 'egun bat',
			dd : '%d egun',
			M : 'hilabete bat',
			MM : '%d hilabete',
			y : 'urte bat',
			yy : '%d urte'
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : Persian (fa)
	//! author : Ebrahim Byagowi : https://github.com/ebraminio

	var fa__symbolMap = {
		'1': '۱',
		'2': '۲',
		'3': '۳',
		'4': '۴',
		'5': '۵',
		'6': '۶',
		'7': '۷',
		'8': '۸',
		'9': '۹',
		'0': '۰'
	}, fa__numberMap = {
		'۱': '1',
		'۲': '2',
		'۳': '3',
		'۴': '4',
		'۵': '5',
		'۶': '6',
		'۷': '7',
		'۸': '8',
		'۹': '9',
		'۰': '0'
	};

	var fa = moment__default.defineLocale('fa', {
		months : 'ژانویه_فوریه_مارس_آوریل_مه_ژوئن_ژوئیه_اوت_سپتامبر_اکتبر_نوامبر_دسامبر'.split('_'),
		monthsShort : 'ژانویه_فوریه_مارس_آوریل_مه_ژوئن_ژوئیه_اوت_سپتامبر_اکتبر_نوامبر_دسامبر'.split('_'),
		weekdays : 'یک\u200cشنبه_دوشنبه_سه\u200cشنبه_چهارشنبه_پنج\u200cشنبه_جمعه_شنبه'.split('_'),
		weekdaysShort : 'یک\u200cشنبه_دوشنبه_سه\u200cشنبه_چهارشنبه_پنج\u200cشنبه_جمعه_شنبه'.split('_'),
		weekdaysMin : 'ی_د_س_چ_پ_ج_ش'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd, D MMMM YYYY HH:mm'
		},
		meridiemParse: /قبل از ظهر|بعد از ظهر/,
		isPM: function (input) {
			return /بعد از ظهر/.test(input);
		},
		meridiem : function (hour, minute, isLower) {
			if (hour < 12) {
				return 'قبل از ظهر';
			} else {
				return 'بعد از ظهر';
			}
		},
		calendar : {
			sameDay : '[امروز ساعت] LT',
			nextDay : '[فردا ساعت] LT',
			nextWeek : 'dddd [ساعت] LT',
			lastDay : '[دیروز ساعت] LT',
			lastWeek : 'dddd [پیش] [ساعت] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'در %s',
			past : '%s پیش',
			s : 'چندین ثانیه',
			m : 'یک دقیقه',
			mm : '%d دقیقه',
			h : 'یک ساعت',
			hh : '%d ساعت',
			d : 'یک روز',
			dd : '%d روز',
			M : 'یک ماه',
			MM : '%d ماه',
			y : 'یک سال',
			yy : '%d سال'
		},
		preparse: function (string) {
			return string.replace(/[۰-۹]/g, function (match) {
				return fa__numberMap[match];
			}).replace(/،/g, ',');
		},
		postformat: function (string) {
			return string.replace(/\d/g, function (match) {
				return fa__symbolMap[match];
			}).replace(/,/g, '،');
		},
		ordinalParse: /\d{1,2}م/,
		ordinal : '%dم',
		week : {
			dow : 6, // Saturday is the first day of the week.
			doy : 12 // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : finnish (fi)
	//! author : Tarmo Aidantausta : https://github.com/bleadof

	var numbersPast = 'nolla yksi kaksi kolme neljä viisi kuusi seitsemän kahdeksan yhdeksän'.split(' '),
		numbersFuture = [
			'nolla', 'yhden', 'kahden', 'kolmen', 'neljän', 'viiden', 'kuuden',
			numbersPast[7], numbersPast[8], numbersPast[9]
		];
	function fi__translate(number, withoutSuffix, key, isFuture) {
		var result = '';
		switch (key) {
		case 's':
			return isFuture ? 'muutaman sekunnin' : 'muutama sekunti';
		case 'm':
			return isFuture ? 'minuutin' : 'minuutti';
		case 'mm':
			result = isFuture ? 'minuutin' : 'minuuttia';
			break;
		case 'h':
			return isFuture ? 'tunnin' : 'tunti';
		case 'hh':
			result = isFuture ? 'tunnin' : 'tuntia';
			break;
		case 'd':
			return isFuture ? 'päivän' : 'päivä';
		case 'dd':
			result = isFuture ? 'päivän' : 'päivää';
			break;
		case 'M':
			return isFuture ? 'kuukauden' : 'kuukausi';
		case 'MM':
			result = isFuture ? 'kuukauden' : 'kuukautta';
			break;
		case 'y':
			return isFuture ? 'vuoden' : 'vuosi';
		case 'yy':
			result = isFuture ? 'vuoden' : 'vuotta';
			break;
		}
		result = verbalNumber(number, isFuture) + ' ' + result;
		return result;
	}
	function verbalNumber(number, isFuture) {
		return number < 10 ? (isFuture ? numbersFuture[number] : numbersPast[number]) : number;
	}

	var fi = moment__default.defineLocale('fi', {
		months : 'tammikuu_helmikuu_maaliskuu_huhtikuu_toukokuu_kesäkuu_heinäkuu_elokuu_syyskuu_lokakuu_marraskuu_joulukuu'.split('_'),
		monthsShort : 'tammi_helmi_maalis_huhti_touko_kesä_heinä_elo_syys_loka_marras_joulu'.split('_'),
		weekdays : 'sunnuntai_maanantai_tiistai_keskiviikko_torstai_perjantai_lauantai'.split('_'),
		weekdaysShort : 'su_ma_ti_ke_to_pe_la'.split('_'),
		weekdaysMin : 'su_ma_ti_ke_to_pe_la'.split('_'),
		longDateFormat : {
			LT : 'HH.mm',
			LTS : 'HH.mm.ss',
			L : 'DD.MM.YYYY',
			LL : 'Do MMMM[ta] YYYY',
			LLL : 'Do MMMM[ta] YYYY, [klo] HH.mm',
			LLLL : 'dddd, Do MMMM[ta] YYYY, [klo] HH.mm',
			l : 'D.M.YYYY',
			ll : 'Do MMM YYYY',
			lll : 'Do MMM YYYY, [klo] HH.mm',
			llll : 'ddd, Do MMM YYYY, [klo] HH.mm'
		},
		calendar : {
			sameDay : '[tänään] [klo] LT',
			nextDay : '[huomenna] [klo] LT',
			nextWeek : 'dddd [klo] LT',
			lastDay : '[eilen] [klo] LT',
			lastWeek : '[viime] dddd[na] [klo] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : '%s päästä',
			past : '%s sitten',
			s : fi__translate,
			m : fi__translate,
			mm : fi__translate,
			h : fi__translate,
			hh : fi__translate,
			d : fi__translate,
			dd : fi__translate,
			M : fi__translate,
			MM : fi__translate,
			y : fi__translate,
			yy : fi__translate
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : faroese (fo)
	//! author : Ragnar Johannesen : https://github.com/ragnar123

	var fo = moment__default.defineLocale('fo', {
		months : 'januar_februar_mars_apríl_mai_juni_juli_august_september_oktober_november_desember'.split('_'),
		monthsShort : 'jan_feb_mar_apr_mai_jun_jul_aug_sep_okt_nov_des'.split('_'),
		weekdays : 'sunnudagur_mánadagur_týsdagur_mikudagur_hósdagur_fríggjadagur_leygardagur'.split('_'),
		weekdaysShort : 'sun_mán_týs_mik_hós_frí_ley'.split('_'),
		weekdaysMin : 'su_má_tý_mi_hó_fr_le'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd D. MMMM, YYYY HH:mm'
		},
		calendar : {
			sameDay : '[Í dag kl.] LT',
			nextDay : '[Í morgin kl.] LT',
			nextWeek : 'dddd [kl.] LT',
			lastDay : '[Í gjár kl.] LT',
			lastWeek : '[síðstu] dddd [kl] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'um %s',
			past : '%s síðani',
			s : 'fá sekund',
			m : 'ein minutt',
			mm : '%d minuttir',
			h : 'ein tími',
			hh : '%d tímar',
			d : 'ein dagur',
			dd : '%d dagar',
			M : 'ein mánaði',
			MM : '%d mánaðir',
			y : 'eitt ár',
			yy : '%d ár'
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : canadian french (fr-ca)
	//! author : Jonathan Abourbih : https://github.com/jonbca

	var fr_ca = moment__default.defineLocale('fr-ca', {
		months : 'janvier_février_mars_avril_mai_juin_juillet_août_septembre_octobre_novembre_décembre'.split('_'),
		monthsShort : 'janv._févr._mars_avr._mai_juin_juil._août_sept._oct._nov._déc.'.split('_'),
		weekdays : 'dimanche_lundi_mardi_mercredi_jeudi_vendredi_samedi'.split('_'),
		weekdaysShort : 'dim._lun._mar._mer._jeu._ven._sam.'.split('_'),
		weekdaysMin : 'Di_Lu_Ma_Me_Je_Ve_Sa'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'YYYY-MM-DD',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd D MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay: '[Aujourd\'hui à] LT',
			nextDay: '[Demain à] LT',
			nextWeek: 'dddd [à] LT',
			lastDay: '[Hier à] LT',
			lastWeek: 'dddd [dernier à] LT',
			sameElse: 'L'
		},
		relativeTime : {
			future : 'dans %s',
			past : 'il y a %s',
			s : 'quelques secondes',
			m : 'une minute',
			mm : '%d minutes',
			h : 'une heure',
			hh : '%d heures',
			d : 'un jour',
			dd : '%d jours',
			M : 'un mois',
			MM : '%d mois',
			y : 'un an',
			yy : '%d ans'
		},
		ordinalParse: /\d{1,2}(er|e)/,
		ordinal : function (number) {
			return number + (number === 1 ? 'er' : 'e');
		}
	});

	//! moment.js locale configuration
	//! locale : swiss french (fr)
	//! author : Gaspard Bucher : https://github.com/gaspard

	var fr_ch = moment__default.defineLocale('fr-ch', {
		months : 'janvier_février_mars_avril_mai_juin_juillet_août_septembre_octobre_novembre_décembre'.split('_'),
		monthsShort : 'janv._févr._mars_avr._mai_juin_juil._août_sept._oct._nov._déc.'.split('_'),
		weekdays : 'dimanche_lundi_mardi_mercredi_jeudi_vendredi_samedi'.split('_'),
		weekdaysShort : 'dim._lun._mar._mer._jeu._ven._sam.'.split('_'),
		weekdaysMin : 'Di_Lu_Ma_Me_Je_Ve_Sa'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD.MM.YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd D MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay: '[Aujourd\'hui à] LT',
			nextDay: '[Demain à] LT',
			nextWeek: 'dddd [à] LT',
			lastDay: '[Hier à] LT',
			lastWeek: 'dddd [dernier à] LT',
			sameElse: 'L'
		},
		relativeTime : {
			future : 'dans %s',
			past : 'il y a %s',
			s : 'quelques secondes',
			m : 'une minute',
			mm : '%d minutes',
			h : 'une heure',
			hh : '%d heures',
			d : 'un jour',
			dd : '%d jours',
			M : 'un mois',
			MM : '%d mois',
			y : 'un an',
			yy : '%d ans'
		},
		ordinalParse: /\d{1,2}(er|e)/,
		ordinal : function (number) {
			return number + (number === 1 ? 'er' : 'e');
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : french (fr)
	//! author : John Fischer : https://github.com/jfroffice

	var fr = moment__default.defineLocale('fr', {
		months : 'janvier_février_mars_avril_mai_juin_juillet_août_septembre_octobre_novembre_décembre'.split('_'),
		monthsShort : 'janv._févr._mars_avr._mai_juin_juil._août_sept._oct._nov._déc.'.split('_'),
		weekdays : 'dimanche_lundi_mardi_mercredi_jeudi_vendredi_samedi'.split('_'),
		weekdaysShort : 'dim._lun._mar._mer._jeu._ven._sam.'.split('_'),
		weekdaysMin : 'Di_Lu_Ma_Me_Je_Ve_Sa'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd D MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay: '[Aujourd\'hui à] LT',
			nextDay: '[Demain à] LT',
			nextWeek: 'dddd [à] LT',
			lastDay: '[Hier à] LT',
			lastWeek: 'dddd [dernier à] LT',
			sameElse: 'L'
		},
		relativeTime : {
			future : 'dans %s',
			past : 'il y a %s',
			s : 'quelques secondes',
			m : 'une minute',
			mm : '%d minutes',
			h : 'une heure',
			hh : '%d heures',
			d : 'un jour',
			dd : '%d jours',
			M : 'un mois',
			MM : '%d mois',
			y : 'un an',
			yy : '%d ans'
		},
		ordinalParse: /\d{1,2}(er|)/,
		ordinal : function (number) {
			return number + (number === 1 ? 'er' : '');
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : frisian (fy)
	//! author : Robin van der Vliet : https://github.com/robin0van0der0v

	var fy__monthsShortWithDots = 'jan._feb._mrt._apr._mai_jun._jul._aug._sep._okt._nov._des.'.split('_'),
		fy__monthsShortWithoutDots = 'jan_feb_mrt_apr_mai_jun_jul_aug_sep_okt_nov_des'.split('_');

	var fy = moment__default.defineLocale('fy', {
		months : 'jannewaris_febrewaris_maart_april_maaie_juny_july_augustus_septimber_oktober_novimber_desimber'.split('_'),
		monthsShort : function (m, format) {
			if (/-MMM-/.test(format)) {
				return fy__monthsShortWithoutDots[m.month()];
			} else {
				return fy__monthsShortWithDots[m.month()];
			}
		},
		weekdays : 'snein_moandei_tiisdei_woansdei_tongersdei_freed_sneon'.split('_'),
		weekdaysShort : 'si._mo._ti._wo._to._fr._so.'.split('_'),
		weekdaysMin : 'Si_Mo_Ti_Wo_To_Fr_So'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD-MM-YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd D MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay: '[hjoed om] LT',
			nextDay: '[moarn om] LT',
			nextWeek: 'dddd [om] LT',
			lastDay: '[juster om] LT',
			lastWeek: '[ôfrûne] dddd [om] LT',
			sameElse: 'L'
		},
		relativeTime : {
			future : 'oer %s',
			past : '%s lyn',
			s : 'in pear sekonden',
			m : 'ien minút',
			mm : '%d minuten',
			h : 'ien oere',
			hh : '%d oeren',
			d : 'ien dei',
			dd : '%d dagen',
			M : 'ien moanne',
			MM : '%d moannen',
			y : 'ien jier',
			yy : '%d jierren'
		},
		ordinalParse: /\d{1,2}(ste|de)/,
		ordinal : function (number) {
			return number + ((number === 1 || number === 8 || number >= 20) ? 'ste' : 'de');
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : great britain scottish gealic (gd)
	//! author : Jon Ashdown : https://github.com/jonashdown

	var gd__months = [
		'Am Faoilleach', 'An Gearran', 'Am Màrt', 'An Giblean', 'An Cèitean', 'An t-Ògmhios', 'An t-Iuchar', 'An Lùnastal', 'An t-Sultain', 'An Dàmhair', 'An t-Samhain', 'An Dùbhlachd'
	];

	var gd__monthsShort = ['Faoi', 'Gear', 'Màrt', 'Gibl', 'Cèit', 'Ògmh', 'Iuch', 'Lùn', 'Sult', 'Dàmh', 'Samh', 'Dùbh'];

	var gd__weekdays = ['Didòmhnaich', 'Diluain', 'Dimàirt', 'Diciadain', 'Diardaoin', 'Dihaoine', 'Disathairne'];

	var weekdaysShort = ['Did', 'Dil', 'Dim', 'Dic', 'Dia', 'Dih', 'Dis'];

	var weekdaysMin = ['Dò', 'Lu', 'Mà', 'Ci', 'Ar', 'Ha', 'Sa'];

	var gd = moment__default.defineLocale('gd', {
		months : gd__months,
		monthsShort : gd__monthsShort,
		monthsParseExact : true,
		weekdays : gd__weekdays,
		weekdaysShort : weekdaysShort,
		weekdaysMin : weekdaysMin,
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd, D MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay : '[An-diugh aig] LT',
			nextDay : '[A-màireach aig] LT',
			nextWeek : 'dddd [aig] LT',
			lastDay : '[An-dè aig] LT',
			lastWeek : 'dddd [seo chaidh] [aig] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'ann an %s',
			past : 'bho chionn %s',
			s : 'beagan diogan',
			m : 'mionaid',
			mm : '%d mionaidean',
			h : 'uair',
			hh : '%d uairean',
			d : 'latha',
			dd : '%d latha',
			M : 'mìos',
			MM : '%d mìosan',
			y : 'bliadhna',
			yy : '%d bliadhna'
		},
		ordinalParse : /\d{1,2}(d|na|mh)/,
		ordinal : function (number) {
			var output = number === 1 ? 'd' : number % 10 === 2 ? 'na' : 'mh';
			return number + output;
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : galician (gl)
	//! author : Juan G. Hurtado : https://github.com/juanghurtado

	var gl = moment__default.defineLocale('gl', {
		months : 'Xaneiro_Febreiro_Marzo_Abril_Maio_Xuño_Xullo_Agosto_Setembro_Outubro_Novembro_Decembro'.split('_'),
		monthsShort : 'Xan._Feb._Mar._Abr._Mai._Xuñ._Xul._Ago._Set._Out._Nov._Dec.'.split('_'),
		weekdays : 'Domingo_Luns_Martes_Mércores_Xoves_Venres_Sábado'.split('_'),
		weekdaysShort : 'Dom._Lun._Mar._Mér._Xov._Ven._Sáb.'.split('_'),
		weekdaysMin : 'Do_Lu_Ma_Mé_Xo_Ve_Sá'.split('_'),
		longDateFormat : {
			LT : 'H:mm',
			LTS : 'H:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY H:mm',
			LLLL : 'dddd D MMMM YYYY H:mm'
		},
		calendar : {
			sameDay : function () {
				return '[hoxe ' + ((this.hours() !== 1) ? 'ás' : 'á') + '] LT';
			},
			nextDay : function () {
				return '[mañá ' + ((this.hours() !== 1) ? 'ás' : 'á') + '] LT';
			},
			nextWeek : function () {
				return 'dddd [' + ((this.hours() !== 1) ? 'ás' : 'a') + '] LT';
			},
			lastDay : function () {
				return '[onte ' + ((this.hours() !== 1) ? 'á' : 'a') + '] LT';
			},
			lastWeek : function () {
				return '[o] dddd [pasado ' + ((this.hours() !== 1) ? 'ás' : 'a') + '] LT';
			},
			sameElse : 'L'
		},
		relativeTime : {
			future : function (str) {
				if (str === 'uns segundos') {
					return 'nuns segundos';
				}
				return 'en ' + str;
			},
			past : 'hai %s',
			s : 'uns segundos',
			m : 'un minuto',
			mm : '%d minutos',
			h : 'unha hora',
			hh : '%d horas',
			d : 'un día',
			dd : '%d días',
			M : 'un mes',
			MM : '%d meses',
			y : 'un ano',
			yy : '%d anos'
		},
		ordinalParse : /\d{1,2}º/,
		ordinal : '%dº',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : Hebrew (he)
	//! author : Tomer Cohen : https://github.com/tomer
	//! author : Moshe Simantov : https://github.com/DevelopmentIL
	//! author : Tal Ater : https://github.com/TalAter

	var he = moment__default.defineLocale('he', {
		months : 'ינואר_פברואר_מרץ_אפריל_מאי_יוני_יולי_אוגוסט_ספטמבר_אוקטובר_נובמבר_דצמבר'.split('_'),
		monthsShort : 'ינו׳_פבר׳_מרץ_אפר׳_מאי_יוני_יולי_אוג׳_ספט׳_אוק׳_נוב׳_דצמ׳'.split('_'),
		weekdays : 'ראשון_שני_שלישי_רביעי_חמישי_שישי_שבת'.split('_'),
		weekdaysShort : 'א׳_ב׳_ג׳_ד׳_ה׳_ו׳_ש׳'.split('_'),
		weekdaysMin : 'א_ב_ג_ד_ה_ו_ש'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D [ב]MMMM YYYY',
			LLL : 'D [ב]MMMM YYYY HH:mm',
			LLLL : 'dddd, D [ב]MMMM YYYY HH:mm',
			l : 'D/M/YYYY',
			ll : 'D MMM YYYY',
			lll : 'D MMM YYYY HH:mm',
			llll : 'ddd, D MMM YYYY HH:mm'
		},
		calendar : {
			sameDay : '[היום ב־]LT',
			nextDay : '[מחר ב־]LT',
			nextWeek : 'dddd [בשעה] LT',
			lastDay : '[אתמול ב־]LT',
			lastWeek : '[ביום] dddd [האחרון בשעה] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'בעוד %s',
			past : 'לפני %s',
			s : 'מספר שניות',
			m : 'דקה',
			mm : '%d דקות',
			h : 'שעה',
			hh : function (number) {
				if (number === 2) {
					return 'שעתיים';
				}
				return number + ' שעות';
			},
			d : 'יום',
			dd : function (number) {
				if (number === 2) {
					return 'יומיים';
				}
				return number + ' ימים';
			},
			M : 'חודש',
			MM : function (number) {
				if (number === 2) {
					return 'חודשיים';
				}
				return number + ' חודשים';
			},
			y : 'שנה',
			yy : function (number) {
				if (number === 2) {
					return 'שנתיים';
				} else if (number % 10 === 0 && number !== 10) {
					return number + ' שנה';
				}
				return number + ' שנים';
			}
		}
	});

	//! moment.js locale configuration
	//! locale : hindi (hi)
	//! author : Mayank Singhal : https://github.com/mayanksinghal

	var hi__symbolMap = {
		'1': '१',
		'2': '२',
		'3': '३',
		'4': '४',
		'5': '५',
		'6': '६',
		'7': '७',
		'8': '८',
		'9': '९',
		'0': '०'
	},
	hi__numberMap = {
		'१': '1',
		'२': '2',
		'३': '3',
		'४': '4',
		'५': '5',
		'६': '6',
		'७': '7',
		'८': '8',
		'९': '9',
		'०': '0'
	};

	var hi = moment__default.defineLocale('hi', {
		months : 'जनवरी_फ़रवरी_मार्च_अप्रैल_मई_जून_जुलाई_अगस्त_सितम्बर_अक्टूबर_नवम्बर_दिसम्बर'.split('_'),
		monthsShort : 'जन._फ़र._मार्च_अप्रै._मई_जून_जुल._अग._सित._अक्टू._नव._दिस.'.split('_'),
		weekdays : 'रविवार_सोमवार_मंगलवार_बुधवार_गुरूवार_शुक्रवार_शनिवार'.split('_'),
		weekdaysShort : 'रवि_सोम_मंगल_बुध_गुरू_शुक्र_शनि'.split('_'),
		weekdaysMin : 'र_सो_मं_बु_गु_शु_श'.split('_'),
		longDateFormat : {
			LT : 'A h:mm बजे',
			LTS : 'A h:mm:ss बजे',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY, A h:mm बजे',
			LLLL : 'dddd, D MMMM YYYY, A h:mm बजे'
		},
		calendar : {
			sameDay : '[आज] LT',
			nextDay : '[कल] LT',
			nextWeek : 'dddd, LT',
			lastDay : '[कल] LT',
			lastWeek : '[पिछले] dddd, LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : '%s में',
			past : '%s पहले',
			s : 'कुछ ही क्षण',
			m : 'एक मिनट',
			mm : '%d मिनट',
			h : 'एक घंटा',
			hh : '%d घंटे',
			d : 'एक दिन',
			dd : '%d दिन',
			M : 'एक महीने',
			MM : '%d महीने',
			y : 'एक वर्ष',
			yy : '%d वर्ष'
		},
		preparse: function (string) {
			return string.replace(/[१२३४५६७८९०]/g, function (match) {
				return hi__numberMap[match];
			});
		},
		postformat: function (string) {
			return string.replace(/\d/g, function (match) {
				return hi__symbolMap[match];
			});
		},
		// Hindi notation for meridiems are quite fuzzy in practice. While there exists
		// a rigid notion of a 'Pahar' it is not used as rigidly in modern Hindi.
		meridiemParse: /रात|सुबह|दोपहर|शाम/,
		meridiemHour : function (hour, meridiem) {
			if (hour === 12) {
				hour = 0;
			}
			if (meridiem === 'रात') {
				return hour < 4 ? hour : hour + 12;
			} else if (meridiem === 'सुबह') {
				return hour;
			} else if (meridiem === 'दोपहर') {
				return hour >= 10 ? hour : hour + 12;
			} else if (meridiem === 'शाम') {
				return hour + 12;
			}
		},
		meridiem : function (hour, minute, isLower) {
			if (hour < 4) {
				return 'रात';
			} else if (hour < 10) {
				return 'सुबह';
			} else if (hour < 17) {
				return 'दोपहर';
			} else if (hour < 20) {
				return 'शाम';
			} else {
				return 'रात';
			}
		},
		week : {
			dow : 0, // Sunday is the first day of the week.
			doy : 6  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : hrvatski (hr)
	//! author : Bojan Marković : https://github.com/bmarkovic

	function hr__translate(number, withoutSuffix, key) {
		var result = number + ' ';
		switch (key) {
		case 'm':
			return withoutSuffix ? 'jedna minuta' : 'jedne minute';
		case 'mm':
			if (number === 1) {
				result += 'minuta';
			} else if (number === 2 || number === 3 || number === 4) {
				result += 'minute';
			} else {
				result += 'minuta';
			}
			return result;
		case 'h':
			return withoutSuffix ? 'jedan sat' : 'jednog sata';
		case 'hh':
			if (number === 1) {
				result += 'sat';
			} else if (number === 2 || number === 3 || number === 4) {
				result += 'sata';
			} else {
				result += 'sati';
			}
			return result;
		case 'dd':
			if (number === 1) {
				result += 'dan';
			} else {
				result += 'dana';
			}
			return result;
		case 'MM':
			if (number === 1) {
				result += 'mjesec';
			} else if (number === 2 || number === 3 || number === 4) {
				result += 'mjeseca';
			} else {
				result += 'mjeseci';
			}
			return result;
		case 'yy':
			if (number === 1) {
				result += 'godina';
			} else if (number === 2 || number === 3 || number === 4) {
				result += 'godine';
			} else {
				result += 'godina';
			}
			return result;
		}
	}

	var hr = moment__default.defineLocale('hr', {
		months : {
			format: 'siječnja_veljače_ožujka_travnja_svibnja_lipnja_srpnja_kolovoza_rujna_listopada_studenoga_prosinca'.split('_'),
			standalone: 'siječanj_veljača_ožujak_travanj_svibanj_lipanj_srpanj_kolovoz_rujan_listopad_studeni_prosinac'.split('_')
		},
		monthsShort : 'sij._velj._ožu._tra._svi._lip._srp._kol._ruj._lis._stu._pro.'.split('_'),
		weekdays : 'nedjelja_ponedjeljak_utorak_srijeda_četvrtak_petak_subota'.split('_'),
		weekdaysShort : 'ned._pon._uto._sri._čet._pet._sub.'.split('_'),
		weekdaysMin : 'ne_po_ut_sr_če_pe_su'.split('_'),
		longDateFormat : {
			LT : 'H:mm',
			LTS : 'H:mm:ss',
			L : 'DD. MM. YYYY',
			LL : 'D. MMMM YYYY',
			LLL : 'D. MMMM YYYY H:mm',
			LLLL : 'dddd, D. MMMM YYYY H:mm'
		},
		calendar : {
			sameDay  : '[danas u] LT',
			nextDay  : '[sutra u] LT',
			nextWeek : function () {
				switch (this.day()) {
				case 0:
					return '[u] [nedjelju] [u] LT';
				case 3:
					return '[u] [srijedu] [u] LT';
				case 6:
					return '[u] [subotu] [u] LT';
				case 1:
				case 2:
				case 4:
				case 5:
					return '[u] dddd [u] LT';
				}
			},
			lastDay  : '[jučer u] LT',
			lastWeek : function () {
				switch (this.day()) {
				case 0:
				case 3:
					return '[prošlu] dddd [u] LT';
				case 6:
					return '[prošle] [subote] [u] LT';
				case 1:
				case 2:
				case 4:
				case 5:
					return '[prošli] dddd [u] LT';
				}
			},
			sameElse : 'L'
		},
		relativeTime : {
			future : 'za %s',
			past   : 'prije %s',
			s      : 'par sekundi',
			m      : hr__translate,
			mm     : hr__translate,
			h      : hr__translate,
			hh     : hr__translate,
			d      : 'dan',
			dd     : hr__translate,
			M      : 'mjesec',
			MM     : hr__translate,
			y      : 'godinu',
			yy     : hr__translate
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : hungarian (hu)
	//! author : Adam Brunner : https://github.com/adambrunner

	var weekEndings = 'vasárnap hétfőn kedden szerdán csütörtökön pénteken szombaton'.split(' ');
	function hu__translate(number, withoutSuffix, key, isFuture) {
		var num = number,
			suffix;
		switch (key) {
		case 's':
			return (isFuture || withoutSuffix) ? 'néhány másodperc' : 'néhány másodperce';
		case 'm':
			return 'egy' + (isFuture || withoutSuffix ? ' perc' : ' perce');
		case 'mm':
			return num + (isFuture || withoutSuffix ? ' perc' : ' perce');
		case 'h':
			return 'egy' + (isFuture || withoutSuffix ? ' óra' : ' órája');
		case 'hh':
			return num + (isFuture || withoutSuffix ? ' óra' : ' órája');
		case 'd':
			return 'egy' + (isFuture || withoutSuffix ? ' nap' : ' napja');
		case 'dd':
			return num + (isFuture || withoutSuffix ? ' nap' : ' napja');
		case 'M':
			return 'egy' + (isFuture || withoutSuffix ? ' hónap' : ' hónapja');
		case 'MM':
			return num + (isFuture || withoutSuffix ? ' hónap' : ' hónapja');
		case 'y':
			return 'egy' + (isFuture || withoutSuffix ? ' év' : ' éve');
		case 'yy':
			return num + (isFuture || withoutSuffix ? ' év' : ' éve');
		}
		return '';
	}
	function week(isFuture) {
		return (isFuture ? '' : '[múlt] ') + '[' + weekEndings[this.day()] + '] LT[-kor]';
	}

	var hu = moment__default.defineLocale('hu', {
		months : 'január_február_március_április_május_június_július_augusztus_szeptember_október_november_december'.split('_'),
		monthsShort : 'jan_feb_márc_ápr_máj_jún_júl_aug_szept_okt_nov_dec'.split('_'),
		weekdays : 'vasárnap_hétfő_kedd_szerda_csütörtök_péntek_szombat'.split('_'),
		weekdaysShort : 'vas_hét_kedd_sze_csüt_pén_szo'.split('_'),
		weekdaysMin : 'v_h_k_sze_cs_p_szo'.split('_'),
		longDateFormat : {
			LT : 'H:mm',
			LTS : 'H:mm:ss',
			L : 'YYYY.MM.DD.',
			LL : 'YYYY. MMMM D.',
			LLL : 'YYYY. MMMM D. H:mm',
			LLLL : 'YYYY. MMMM D., dddd H:mm'
		},
		meridiemParse: /de|du/i,
		isPM: function (input) {
			return input.charAt(1).toLowerCase() === 'u';
		},
		meridiem : function (hours, minutes, isLower) {
			if (hours < 12) {
				return isLower === true ? 'de' : 'DE';
			} else {
				return isLower === true ? 'du' : 'DU';
			}
		},
		calendar : {
			sameDay : '[ma] LT[-kor]',
			nextDay : '[holnap] LT[-kor]',
			nextWeek : function () {
				return week.call(this, true);
			},
			lastDay : '[tegnap] LT[-kor]',
			lastWeek : function () {
				return week.call(this, false);
			},
			sameElse : 'L'
		},
		relativeTime : {
			future : '%s múlva',
			past : '%s',
			s : hu__translate,
			m : hu__translate,
			mm : hu__translate,
			h : hu__translate,
			hh : hu__translate,
			d : hu__translate,
			dd : hu__translate,
			M : hu__translate,
			MM : hu__translate,
			y : hu__translate,
			yy : hu__translate
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : Armenian (hy-am)
	//! author : Armendarabyan : https://github.com/armendarabyan

	var hy_am = moment__default.defineLocale('hy-am', {
		months : {
			format: 'հունվարի_փետրվարի_մարտի_ապրիլի_մայիսի_հունիսի_հուլիսի_օգոստոսի_սեպտեմբերի_հոկտեմբերի_նոյեմբերի_դեկտեմբերի'.split('_'),
			standalone: 'հունվար_փետրվար_մարտ_ապրիլ_մայիս_հունիս_հուլիս_օգոստոս_սեպտեմբեր_հոկտեմբեր_նոյեմբեր_դեկտեմբեր'.split('_')
		},
		monthsShort : 'հնվ_փտր_մրտ_ապր_մյս_հնս_հլս_օգս_սպտ_հկտ_նմբ_դկտ'.split('_'),
		weekdays : 'կիրակի_երկուշաբթի_երեքշաբթի_չորեքշաբթի_հինգշաբթի_ուրբաթ_շաբաթ'.split('_'),
		weekdaysShort : 'կրկ_երկ_երք_չրք_հնգ_ուրբ_շբթ'.split('_'),
		weekdaysMin : 'կրկ_երկ_երք_չրք_հնգ_ուրբ_շբթ'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD.MM.YYYY',
			LL : 'D MMMM YYYY թ.',
			LLL : 'D MMMM YYYY թ., HH:mm',
			LLLL : 'dddd, D MMMM YYYY թ., HH:mm'
		},
		calendar : {
			sameDay: '[այսօր] LT',
			nextDay: '[վաղը] LT',
			lastDay: '[երեկ] LT',
			nextWeek: function () {
				return 'dddd [օրը ժամը] LT';
			},
			lastWeek: function () {
				return '[անցած] dddd [օրը ժամը] LT';
			},
			sameElse: 'L'
		},
		relativeTime : {
			future : '%s հետո',
			past : '%s առաջ',
			s : 'մի քանի վայրկյան',
			m : 'րոպե',
			mm : '%d րոպե',
			h : 'ժամ',
			hh : '%d ժամ',
			d : 'օր',
			dd : '%d օր',
			M : 'ամիս',
			MM : '%d ամիս',
			y : 'տարի',
			yy : '%d տարի'
		},
		meridiemParse: /գիշերվա|առավոտվա|ցերեկվա|երեկոյան/,
		isPM: function (input) {
			return /^(ցերեկվա|երեկոյան)$/.test(input);
		},
		meridiem : function (hour) {
			if (hour < 4) {
				return 'գիշերվա';
			} else if (hour < 12) {
				return 'առավոտվա';
			} else if (hour < 17) {
				return 'ցերեկվա';
			} else {
				return 'երեկոյան';
			}
		},
		ordinalParse: /\d{1,2}|\d{1,2}-(ին|րդ)/,
		ordinal: function (number, period) {
			switch (period) {
			case 'DDD':
			case 'w':
			case 'W':
			case 'DDDo':
				if (number === 1) {
					return number + '-ին';
				}
				return number + '-րդ';
			default:
				return number;
			}
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : Bahasa Indonesia (id)
	//! author : Mohammad Satrio Utomo : https://github.com/tyok
	//! reference: http://id.wikisource.org/wiki/Pedoman_Umum_Ejaan_Bahasa_Indonesia_yang_Disempurnakan

	var id = moment__default.defineLocale('id', {
		months : 'Januari_Februari_Maret_April_Mei_Juni_Juli_Agustus_September_Oktober_November_Desember'.split('_'),
		monthsShort : 'Jan_Feb_Mar_Apr_Mei_Jun_Jul_Ags_Sep_Okt_Nov_Des'.split('_'),
		weekdays : 'Minggu_Senin_Selasa_Rabu_Kamis_Jumat_Sabtu'.split('_'),
		weekdaysShort : 'Min_Sen_Sel_Rab_Kam_Jum_Sab'.split('_'),
		weekdaysMin : 'Mg_Sn_Sl_Rb_Km_Jm_Sb'.split('_'),
		longDateFormat : {
			LT : 'HH.mm',
			LTS : 'HH.mm.ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY [pukul] HH.mm',
			LLLL : 'dddd, D MMMM YYYY [pukul] HH.mm'
		},
		meridiemParse: /pagi|siang|sore|malam/,
		meridiemHour : function (hour, meridiem) {
			if (hour === 12) {
				hour = 0;
			}
			if (meridiem === 'pagi') {
				return hour;
			} else if (meridiem === 'siang') {
				return hour >= 11 ? hour : hour + 12;
			} else if (meridiem === 'sore' || meridiem === 'malam') {
				return hour + 12;
			}
		},
		meridiem : function (hours, minutes, isLower) {
			if (hours < 11) {
				return 'pagi';
			} else if (hours < 15) {
				return 'siang';
			} else if (hours < 19) {
				return 'sore';
			} else {
				return 'malam';
			}
		},
		calendar : {
			sameDay : '[Hari ini pukul] LT',
			nextDay : '[Besok pukul] LT',
			nextWeek : 'dddd [pukul] LT',
			lastDay : '[Kemarin pukul] LT',
			lastWeek : 'dddd [lalu pukul] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'dalam %s',
			past : '%s yang lalu',
			s : 'beberapa detik',
			m : 'semenit',
			mm : '%d menit',
			h : 'sejam',
			hh : '%d jam',
			d : 'sehari',
			dd : '%d hari',
			M : 'sebulan',
			MM : '%d bulan',
			y : 'setahun',
			yy : '%d tahun'
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : icelandic (is)
	//! author : Hinrik Örn Sigurðsson : https://github.com/hinrik

	function is__plural(n) {
		if (n % 100 === 11) {
			return true;
		} else if (n % 10 === 1) {
			return false;
		}
		return true;
	}
	function is__translate(number, withoutSuffix, key, isFuture) {
		var result = number + ' ';
		switch (key) {
		case 's':
			return withoutSuffix || isFuture ? 'nokkrar sekúndur' : 'nokkrum sekúndum';
		case 'm':
			return withoutSuffix ? 'mínúta' : 'mínútu';
		case 'mm':
			if (is__plural(number)) {
				return result + (withoutSuffix || isFuture ? 'mínútur' : 'mínútum');
			} else if (withoutSuffix) {
				return result + 'mínúta';
			}
			return result + 'mínútu';
		case 'hh':
			if (is__plural(number)) {
				return result + (withoutSuffix || isFuture ? 'klukkustundir' : 'klukkustundum');
			}
			return result + 'klukkustund';
		case 'd':
			if (withoutSuffix) {
				return 'dagur';
			}
			return isFuture ? 'dag' : 'degi';
		case 'dd':
			if (is__plural(number)) {
				if (withoutSuffix) {
					return result + 'dagar';
				}
				return result + (isFuture ? 'daga' : 'dögum');
			} else if (withoutSuffix) {
				return result + 'dagur';
			}
			return result + (isFuture ? 'dag' : 'degi');
		case 'M':
			if (withoutSuffix) {
				return 'mánuður';
			}
			return isFuture ? 'mánuð' : 'mánuði';
		case 'MM':
			if (is__plural(number)) {
				if (withoutSuffix) {
					return result + 'mánuðir';
				}
				return result + (isFuture ? 'mánuði' : 'mánuðum');
			} else if (withoutSuffix) {
				return result + 'mánuður';
			}
			return result + (isFuture ? 'mánuð' : 'mánuði');
		case 'y':
			return withoutSuffix || isFuture ? 'ár' : 'ári';
		case 'yy':
			if (is__plural(number)) {
				return result + (withoutSuffix || isFuture ? 'ár' : 'árum');
			}
			return result + (withoutSuffix || isFuture ? 'ár' : 'ári');
		}
	}

	var is = moment__default.defineLocale('is', {
		months : 'janúar_febrúar_mars_apríl_maí_júní_júlí_ágúst_september_október_nóvember_desember'.split('_'),
		monthsShort : 'jan_feb_mar_apr_maí_jún_júl_ágú_sep_okt_nóv_des'.split('_'),
		weekdays : 'sunnudagur_mánudagur_þriðjudagur_miðvikudagur_fimmtudagur_föstudagur_laugardagur'.split('_'),
		weekdaysShort : 'sun_mán_þri_mið_fim_fös_lau'.split('_'),
		weekdaysMin : 'Su_Má_Þr_Mi_Fi_Fö_La'.split('_'),
		longDateFormat : {
			LT : 'H:mm',
			LTS : 'H:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D. MMMM YYYY',
			LLL : 'D. MMMM YYYY [kl.] H:mm',
			LLLL : 'dddd, D. MMMM YYYY [kl.] H:mm'
		},
		calendar : {
			sameDay : '[í dag kl.] LT',
			nextDay : '[á morgun kl.] LT',
			nextWeek : 'dddd [kl.] LT',
			lastDay : '[í gær kl.] LT',
			lastWeek : '[síðasta] dddd [kl.] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'eftir %s',
			past : 'fyrir %s síðan',
			s : is__translate,
			m : is__translate,
			mm : is__translate,
			h : 'klukkustund',
			hh : is__translate,
			d : is__translate,
			dd : is__translate,
			M : is__translate,
			MM : is__translate,
			y : is__translate,
			yy : is__translate
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : italian (it)
	//! author : Lorenzo : https://github.com/aliem
	//! author: Mattia Larentis: https://github.com/nostalgiaz

	var it = moment__default.defineLocale('it', {
		months : 'gennaio_febbraio_marzo_aprile_maggio_giugno_luglio_agosto_settembre_ottobre_novembre_dicembre'.split('_'),
		monthsShort : 'gen_feb_mar_apr_mag_giu_lug_ago_set_ott_nov_dic'.split('_'),
		weekdays : 'Domenica_Lunedì_Martedì_Mercoledì_Giovedì_Venerdì_Sabato'.split('_'),
		weekdaysShort : 'Dom_Lun_Mar_Mer_Gio_Ven_Sab'.split('_'),
		weekdaysMin : 'Do_Lu_Ma_Me_Gi_Ve_Sa'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd, D MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay: '[Oggi alle] LT',
			nextDay: '[Domani alle] LT',
			nextWeek: 'dddd [alle] LT',
			lastDay: '[Ieri alle] LT',
			lastWeek: function () {
				switch (this.day()) {
					case 0:
						return '[la scorsa] dddd [alle] LT';
					default:
						return '[lo scorso] dddd [alle] LT';
				}
			},
			sameElse: 'L'
		},
		relativeTime : {
			future : function (s) {
				return ((/^[0-9].+$/).test(s) ? 'tra' : 'in') + ' ' + s;
			},
			past : '%s fa',
			s : 'alcuni secondi',
			m : 'un minuto',
			mm : '%d minuti',
			h : 'un\'ora',
			hh : '%d ore',
			d : 'un giorno',
			dd : '%d giorni',
			M : 'un mese',
			MM : '%d mesi',
			y : 'un anno',
			yy : '%d anni'
		},
		ordinalParse : /\d{1,2}º/,
		ordinal: '%dº',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : japanese (ja)
	//! author : LI Long : https://github.com/baryon

	var ja = moment__default.defineLocale('ja', {
		months : '1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月'.split('_'),
		monthsShort : '1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月'.split('_'),
		weekdays : '日曜日_月曜日_火曜日_水曜日_木曜日_金曜日_土曜日'.split('_'),
		weekdaysShort : '日_月_火_水_木_金_土'.split('_'),
		weekdaysMin : '日_月_火_水_木_金_土'.split('_'),
		longDateFormat : {
			LT : 'Ah時m分',
			LTS : 'Ah時m分s秒',
			L : 'YYYY/MM/DD',
			LL : 'YYYY年M月D日',
			LLL : 'YYYY年M月D日Ah時m分',
			LLLL : 'YYYY年M月D日Ah時m分 dddd'
		},
		meridiemParse: /午前|午後/i,
		isPM : function (input) {
			return input === '午後';
		},
		meridiem : function (hour, minute, isLower) {
			if (hour < 12) {
				return '午前';
			} else {
				return '午後';
			}
		},
		calendar : {
			sameDay : '[今日] LT',
			nextDay : '[明日] LT',
			nextWeek : '[来週]dddd LT',
			lastDay : '[昨日] LT',
			lastWeek : '[前週]dddd LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : '%s後',
			past : '%s前',
			s : '数秒',
			m : '1分',
			mm : '%d分',
			h : '1時間',
			hh : '%d時間',
			d : '1日',
			dd : '%d日',
			M : '1ヶ月',
			MM : '%dヶ月',
			y : '1年',
			yy : '%d年'
		}
	});

	//! moment.js locale configuration
	//! locale : Boso Jowo (jv)
	//! author : Rony Lantip : https://github.com/lantip
	//! reference: http://jv.wikipedia.org/wiki/Basa_Jawa

	var jv = moment__default.defineLocale('jv', {
		months : 'Januari_Februari_Maret_April_Mei_Juni_Juli_Agustus_September_Oktober_Nopember_Desember'.split('_'),
		monthsShort : 'Jan_Feb_Mar_Apr_Mei_Jun_Jul_Ags_Sep_Okt_Nop_Des'.split('_'),
		weekdays : 'Minggu_Senen_Seloso_Rebu_Kemis_Jemuwah_Septu'.split('_'),
		weekdaysShort : 'Min_Sen_Sel_Reb_Kem_Jem_Sep'.split('_'),
		weekdaysMin : 'Mg_Sn_Sl_Rb_Km_Jm_Sp'.split('_'),
		longDateFormat : {
			LT : 'HH.mm',
			LTS : 'HH.mm.ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY [pukul] HH.mm',
			LLLL : 'dddd, D MMMM YYYY [pukul] HH.mm'
		},
		meridiemParse: /enjing|siyang|sonten|ndalu/,
		meridiemHour : function (hour, meridiem) {
			if (hour === 12) {
				hour = 0;
			}
			if (meridiem === 'enjing') {
				return hour;
			} else if (meridiem === 'siyang') {
				return hour >= 11 ? hour : hour + 12;
			} else if (meridiem === 'sonten' || meridiem === 'ndalu') {
				return hour + 12;
			}
		},
		meridiem : function (hours, minutes, isLower) {
			if (hours < 11) {
				return 'enjing';
			} else if (hours < 15) {
				return 'siyang';
			} else if (hours < 19) {
				return 'sonten';
			} else {
				return 'ndalu';
			}
		},
		calendar : {
			sameDay : '[Dinten puniko pukul] LT',
			nextDay : '[Mbenjang pukul] LT',
			nextWeek : 'dddd [pukul] LT',
			lastDay : '[Kala wingi pukul] LT',
			lastWeek : 'dddd [kepengker pukul] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'wonten ing %s',
			past : '%s ingkang kepengker',
			s : 'sawetawis detik',
			m : 'setunggal menit',
			mm : '%d menit',
			h : 'setunggal jam',
			hh : '%d jam',
			d : 'sedinten',
			dd : '%d dinten',
			M : 'sewulan',
			MM : '%d wulan',
			y : 'setaun',
			yy : '%d taun'
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : Georgian (ka)
	//! author : Irakli Janiashvili : https://github.com/irakli-janiashvili

	var ka = moment__default.defineLocale('ka', {
		months : {
			standalone: 'იანვარი_თებერვალი_მარტი_აპრილი_მაისი_ივნისი_ივლისი_აგვისტო_სექტემბერი_ოქტომბერი_ნოემბერი_დეკემბერი'.split('_'),
			format: 'იანვარს_თებერვალს_მარტს_აპრილის_მაისს_ივნისს_ივლისს_აგვისტს_სექტემბერს_ოქტომბერს_ნოემბერს_დეკემბერს'.split('_')
		},
		monthsShort : 'იან_თებ_მარ_აპრ_მაი_ივნ_ივლ_აგვ_სექ_ოქტ_ნოე_დეკ'.split('_'),
		weekdays : {
			standalone: 'კვირა_ორშაბათი_სამშაბათი_ოთხშაბათი_ხუთშაბათი_პარასკევი_შაბათი'.split('_'),
			format: 'კვირას_ორშაბათს_სამშაბათს_ოთხშაბათს_ხუთშაბათს_პარასკევს_შაბათს'.split('_'),
			isFormat: /(წინა|შემდეგ)/
		},
		weekdaysShort : 'კვი_ორშ_სამ_ოთხ_ხუთ_პარ_შაბ'.split('_'),
		weekdaysMin : 'კვ_ორ_სა_ოთ_ხუ_პა_შა'.split('_'),
		longDateFormat : {
			LT : 'h:mm A',
			LTS : 'h:mm:ss A',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY h:mm A',
			LLLL : 'dddd, D MMMM YYYY h:mm A'
		},
		calendar : {
			sameDay : '[დღეს] LT[-ზე]',
			nextDay : '[ხვალ] LT[-ზე]',
			lastDay : '[გუშინ] LT[-ზე]',
			nextWeek : '[შემდეგ] dddd LT[-ზე]',
			lastWeek : '[წინა] dddd LT-ზე',
			sameElse : 'L'
		},
		relativeTime : {
			future : function (s) {
				return (/(წამი|წუთი|საათი|წელი)/).test(s) ?
					s.replace(/ი$/, 'ში') :
					s + 'ში';
			},
			past : function (s) {
				if ((/(წამი|წუთი|საათი|დღე|თვე)/).test(s)) {
					return s.replace(/(ი|ე)$/, 'ის წინ');
				}
				if ((/წელი/).test(s)) {
					return s.replace(/წელი$/, 'წლის წინ');
				}
			},
			s : 'რამდენიმე წამი',
			m : 'წუთი',
			mm : '%d წუთი',
			h : 'საათი',
			hh : '%d საათი',
			d : 'დღე',
			dd : '%d დღე',
			M : 'თვე',
			MM : '%d თვე',
			y : 'წელი',
			yy : '%d წელი'
		},
		ordinalParse: /0|1-ლი|მე-\d{1,2}|\d{1,2}-ე/,
		ordinal : function (number) {
			if (number === 0) {
				return number;
			}
			if (number === 1) {
				return number + '-ლი';
			}
			if ((number < 20) || (number <= 100 && (number % 20 === 0)) || (number % 100 === 0)) {
				return 'მე-' + number;
			}
			return number + '-ე';
		},
		week : {
			dow : 1,
			doy : 7
		}
	});

	//! moment.js locale configuration
	//! locale : kazakh (kk)
	//! authors : Nurlan Rakhimzhanov : https://github.com/nurlan

	var kk__suffixes = {
		0: '-ші',
		1: '-ші',
		2: '-ші',
		3: '-ші',
		4: '-ші',
		5: '-ші',
		6: '-шы',
		7: '-ші',
		8: '-ші',
		9: '-шы',
		10: '-шы',
		20: '-шы',
		30: '-шы',
		40: '-шы',
		50: '-ші',
		60: '-шы',
		70: '-ші',
		80: '-ші',
		90: '-шы',
		100: '-ші'
	};

	var kk = moment__default.defineLocale('kk', {
		months : 'Қаңтар_Ақпан_Наурыз_Сәуір_Мамыр_Маусым_Шілде_Тамыз_Қыркүйек_Қазан_Қараша_Желтоқсан'.split('_'),
		monthsShort : 'Қаң_Ақп_Нау_Сәу_Мам_Мау_Шіл_Там_Қыр_Қаз_Қар_Жел'.split('_'),
		weekdays : 'Жексенбі_Дүйсенбі_Сейсенбі_Сәрсенбі_Бейсенбі_Жұма_Сенбі'.split('_'),
		weekdaysShort : 'Жек_Дүй_Сей_Сәр_Бей_Жұм_Сен'.split('_'),
		weekdaysMin : 'Жк_Дй_Сй_Ср_Бй_Жм_Сн'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD.MM.YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd, D MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay : '[Бүгін сағат] LT',
			nextDay : '[Ертең сағат] LT',
			nextWeek : 'dddd [сағат] LT',
			lastDay : '[Кеше сағат] LT',
			lastWeek : '[Өткен аптаның] dddd [сағат] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : '%s ішінде',
			past : '%s бұрын',
			s : 'бірнеше секунд',
			m : 'бір минут',
			mm : '%d минут',
			h : 'бір сағат',
			hh : '%d сағат',
			d : 'бір күн',
			dd : '%d күн',
			M : 'бір ай',
			MM : '%d ай',
			y : 'бір жыл',
			yy : '%d жыл'
		},
		ordinalParse: /\d{1,2}-(ші|шы)/,
		ordinal : function (number) {
			var a = number % 10,
				b = number >= 100 ? 100 : null;
			return number + (kk__suffixes[number] || kk__suffixes[a] || kk__suffixes[b]);
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : khmer (km)
	//! author : Kruy Vanna : https://github.com/kruyvanna

	var km = moment__default.defineLocale('km', {
		months: 'មករា_កុម្ភៈ_មិនា_មេសា_ឧសភា_មិថុនា_កក្កដា_សីហា_កញ្ញា_តុលា_វិច្ឆិកា_ធ្នូ'.split('_'),
		monthsShort: 'មករា_កុម្ភៈ_មិនា_មេសា_ឧសភា_មិថុនា_កក្កដា_សីហា_កញ្ញា_តុលា_វិច្ឆិកា_ធ្នូ'.split('_'),
		weekdays: 'អាទិត្យ_ច័ន្ទ_អង្គារ_ពុធ_ព្រហស្បតិ៍_សុក្រ_សៅរ៍'.split('_'),
		weekdaysShort: 'អាទិត្យ_ច័ន្ទ_អង្គារ_ពុធ_ព្រហស្បតិ៍_សុក្រ_សៅរ៍'.split('_'),
		weekdaysMin: 'អាទិត្យ_ច័ន្ទ_អង្គារ_ពុធ_ព្រហស្បតិ៍_សុក្រ_សៅរ៍'.split('_'),
		longDateFormat: {
			LT: 'HH:mm',
			LTS : 'HH:mm:ss',
			L: 'DD/MM/YYYY',
			LL: 'D MMMM YYYY',
			LLL: 'D MMMM YYYY HH:mm',
			LLLL: 'dddd, D MMMM YYYY HH:mm'
		},
		calendar: {
			sameDay: '[ថ្ងៃនេះ ម៉ោង] LT',
			nextDay: '[ស្អែក ម៉ោង] LT',
			nextWeek: 'dddd [ម៉ោង] LT',
			lastDay: '[ម្សិលមិញ ម៉ោង] LT',
			lastWeek: 'dddd [សប្តាហ៍មុន] [ម៉ោង] LT',
			sameElse: 'L'
		},
		relativeTime: {
			future: '%sទៀត',
			past: '%sមុន',
			s: 'ប៉ុន្មានវិនាទី',
			m: 'មួយនាទី',
			mm: '%d នាទី',
			h: 'មួយម៉ោង',
			hh: '%d ម៉ោង',
			d: 'មួយថ្ងៃ',
			dd: '%d ថ្ងៃ',
			M: 'មួយខែ',
			MM: '%d ខែ',
			y: 'មួយឆ្នាំ',
			yy: '%d ឆ្នាំ'
		},
		week: {
			dow: 1, // Monday is the first day of the week.
			doy: 4 // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : korean (ko)
	//!
	//! authors
	//!
	//! - Kyungwook, Park : https://github.com/kyungw00k
	//! - Jeeeyul Lee <jeeeyul@gmail.com>

	var ko = moment__default.defineLocale('ko', {
		months : '1월_2월_3월_4월_5월_6월_7월_8월_9월_10월_11월_12월'.split('_'),
		monthsShort : '1월_2월_3월_4월_5월_6월_7월_8월_9월_10월_11월_12월'.split('_'),
		weekdays : '일요일_월요일_화요일_수요일_목요일_금요일_토요일'.split('_'),
		weekdaysShort : '일_월_화_수_목_금_토'.split('_'),
		weekdaysMin : '일_월_화_수_목_금_토'.split('_'),
		longDateFormat : {
			LT : 'A h시 m분',
			LTS : 'A h시 m분 s초',
			L : 'YYYY.MM.DD',
			LL : 'YYYY년 MMMM D일',
			LLL : 'YYYY년 MMMM D일 A h시 m분',
			LLLL : 'YYYY년 MMMM D일 dddd A h시 m분'
		},
		calendar : {
			sameDay : '오늘 LT',
			nextDay : '내일 LT',
			nextWeek : 'dddd LT',
			lastDay : '어제 LT',
			lastWeek : '지난주 dddd LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : '%s 후',
			past : '%s 전',
			s : '몇초',
			ss : '%d초',
			m : '일분',
			mm : '%d분',
			h : '한시간',
			hh : '%d시간',
			d : '하루',
			dd : '%d일',
			M : '한달',
			MM : '%d달',
			y : '일년',
			yy : '%d년'
		},
		ordinalParse : /\d{1,2}일/,
		ordinal : '%d일',
		meridiemParse : /오전|오후/,
		isPM : function (token) {
			return token === '오후';
		},
		meridiem : function (hour, minute, isUpper) {
			return hour < 12 ? '오전' : '오후';
		}
	});

	//! moment.js locale configuration
	//! locale : Luxembourgish (lb)
	//! author : mweimerskirch : https://github.com/mweimerskirch, David Raison : https://github.com/kwisatz

	function lb__processRelativeTime(number, withoutSuffix, key, isFuture) {
		var format = {
			'm': ['eng Minutt', 'enger Minutt'],
			'h': ['eng Stonn', 'enger Stonn'],
			'd': ['een Dag', 'engem Dag'],
			'M': ['ee Mount', 'engem Mount'],
			'y': ['ee Joer', 'engem Joer']
		};
		return withoutSuffix ? format[key][0] : format[key][1];
	}
	function processFutureTime(string) {
		var number = string.substr(0, string.indexOf(' '));
		if (eifelerRegelAppliesToNumber(number)) {
			return 'a ' + string;
		}
		return 'an ' + string;
	}
	function processPastTime(string) {
		var number = string.substr(0, string.indexOf(' '));
		if (eifelerRegelAppliesToNumber(number)) {
			return 'viru ' + string;
		}
		return 'virun ' + string;
	}
	/**
	 * Returns true if the word before the given number loses the '-n' ending.
	 * e.g. 'an 10 Deeg' but 'a 5 Deeg'
	 *
	 * @param number {integer}
	 * @returns {boolean}
	 */
	function eifelerRegelAppliesToNumber(number) {
		number = parseInt(number, 10);
		if (isNaN(number)) {
			return false;
		}
		if (number < 0) {
			// Negative Number --> always true
			return true;
		} else if (number < 10) {
			// Only 1 digit
			if (4 <= number && number <= 7) {
				return true;
			}
			return false;
		} else if (number < 100) {
			// 2 digits
			var lastDigit = number % 10, firstDigit = number / 10;
			if (lastDigit === 0) {
				return eifelerRegelAppliesToNumber(firstDigit);
			}
			return eifelerRegelAppliesToNumber(lastDigit);
		} else if (number < 10000) {
			// 3 or 4 digits --> recursively check first digit
			while (number >= 10) {
				number = number / 10;
			}
			return eifelerRegelAppliesToNumber(number);
		} else {
			// Anything larger than 4 digits: recursively check first n-3 digits
			number = number / 1000;
			return eifelerRegelAppliesToNumber(number);
		}
	}

	var lb = moment__default.defineLocale('lb', {
		months: 'Januar_Februar_Mäerz_Abrëll_Mee_Juni_Juli_August_September_Oktober_November_Dezember'.split('_'),
		monthsShort: 'Jan._Febr._Mrz._Abr._Mee_Jun._Jul._Aug._Sept._Okt._Nov._Dez.'.split('_'),
		weekdays: 'Sonndeg_Méindeg_Dënschdeg_Mëttwoch_Donneschdeg_Freideg_Samschdeg'.split('_'),
		weekdaysShort: 'So._Mé._Dë._Më._Do._Fr._Sa.'.split('_'),
		weekdaysMin: 'So_Mé_Dë_Më_Do_Fr_Sa'.split('_'),
		longDateFormat: {
			LT: 'H:mm [Auer]',
			LTS: 'H:mm:ss [Auer]',
			L: 'DD.MM.YYYY',
			LL: 'D. MMMM YYYY',
			LLL: 'D. MMMM YYYY H:mm [Auer]',
			LLLL: 'dddd, D. MMMM YYYY H:mm [Auer]'
		},
		calendar: {
			sameDay: '[Haut um] LT',
			sameElse: 'L',
			nextDay: '[Muer um] LT',
			nextWeek: 'dddd [um] LT',
			lastDay: '[Gëschter um] LT',
			lastWeek: function () {
				// Different date string for 'Dënschdeg' (Tuesday) and 'Donneschdeg' (Thursday) due to phonological rule
				switch (this.day()) {
					case 2:
					case 4:
						return '[Leschten] dddd [um] LT';
					default:
						return '[Leschte] dddd [um] LT';
				}
			}
		},
		relativeTime : {
			future : processFutureTime,
			past : processPastTime,
			s : 'e puer Sekonnen',
			m : lb__processRelativeTime,
			mm : '%d Minutten',
			h : lb__processRelativeTime,
			hh : '%d Stonnen',
			d : lb__processRelativeTime,
			dd : '%d Deeg',
			M : lb__processRelativeTime,
			MM : '%d Méint',
			y : lb__processRelativeTime,
			yy : '%d Joer'
		},
		ordinalParse: /\d{1,2}\./,
		ordinal: '%d.',
		week: {
			dow: 1, // Monday is the first day of the week.
			doy: 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : lao (lo)
	//! author : Ryan Hart : https://github.com/ryanhart2

	var lo = moment__default.defineLocale('lo', {
		months : 'ມັງກອນ_ກຸມພາ_ມີນາ_ເມສາ_ພຶດສະພາ_ມິຖຸນາ_ກໍລະກົດ_ສິງຫາ_ກັນຍາ_ຕຸລາ_ພະຈິກ_ທັນວາ'.split('_'),
		monthsShort : 'ມັງກອນ_ກຸມພາ_ມີນາ_ເມສາ_ພຶດສະພາ_ມິຖຸນາ_ກໍລະກົດ_ສິງຫາ_ກັນຍາ_ຕຸລາ_ພະຈິກ_ທັນວາ'.split('_'),
		weekdays : 'ອາທິດ_ຈັນ_ອັງຄານ_ພຸດ_ພະຫັດ_ສຸກ_ເສົາ'.split('_'),
		weekdaysShort : 'ທິດ_ຈັນ_ອັງຄານ_ພຸດ_ພະຫັດ_ສຸກ_ເສົາ'.split('_'),
		weekdaysMin : 'ທ_ຈ_ອຄ_ພ_ພຫ_ສກ_ສ'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'ວັນdddd D MMMM YYYY HH:mm'
		},
		meridiemParse: /ຕອນເຊົ້າ|ຕອນແລງ/,
		isPM: function (input) {
			return input === 'ຕອນແລງ';
		},
		meridiem : function (hour, minute, isLower) {
			if (hour < 12) {
				return 'ຕອນເຊົ້າ';
			} else {
				return 'ຕອນແລງ';
			}
		},
		calendar : {
			sameDay : '[ມື້ນີ້ເວລາ] LT',
			nextDay : '[ມື້ອື່ນເວລາ] LT',
			nextWeek : '[ວັນ]dddd[ໜ້າເວລາ] LT',
			lastDay : '[ມື້ວານນີ້ເວລາ] LT',
			lastWeek : '[ວັນ]dddd[ແລ້ວນີ້ເວລາ] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'ອີກ %s',
			past : '%sຜ່ານມາ',
			s : 'ບໍ່ເທົ່າໃດວິນາທີ',
			m : '1 ນາທີ',
			mm : '%d ນາທີ',
			h : '1 ຊົ່ວໂມງ',
			hh : '%d ຊົ່ວໂມງ',
			d : '1 ມື້',
			dd : '%d ມື້',
			M : '1 ເດືອນ',
			MM : '%d ເດືອນ',
			y : '1 ປີ',
			yy : '%d ປີ'
		},
		ordinalParse: /(ທີ່)\d{1,2}/,
		ordinal : function (number) {
			return 'ທີ່' + number;
		}
	});

	//! moment.js locale configuration
	//! locale : Lithuanian (lt)
	//! author : Mindaugas Mozūras : https://github.com/mmozuras

	var lt__units = {
		'm' : 'minutė_minutės_minutę',
		'mm': 'minutės_minučių_minutes',
		'h' : 'valanda_valandos_valandą',
		'hh': 'valandos_valandų_valandas',
		'd' : 'diena_dienos_dieną',
		'dd': 'dienos_dienų_dienas',
		'M' : 'mėnuo_mėnesio_mėnesį',
		'MM': 'mėnesiai_mėnesių_mėnesius',
		'y' : 'metai_metų_metus',
		'yy': 'metai_metų_metus'
	};
	function translateSeconds(number, withoutSuffix, key, isFuture) {
		if (withoutSuffix) {
			return 'kelios sekundės';
		} else {
			return isFuture ? 'kelių sekundžių' : 'kelias sekundes';
		}
	}
	function translateSingular(number, withoutSuffix, key, isFuture) {
		return withoutSuffix ? forms(key)[0] : (isFuture ? forms(key)[1] : forms(key)[2]);
	}
	function special(number) {
		return number % 10 === 0 || (number > 10 && number < 20);
	}
	function forms(key) {
		return lt__units[key].split('_');
	}
	function lt__translate(number, withoutSuffix, key, isFuture) {
		var result = number + ' ';
		if (number === 1) {
			return result + translateSingular(number, withoutSuffix, key[0], isFuture);
		} else if (withoutSuffix) {
			return result + (special(number) ? forms(key)[1] : forms(key)[0]);
		} else {
			if (isFuture) {
				return result + forms(key)[1];
			} else {
				return result + (special(number) ? forms(key)[1] : forms(key)[2]);
			}
		}
	}
	var lt = moment__default.defineLocale('lt', {
		months : {
			format: 'sausio_vasario_kovo_balandžio_gegužės_birželio_liepos_rugpjūčio_rugsėjo_spalio_lapkričio_gruodžio'.split('_'),
			standalone: 'sausis_vasaris_kovas_balandis_gegužė_birželis_liepa_rugpjūtis_rugsėjis_spalis_lapkritis_gruodis'.split('_')
		},
		monthsShort : 'sau_vas_kov_bal_geg_bir_lie_rgp_rgs_spa_lap_grd'.split('_'),
		weekdays : {
			format: 'sekmadienį_pirmadienį_antradienį_trečiadienį_ketvirtadienį_penktadienį_šeštadienį'.split('_'),
			standalone: 'sekmadienis_pirmadienis_antradienis_trečiadienis_ketvirtadienis_penktadienis_šeštadienis'.split('_'),
			isFormat: /dddd HH:mm/
		},
		weekdaysShort : 'Sek_Pir_Ant_Tre_Ket_Pen_Šeš'.split('_'),
		weekdaysMin : 'S_P_A_T_K_Pn_Š'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'YYYY-MM-DD',
			LL : 'YYYY [m.] MMMM D [d.]',
			LLL : 'YYYY [m.] MMMM D [d.], HH:mm [val.]',
			LLLL : 'YYYY [m.] MMMM D [d.], dddd, HH:mm [val.]',
			l : 'YYYY-MM-DD',
			ll : 'YYYY [m.] MMMM D [d.]',
			lll : 'YYYY [m.] MMMM D [d.], HH:mm [val.]',
			llll : 'YYYY [m.] MMMM D [d.], ddd, HH:mm [val.]'
		},
		calendar : {
			sameDay : '[Šiandien] LT',
			nextDay : '[Rytoj] LT',
			nextWeek : 'dddd LT',
			lastDay : '[Vakar] LT',
			lastWeek : '[Praėjusį] dddd LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'po %s',
			past : 'prieš %s',
			s : translateSeconds,
			m : translateSingular,
			mm : lt__translate,
			h : translateSingular,
			hh : lt__translate,
			d : translateSingular,
			dd : lt__translate,
			M : translateSingular,
			MM : lt__translate,
			y : translateSingular,
			yy : lt__translate
		},
		ordinalParse: /\d{1,2}-oji/,
		ordinal : function (number) {
			return number + '-oji';
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : latvian (lv)
	//! author : Kristaps Karlsons : https://github.com/skakri
	//! author : Jānis Elmeris : https://github.com/JanisE

	var lv__units = {
		'm': 'minūtes_minūtēm_minūte_minūtes'.split('_'),
		'mm': 'minūtes_minūtēm_minūte_minūtes'.split('_'),
		'h': 'stundas_stundām_stunda_stundas'.split('_'),
		'hh': 'stundas_stundām_stunda_stundas'.split('_'),
		'd': 'dienas_dienām_diena_dienas'.split('_'),
		'dd': 'dienas_dienām_diena_dienas'.split('_'),
		'M': 'mēneša_mēnešiem_mēnesis_mēneši'.split('_'),
		'MM': 'mēneša_mēnešiem_mēnesis_mēneši'.split('_'),
		'y': 'gada_gadiem_gads_gadi'.split('_'),
		'yy': 'gada_gadiem_gads_gadi'.split('_')
	};
	/**
	 * @param withoutSuffix boolean true = a length of time; false = before/after a period of time.
	 */
	function lv__format(forms, number, withoutSuffix) {
		if (withoutSuffix) {
			// E.g. "21 minūte", "3 minūtes".
			return number % 10 === 1 && number !== 11 ? forms[2] : forms[3];
		} else {
			// E.g. "21 minūtes" as in "pēc 21 minūtes".
			// E.g. "3 minūtēm" as in "pēc 3 minūtēm".
			return number % 10 === 1 && number !== 11 ? forms[0] : forms[1];
		}
	}
	function lv__relativeTimeWithPlural(number, withoutSuffix, key) {
		return number + ' ' + lv__format(lv__units[key], number, withoutSuffix);
	}
	function relativeTimeWithSingular(number, withoutSuffix, key) {
		return lv__format(lv__units[key], number, withoutSuffix);
	}
	function relativeSeconds(number, withoutSuffix) {
		return withoutSuffix ? 'dažas sekundes' : 'dažām sekundēm';
	}

	var lv = moment__default.defineLocale('lv', {
		months : 'janvāris_februāris_marts_aprīlis_maijs_jūnijs_jūlijs_augusts_septembris_oktobris_novembris_decembris'.split('_'),
		monthsShort : 'jan_feb_mar_apr_mai_jūn_jūl_aug_sep_okt_nov_dec'.split('_'),
		weekdays : 'svētdiena_pirmdiena_otrdiena_trešdiena_ceturtdiena_piektdiena_sestdiena'.split('_'),
		weekdaysShort : 'Sv_P_O_T_C_Pk_S'.split('_'),
		weekdaysMin : 'Sv_P_O_T_C_Pk_S'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD.MM.YYYY.',
			LL : 'YYYY. [gada] D. MMMM',
			LLL : 'YYYY. [gada] D. MMMM, HH:mm',
			LLLL : 'YYYY. [gada] D. MMMM, dddd, HH:mm'
		},
		calendar : {
			sameDay : '[Šodien pulksten] LT',
			nextDay : '[Rīt pulksten] LT',
			nextWeek : 'dddd [pulksten] LT',
			lastDay : '[Vakar pulksten] LT',
			lastWeek : '[Pagājušā] dddd [pulksten] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'pēc %s',
			past : 'pirms %s',
			s : relativeSeconds,
			m : relativeTimeWithSingular,
			mm : lv__relativeTimeWithPlural,
			h : relativeTimeWithSingular,
			hh : lv__relativeTimeWithPlural,
			d : relativeTimeWithSingular,
			dd : lv__relativeTimeWithPlural,
			M : relativeTimeWithSingular,
			MM : lv__relativeTimeWithPlural,
			y : relativeTimeWithSingular,
			yy : lv__relativeTimeWithPlural
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : Montenegrin (me)
	//! author : Miodrag Nikač <miodrag@restartit.me> : https://github.com/miodragnikac

	var me__translator = {
		words: { //Different grammatical cases
			m: ['jedan minut', 'jednog minuta'],
			mm: ['minut', 'minuta', 'minuta'],
			h: ['jedan sat', 'jednog sata'],
			hh: ['sat', 'sata', 'sati'],
			dd: ['dan', 'dana', 'dana'],
			MM: ['mjesec', 'mjeseca', 'mjeseci'],
			yy: ['godina', 'godine', 'godina']
		},
		correctGrammaticalCase: function (number, wordKey) {
			return number === 1 ? wordKey[0] : (number >= 2 && number <= 4 ? wordKey[1] : wordKey[2]);
		},
		translate: function (number, withoutSuffix, key) {
			var wordKey = me__translator.words[key];
			if (key.length === 1) {
				return withoutSuffix ? wordKey[0] : wordKey[1];
			} else {
				return number + ' ' + me__translator.correctGrammaticalCase(number, wordKey);
			}
		}
	};

	var me = moment__default.defineLocale('me', {
		months: ['januar', 'februar', 'mart', 'april', 'maj', 'jun', 'jul', 'avgust', 'septembar', 'oktobar', 'novembar', 'decembar'],
		monthsShort: ['jan.', 'feb.', 'mar.', 'apr.', 'maj', 'jun', 'jul', 'avg.', 'sep.', 'okt.', 'nov.', 'dec.'],
		weekdays: ['nedjelja', 'ponedjeljak', 'utorak', 'srijeda', 'četvrtak', 'petak', 'subota'],
		weekdaysShort: ['ned.', 'pon.', 'uto.', 'sri.', 'čet.', 'pet.', 'sub.'],
		weekdaysMin: ['ne', 'po', 'ut', 'sr', 'če', 'pe', 'su'],
		longDateFormat: {
			LT: 'H:mm',
			LTS : 'H:mm:ss',
			L: 'DD. MM. YYYY',
			LL: 'D. MMMM YYYY',
			LLL: 'D. MMMM YYYY H:mm',
			LLLL: 'dddd, D. MMMM YYYY H:mm'
		},
		calendar: {
			sameDay: '[danas u] LT',
			nextDay: '[sjutra u] LT',

			nextWeek: function () {
				switch (this.day()) {
				case 0:
					return '[u] [nedjelju] [u] LT';
				case 3:
					return '[u] [srijedu] [u] LT';
				case 6:
					return '[u] [subotu] [u] LT';
				case 1:
				case 2:
				case 4:
				case 5:
					return '[u] dddd [u] LT';
				}
			},
			lastDay  : '[juče u] LT',
			lastWeek : function () {
				var lastWeekDays = [
					'[prošle] [nedjelje] [u] LT',
					'[prošlog] [ponedjeljka] [u] LT',
					'[prošlog] [utorka] [u] LT',
					'[prošle] [srijede] [u] LT',
					'[prošlog] [četvrtka] [u] LT',
					'[prošlog] [petka] [u] LT',
					'[prošle] [subote] [u] LT'
				];
				return lastWeekDays[this.day()];
			},
			sameElse : 'L'
		},
		relativeTime : {
			future : 'za %s',
			past   : 'prije %s',
			s      : 'nekoliko sekundi',
			m      : me__translator.translate,
			mm     : me__translator.translate,
			h      : me__translator.translate,
			hh     : me__translator.translate,
			d      : 'dan',
			dd     : me__translator.translate,
			M      : 'mjesec',
			MM     : me__translator.translate,
			y      : 'godinu',
			yy     : me__translator.translate
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : macedonian (mk)
	//! author : Borislav Mickov : https://github.com/B0k0

	var mk = moment__default.defineLocale('mk', {
		months : 'јануари_февруари_март_април_мај_јуни_јули_август_септември_октомври_ноември_декември'.split('_'),
		monthsShort : 'јан_фев_мар_апр_мај_јун_јул_авг_сеп_окт_ное_дек'.split('_'),
		weekdays : 'недела_понеделник_вторник_среда_четврток_петок_сабота'.split('_'),
		weekdaysShort : 'нед_пон_вто_сре_чет_пет_саб'.split('_'),
		weekdaysMin : 'нe_пo_вт_ср_че_пе_сa'.split('_'),
		longDateFormat : {
			LT : 'H:mm',
			LTS : 'H:mm:ss',
			L : 'D.MM.YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY H:mm',
			LLLL : 'dddd, D MMMM YYYY H:mm'
		},
		calendar : {
			sameDay : '[Денес во] LT',
			nextDay : '[Утре во] LT',
			nextWeek : '[Во] dddd [во] LT',
			lastDay : '[Вчера во] LT',
			lastWeek : function () {
				switch (this.day()) {
				case 0:
				case 3:
				case 6:
					return '[Изминатата] dddd [во] LT';
				case 1:
				case 2:
				case 4:
				case 5:
					return '[Изминатиот] dddd [во] LT';
				}
			},
			sameElse : 'L'
		},
		relativeTime : {
			future : 'после %s',
			past : 'пред %s',
			s : 'неколку секунди',
			m : 'минута',
			mm : '%d минути',
			h : 'час',
			hh : '%d часа',
			d : 'ден',
			dd : '%d дена',
			M : 'месец',
			MM : '%d месеци',
			y : 'година',
			yy : '%d години'
		},
		ordinalParse: /\d{1,2}-(ев|ен|ти|ви|ри|ми)/,
		ordinal : function (number) {
			var lastDigit = number % 10,
				last2Digits = number % 100;
			if (number === 0) {
				return number + '-ев';
			} else if (last2Digits === 0) {
				return number + '-ен';
			} else if (last2Digits > 10 && last2Digits < 20) {
				return number + '-ти';
			} else if (lastDigit === 1) {
				return number + '-ви';
			} else if (lastDigit === 2) {
				return number + '-ри';
			} else if (lastDigit === 7 || lastDigit === 8) {
				return number + '-ми';
			} else {
				return number + '-ти';
			}
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : malayalam (ml)
	//! author : Floyd Pink : https://github.com/floydpink

	var ml = moment__default.defineLocale('ml', {
		months : 'ജനുവരി_ഫെബ്രുവരി_മാർച്ച്_ഏപ്രിൽ_മേയ്_ജൂൺ_ജൂലൈ_ഓഗസ്റ്റ്_സെപ്റ്റംബർ_ഒക്ടോബർ_നവംബർ_ഡിസംബർ'.split('_'),
		monthsShort : 'ജനു._ഫെബ്രു._മാർ._ഏപ്രി._മേയ്_ജൂൺ_ജൂലൈ._ഓഗ._സെപ്റ്റ._ഒക്ടോ._നവം._ഡിസം.'.split('_'),
		weekdays : 'ഞായറാഴ്ച_തിങ്കളാഴ്ച_ചൊവ്വാഴ്ച_ബുധനാഴ്ച_വ്യാഴാഴ്ച_വെള്ളിയാഴ്ച_ശനിയാഴ്ച'.split('_'),
		weekdaysShort : 'ഞായർ_തിങ്കൾ_ചൊവ്വ_ബുധൻ_വ്യാഴം_വെള്ളി_ശനി'.split('_'),
		weekdaysMin : 'ഞാ_തി_ചൊ_ബു_വ്യാ_വെ_ശ'.split('_'),
		longDateFormat : {
			LT : 'A h:mm -നു',
			LTS : 'A h:mm:ss -നു',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY, A h:mm -നു',
			LLLL : 'dddd, D MMMM YYYY, A h:mm -നു'
		},
		calendar : {
			sameDay : '[ഇന്ന്] LT',
			nextDay : '[നാളെ] LT',
			nextWeek : 'dddd, LT',
			lastDay : '[ഇന്നലെ] LT',
			lastWeek : '[കഴിഞ്ഞ] dddd, LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : '%s കഴിഞ്ഞ്',
			past : '%s മുൻപ്',
			s : 'അൽപ നിമിഷങ്ങൾ',
			m : 'ഒരു മിനിറ്റ്',
			mm : '%d മിനിറ്റ്',
			h : 'ഒരു മണിക്കൂർ',
			hh : '%d മണിക്കൂർ',
			d : 'ഒരു ദിവസം',
			dd : '%d ദിവസം',
			M : 'ഒരു മാസം',
			MM : '%d മാസം',
			y : 'ഒരു വർഷം',
			yy : '%d വർഷം'
		},
		meridiemParse: /രാത്രി|രാവിലെ|ഉച്ച കഴിഞ്ഞ്|വൈകുന്നേരം|രാത്രി/i,
		isPM : function (input) {
			return /^(ഉച്ച കഴിഞ്ഞ്|വൈകുന്നേരം|രാത്രി)$/.test(input);
		},
		meridiem : function (hour, minute, isLower) {
			if (hour < 4) {
				return 'രാത്രി';
			} else if (hour < 12) {
				return 'രാവിലെ';
			} else if (hour < 17) {
				return 'ഉച്ച കഴിഞ്ഞ്';
			} else if (hour < 20) {
				return 'വൈകുന്നേരം';
			} else {
				return 'രാത്രി';
			}
		}
	});

	//! moment.js locale configuration
	//! locale : Marathi (mr)
	//! author : Harshad Kale : https://github.com/kalehv
	//! author : Vivek Athalye : https://github.com/vnathalye

	var mr__symbolMap = {
		'1': '१',
		'2': '२',
		'3': '३',
		'4': '४',
		'5': '५',
		'6': '६',
		'7': '७',
		'8': '८',
		'9': '९',
		'0': '०'
	},
	mr__numberMap = {
		'१': '1',
		'२': '2',
		'३': '3',
		'४': '4',
		'५': '5',
		'६': '6',
		'७': '7',
		'८': '8',
		'९': '9',
		'०': '0'
	};

	function relativeTimeMr(number, withoutSuffix, string, isFuture)
	{
		var output = '';
		if (withoutSuffix) {
			switch (string) {
				case 's': output = 'काही सेकंद'; break;
				case 'm': output = 'एक मिनिट'; break;
				case 'mm': output = '%d मिनिटे'; break;
				case 'h': output = 'एक तास'; break;
				case 'hh': output = '%d तास'; break;
				case 'd': output = 'एक दिवस'; break;
				case 'dd': output = '%d दिवस'; break;
				case 'M': output = 'एक महिना'; break;
				case 'MM': output = '%d महिने'; break;
				case 'y': output = 'एक वर्ष'; break;
				case 'yy': output = '%d वर्षे'; break;
			}
		}
		else {
			switch (string) {
				case 's': output = 'काही सेकंदां'; break;
				case 'm': output = 'एका मिनिटा'; break;
				case 'mm': output = '%d मिनिटां'; break;
				case 'h': output = 'एका तासा'; break;
				case 'hh': output = '%d तासां'; break;
				case 'd': output = 'एका दिवसा'; break;
				case 'dd': output = '%d दिवसां'; break;
				case 'M': output = 'एका महिन्या'; break;
				case 'MM': output = '%d महिन्यां'; break;
				case 'y': output = 'एका वर्षा'; break;
				case 'yy': output = '%d वर्षां'; break;
			}
		}
		return output.replace(/%d/i, number);
	}

	var mr = moment__default.defineLocale('mr', {
		months : 'जानेवारी_फेब्रुवारी_मार्च_एप्रिल_मे_जून_जुलै_ऑगस्ट_सप्टेंबर_ऑक्टोबर_नोव्हेंबर_डिसेंबर'.split('_'),
		monthsShort: 'जाने._फेब्रु._मार्च._एप्रि._मे._जून._जुलै._ऑग._सप्टें._ऑक्टो._नोव्हें._डिसें.'.split('_'),
		weekdays : 'रविवार_सोमवार_मंगळवार_बुधवार_गुरूवार_शुक्रवार_शनिवार'.split('_'),
		weekdaysShort : 'रवि_सोम_मंगळ_बुध_गुरू_शुक्र_शनि'.split('_'),
		weekdaysMin : 'र_सो_मं_बु_गु_शु_श'.split('_'),
		longDateFormat : {
			LT : 'A h:mm वाजता',
			LTS : 'A h:mm:ss वाजता',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY, A h:mm वाजता',
			LLLL : 'dddd, D MMMM YYYY, A h:mm वाजता'
		},
		calendar : {
			sameDay : '[आज] LT',
			nextDay : '[उद्या] LT',
			nextWeek : 'dddd, LT',
			lastDay : '[काल] LT',
			lastWeek: '[मागील] dddd, LT',
			sameElse : 'L'
		},
		relativeTime : {
			future: '%sमध्ये',
			past: '%sपूर्वी',
			s: relativeTimeMr,
			m: relativeTimeMr,
			mm: relativeTimeMr,
			h: relativeTimeMr,
			hh: relativeTimeMr,
			d: relativeTimeMr,
			dd: relativeTimeMr,
			M: relativeTimeMr,
			MM: relativeTimeMr,
			y: relativeTimeMr,
			yy: relativeTimeMr
		},
		preparse: function (string) {
			return string.replace(/[१२३४५६७८९०]/g, function (match) {
				return mr__numberMap[match];
			});
		},
		postformat: function (string) {
			return string.replace(/\d/g, function (match) {
				return mr__symbolMap[match];
			});
		},
		meridiemParse: /रात्री|सकाळी|दुपारी|सायंकाळी/,
		meridiemHour : function (hour, meridiem) {
			if (hour === 12) {
				hour = 0;
			}
			if (meridiem === 'रात्री') {
				return hour < 4 ? hour : hour + 12;
			} else if (meridiem === 'सकाळी') {
				return hour;
			} else if (meridiem === 'दुपारी') {
				return hour >= 10 ? hour : hour + 12;
			} else if (meridiem === 'सायंकाळी') {
				return hour + 12;
			}
		},
		meridiem: function (hour, minute, isLower) {
			if (hour < 4) {
				return 'रात्री';
			} else if (hour < 10) {
				return 'सकाळी';
			} else if (hour < 17) {
				return 'दुपारी';
			} else if (hour < 20) {
				return 'सायंकाळी';
			} else {
				return 'रात्री';
			}
		},
		week : {
			dow : 0, // Sunday is the first day of the week.
			doy : 6  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : Bahasa Malaysia (ms-MY)
	//! author : Weldan Jamili : https://github.com/weldan

	var ms_my = moment__default.defineLocale('ms-my', {
		months : 'Januari_Februari_Mac_April_Mei_Jun_Julai_Ogos_September_Oktober_November_Disember'.split('_'),
		monthsShort : 'Jan_Feb_Mac_Apr_Mei_Jun_Jul_Ogs_Sep_Okt_Nov_Dis'.split('_'),
		weekdays : 'Ahad_Isnin_Selasa_Rabu_Khamis_Jumaat_Sabtu'.split('_'),
		weekdaysShort : 'Ahd_Isn_Sel_Rab_Kha_Jum_Sab'.split('_'),
		weekdaysMin : 'Ah_Is_Sl_Rb_Km_Jm_Sb'.split('_'),
		longDateFormat : {
			LT : 'HH.mm',
			LTS : 'HH.mm.ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY [pukul] HH.mm',
			LLLL : 'dddd, D MMMM YYYY [pukul] HH.mm'
		},
		meridiemParse: /pagi|tengahari|petang|malam/,
		meridiemHour: function (hour, meridiem) {
			if (hour === 12) {
				hour = 0;
			}
			if (meridiem === 'pagi') {
				return hour;
			} else if (meridiem === 'tengahari') {
				return hour >= 11 ? hour : hour + 12;
			} else if (meridiem === 'petang' || meridiem === 'malam') {
				return hour + 12;
			}
		},
		meridiem : function (hours, minutes, isLower) {
			if (hours < 11) {
				return 'pagi';
			} else if (hours < 15) {
				return 'tengahari';
			} else if (hours < 19) {
				return 'petang';
			} else {
				return 'malam';
			}
		},
		calendar : {
			sameDay : '[Hari ini pukul] LT',
			nextDay : '[Esok pukul] LT',
			nextWeek : 'dddd [pukul] LT',
			lastDay : '[Kelmarin pukul] LT',
			lastWeek : 'dddd [lepas pukul] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'dalam %s',
			past : '%s yang lepas',
			s : 'beberapa saat',
			m : 'seminit',
			mm : '%d minit',
			h : 'sejam',
			hh : '%d jam',
			d : 'sehari',
			dd : '%d hari',
			M : 'sebulan',
			MM : '%d bulan',
			y : 'setahun',
			yy : '%d tahun'
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : Bahasa Malaysia (ms-MY)
	//! author : Weldan Jamili : https://github.com/weldan

	var locale_ms = moment__default.defineLocale('ms', {
		months : 'Januari_Februari_Mac_April_Mei_Jun_Julai_Ogos_September_Oktober_November_Disember'.split('_'),
		monthsShort : 'Jan_Feb_Mac_Apr_Mei_Jun_Jul_Ogs_Sep_Okt_Nov_Dis'.split('_'),
		weekdays : 'Ahad_Isnin_Selasa_Rabu_Khamis_Jumaat_Sabtu'.split('_'),
		weekdaysShort : 'Ahd_Isn_Sel_Rab_Kha_Jum_Sab'.split('_'),
		weekdaysMin : 'Ah_Is_Sl_Rb_Km_Jm_Sb'.split('_'),
		longDateFormat : {
			LT : 'HH.mm',
			LTS : 'HH.mm.ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY [pukul] HH.mm',
			LLLL : 'dddd, D MMMM YYYY [pukul] HH.mm'
		},
		meridiemParse: /pagi|tengahari|petang|malam/,
		meridiemHour: function (hour, meridiem) {
			if (hour === 12) {
				hour = 0;
			}
			if (meridiem === 'pagi') {
				return hour;
			} else if (meridiem === 'tengahari') {
				return hour >= 11 ? hour : hour + 12;
			} else if (meridiem === 'petang' || meridiem === 'malam') {
				return hour + 12;
			}
		},
		meridiem : function (hours, minutes, isLower) {
			if (hours < 11) {
				return 'pagi';
			} else if (hours < 15) {
				return 'tengahari';
			} else if (hours < 19) {
				return 'petang';
			} else {
				return 'malam';
			}
		},
		calendar : {
			sameDay : '[Hari ini pukul] LT',
			nextDay : '[Esok pukul] LT',
			nextWeek : 'dddd [pukul] LT',
			lastDay : '[Kelmarin pukul] LT',
			lastWeek : 'dddd [lepas pukul] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'dalam %s',
			past : '%s yang lepas',
			s : 'beberapa saat',
			m : 'seminit',
			mm : '%d minit',
			h : 'sejam',
			hh : '%d jam',
			d : 'sehari',
			dd : '%d hari',
			M : 'sebulan',
			MM : '%d bulan',
			y : 'setahun',
			yy : '%d tahun'
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : Burmese (my)
	//! author : Squar team, mysquar.com

	var my__symbolMap = {
		'1': '၁',
		'2': '၂',
		'3': '၃',
		'4': '၄',
		'5': '၅',
		'6': '၆',
		'7': '၇',
		'8': '၈',
		'9': '၉',
		'0': '၀'
	}, my__numberMap = {
		'၁': '1',
		'၂': '2',
		'၃': '3',
		'၄': '4',
		'၅': '5',
		'၆': '6',
		'၇': '7',
		'၈': '8',
		'၉': '9',
		'၀': '0'
	};

	var my = moment__default.defineLocale('my', {
		months: 'ဇန်နဝါရီ_ဖေဖော်ဝါရီ_မတ်_ဧပြီ_မေ_ဇွန်_ဇူလိုင်_သြဂုတ်_စက်တင်ဘာ_အောက်တိုဘာ_နိုဝင်ဘာ_ဒီဇင်ဘာ'.split('_'),
		monthsShort: 'ဇန်_ဖေ_မတ်_ပြီ_မေ_ဇွန်_လိုင်_သြ_စက်_အောက်_နို_ဒီ'.split('_'),
		weekdays: 'တနင်္ဂနွေ_တနင်္လာ_အင်္ဂါ_ဗုဒ္ဓဟူး_ကြာသပတေး_သောကြာ_စနေ'.split('_'),
		weekdaysShort: 'နွေ_လာ_ဂါ_ဟူး_ကြာ_သော_နေ'.split('_'),
		weekdaysMin: 'နွေ_လာ_ဂါ_ဟူး_ကြာ_သော_နေ'.split('_'),

		longDateFormat: {
			LT: 'HH:mm',
			LTS: 'HH:mm:ss',
			L: 'DD/MM/YYYY',
			LL: 'D MMMM YYYY',
			LLL: 'D MMMM YYYY HH:mm',
			LLLL: 'dddd D MMMM YYYY HH:mm'
		},
		calendar: {
			sameDay: '[ယနေ.] LT [မှာ]',
			nextDay: '[မနက်ဖြန်] LT [မှာ]',
			nextWeek: 'dddd LT [မှာ]',
			lastDay: '[မနေ.က] LT [မှာ]',
			lastWeek: '[ပြီးခဲ့သော] dddd LT [မှာ]',
			sameElse: 'L'
		},
		relativeTime: {
			future: 'လာမည့် %s မှာ',
			past: 'လွန်ခဲ့သော %s က',
			s: 'စက္ကန်.အနည်းငယ်',
			m: 'တစ်မိနစ်',
			mm: '%d မိနစ်',
			h: 'တစ်နာရီ',
			hh: '%d နာရီ',
			d: 'တစ်ရက်',
			dd: '%d ရက်',
			M: 'တစ်လ',
			MM: '%d လ',
			y: 'တစ်နှစ်',
			yy: '%d နှစ်'
		},
		preparse: function (string) {
			return string.replace(/[၁၂၃၄၅၆၇၈၉၀]/g, function (match) {
				return my__numberMap[match];
			});
		},
		postformat: function (string) {
			return string.replace(/\d/g, function (match) {
				return my__symbolMap[match];
			});
		},
		week: {
			dow: 1, // Monday is the first day of the week.
			doy: 4 // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : norwegian bokmål (nb)
	//! authors : Espen Hovlandsdal : https://github.com/rexxars
	//!           Sigurd Gartmann : https://github.com/sigurdga

	var nb = moment__default.defineLocale('nb', {
		months : 'januar_februar_mars_april_mai_juni_juli_august_september_oktober_november_desember'.split('_'),
		monthsShort : 'jan._feb._mars_april_mai_juni_juli_aug._sep._okt._nov._des.'.split('_'),
		weekdays : 'søndag_mandag_tirsdag_onsdag_torsdag_fredag_lørdag'.split('_'),
		weekdaysShort : 'sø._ma._ti._on._to._fr._lø.'.split('_'),
		weekdaysMin : 'sø_ma_ti_on_to_fr_lø'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD.MM.YYYY',
			LL : 'D. MMMM YYYY',
			LLL : 'D. MMMM YYYY [kl.] HH:mm',
			LLLL : 'dddd D. MMMM YYYY [kl.] HH:mm'
		},
		calendar : {
			sameDay: '[i dag kl.] LT',
			nextDay: '[i morgen kl.] LT',
			nextWeek: 'dddd [kl.] LT',
			lastDay: '[i går kl.] LT',
			lastWeek: '[forrige] dddd [kl.] LT',
			sameElse: 'L'
		},
		relativeTime : {
			future : 'om %s',
			past : 'for %s siden',
			s : 'noen sekunder',
			m : 'ett minutt',
			mm : '%d minutter',
			h : 'en time',
			hh : '%d timer',
			d : 'en dag',
			dd : '%d dager',
			M : 'en måned',
			MM : '%d måneder',
			y : 'ett år',
			yy : '%d år'
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : nepali/nepalese
	//! author : suvash : https://github.com/suvash

	var ne__symbolMap = {
		'1': '१',
		'2': '२',
		'3': '३',
		'4': '४',
		'5': '५',
		'6': '६',
		'7': '७',
		'8': '८',
		'9': '९',
		'0': '०'
	},
	ne__numberMap = {
		'१': '1',
		'२': '2',
		'३': '3',
		'४': '4',
		'५': '5',
		'६': '6',
		'७': '7',
		'८': '8',
		'९': '9',
		'०': '0'
	};

	var ne = moment__default.defineLocale('ne', {
		months : 'जनवरी_फेब्रुवरी_मार्च_अप्रिल_मई_जुन_जुलाई_अगष्ट_सेप्टेम्बर_अक्टोबर_नोभेम्बर_डिसेम्बर'.split('_'),
		monthsShort : 'जन._फेब्रु._मार्च_अप्रि._मई_जुन_जुलाई._अग._सेप्ट._अक्टो._नोभे._डिसे.'.split('_'),
		weekdays : 'आइतबार_सोमबार_मङ्गलबार_बुधबार_बिहिबार_शुक्रबार_शनिबार'.split('_'),
		weekdaysShort : 'आइत._सोम._मङ्गल._बुध._बिहि._शुक्र._शनि.'.split('_'),
		weekdaysMin : 'आ._सो._मं._बु._बि._शु._श.'.split('_'),
		longDateFormat : {
			LT : 'Aको h:mm बजे',
			LTS : 'Aको h:mm:ss बजे',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY, Aको h:mm बजे',
			LLLL : 'dddd, D MMMM YYYY, Aको h:mm बजे'
		},
		preparse: function (string) {
			return string.replace(/[१२३४५६७८९०]/g, function (match) {
				return ne__numberMap[match];
			});
		},
		postformat: function (string) {
			return string.replace(/\d/g, function (match) {
				return ne__symbolMap[match];
			});
		},
		meridiemParse: /राति|बिहान|दिउँसो|साँझ/,
		meridiemHour : function (hour, meridiem) {
			if (hour === 12) {
				hour = 0;
			}
			if (meridiem === 'राति') {
				return hour < 4 ? hour : hour + 12;
			} else if (meridiem === 'बिहान') {
				return hour;
			} else if (meridiem === 'दिउँसो') {
				return hour >= 10 ? hour : hour + 12;
			} else if (meridiem === 'साँझ') {
				return hour + 12;
			}
		},
		meridiem : function (hour, minute, isLower) {
			if (hour < 3) {
				return 'राति';
			} else if (hour < 12) {
				return 'बिहान';
			} else if (hour < 16) {
				return 'दिउँसो';
			} else if (hour < 20) {
				return 'साँझ';
			} else {
				return 'राति';
			}
		},
		calendar : {
			sameDay : '[आज] LT',
			nextDay : '[भोलि] LT',
			nextWeek : '[आउँदो] dddd[,] LT',
			lastDay : '[हिजो] LT',
			lastWeek : '[गएको] dddd[,] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : '%sमा',
			past : '%s अगाडि',
			s : 'केही क्षण',
			m : 'एक मिनेट',
			mm : '%d मिनेट',
			h : 'एक घण्टा',
			hh : '%d घण्टा',
			d : 'एक दिन',
			dd : '%d दिन',
			M : 'एक महिना',
			MM : '%d महिना',
			y : 'एक बर्ष',
			yy : '%d बर्ष'
		},
		week : {
			dow : 0, // Sunday is the first day of the week.
			doy : 6  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : dutch (nl)
	//! author : Joris Röling : https://github.com/jjupiter

	var nl__monthsShortWithDots = 'jan._feb._mrt._apr._mei_jun._jul._aug._sep._okt._nov._dec.'.split('_'),
		nl__monthsShortWithoutDots = 'jan_feb_mrt_apr_mei_jun_jul_aug_sep_okt_nov_dec'.split('_');

	var nl = moment__default.defineLocale('nl', {
		months : 'januari_februari_maart_april_mei_juni_juli_augustus_september_oktober_november_december'.split('_'),
		monthsShort : function (m, format) {
			if (/-MMM-/.test(format)) {
				return nl__monthsShortWithoutDots[m.month()];
			} else {
				return nl__monthsShortWithDots[m.month()];
			}
		},
		weekdays : 'zondag_maandag_dinsdag_woensdag_donderdag_vrijdag_zaterdag'.split('_'),
		weekdaysShort : 'zo._ma._di._wo._do._vr._za.'.split('_'),
		weekdaysMin : 'Zo_Ma_Di_Wo_Do_Vr_Za'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD-MM-YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd D MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay: '[vandaag om] LT',
			nextDay: '[morgen om] LT',
			nextWeek: 'dddd [om] LT',
			lastDay: '[gisteren om] LT',
			lastWeek: '[afgelopen] dddd [om] LT',
			sameElse: 'L'
		},
		relativeTime : {
			future : 'over %s',
			past : '%s geleden',
			s : 'een paar seconden',
			m : 'één minuut',
			mm : '%d minuten',
			h : 'één uur',
			hh : '%d uur',
			d : 'één dag',
			dd : '%d dagen',
			M : 'één maand',
			MM : '%d maanden',
			y : 'één jaar',
			yy : '%d jaar'
		},
		ordinalParse: /\d{1,2}(ste|de)/,
		ordinal : function (number) {
			return number + ((number === 1 || number === 8 || number >= 20) ? 'ste' : 'de');
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : norwegian nynorsk (nn)
	//! author : https://github.com/mechuwind

	var nn = moment__default.defineLocale('nn', {
		months : 'januar_februar_mars_april_mai_juni_juli_august_september_oktober_november_desember'.split('_'),
		monthsShort : 'jan_feb_mar_apr_mai_jun_jul_aug_sep_okt_nov_des'.split('_'),
		weekdays : 'sundag_måndag_tysdag_onsdag_torsdag_fredag_laurdag'.split('_'),
		weekdaysShort : 'sun_mån_tys_ons_tor_fre_lau'.split('_'),
		weekdaysMin : 'su_må_ty_on_to_fr_lø'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD.MM.YYYY',
			LL : 'D. MMMM YYYY',
			LLL : 'D. MMMM YYYY [kl.] H:mm',
			LLLL : 'dddd D. MMMM YYYY [kl.] HH:mm'
		},
		calendar : {
			sameDay: '[I dag klokka] LT',
			nextDay: '[I morgon klokka] LT',
			nextWeek: 'dddd [klokka] LT',
			lastDay: '[I går klokka] LT',
			lastWeek: '[Føregåande] dddd [klokka] LT',
			sameElse: 'L'
		},
		relativeTime : {
			future : 'om %s',
			past : 'for %s sidan',
			s : 'nokre sekund',
			m : 'eit minutt',
			mm : '%d minutt',
			h : 'ein time',
			hh : '%d timar',
			d : 'ein dag',
			dd : '%d dagar',
			M : 'ein månad',
			MM : '%d månader',
			y : 'eit år',
			yy : '%d år'
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : polish (pl)
	//! author : Rafal Hirsz : https://github.com/evoL

	var monthsNominative = 'styczeń_luty_marzec_kwiecień_maj_czerwiec_lipiec_sierpień_wrzesień_październik_listopad_grudzień'.split('_'),
		monthsSubjective = 'stycznia_lutego_marca_kwietnia_maja_czerwca_lipca_sierpnia_września_października_listopada_grudnia'.split('_');
	function pl__plural(n) {
		return (n % 10 < 5) && (n % 10 > 1) && ((~~(n / 10) % 10) !== 1);
	}
	function pl__translate(number, withoutSuffix, key) {
		var result = number + ' ';
		switch (key) {
		case 'm':
			return withoutSuffix ? 'minuta' : 'minutę';
		case 'mm':
			return result + (pl__plural(number) ? 'minuty' : 'minut');
		case 'h':
			return withoutSuffix  ? 'godzina'  : 'godzinę';
		case 'hh':
			return result + (pl__plural(number) ? 'godziny' : 'godzin');
		case 'MM':
			return result + (pl__plural(number) ? 'miesiące' : 'miesięcy');
		case 'yy':
			return result + (pl__plural(number) ? 'lata' : 'lat');
		}
	}

	var pl = moment__default.defineLocale('pl', {
		months : function (momentToFormat, format) {
			if (format === '') {
				// Hack: if format empty we know this is used to generate
				// RegExp by moment. Give then back both valid forms of months
				// in RegExp ready format.
				return '(' + monthsSubjective[momentToFormat.month()] + '|' + monthsNominative[momentToFormat.month()] + ')';
			} else if (/D MMMM/.test(format)) {
				return monthsSubjective[momentToFormat.month()];
			} else {
				return monthsNominative[momentToFormat.month()];
			}
		},
		monthsShort : 'sty_lut_mar_kwi_maj_cze_lip_sie_wrz_paź_lis_gru'.split('_'),
		weekdays : 'niedziela_poniedziałek_wtorek_środa_czwartek_piątek_sobota'.split('_'),
		weekdaysShort : 'nie_pon_wt_śr_czw_pt_sb'.split('_'),
		weekdaysMin : 'Nd_Pn_Wt_Śr_Cz_Pt_So'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD.MM.YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd, D MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay: '[Dziś o] LT',
			nextDay: '[Jutro o] LT',
			nextWeek: '[W] dddd [o] LT',
			lastDay: '[Wczoraj o] LT',
			lastWeek: function () {
				switch (this.day()) {
				case 0:
					return '[W zeszłą niedzielę o] LT';
				case 3:
					return '[W zeszłą środę o] LT';
				case 6:
					return '[W zeszłą sobotę o] LT';
				default:
					return '[W zeszły] dddd [o] LT';
				}
			},
			sameElse: 'L'
		},
		relativeTime : {
			future : 'za %s',
			past : '%s temu',
			s : 'kilka sekund',
			m : pl__translate,
			mm : pl__translate,
			h : pl__translate,
			hh : pl__translate,
			d : '1 dzień',
			dd : '%d dni',
			M : 'miesiąc',
			MM : pl__translate,
			y : 'rok',
			yy : pl__translate
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : brazilian portuguese (pt-br)
	//! author : Caio Ribeiro Pereira : https://github.com/caio-ribeiro-pereira

	var pt_br = moment__default.defineLocale('pt-br', {
		months : 'Janeiro_Fevereiro_Março_Abril_Maio_Junho_Julho_Agosto_Setembro_Outubro_Novembro_Dezembro'.split('_'),
		monthsShort : 'Jan_Fev_Mar_Abr_Mai_Jun_Jul_Ago_Set_Out_Nov_Dez'.split('_'),
		weekdays : 'Domingo_Segunda-Feira_Terça-Feira_Quarta-Feira_Quinta-Feira_Sexta-Feira_Sábado'.split('_'),
		weekdaysShort : 'Dom_Seg_Ter_Qua_Qui_Sex_Sáb'.split('_'),
		weekdaysMin : 'Dom_2ª_3ª_4ª_5ª_6ª_Sáb'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D [de] MMMM [de] YYYY',
			LLL : 'D [de] MMMM [de] YYYY [às] HH:mm',
			LLLL : 'dddd, D [de] MMMM [de] YYYY [às] HH:mm'
		},
		calendar : {
			sameDay: '[Hoje às] LT',
			nextDay: '[Amanhã às] LT',
			nextWeek: 'dddd [às] LT',
			lastDay: '[Ontem às] LT',
			lastWeek: function () {
				return (this.day() === 0 || this.day() === 6) ?
					'[Último] dddd [às] LT' : // Saturday + Sunday
					'[Última] dddd [às] LT'; // Monday - Friday
			},
			sameElse: 'L'
		},
		relativeTime : {
			future : 'em %s',
			past : '%s atrás',
			s : 'poucos segundos',
			m : 'um minuto',
			mm : '%d minutos',
			h : 'uma hora',
			hh : '%d horas',
			d : 'um dia',
			dd : '%d dias',
			M : 'um mês',
			MM : '%d meses',
			y : 'um ano',
			yy : '%d anos'
		},
		ordinalParse: /\d{1,2}º/,
		ordinal : '%dº'
	});

	//! moment.js locale configuration
	//! locale : portuguese (pt)
	//! author : Jefferson : https://github.com/jalex79

	var pt = moment__default.defineLocale('pt', {
		months : 'Janeiro_Fevereiro_Março_Abril_Maio_Junho_Julho_Agosto_Setembro_Outubro_Novembro_Dezembro'.split('_'),
		monthsShort : 'Jan_Fev_Mar_Abr_Mai_Jun_Jul_Ago_Set_Out_Nov_Dez'.split('_'),
		weekdays : 'Domingo_Segunda-Feira_Terça-Feira_Quarta-Feira_Quinta-Feira_Sexta-Feira_Sábado'.split('_'),
		weekdaysShort : 'Dom_Seg_Ter_Qua_Qui_Sex_Sáb'.split('_'),
		weekdaysMin : 'Dom_2ª_3ª_4ª_5ª_6ª_Sáb'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D [de] MMMM [de] YYYY',
			LLL : 'D [de] MMMM [de] YYYY HH:mm',
			LLLL : 'dddd, D [de] MMMM [de] YYYY HH:mm'
		},
		calendar : {
			sameDay: '[Hoje às] LT',
			nextDay: '[Amanhã às] LT',
			nextWeek: 'dddd [às] LT',
			lastDay: '[Ontem às] LT',
			lastWeek: function () {
				return (this.day() === 0 || this.day() === 6) ?
					'[Último] dddd [às] LT' : // Saturday + Sunday
					'[Última] dddd [às] LT'; // Monday - Friday
			},
			sameElse: 'L'
		},
		relativeTime : {
			future : 'em %s',
			past : 'há %s',
			s : 'segundos',
			m : 'um minuto',
			mm : '%d minutos',
			h : 'uma hora',
			hh : '%d horas',
			d : 'um dia',
			dd : '%d dias',
			M : 'um mês',
			MM : '%d meses',
			y : 'um ano',
			yy : '%d anos'
		},
		ordinalParse: /\d{1,2}º/,
		ordinal : '%dº',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : romanian (ro)
	//! author : Vlad Gurdiga : https://github.com/gurdiga
	//! author : Valentin Agachi : https://github.com/avaly

	function ro__relativeTimeWithPlural(number, withoutSuffix, key) {
		var format = {
				'mm': 'minute',
				'hh': 'ore',
				'dd': 'zile',
				'MM': 'luni',
				'yy': 'ani'
			},
			separator = ' ';
		if (number % 100 >= 20 || (number >= 100 && number % 100 === 0)) {
			separator = ' de ';
		}
		return number + separator + format[key];
	}

	var ro = moment__default.defineLocale('ro', {
		months : 'ianuarie_februarie_martie_aprilie_mai_iunie_iulie_august_septembrie_octombrie_noiembrie_decembrie'.split('_'),
		monthsShort : 'ian._febr._mart._apr._mai_iun._iul._aug._sept._oct._nov._dec.'.split('_'),
		weekdays : 'duminică_luni_marți_miercuri_joi_vineri_sâmbătă'.split('_'),
		weekdaysShort : 'Dum_Lun_Mar_Mie_Joi_Vin_Sâm'.split('_'),
		weekdaysMin : 'Du_Lu_Ma_Mi_Jo_Vi_Sâ'.split('_'),
		longDateFormat : {
			LT : 'H:mm',
			LTS : 'H:mm:ss',
			L : 'DD.MM.YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY H:mm',
			LLLL : 'dddd, D MMMM YYYY H:mm'
		},
		calendar : {
			sameDay: '[azi la] LT',
			nextDay: '[mâine la] LT',
			nextWeek: 'dddd [la] LT',
			lastDay: '[ieri la] LT',
			lastWeek: '[fosta] dddd [la] LT',
			sameElse: 'L'
		},
		relativeTime : {
			future : 'peste %s',
			past : '%s în urmă',
			s : 'câteva secunde',
			m : 'un minut',
			mm : ro__relativeTimeWithPlural,
			h : 'o oră',
			hh : ro__relativeTimeWithPlural,
			d : 'o zi',
			dd : ro__relativeTimeWithPlural,
			M : 'o lună',
			MM : ro__relativeTimeWithPlural,
			y : 'un an',
			yy : ro__relativeTimeWithPlural
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : russian (ru)
	//! author : Viktorminator : https://github.com/Viktorminator
	//! Author : Menelion Elensúle : https://github.com/Oire

	function ru__plural(word, num) {
		var forms = word.split('_');
		return num % 10 === 1 && num % 100 !== 11 ? forms[0] : (num % 10 >= 2 && num % 10 <= 4 && (num % 100 < 10 || num % 100 >= 20) ? forms[1] : forms[2]);
	}
	function ru__relativeTimeWithPlural(number, withoutSuffix, key) {
		var format = {
			'mm': withoutSuffix ? 'минута_минуты_минут' : 'минуту_минуты_минут',
			'hh': 'час_часа_часов',
			'dd': 'день_дня_дней',
			'MM': 'месяц_месяца_месяцев',
			'yy': 'год_года_лет'
		};
		if (key === 'm') {
			return withoutSuffix ? 'минута' : 'минуту';
		}
		else {
			return number + ' ' + ru__plural(format[key], +number);
		}
	}
	var monthsParse = [/^янв/i, /^фев/i, /^мар/i, /^апр/i, /^ма[й|я]/i, /^июн/i, /^июл/i, /^авг/i, /^сен/i, /^окт/i, /^ноя/i, /^дек/i];

	var ru = moment__default.defineLocale('ru', {
		months : {
			format: 'Января_Февраля_Марта_Апреля_Мая_Июня_Июля_Августа_Сентября_Октября_Ноября_Декабря'.split('_'),
			standalone: 'Январь_Февраль_Март_Апрель_Май_Июнь_Июль_Август_Сентябрь_Октябрь_Ноябрь_Декабрь'.split('_')
		},
		monthsShort : {
			format: 'янв_фев_мар_апр_мая_июня_июля_авг_сен_окт_ноя_дек'.split('_'),
			standalone: 'янв_фев_март_апр_май_июнь_июль_авг_сен_окт_ноя_дек'.split('_')
		},
		weekdays : {
			standalone: 'Воскресенье_Понедельник_Вторник_Среда_Четверг_Пятница_Суббота'.split('_'),
			format: 'Воскресенье_Понедельник_Вторник_Среду_Четверг_Пятницу_Субботу'.split('_'),
			isFormat: /\[ ?[Вв] ?(?:прошлую|следующую|эту)? ?\] ?dddd/
		},
		weekdaysShort : 'Вс_Пн_Вт_Ср_Чт_Пт_Сб'.split('_'),
		weekdaysMin : 'Вс_Пн_Вт_Ср_Чт_Пт_Сб'.split('_'),
		monthsParse : monthsParse,
		longMonthsParse : monthsParse,
		shortMonthsParse : monthsParse,
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD.MM.YYYY',
			LL : 'D MMMM YYYY г.',
			LLL : 'D MMMM YYYY г., HH:mm',
			LLLL : 'dddd, D MMMM YYYY г., HH:mm'
		},
		calendar : {
			sameDay: '[Сегодня в] LT',
			nextDay: '[Завтра в] LT',
			lastDay: '[Вчера в] LT',
			nextWeek: function (now) {
				if (now.week() !== this.week()) {
					switch (this.day()) {
					case 0:
						return '[В следующее] dddd [в] LT';
					case 1:
					case 2:
					case 4:
						return '[В следующий] dddd [в] LT';
					case 3:
					case 5:
					case 6:
						return '[В следующую] dddd [в] LT';
					}
				} else {
					if (this.day() === 2) {
						return '[Во] dddd [в] LT';
					} else {
						return '[В] dddd [в] LT';
					}
				}
			},
			lastWeek: function (now) {
				if (now.week() !== this.week()) {
					switch (this.day()) {
					case 0:
						return '[В прошлое] dddd [в] LT';
					case 1:
					case 2:
					case 4:
						return '[В прошлый] dddd [в] LT';
					case 3:
					case 5:
					case 6:
						return '[В прошлую] dddd [в] LT';
					}
				} else {
					if (this.day() === 2) {
						return '[Во] dddd [в] LT';
					} else {
						return '[В] dddd [в] LT';
					}
				}
			},
			sameElse: 'L'
		},
		relativeTime : {
			future : 'через %s',
			past : '%s назад',
			s : 'несколько секунд',
			m : ru__relativeTimeWithPlural,
			mm : ru__relativeTimeWithPlural,
			h : 'час',
			hh : ru__relativeTimeWithPlural,
			d : 'день',
			dd : ru__relativeTimeWithPlural,
			M : 'месяц',
			MM : ru__relativeTimeWithPlural,
			y : 'год',
			yy : ru__relativeTimeWithPlural
		},
		meridiemParse: /ночи|утра|дня|вечера/i,
		isPM : function (input) {
			return /^(дня|вечера)$/.test(input);
		},
		meridiem : function (hour, minute, isLower) {
			if (hour < 4) {
				return 'ночи';
			} else if (hour < 12) {
				return 'утра';
			} else if (hour < 17) {
				return 'дня';
			} else {
				return 'вечера';
			}
		},
		ordinalParse: /\d{1,2}-(й|го|я)/,
		ordinal: function (number, period) {
			switch (period) {
			case 'M':
			case 'd':
			case 'DDD':
				return number + '-й';
			case 'D':
				return number + '-го';
			case 'w':
			case 'W':
				return number + '-я';
			default:
				return number;
			}
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : Northern Sami (se)
	//! authors : Bård Rolstad Henriksen : https://github.com/karamell


	var se = moment__default.defineLocale('se', {
		months : 'ođđajagemánnu_guovvamánnu_njukčamánnu_cuoŋománnu_miessemánnu_geassemánnu_suoidnemánnu_borgemánnu_čakčamánnu_golggotmánnu_skábmamánnu_juovlamánnu'.split('_'),
		monthsShort : 'ođđj_guov_njuk_cuo_mies_geas_suoi_borg_čakč_golg_skáb_juov'.split('_'),
		weekdays : 'sotnabeaivi_vuossárga_maŋŋebárga_gaskavahkku_duorastat_bearjadat_lávvardat'.split('_'),
		weekdaysShort : 'sotn_vuos_maŋ_gask_duor_bear_láv'.split('_'),
		weekdaysMin : 's_v_m_g_d_b_L'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD.MM.YYYY',
			LL : 'MMMM D. [b.] YYYY',
			LLL : 'MMMM D. [b.] YYYY [ti.] HH:mm',
			LLLL : 'dddd, MMMM D. [b.] YYYY [ti.] HH:mm'
		},
		calendar : {
			sameDay: '[otne ti] LT',
			nextDay: '[ihttin ti] LT',
			nextWeek: 'dddd [ti] LT',
			lastDay: '[ikte ti] LT',
			lastWeek: '[ovddit] dddd [ti] LT',
			sameElse: 'L'
		},
		relativeTime : {
			future : '%s geažes',
			past : 'maŋit %s',
			s : 'moadde sekunddat',
			m : 'okta minuhta',
			mm : '%d minuhtat',
			h : 'okta diimmu',
			hh : '%d diimmut',
			d : 'okta beaivi',
			dd : '%d beaivvit',
			M : 'okta mánnu',
			MM : '%d mánut',
			y : 'okta jahki',
			yy : '%d jagit'
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : Sinhalese (si)
	//! author : Sampath Sitinamaluwa : https://github.com/sampathsris

	/*jshint -W100*/
	var si = moment__default.defineLocale('si', {
		months : 'ජනවාරි_පෙබරවාරි_මාර්තු_අප්‍රේල්_මැයි_ජූනි_ජූලි_අගෝස්තු_සැප්තැම්බර්_ඔක්තෝබර්_නොවැම්බර්_දෙසැම්බර්'.split('_'),
		monthsShort : 'ජන_පෙබ_මාර්_අප්_මැයි_ජූනි_ජූලි_අගෝ_සැප්_ඔක්_නොවැ_දෙසැ'.split('_'),
		weekdays : 'ඉරිදා_සඳුදා_අඟහරුවාදා_බදාදා_බ්‍රහස්පතින්දා_සිකුරාදා_සෙනසුරාදා'.split('_'),
		weekdaysShort : 'ඉරි_සඳු_අඟ_බදා_බ්‍රහ_සිකු_සෙන'.split('_'),
		weekdaysMin : 'ඉ_ස_අ_බ_බ්‍ර_සි_සෙ'.split('_'),
		longDateFormat : {
			LT : 'a h:mm',
			LTS : 'a h:mm:ss',
			L : 'YYYY/MM/DD',
			LL : 'YYYY MMMM D',
			LLL : 'YYYY MMMM D, a h:mm',
			LLLL : 'YYYY MMMM D [වැනි] dddd, a h:mm:ss'
		},
		calendar : {
			sameDay : '[අද] LT[ට]',
			nextDay : '[හෙට] LT[ට]',
			nextWeek : 'dddd LT[ට]',
			lastDay : '[ඊයේ] LT[ට]',
			lastWeek : '[පසුගිය] dddd LT[ට]',
			sameElse : 'L'
		},
		relativeTime : {
			future : '%sකින්',
			past : '%sකට පෙර',
			s : 'තත්පර කිහිපය',
			m : 'මිනිත්තුව',
			mm : 'මිනිත්තු %d',
			h : 'පැය',
			hh : 'පැය %d',
			d : 'දිනය',
			dd : 'දින %d',
			M : 'මාසය',
			MM : 'මාස %d',
			y : 'වසර',
			yy : 'වසර %d'
		},
		ordinalParse: /\d{1,2} වැනි/,
		ordinal : function (number) {
			return number + ' වැනි';
		},
		meridiem : function (hours, minutes, isLower) {
			if (hours > 11) {
				return isLower ? 'ප.ව.' : 'පස් වරු';
			} else {
				return isLower ? 'පෙ.ව.' : 'පෙර වරු';
			}
		}
	});

	//! moment.js locale configuration
	//! locale : slovak (sk)
	//! author : Martin Minka : https://github.com/k2s
	//! based on work of petrbela : https://github.com/petrbela

	var sk__months = 'január_február_marec_apríl_máj_jún_júl_august_september_október_november_december'.split('_'),
		sk__monthsShort = 'jan_feb_mar_apr_máj_jún_júl_aug_sep_okt_nov_dec'.split('_');
	function sk__plural(n) {
		return (n > 1) && (n < 5);
	}
	function sk__translate(number, withoutSuffix, key, isFuture) {
		var result = number + ' ';
		switch (key) {
		case 's':  // a few seconds / in a few seconds / a few seconds ago
			return (withoutSuffix || isFuture) ? 'pár sekúnd' : 'pár sekundami';
		case 'm':  // a minute / in a minute / a minute ago
			return withoutSuffix ? 'minúta' : (isFuture ? 'minútu' : 'minútou');
		case 'mm': // 9 minutes / in 9 minutes / 9 minutes ago
			if (withoutSuffix || isFuture) {
				return result + (sk__plural(number) ? 'minúty' : 'minút');
			} else {
				return result + 'minútami';
			}
			break;
		case 'h':  // an hour / in an hour / an hour ago
			return withoutSuffix ? 'hodina' : (isFuture ? 'hodinu' : 'hodinou');
		case 'hh': // 9 hours / in 9 hours / 9 hours ago
			if (withoutSuffix || isFuture) {
				return result + (sk__plural(number) ? 'hodiny' : 'hodín');
			} else {
				return result + 'hodinami';
			}
			break;
		case 'd':  // a day / in a day / a day ago
			return (withoutSuffix || isFuture) ? 'deň' : 'dňom';
		case 'dd': // 9 days / in 9 days / 9 days ago
			if (withoutSuffix || isFuture) {
				return result + (sk__plural(number) ? 'dni' : 'dní');
			} else {
				return result + 'dňami';
			}
			break;
		case 'M':  // a month / in a month / a month ago
			return (withoutSuffix || isFuture) ? 'mesiac' : 'mesiacom';
		case 'MM': // 9 months / in 9 months / 9 months ago
			if (withoutSuffix || isFuture) {
				return result + (sk__plural(number) ? 'mesiace' : 'mesiacov');
			} else {
				return result + 'mesiacmi';
			}
			break;
		case 'y':  // a year / in a year / a year ago
			return (withoutSuffix || isFuture) ? 'rok' : 'rokom';
		case 'yy': // 9 years / in 9 years / 9 years ago
			if (withoutSuffix || isFuture) {
				return result + (sk__plural(number) ? 'roky' : 'rokov');
			} else {
				return result + 'rokmi';
			}
			break;
		}
	}

	var sk = moment__default.defineLocale('sk', {
		months : sk__months,
		monthsShort : sk__monthsShort,
		weekdays : 'nedeľa_pondelok_utorok_streda_štvrtok_piatok_sobota'.split('_'),
		weekdaysShort : 'ne_po_ut_st_št_pi_so'.split('_'),
		weekdaysMin : 'ne_po_ut_st_št_pi_so'.split('_'),
		longDateFormat : {
			LT: 'H:mm',
			LTS : 'H:mm:ss',
			L : 'DD.MM.YYYY',
			LL : 'D. MMMM YYYY',
			LLL : 'D. MMMM YYYY H:mm',
			LLLL : 'dddd D. MMMM YYYY H:mm'
		},
		calendar : {
			sameDay: '[dnes o] LT',
			nextDay: '[zajtra o] LT',
			nextWeek: function () {
				switch (this.day()) {
				case 0:
					return '[v nedeľu o] LT';
				case 1:
				case 2:
					return '[v] dddd [o] LT';
				case 3:
					return '[v stredu o] LT';
				case 4:
					return '[vo štvrtok o] LT';
				case 5:
					return '[v piatok o] LT';
				case 6:
					return '[v sobotu o] LT';
				}
			},
			lastDay: '[včera o] LT',
			lastWeek: function () {
				switch (this.day()) {
				case 0:
					return '[minulú nedeľu o] LT';
				case 1:
				case 2:
					return '[minulý] dddd [o] LT';
				case 3:
					return '[minulú stredu o] LT';
				case 4:
				case 5:
					return '[minulý] dddd [o] LT';
				case 6:
					return '[minulú sobotu o] LT';
				}
			},
			sameElse: 'L'
		},
		relativeTime : {
			future : 'za %s',
			past : 'pred %s',
			s : sk__translate,
			m : sk__translate,
			mm : sk__translate,
			h : sk__translate,
			hh : sk__translate,
			d : sk__translate,
			dd : sk__translate,
			M : sk__translate,
			MM : sk__translate,
			y : sk__translate,
			yy : sk__translate
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : slovenian (sl)
	//! author : Robert Sedovšek : https://github.com/sedovsek

	function sl__processRelativeTime(number, withoutSuffix, key, isFuture) {
		var result = number + ' ';
		switch (key) {
		case 's':
			return withoutSuffix || isFuture ? 'nekaj sekund' : 'nekaj sekundami';
		case 'm':
			return withoutSuffix ? 'ena minuta' : 'eno minuto';
		case 'mm':
			if (number === 1) {
				result += withoutSuffix ? 'minuta' : 'minuto';
			} else if (number === 2) {
				result += withoutSuffix || isFuture ? 'minuti' : 'minutama';
			} else if (number < 5) {
				result += withoutSuffix || isFuture ? 'minute' : 'minutami';
			} else {
				result += withoutSuffix || isFuture ? 'minut' : 'minutami';
			}
			return result;
		case 'h':
			return withoutSuffix ? 'ena ura' : 'eno uro';
		case 'hh':
			if (number === 1) {
				result += withoutSuffix ? 'ura' : 'uro';
			} else if (number === 2) {
				result += withoutSuffix || isFuture ? 'uri' : 'urama';
			} else if (number < 5) {
				result += withoutSuffix || isFuture ? 'ure' : 'urami';
			} else {
				result += withoutSuffix || isFuture ? 'ur' : 'urami';
			}
			return result;
		case 'd':
			return withoutSuffix || isFuture ? 'en dan' : 'enim dnem';
		case 'dd':
			if (number === 1) {
				result += withoutSuffix || isFuture ? 'dan' : 'dnem';
			} else if (number === 2) {
				result += withoutSuffix || isFuture ? 'dni' : 'dnevoma';
			} else {
				result += withoutSuffix || isFuture ? 'dni' : 'dnevi';
			}
			return result;
		case 'M':
			return withoutSuffix || isFuture ? 'en mesec' : 'enim mesecem';
		case 'MM':
			if (number === 1) {
				result += withoutSuffix || isFuture ? 'mesec' : 'mesecem';
			} else if (number === 2) {
				result += withoutSuffix || isFuture ? 'meseca' : 'mesecema';
			} else if (number < 5) {
				result += withoutSuffix || isFuture ? 'mesece' : 'meseci';
			} else {
				result += withoutSuffix || isFuture ? 'mesecev' : 'meseci';
			}
			return result;
		case 'y':
			return withoutSuffix || isFuture ? 'eno leto' : 'enim letom';
		case 'yy':
			if (number === 1) {
				result += withoutSuffix || isFuture ? 'leto' : 'letom';
			} else if (number === 2) {
				result += withoutSuffix || isFuture ? 'leti' : 'letoma';
			} else if (number < 5) {
				result += withoutSuffix || isFuture ? 'leta' : 'leti';
			} else {
				result += withoutSuffix || isFuture ? 'let' : 'leti';
			}
			return result;
		}
	}

	var sl = moment__default.defineLocale('sl', {
		months : 'januar_februar_marec_april_maj_junij_julij_avgust_september_oktober_november_december'.split('_'),
		monthsShort : 'jan._feb._mar._apr._maj._jun._jul._avg._sep._okt._nov._dec.'.split('_'),
		weekdays : 'nedelja_ponedeljek_torek_sreda_četrtek_petek_sobota'.split('_'),
		weekdaysShort : 'ned._pon._tor._sre._čet._pet._sob.'.split('_'),
		weekdaysMin : 'ne_po_to_sr_če_pe_so'.split('_'),
		longDateFormat : {
			LT : 'H:mm',
			LTS : 'H:mm:ss',
			L : 'DD. MM. YYYY',
			LL : 'D. MMMM YYYY',
			LLL : 'D. MMMM YYYY H:mm',
			LLLL : 'dddd, D. MMMM YYYY H:mm'
		},
		calendar : {
			sameDay  : '[danes ob] LT',
			nextDay  : '[jutri ob] LT',

			nextWeek : function () {
				switch (this.day()) {
				case 0:
					return '[v] [nedeljo] [ob] LT';
				case 3:
					return '[v] [sredo] [ob] LT';
				case 6:
					return '[v] [soboto] [ob] LT';
				case 1:
				case 2:
				case 4:
				case 5:
					return '[v] dddd [ob] LT';
				}
			},
			lastDay  : '[včeraj ob] LT',
			lastWeek : function () {
				switch (this.day()) {
				case 0:
					return '[prejšnjo] [nedeljo] [ob] LT';
				case 3:
					return '[prejšnjo] [sredo] [ob] LT';
				case 6:
					return '[prejšnjo] [soboto] [ob] LT';
				case 1:
				case 2:
				case 4:
				case 5:
					return '[prejšnji] dddd [ob] LT';
				}
			},
			sameElse : 'L'
		},
		relativeTime : {
			future : 'čez %s',
			past   : 'pred %s',
			s      : sl__processRelativeTime,
			m      : sl__processRelativeTime,
			mm     : sl__processRelativeTime,
			h      : sl__processRelativeTime,
			hh     : sl__processRelativeTime,
			d      : sl__processRelativeTime,
			dd     : sl__processRelativeTime,
			M      : sl__processRelativeTime,
			MM     : sl__processRelativeTime,
			y      : sl__processRelativeTime,
			yy     : sl__processRelativeTime
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : Albanian (sq)
	//! author : Flakërim Ismani : https://github.com/flakerimi
	//! author: Menelion Elensúle: https://github.com/Oire (tests)
	//! author : Oerd Cukalla : https://github.com/oerd (fixes)

	var sq = moment__default.defineLocale('sq', {
		months : 'Janar_Shkurt_Mars_Prill_Maj_Qershor_Korrik_Gusht_Shtator_Tetor_Nëntor_Dhjetor'.split('_'),
		monthsShort : 'Jan_Shk_Mar_Pri_Maj_Qer_Kor_Gus_Sht_Tet_Nën_Dhj'.split('_'),
		weekdays : 'E Diel_E Hënë_E Martë_E Mërkurë_E Enjte_E Premte_E Shtunë'.split('_'),
		weekdaysShort : 'Die_Hën_Mar_Mër_Enj_Pre_Sht'.split('_'),
		weekdaysMin : 'D_H_Ma_Më_E_P_Sh'.split('_'),
		meridiemParse: /PD|MD/,
		isPM: function (input) {
			return input.charAt(0) === 'M';
		},
		meridiem : function (hours, minutes, isLower) {
			return hours < 12 ? 'PD' : 'MD';
		},
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd, D MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay : '[Sot në] LT',
			nextDay : '[Nesër në] LT',
			nextWeek : 'dddd [në] LT',
			lastDay : '[Dje në] LT',
			lastWeek : 'dddd [e kaluar në] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'në %s',
			past : '%s më parë',
			s : 'disa sekonda',
			m : 'një minutë',
			mm : '%d minuta',
			h : 'një orë',
			hh : '%d orë',
			d : 'një ditë',
			dd : '%d ditë',
			M : 'një muaj',
			MM : '%d muaj',
			y : 'një vit',
			yy : '%d vite'
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : Serbian-cyrillic (sr-cyrl)
	//! author : Milan Janačković<milanjanackovic@gmail.com> : https://github.com/milan-j

	var sr_cyrl__translator = {
		words: { //Different grammatical cases
			m: ['један минут', 'једне минуте'],
			mm: ['минут', 'минуте', 'минута'],
			h: ['један сат', 'једног сата'],
			hh: ['сат', 'сата', 'сати'],
			dd: ['дан', 'дана', 'дана'],
			MM: ['месец', 'месеца', 'месеци'],
			yy: ['година', 'године', 'година']
		},
		correctGrammaticalCase: function (number, wordKey) {
			return number === 1 ? wordKey[0] : (number >= 2 && number <= 4 ? wordKey[1] : wordKey[2]);
		},
		translate: function (number, withoutSuffix, key) {
			var wordKey = sr_cyrl__translator.words[key];
			if (key.length === 1) {
				return withoutSuffix ? wordKey[0] : wordKey[1];
			} else {
				return number + ' ' + sr_cyrl__translator.correctGrammaticalCase(number, wordKey);
			}
		}
	};

	var sr_cyrl = moment__default.defineLocale('sr-cyrl', {
		months: ['јануар', 'фебруар', 'март', 'април', 'мај', 'јун', 'јул', 'август', 'септембар', 'октобар', 'новембар', 'децембар'],
		monthsShort: ['јан.', 'феб.', 'мар.', 'апр.', 'мај', 'јун', 'јул', 'авг.', 'сеп.', 'окт.', 'нов.', 'дец.'],
		weekdays: ['недеља', 'понедељак', 'уторак', 'среда', 'четвртак', 'петак', 'субота'],
		weekdaysShort: ['нед.', 'пон.', 'уто.', 'сре.', 'чет.', 'пет.', 'суб.'],
		weekdaysMin: ['не', 'по', 'ут', 'ср', 'че', 'пе', 'су'],
		longDateFormat: {
			LT: 'H:mm',
			LTS : 'H:mm:ss',
			L: 'DD. MM. YYYY',
			LL: 'D. MMMM YYYY',
			LLL: 'D. MMMM YYYY H:mm',
			LLLL: 'dddd, D. MMMM YYYY H:mm'
		},
		calendar: {
			sameDay: '[данас у] LT',
			nextDay: '[сутра у] LT',
			nextWeek: function () {
				switch (this.day()) {
				case 0:
					return '[у] [недељу] [у] LT';
				case 3:
					return '[у] [среду] [у] LT';
				case 6:
					return '[у] [суботу] [у] LT';
				case 1:
				case 2:
				case 4:
				case 5:
					return '[у] dddd [у] LT';
				}
			},
			lastDay  : '[јуче у] LT',
			lastWeek : function () {
				var lastWeekDays = [
					'[прошле] [недеље] [у] LT',
					'[прошлог] [понедељка] [у] LT',
					'[прошлог] [уторка] [у] LT',
					'[прошле] [среде] [у] LT',
					'[прошлог] [четвртка] [у] LT',
					'[прошлог] [петка] [у] LT',
					'[прошле] [суботе] [у] LT'
				];
				return lastWeekDays[this.day()];
			},
			sameElse : 'L'
		},
		relativeTime : {
			future : 'за %s',
			past   : 'пре %s',
			s      : 'неколико секунди',
			m      : sr_cyrl__translator.translate,
			mm     : sr_cyrl__translator.translate,
			h      : sr_cyrl__translator.translate,
			hh     : sr_cyrl__translator.translate,
			d      : 'дан',
			dd     : sr_cyrl__translator.translate,
			M      : 'месец',
			MM     : sr_cyrl__translator.translate,
			y      : 'годину',
			yy     : sr_cyrl__translator.translate
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : Serbian-latin (sr)
	//! author : Milan Janačković<milanjanackovic@gmail.com> : https://github.com/milan-j

	var sr__translator = {
		words: { //Different grammatical cases
			m: ['jedan minut', 'jedne minute'],
			mm: ['minut', 'minute', 'minuta'],
			h: ['jedan sat', 'jednog sata'],
			hh: ['sat', 'sata', 'sati'],
			dd: ['dan', 'dana', 'dana'],
			MM: ['mesec', 'meseca', 'meseci'],
			yy: ['godina', 'godine', 'godina']
		},
		correctGrammaticalCase: function (number, wordKey) {
			return number === 1 ? wordKey[0] : (number >= 2 && number <= 4 ? wordKey[1] : wordKey[2]);
		},
		translate: function (number, withoutSuffix, key) {
			var wordKey = sr__translator.words[key];
			if (key.length === 1) {
				return withoutSuffix ? wordKey[0] : wordKey[1];
			} else {
				return number + ' ' + sr__translator.correctGrammaticalCase(number, wordKey);
			}
		}
	};

	var sr = moment__default.defineLocale('sr', {
		months: ['januar', 'februar', 'mart', 'april', 'maj', 'jun', 'jul', 'avgust', 'septembar', 'oktobar', 'novembar', 'decembar'],
		monthsShort: ['jan.', 'feb.', 'mar.', 'apr.', 'maj', 'jun', 'jul', 'avg.', 'sep.', 'okt.', 'nov.', 'dec.'],
		weekdays: ['nedelja', 'ponedeljak', 'utorak', 'sreda', 'četvrtak', 'petak', 'subota'],
		weekdaysShort: ['ned.', 'pon.', 'uto.', 'sre.', 'čet.', 'pet.', 'sub.'],
		weekdaysMin: ['ne', 'po', 'ut', 'sr', 'če', 'pe', 'su'],
		longDateFormat: {
			LT: 'H:mm',
			LTS : 'H:mm:ss',
			L: 'DD. MM. YYYY',
			LL: 'D. MMMM YYYY',
			LLL: 'D. MMMM YYYY H:mm',
			LLLL: 'dddd, D. MMMM YYYY H:mm'
		},
		calendar: {
			sameDay: '[danas u] LT',
			nextDay: '[sutra u] LT',
			nextWeek: function () {
				switch (this.day()) {
				case 0:
					return '[u] [nedelju] [u] LT';
				case 3:
					return '[u] [sredu] [u] LT';
				case 6:
					return '[u] [subotu] [u] LT';
				case 1:
				case 2:
				case 4:
				case 5:
					return '[u] dddd [u] LT';
				}
			},
			lastDay  : '[juče u] LT',
			lastWeek : function () {
				var lastWeekDays = [
					'[prošle] [nedelje] [u] LT',
					'[prošlog] [ponedeljka] [u] LT',
					'[prošlog] [utorka] [u] LT',
					'[prošle] [srede] [u] LT',
					'[prošlog] [četvrtka] [u] LT',
					'[prošlog] [petka] [u] LT',
					'[prošle] [subote] [u] LT'
				];
				return lastWeekDays[this.day()];
			},
			sameElse : 'L'
		},
		relativeTime : {
			future : 'za %s',
			past   : 'pre %s',
			s      : 'nekoliko sekundi',
			m      : sr__translator.translate,
			mm     : sr__translator.translate,
			h      : sr__translator.translate,
			hh     : sr__translator.translate,
			d      : 'dan',
			dd     : sr__translator.translate,
			M      : 'mesec',
			MM     : sr__translator.translate,
			y      : 'godinu',
			yy     : sr__translator.translate
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : swedish (sv)
	//! author : Jens Alm : https://github.com/ulmus

	var sv = moment__default.defineLocale('sv', {
		months : 'januari_februari_mars_april_maj_juni_juli_augusti_september_oktober_november_december'.split('_'),
		monthsShort : 'jan_feb_mar_apr_maj_jun_jul_aug_sep_okt_nov_dec'.split('_'),
		weekdays : 'söndag_måndag_tisdag_onsdag_torsdag_fredag_lördag'.split('_'),
		weekdaysShort : 'sön_mån_tis_ons_tor_fre_lör'.split('_'),
		weekdaysMin : 'sö_må_ti_on_to_fr_lö'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'YYYY-MM-DD',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd D MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay: '[Idag] LT',
			nextDay: '[Imorgon] LT',
			lastDay: '[Igår] LT',
			nextWeek: '[På] dddd LT',
			lastWeek: '[I] dddd[s] LT',
			sameElse: 'L'
		},
		relativeTime : {
			future : 'om %s',
			past : 'för %s sedan',
			s : 'några sekunder',
			m : 'en minut',
			mm : '%d minuter',
			h : 'en timme',
			hh : '%d timmar',
			d : 'en dag',
			dd : '%d dagar',
			M : 'en månad',
			MM : '%d månader',
			y : 'ett år',
			yy : '%d år'
		},
		ordinalParse: /\d{1,2}(e|a)/,
		ordinal : function (number) {
			var b = number % 10,
				output = (~~(number % 100 / 10) === 1) ? 'e' :
				(b === 1) ? 'a' :
				(b === 2) ? 'a' :
				(b === 3) ? 'e' : 'e';
			return number + output;
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : swahili (sw)
	//! author : Fahad Kassim : https://github.com/fadsel

	var sw = moment__default.defineLocale('sw', {
		months : 'Januari_Februari_Machi_Aprili_Mei_Juni_Julai_Agosti_Septemba_Oktoba_Novemba_Desemba'.split('_'),
		monthsShort : 'Jan_Feb_Mac_Apr_Mei_Jun_Jul_Ago_Sep_Okt_Nov_Des'.split('_'),
		weekdays : 'Jumapili_Jumatatu_Jumanne_Jumatano_Alhamisi_Ijumaa_Jumamosi'.split('_'),
		weekdaysShort : 'Jpl_Jtat_Jnne_Jtan_Alh_Ijm_Jmos'.split('_'),
		weekdaysMin : 'J2_J3_J4_J5_Al_Ij_J1'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD.MM.YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd, D MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay : '[leo saa] LT',
			nextDay : '[kesho saa] LT',
			nextWeek : '[wiki ijayo] dddd [saat] LT',
			lastDay : '[jana] LT',
			lastWeek : '[wiki iliyopita] dddd [saat] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : '%s baadaye',
			past : 'tokea %s',
			s : 'hivi punde',
			m : 'dakika moja',
			mm : 'dakika %d',
			h : 'saa limoja',
			hh : 'masaa %d',
			d : 'siku moja',
			dd : 'masiku %d',
			M : 'mwezi mmoja',
			MM : 'miezi %d',
			y : 'mwaka mmoja',
			yy : 'miaka %d'
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : tamil (ta)
	//! author : Arjunkumar Krishnamoorthy : https://github.com/tk120404

	var ta__symbolMap = {
		'1': '௧',
		'2': '௨',
		'3': '௩',
		'4': '௪',
		'5': '௫',
		'6': '௬',
		'7': '௭',
		'8': '௮',
		'9': '௯',
		'0': '௦'
	}, ta__numberMap = {
		'௧': '1',
		'௨': '2',
		'௩': '3',
		'௪': '4',
		'௫': '5',
		'௬': '6',
		'௭': '7',
		'௮': '8',
		'௯': '9',
		'௦': '0'
	};

	var ta = moment__default.defineLocale('ta', {
		months : 'ஜனவரி_பிப்ரவரி_மார்ச்_ஏப்ரல்_மே_ஜூன்_ஜூலை_ஆகஸ்ட்_செப்டெம்பர்_அக்டோபர்_நவம்பர்_டிசம்பர்'.split('_'),
		monthsShort : 'ஜனவரி_பிப்ரவரி_மார்ச்_ஏப்ரல்_மே_ஜூன்_ஜூலை_ஆகஸ்ட்_செப்டெம்பர்_அக்டோபர்_நவம்பர்_டிசம்பர்'.split('_'),
		weekdays : 'ஞாயிற்றுக்கிழமை_திங்கட்கிழமை_செவ்வாய்கிழமை_புதன்கிழமை_வியாழக்கிழமை_வெள்ளிக்கிழமை_சனிக்கிழமை'.split('_'),
		weekdaysShort : 'ஞாயிறு_திங்கள்_செவ்வாய்_புதன்_வியாழன்_வெள்ளி_சனி'.split('_'),
		weekdaysMin : 'ஞா_தி_செ_பு_வி_வெ_ச'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY, HH:mm',
			LLLL : 'dddd, D MMMM YYYY, HH:mm'
		},
		calendar : {
			sameDay : '[இன்று] LT',
			nextDay : '[நாளை] LT',
			nextWeek : 'dddd, LT',
			lastDay : '[நேற்று] LT',
			lastWeek : '[கடந்த வாரம்] dddd, LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : '%s இல்',
			past : '%s முன்',
			s : 'ஒரு சில விநாடிகள்',
			m : 'ஒரு நிமிடம்',
			mm : '%d நிமிடங்கள்',
			h : 'ஒரு மணி நேரம்',
			hh : '%d மணி நேரம்',
			d : 'ஒரு நாள்',
			dd : '%d நாட்கள்',
			M : 'ஒரு மாதம்',
			MM : '%d மாதங்கள்',
			y : 'ஒரு வருடம்',
			yy : '%d ஆண்டுகள்'
		},
		ordinalParse: /\d{1,2}வது/,
		ordinal : function (number) {
			return number + 'வது';
		},
		preparse: function (string) {
			return string.replace(/[௧௨௩௪௫௬௭௮௯௦]/g, function (match) {
				return ta__numberMap[match];
			});
		},
		postformat: function (string) {
			return string.replace(/\d/g, function (match) {
				return ta__symbolMap[match];
			});
		},
		// refer http://ta.wikipedia.org/s/1er1
		meridiemParse: /யாமம்|வைகறை|காலை|நண்பகல்|எற்பாடு|மாலை/,
		meridiem : function (hour, minute, isLower) {
			if (hour < 2) {
				return ' யாமம்';
			} else if (hour < 6) {
				return ' வைகறை';  // வைகறை
			} else if (hour < 10) {
				return ' காலை'; // காலை
			} else if (hour < 14) {
				return ' நண்பகல்'; // நண்பகல்
			} else if (hour < 18) {
				return ' எற்பாடு'; // எற்பாடு
			} else if (hour < 22) {
				return ' மாலை'; // மாலை
			} else {
				return ' யாமம்';
			}
		},
		meridiemHour : function (hour, meridiem) {
			if (hour === 12) {
				hour = 0;
			}
			if (meridiem === 'யாமம்') {
				return hour < 2 ? hour : hour + 12;
			} else if (meridiem === 'வைகறை' || meridiem === 'காலை') {
				return hour;
			} else if (meridiem === 'நண்பகல்') {
				return hour >= 10 ? hour : hour + 12;
			} else {
				return hour + 12;
			}
		},
		week : {
			dow : 0, // Sunday is the first day of the week.
			doy : 6  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : telugu (te)
	//! author : Krishna Chaitanya Thota : https://github.com/kcthota

	var te = moment__default.defineLocale('te', {
		months : 'జనవరి_ఫిబ్రవరి_మార్చి_ఏప్రిల్_మే_జూన్_జూలై_ఆగస్టు_సెప్టెంబర్_అక్టోబర్_నవంబర్_డిసెంబర్'.split('_'),
		monthsShort : 'జన._ఫిబ్ర._మార్చి_ఏప్రి._మే_జూన్_జూలై_ఆగ._సెప్._అక్టో._నవ._డిసె.'.split('_'),
		weekdays : 'ఆదివారం_సోమవారం_మంగళవారం_బుధవారం_గురువారం_శుక్రవారం_శనివారం'.split('_'),
		weekdaysShort : 'ఆది_సోమ_మంగళ_బుధ_గురు_శుక్ర_శని'.split('_'),
		weekdaysMin : 'ఆ_సో_మం_బు_గు_శు_శ'.split('_'),
		longDateFormat : {
			LT : 'A h:mm',
			LTS : 'A h:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY, A h:mm',
			LLLL : 'dddd, D MMMM YYYY, A h:mm'
		},
		calendar : {
			sameDay : '[నేడు] LT',
			nextDay : '[రేపు] LT',
			nextWeek : 'dddd, LT',
			lastDay : '[నిన్న] LT',
			lastWeek : '[గత] dddd, LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : '%s లో',
			past : '%s క్రితం',
			s : 'కొన్ని క్షణాలు',
			m : 'ఒక నిమిషం',
			mm : '%d నిమిషాలు',
			h : 'ఒక గంట',
			hh : '%d గంటలు',
			d : 'ఒక రోజు',
			dd : '%d రోజులు',
			M : 'ఒక నెల',
			MM : '%d నెలలు',
			y : 'ఒక సంవత్సరం',
			yy : '%d సంవత్సరాలు'
		},
		ordinalParse : /\d{1,2}వ/,
		ordinal : '%dవ',
		meridiemParse: /రాత్రి|ఉదయం|మధ్యాహ్నం|సాయంత్రం/,
		meridiemHour : function (hour, meridiem) {
			if (hour === 12) {
				hour = 0;
			}
			if (meridiem === 'రాత్రి') {
				return hour < 4 ? hour : hour + 12;
			} else if (meridiem === 'ఉదయం') {
				return hour;
			} else if (meridiem === 'మధ్యాహ్నం') {
				return hour >= 10 ? hour : hour + 12;
			} else if (meridiem === 'సాయంత్రం') {
				return hour + 12;
			}
		},
		meridiem : function (hour, minute, isLower) {
			if (hour < 4) {
				return 'రాత్రి';
			} else if (hour < 10) {
				return 'ఉదయం';
			} else if (hour < 17) {
				return 'మధ్యాహ్నం';
			} else if (hour < 20) {
				return 'సాయంత్రం';
			} else {
				return 'రాత్రి';
			}
		},
		week : {
			dow : 0, // Sunday is the first day of the week.
			doy : 6  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : thai (th)
	//! author : Kridsada Thanabulpong : https://github.com/sirn

	var th = moment__default.defineLocale('th', {
		months : 'มกราคม_กุมภาพันธ์_มีนาคม_เมษายน_พฤษภาคม_มิถุนายน_กรกฎาคม_สิงหาคม_กันยายน_ตุลาคม_พฤศจิกายน_ธันวาคม'.split('_'),
		monthsShort : 'มกรา_กุมภา_มีนา_เมษา_พฤษภา_มิถุนา_กรกฎา_สิงหา_กันยา_ตุลา_พฤศจิกา_ธันวา'.split('_'),
		weekdays : 'อาทิตย์_จันทร์_อังคาร_พุธ_พฤหัสบดี_ศุกร์_เสาร์'.split('_'),
		weekdaysShort : 'อาทิตย์_จันทร์_อังคาร_พุธ_พฤหัส_ศุกร์_เสาร์'.split('_'), // yes, three characters difference
		weekdaysMin : 'อา._จ._อ._พ._พฤ._ศ._ส.'.split('_'),
		longDateFormat : {
			LT : 'H นาฬิกา m นาที',
			LTS : 'H นาฬิกา m นาที s วินาที',
			L : 'YYYY/MM/DD',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY เวลา H นาฬิกา m นาที',
			LLLL : 'วันddddที่ D MMMM YYYY เวลา H นาฬิกา m นาที'
		},
		meridiemParse: /ก่อนเที่ยง|หลังเที่ยง/,
		isPM: function (input) {
			return input === 'หลังเที่ยง';
		},
		meridiem : function (hour, minute, isLower) {
			if (hour < 12) {
				return 'ก่อนเที่ยง';
			} else {
				return 'หลังเที่ยง';
			}
		},
		calendar : {
			sameDay : '[วันนี้ เวลา] LT',
			nextDay : '[พรุ่งนี้ เวลา] LT',
			nextWeek : 'dddd[หน้า เวลา] LT',
			lastDay : '[เมื่อวานนี้ เวลา] LT',
			lastWeek : '[วัน]dddd[ที่แล้ว เวลา] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'อีก %s',
			past : '%sที่แล้ว',
			s : 'ไม่กี่วินาที',
			m : '1 นาที',
			mm : '%d นาที',
			h : '1 ชั่วโมง',
			hh : '%d ชั่วโมง',
			d : '1 วัน',
			dd : '%d วัน',
			M : '1 เดือน',
			MM : '%d เดือน',
			y : '1 ปี',
			yy : '%d ปี'
		}
	});

	//! moment.js locale configuration
	//! locale : Tagalog/Filipino (tl-ph)
	//! author : Dan Hagman

	var tl_ph = moment__default.defineLocale('tl-ph', {
		months : 'Enero_Pebrero_Marso_Abril_Mayo_Hunyo_Hulyo_Agosto_Setyembre_Oktubre_Nobyembre_Disyembre'.split('_'),
		monthsShort : 'Ene_Peb_Mar_Abr_May_Hun_Hul_Ago_Set_Okt_Nob_Dis'.split('_'),
		weekdays : 'Linggo_Lunes_Martes_Miyerkules_Huwebes_Biyernes_Sabado'.split('_'),
		weekdaysShort : 'Lin_Lun_Mar_Miy_Huw_Biy_Sab'.split('_'),
		weekdaysMin : 'Li_Lu_Ma_Mi_Hu_Bi_Sab'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'MM/D/YYYY',
			LL : 'MMMM D, YYYY',
			LLL : 'MMMM D, YYYY HH:mm',
			LLLL : 'dddd, MMMM DD, YYYY HH:mm'
		},
		calendar : {
			sameDay: '[Ngayon sa] LT',
			nextDay: '[Bukas sa] LT',
			nextWeek: 'dddd [sa] LT',
			lastDay: '[Kahapon sa] LT',
			lastWeek: 'dddd [huling linggo] LT',
			sameElse: 'L'
		},
		relativeTime : {
			future : 'sa loob ng %s',
			past : '%s ang nakalipas',
			s : 'ilang segundo',
			m : 'isang minuto',
			mm : '%d minuto',
			h : 'isang oras',
			hh : '%d oras',
			d : 'isang araw',
			dd : '%d araw',
			M : 'isang buwan',
			MM : '%d buwan',
			y : 'isang taon',
			yy : '%d taon'
		},
		ordinalParse: /\d{1,2}/,
		ordinal : function (number) {
			return number;
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : Klingon (tlh)
	//! author : Dominika Kruk : https://github.com/amaranthrose

	var numbersNouns = 'pagh_wa’_cha’_wej_loS_vagh_jav_Soch_chorgh_Hut'.split('_');

	function translateFuture(output) {
		var time = output;
		time = (output.indexOf('jaj') !== -1) ?
		time.slice(0, -3) + 'leS' :
		(output.indexOf('jar') !== -1) ?
		time.slice(0, -3) + 'waQ' :
		(output.indexOf('DIS') !== -1) ?
		time.slice(0, -3) + 'nem' :
		time + ' pIq';
		return time;
	}

	function translatePast(output) {
		var time = output;
		time = (output.indexOf('jaj') !== -1) ?
		time.slice(0, -3) + 'Hu’' :
		(output.indexOf('jar') !== -1) ?
		time.slice(0, -3) + 'wen' :
		(output.indexOf('DIS') !== -1) ?
		time.slice(0, -3) + 'ben' :
		time + ' ret';
		return time;
	}

	function tlh__translate(number, withoutSuffix, string, isFuture) {
		var numberNoun = numberAsNoun(number);
		switch (string) {
			case 'mm':
				return numberNoun + ' tup';
			case 'hh':
				return numberNoun + ' rep';
			case 'dd':
				return numberNoun + ' jaj';
			case 'MM':
				return numberNoun + ' jar';
			case 'yy':
				return numberNoun + ' DIS';
		}
	}

	function numberAsNoun(number) {
		var hundred = Math.floor((number % 1000) / 100),
		ten = Math.floor((number % 100) / 10),
		one = number % 10,
		word = '';
		if (hundred > 0) {
			word += numbersNouns[hundred] + 'vatlh';
		}
		if (ten > 0) {
			word += ((word !== '') ? ' ' : '') + numbersNouns[ten] + 'maH';
		}
		if (one > 0) {
			word += ((word !== '') ? ' ' : '') + numbersNouns[one];
		}
		return (word === '') ? 'pagh' : word;
	}

	var tlh = moment__default.defineLocale('tlh', {
		months : 'tera’ jar wa’_tera’ jar cha’_tera’ jar wej_tera’ jar loS_tera’ jar vagh_tera’ jar jav_tera’ jar Soch_tera’ jar chorgh_tera’ jar Hut_tera’ jar wa’maH_tera’ jar wa’maH wa’_tera’ jar wa’maH cha’'.split('_'),
		monthsShort : 'jar wa’_jar cha’_jar wej_jar loS_jar vagh_jar jav_jar Soch_jar chorgh_jar Hut_jar wa’maH_jar wa’maH wa’_jar wa’maH cha’'.split('_'),
		weekdays : 'lojmItjaj_DaSjaj_povjaj_ghItlhjaj_loghjaj_buqjaj_ghInjaj'.split('_'),
		weekdaysShort : 'lojmItjaj_DaSjaj_povjaj_ghItlhjaj_loghjaj_buqjaj_ghInjaj'.split('_'),
		weekdaysMin : 'lojmItjaj_DaSjaj_povjaj_ghItlhjaj_loghjaj_buqjaj_ghInjaj'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD.MM.YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd, D MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay: '[DaHjaj] LT',
			nextDay: '[wa’leS] LT',
			nextWeek: 'LLL',
			lastDay: '[wa’Hu’] LT',
			lastWeek: 'LLL',
			sameElse: 'L'
		},
		relativeTime : {
			future : translateFuture,
			past : translatePast,
			s : 'puS lup',
			m : 'wa’ tup',
			mm : tlh__translate,
			h : 'wa’ rep',
			hh : tlh__translate,
			d : 'wa’ jaj',
			dd : tlh__translate,
			M : 'wa’ jar',
			MM : tlh__translate,
			y : 'wa’ DIS',
			yy : tlh__translate
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : turkish (tr)
	//! authors : Erhan Gundogan : https://github.com/erhangundogan,
	//!           Burak Yiğit Kaya: https://github.com/BYK

	var tr__suffixes = {
		1: '\'inci',
		5: '\'inci',
		8: '\'inci',
		70: '\'inci',
		80: '\'inci',
		2: '\'nci',
		7: '\'nci',
		20: '\'nci',
		50: '\'nci',
		3: '\'üncü',
		4: '\'üncü',
		100: '\'üncü',
		6: '\'ncı',
		9: '\'uncu',
		10: '\'uncu',
		30: '\'uncu',
		60: '\'ıncı',
		90: '\'ıncı'
	};

	var tr = moment__default.defineLocale('tr', {
		months : 'Ocak_Şubat_Mart_Nisan_Mayıs_Haziran_Temmuz_Ağustos_Eylül_Ekim_Kasım_Aralık'.split('_'),
		monthsShort : 'Oca_Şub_Mar_Nis_May_Haz_Tem_Ağu_Eyl_Eki_Kas_Ara'.split('_'),
		weekdays : 'Pazar_Pazartesi_Salı_Çarşamba_Perşembe_Cuma_Cumartesi'.split('_'),
		weekdaysShort : 'Paz_Pts_Sal_Çar_Per_Cum_Cts'.split('_'),
		weekdaysMin : 'Pz_Pt_Sa_Ça_Pe_Cu_Ct'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD.MM.YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd, D MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay : '[bugün saat] LT',
			nextDay : '[yarın saat] LT',
			nextWeek : '[haftaya] dddd [saat] LT',
			lastDay : '[dün] LT',
			lastWeek : '[geçen hafta] dddd [saat] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : '%s sonra',
			past : '%s önce',
			s : 'birkaç saniye',
			m : 'bir dakika',
			mm : '%d dakika',
			h : 'bir saat',
			hh : '%d saat',
			d : 'bir gün',
			dd : '%d gün',
			M : 'bir ay',
			MM : '%d ay',
			y : 'bir yıl',
			yy : '%d yıl'
		},
		ordinalParse: /\d{1,2}'(inci|nci|üncü|ncı|uncu|ıncı)/,
		ordinal : function (number) {
			if (number === 0) {  // special case for zero
				return number + '\'ıncı';
			}
			var a = number % 10,
				b = number % 100 - a,
				c = number >= 100 ? 100 : null;
			return number + (tr__suffixes[a] || tr__suffixes[b] || tr__suffixes[c]);
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : talossan (tzl)
	//! author : Robin van der Vliet : https://github.com/robin0van0der0v with the help of Iustì Canun


	// After the year there should be a slash and the amount of years since December 26, 1979 in Roman numerals.
	// This is currently too difficult (maybe even impossible) to add.
	var tzl = moment__default.defineLocale('tzl', {
		months : 'Januar_Fevraglh_Març_Avrïu_Mai_Gün_Julia_Guscht_Setemvar_Listopäts_Noemvar_Zecemvar'.split('_'),
		monthsShort : 'Jan_Fev_Mar_Avr_Mai_Gün_Jul_Gus_Set_Lis_Noe_Zec'.split('_'),
		weekdays : 'Súladi_Lúneçi_Maitzi_Márcuri_Xhúadi_Viénerçi_Sáturi'.split('_'),
		weekdaysShort : 'Súl_Lún_Mai_Már_Xhú_Vié_Sát'.split('_'),
		weekdaysMin : 'Sú_Lú_Ma_Má_Xh_Vi_Sá'.split('_'),
		longDateFormat : {
			LT : 'HH.mm',
			LTS : 'HH.mm.ss',
			L : 'DD.MM.YYYY',
			LL : 'D. MMMM [dallas] YYYY',
			LLL : 'D. MMMM [dallas] YYYY HH.mm',
			LLLL : 'dddd, [li] D. MMMM [dallas] YYYY HH.mm'
		},
		meridiem : function (hours, minutes, isLower) {
			if (hours > 11) {
				return isLower ? 'd\'o' : 'D\'O';
			} else {
				return isLower ? 'd\'a' : 'D\'A';
			}
		},
		calendar : {
			sameDay : '[oxhi à] LT',
			nextDay : '[demà à] LT',
			nextWeek : 'dddd [à] LT',
			lastDay : '[ieiri à] LT',
			lastWeek : '[sür el] dddd [lasteu à] LT',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'osprei %s',
			past : 'ja%s',
			s : tzl__processRelativeTime,
			m : tzl__processRelativeTime,
			mm : tzl__processRelativeTime,
			h : tzl__processRelativeTime,
			hh : tzl__processRelativeTime,
			d : tzl__processRelativeTime,
			dd : tzl__processRelativeTime,
			M : tzl__processRelativeTime,
			MM : tzl__processRelativeTime,
			y : tzl__processRelativeTime,
			yy : tzl__processRelativeTime
		},
		ordinalParse: /\d{1,2}\./,
		ordinal : '%d.',
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	function tzl__processRelativeTime(number, withoutSuffix, key, isFuture) {
		var format = {
			's': ['viensas secunds', '\'iensas secunds'],
			'm': ['\'n míut', '\'iens míut'],
			'mm': [number + ' míuts', '' + number + ' míuts'],
			'h': ['\'n þora', '\'iensa þora'],
			'hh': [number + ' þoras', '' + number + ' þoras'],
			'd': ['\'n ziua', '\'iensa ziua'],
			'dd': [number + ' ziuas', '' + number + ' ziuas'],
			'M': ['\'n mes', '\'iens mes'],
			'MM': [number + ' mesen', '' + number + ' mesen'],
			'y': ['\'n ar', '\'iens ar'],
			'yy': [number + ' ars', '' + number + ' ars']
		};
		return isFuture ? format[key][0] : (withoutSuffix ? format[key][0] : format[key][1]);
	}

	//! moment.js locale configuration
	//! locale : Morocco Central Atlas Tamaziɣt in Latin (tzm-latn)
	//! author : Abdel Said : https://github.com/abdelsaid

	var tzm_latn = moment__default.defineLocale('tzm-latn', {
		months : 'innayr_brˤayrˤ_marˤsˤ_ibrir_mayyw_ywnyw_ywlywz_ɣwšt_šwtanbir_ktˤwbrˤ_nwwanbir_dwjnbir'.split('_'),
		monthsShort : 'innayr_brˤayrˤ_marˤsˤ_ibrir_mayyw_ywnyw_ywlywz_ɣwšt_šwtanbir_ktˤwbrˤ_nwwanbir_dwjnbir'.split('_'),
		weekdays : 'asamas_aynas_asinas_akras_akwas_asimwas_asiḍyas'.split('_'),
		weekdaysShort : 'asamas_aynas_asinas_akras_akwas_asimwas_asiḍyas'.split('_'),
		weekdaysMin : 'asamas_aynas_asinas_akras_akwas_asimwas_asiḍyas'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd D MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay: '[asdkh g] LT',
			nextDay: '[aska g] LT',
			nextWeek: 'dddd [g] LT',
			lastDay: '[assant g] LT',
			lastWeek: 'dddd [g] LT',
			sameElse: 'L'
		},
		relativeTime : {
			future : 'dadkh s yan %s',
			past : 'yan %s',
			s : 'imik',
			m : 'minuḍ',
			mm : '%d minuḍ',
			h : 'saɛa',
			hh : '%d tassaɛin',
			d : 'ass',
			dd : '%d ossan',
			M : 'ayowr',
			MM : '%d iyyirn',
			y : 'asgas',
			yy : '%d isgasn'
		},
		week : {
			dow : 6, // Saturday is the first day of the week.
			doy : 12  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : Morocco Central Atlas Tamaziɣt (tzm)
	//! author : Abdel Said : https://github.com/abdelsaid

	var tzm = moment__default.defineLocale('tzm', {
		months : 'ⵉⵏⵏⴰⵢⵔ_ⴱⵕⴰⵢⵕ_ⵎⴰⵕⵚ_ⵉⴱⵔⵉⵔ_ⵎⴰⵢⵢⵓ_ⵢⵓⵏⵢⵓ_ⵢⵓⵍⵢⵓⵣ_ⵖⵓⵛⵜ_ⵛⵓⵜⴰⵏⴱⵉⵔ_ⴽⵟⵓⴱⵕ_ⵏⵓⵡⴰⵏⴱⵉⵔ_ⴷⵓⵊⵏⴱⵉⵔ'.split('_'),
		monthsShort : 'ⵉⵏⵏⴰⵢⵔ_ⴱⵕⴰⵢⵕ_ⵎⴰⵕⵚ_ⵉⴱⵔⵉⵔ_ⵎⴰⵢⵢⵓ_ⵢⵓⵏⵢⵓ_ⵢⵓⵍⵢⵓⵣ_ⵖⵓⵛⵜ_ⵛⵓⵜⴰⵏⴱⵉⵔ_ⴽⵟⵓⴱⵕ_ⵏⵓⵡⴰⵏⴱⵉⵔ_ⴷⵓⵊⵏⴱⵉⵔ'.split('_'),
		weekdays : 'ⴰⵙⴰⵎⴰⵙ_ⴰⵢⵏⴰⵙ_ⴰⵙⵉⵏⴰⵙ_ⴰⴽⵔⴰⵙ_ⴰⴽⵡⴰⵙ_ⴰⵙⵉⵎⵡⴰⵙ_ⴰⵙⵉⴹⵢⴰⵙ'.split('_'),
		weekdaysShort : 'ⴰⵙⴰⵎⴰⵙ_ⴰⵢⵏⴰⵙ_ⴰⵙⵉⵏⴰⵙ_ⴰⴽⵔⴰⵙ_ⴰⴽⵡⴰⵙ_ⴰⵙⵉⵎⵡⴰⵙ_ⴰⵙⵉⴹⵢⴰⵙ'.split('_'),
		weekdaysMin : 'ⴰⵙⴰⵎⴰⵙ_ⴰⵢⵏⴰⵙ_ⴰⵙⵉⵏⴰⵙ_ⴰⴽⵔⴰⵙ_ⴰⴽⵡⴰⵙ_ⴰⵙⵉⵎⵡⴰⵙ_ⴰⵙⵉⴹⵢⴰⵙ'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS: 'HH:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'dddd D MMMM YYYY HH:mm'
		},
		calendar : {
			sameDay: '[ⴰⵙⴷⵅ ⴴ] LT',
			nextDay: '[ⴰⵙⴽⴰ ⴴ] LT',
			nextWeek: 'dddd [ⴴ] LT',
			lastDay: '[ⴰⵚⴰⵏⵜ ⴴ] LT',
			lastWeek: 'dddd [ⴴ] LT',
			sameElse: 'L'
		},
		relativeTime : {
			future : 'ⴷⴰⴷⵅ ⵙ ⵢⴰⵏ %s',
			past : 'ⵢⴰⵏ %s',
			s : 'ⵉⵎⵉⴽ',
			m : 'ⵎⵉⵏⵓⴺ',
			mm : '%d ⵎⵉⵏⵓⴺ',
			h : 'ⵙⴰⵄⴰ',
			hh : '%d ⵜⴰⵙⵙⴰⵄⵉⵏ',
			d : 'ⴰⵙⵙ',
			dd : '%d oⵙⵙⴰⵏ',
			M : 'ⴰⵢoⵓⵔ',
			MM : '%d ⵉⵢⵢⵉⵔⵏ',
			y : 'ⴰⵙⴳⴰⵙ',
			yy : '%d ⵉⵙⴳⴰⵙⵏ'
		},
		week : {
			dow : 6, // Saturday is the first day of the week.
			doy : 12  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : ukrainian (uk)
	//! author : zemlanin : https://github.com/zemlanin
	//! Author : Menelion Elensúle : https://github.com/Oire

	function uk__plural(word, num) {
		var forms = word.split('_');
		return num % 10 === 1 && num % 100 !== 11 ? forms[0] : (num % 10 >= 2 && num % 10 <= 4 && (num % 100 < 10 || num % 100 >= 20) ? forms[1] : forms[2]);
	}
	function uk__relativeTimeWithPlural(number, withoutSuffix, key) {
		var format = {
			'mm': withoutSuffix ? 'хвилина_хвилини_хвилин' : 'хвилину_хвилини_хвилин',
			'hh': withoutSuffix ? 'година_години_годин' : 'годину_години_годин',
			'dd': 'день_дні_днів',
			'MM': 'місяць_місяці_місяців',
			'yy': 'рік_роки_років'
		};
		if (key === 'm') {
			return withoutSuffix ? 'хвилина' : 'хвилину';
		}
		else if (key === 'h') {
			return withoutSuffix ? 'година' : 'годину';
		}
		else {
			return number + ' ' + uk__plural(format[key], +number);
		}
	}
	function weekdaysCaseReplace(m, format) {
		var weekdays = {
			'nominative': 'неділя_понеділок_вівторок_середа_четвер_п’ятниця_субота'.split('_'),
			'accusative': 'неділю_понеділок_вівторок_середу_четвер_п’ятницю_суботу'.split('_'),
			'genitive': 'неділі_понеділка_вівторка_середи_четверга_п’ятниці_суботи'.split('_')
		},
		nounCase = (/(\[[ВвУу]\]) ?dddd/).test(format) ?
			'accusative' :
			((/\[?(?:минулої|наступної)? ?\] ?dddd/).test(format) ?
				'genitive' :
				'nominative');
		return weekdays[nounCase][m.day()];
	}
	function processHoursFunction(str) {
		return function () {
			return str + 'о' + (this.hours() === 11 ? 'б' : '') + '] LT';
		};
	}

	var uk = moment__default.defineLocale('uk', {
		months : {
			'format': 'січня_лютого_березня_квітня_травня_червня_липня_серпня_вересня_жовтня_листопада_грудня'.split('_'),
			'standalone': 'січень_лютий_березень_квітень_травень_червень_липень_серпень_вересень_жовтень_листопад_грудень'.split('_')
		},
		monthsShort : 'січ_лют_бер_квіт_трав_черв_лип_серп_вер_жовт_лист_груд'.split('_'),
		weekdays : weekdaysCaseReplace,
		weekdaysShort : 'нд_пн_вт_ср_чт_пт_сб'.split('_'),
		weekdaysMin : 'нд_пн_вт_ср_чт_пт_сб'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD.MM.YYYY',
			LL : 'D MMMM YYYY р.',
			LLL : 'D MMMM YYYY р., HH:mm',
			LLLL : 'dddd, D MMMM YYYY р., HH:mm'
		},
		calendar : {
			sameDay: processHoursFunction('[Сьогодні '),
			nextDay: processHoursFunction('[Завтра '),
			lastDay: processHoursFunction('[Вчора '),
			nextWeek: processHoursFunction('[У] dddd ['),
			lastWeek: function () {
				switch (this.day()) {
				case 0:
				case 3:
				case 5:
				case 6:
					return processHoursFunction('[Минулої] dddd [').call(this);
				case 1:
				case 2:
				case 4:
					return processHoursFunction('[Минулого] dddd [').call(this);
				}
			},
			sameElse: 'L'
		},
		relativeTime : {
			future : 'за %s',
			past : '%s тому',
			s : 'декілька секунд',
			m : uk__relativeTimeWithPlural,
			mm : uk__relativeTimeWithPlural,
			h : 'годину',
			hh : uk__relativeTimeWithPlural,
			d : 'день',
			dd : uk__relativeTimeWithPlural,
			M : 'місяць',
			MM : uk__relativeTimeWithPlural,
			y : 'рік',
			yy : uk__relativeTimeWithPlural
		},
		// M. E.: those two are virtually unused but a user might want to implement them for his/her website for some reason
		meridiemParse: /ночі|ранку|дня|вечора/,
		isPM: function (input) {
			return /^(дня|вечора)$/.test(input);
		},
		meridiem : function (hour, minute, isLower) {
			if (hour < 4) {
				return 'ночі';
			} else if (hour < 12) {
				return 'ранку';
			} else if (hour < 17) {
				return 'дня';
			} else {
				return 'вечора';
			}
		},
		ordinalParse: /\d{1,2}-(й|го)/,
		ordinal: function (number, period) {
			switch (period) {
			case 'M':
			case 'd':
			case 'DDD':
			case 'w':
			case 'W':
				return number + '-й';
			case 'D':
				return number + '-го';
			default:
				return number;
			}
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 1st is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : uzbek (uz)
	//! author : Sardor Muminov : https://github.com/muminoff

	var uz = moment__default.defineLocale('uz', {
		months : 'январ_феврал_март_апрел_май_июн_июл_август_сентябр_октябр_ноябр_декабр'.split('_'),
		monthsShort : 'янв_фев_мар_апр_май_июн_июл_авг_сен_окт_ноя_дек'.split('_'),
		weekdays : 'Якшанба_Душанба_Сешанба_Чоршанба_Пайшанба_Жума_Шанба'.split('_'),
		weekdaysShort : 'Якш_Душ_Сеш_Чор_Пай_Жум_Шан'.split('_'),
		weekdaysMin : 'Як_Ду_Се_Чо_Па_Жу_Ша'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM YYYY',
			LLL : 'D MMMM YYYY HH:mm',
			LLLL : 'D MMMM YYYY, dddd HH:mm'
		},
		calendar : {
			sameDay : '[Бугун соат] LT [да]',
			nextDay : '[Эртага] LT [да]',
			nextWeek : 'dddd [куни соат] LT [да]',
			lastDay : '[Кеча соат] LT [да]',
			lastWeek : '[Утган] dddd [куни соат] LT [да]',
			sameElse : 'L'
		},
		relativeTime : {
			future : 'Якин %s ичида',
			past : 'Бир неча %s олдин',
			s : 'фурсат',
			m : 'бир дакика',
			mm : '%d дакика',
			h : 'бир соат',
			hh : '%d соат',
			d : 'бир кун',
			dd : '%d кун',
			M : 'бир ой',
			MM : '%d ой',
			y : 'бир йил',
			yy : '%d йил'
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 7  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : vietnamese (vi)
	//! author : Bang Nguyen : https://github.com/bangnk

	var vi = moment__default.defineLocale('vi', {
		months : 'tháng 1_tháng 2_tháng 3_tháng 4_tháng 5_tháng 6_tháng 7_tháng 8_tháng 9_tháng 10_tháng 11_tháng 12'.split('_'),
		monthsShort : 'Th01_Th02_Th03_Th04_Th05_Th06_Th07_Th08_Th09_Th10_Th11_Th12'.split('_'),
		weekdays : 'chủ nhật_thứ hai_thứ ba_thứ tư_thứ năm_thứ sáu_thứ bảy'.split('_'),
		weekdaysShort : 'CN_T2_T3_T4_T5_T6_T7'.split('_'),
		weekdaysMin : 'CN_T2_T3_T4_T5_T6_T7'.split('_'),
		longDateFormat : {
			LT : 'HH:mm',
			LTS : 'HH:mm:ss',
			L : 'DD/MM/YYYY',
			LL : 'D MMMM [năm] YYYY',
			LLL : 'D MMMM [năm] YYYY HH:mm',
			LLLL : 'dddd, D MMMM [năm] YYYY HH:mm',
			l : 'DD/M/YYYY',
			ll : 'D MMM YYYY',
			lll : 'D MMM YYYY HH:mm',
			llll : 'ddd, D MMM YYYY HH:mm'
		},
		calendar : {
			sameDay: '[Hôm nay lúc] LT',
			nextDay: '[Ngày mai lúc] LT',
			nextWeek: 'dddd [tuần tới lúc] LT',
			lastDay: '[Hôm qua lúc] LT',
			lastWeek: 'dddd [tuần rồi lúc] LT',
			sameElse: 'L'
		},
		relativeTime : {
			future : '%s tới',
			past : '%s trước',
			s : 'vài giây',
			m : 'một phút',
			mm : '%d phút',
			h : 'một giờ',
			hh : '%d giờ',
			d : 'một ngày',
			dd : '%d ngày',
			M : 'một tháng',
			MM : '%d tháng',
			y : 'một năm',
			yy : '%d năm'
		},
		ordinalParse: /\d{1,2}/,
		ordinal : function (number) {
			return number;
		},
		week : {
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : chinese (zh-cn)
	//! author : suupic : https://github.com/suupic
	//! author : Zeno Zeng : https://github.com/zenozeng

	var zh_cn = moment__default.defineLocale('zh-cn', {
		months : '一月_二月_三月_四月_五月_六月_七月_八月_九月_十月_十一月_十二月'.split('_'),
		monthsShort : '1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月'.split('_'),
		weekdays : '星期日_星期一_星期二_星期三_星期四_星期五_星期六'.split('_'),
		weekdaysShort : '周日_周一_周二_周三_周四_周五_周六'.split('_'),
		weekdaysMin : '日_一_二_三_四_五_六'.split('_'),
		longDateFormat : {
			LT : 'Ah点mm分',
			LTS : 'Ah点m分s秒',
			L : 'YYYY-MM-DD',
			LL : 'YYYY年MMMD日',
			LLL : 'YYYY年MMMD日Ah点mm分',
			LLLL : 'YYYY年MMMD日ddddAh点mm分',
			l : 'YYYY-MM-DD',
			ll : 'YYYY年MMMD日',
			lll : 'YYYY年MMMD日Ah点mm分',
			llll : 'YYYY年MMMD日ddddAh点mm分'
		},
		meridiemParse: /凌晨|早上|上午|中午|下午|晚上/,
		meridiemHour: function (hour, meridiem) {
			if (hour === 12) {
				hour = 0;
			}
			if (meridiem === '凌晨' || meridiem === '早上' ||
					meridiem === '上午') {
				return hour;
			} else if (meridiem === '下午' || meridiem === '晚上') {
				return hour + 12;
			} else {
				// '中午'
				return hour >= 11 ? hour : hour + 12;
			}
		},
		meridiem : function (hour, minute, isLower) {
			var hm = hour * 100 + minute;
			if (hm < 600) {
				return '凌晨';
			} else if (hm < 900) {
				return '早上';
			} else if (hm < 1130) {
				return '上午';
			} else if (hm < 1230) {
				return '中午';
			} else if (hm < 1800) {
				return '下午';
			} else {
				return '晚上';
			}
		},
		calendar : {
			sameDay : function () {
				return this.minutes() === 0 ? '[今天]Ah[点整]' : '[今天]LT';
			},
			nextDay : function () {
				return this.minutes() === 0 ? '[明天]Ah[点整]' : '[明天]LT';
			},
			lastDay : function () {
				return this.minutes() === 0 ? '[昨天]Ah[点整]' : '[昨天]LT';
			},
			nextWeek : function () {
				var startOfWeek, prefix;
				startOfWeek = moment__default().startOf('week');
				prefix = this.unix() - startOfWeek.unix() >= 7 * 24 * 3600 ? '[下]' : '[本]';
				return this.minutes() === 0 ? prefix + 'dddAh点整' : prefix + 'dddAh点mm';
			},
			lastWeek : function () {
				var startOfWeek, prefix;
				startOfWeek = moment__default().startOf('week');
				prefix = this.unix() < startOfWeek.unix()  ? '[上]' : '[本]';
				return this.minutes() === 0 ? prefix + 'dddAh点整' : prefix + 'dddAh点mm';
			},
			sameElse : 'LL'
		},
		ordinalParse: /\d{1,2}(日|月|周)/,
		ordinal : function (number, period) {
			switch (period) {
			case 'd':
			case 'D':
			case 'DDD':
				return number + '日';
			case 'M':
				return number + '月';
			case 'w':
			case 'W':
				return number + '周';
			default:
				return number;
			}
		},
		relativeTime : {
			future : '%s内',
			past : '%s前',
			s : '几秒',
			m : '1 分钟',
			mm : '%d 分钟',
			h : '1 小时',
			hh : '%d 小时',
			d : '1 天',
			dd : '%d 天',
			M : '1 个月',
			MM : '%d 个月',
			y : '1 年',
			yy : '%d 年'
		},
		week : {
			// GB/T 7408-1994《数据元和交换格式·信息交换·日期和时间表示法》与ISO 8601:1988等效
			dow : 1, // Monday is the first day of the week.
			doy : 4  // The week that contains Jan 4th is the first week of the year.
		}
	});

	//! moment.js locale configuration
	//! locale : traditional chinese (zh-tw)
	//! author : Ben : https://github.com/ben-lin

	var zh_tw = moment__default.defineLocale('zh-tw', {
		months : '一月_二月_三月_四月_五月_六月_七月_八月_九月_十月_十一月_十二月'.split('_'),
		monthsShort : '1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月'.split('_'),
		weekdays : '星期日_星期一_星期二_星期三_星期四_星期五_星期六'.split('_'),
		weekdaysShort : '週日_週一_週二_週三_週四_週五_週六'.split('_'),
		weekdaysMin : '日_一_二_三_四_五_六'.split('_'),
		longDateFormat : {
			LT : 'Ah點mm分',
			LTS : 'Ah點m分s秒',
			L : 'YYYY年MMMD日',
			LL : 'YYYY年MMMD日',
			LLL : 'YYYY年MMMD日Ah點mm分',
			LLLL : 'YYYY年MMMD日ddddAh點mm分',
			l : 'YYYY年MMMD日',
			ll : 'YYYY年MMMD日',
			lll : 'YYYY年MMMD日Ah點mm分',
			llll : 'YYYY年MMMD日ddddAh點mm分'
		},
		meridiemParse: /早上|上午|中午|下午|晚上/,
		meridiemHour : function (hour, meridiem) {
			if (hour === 12) {
				hour = 0;
			}
			if (meridiem === '早上' || meridiem === '上午') {
				return hour;
			} else if (meridiem === '中午') {
				return hour >= 11 ? hour : hour + 12;
			} else if (meridiem === '下午' || meridiem === '晚上') {
				return hour + 12;
			}
		},
		meridiem : function (hour, minute, isLower) {
			var hm = hour * 100 + minute;
			if (hm < 900) {
				return '早上';
			} else if (hm < 1130) {
				return '上午';
			} else if (hm < 1230) {
				return '中午';
			} else if (hm < 1800) {
				return '下午';
			} else {
				return '晚上';
			}
		},
		calendar : {
			sameDay : '[今天]LT',
			nextDay : '[明天]LT',
			nextWeek : '[下]ddddLT',
			lastDay : '[昨天]LT',
			lastWeek : '[上]ddddLT',
			sameElse : 'L'
		},
		ordinalParse: /\d{1,2}(日|月|週)/,
		ordinal : function (number, period) {
			switch (period) {
			case 'd' :
			case 'D' :
			case 'DDD' :
				return number + '日';
			case 'M' :
				return number + '月';
			case 'w' :
			case 'W' :
				return number + '週';
			default :
				return number;
			}
		},
		relativeTime : {
			future : '%s內',
			past : '%s前',
			s : '幾秒',
			m : '一分鐘',
			mm : '%d分鐘',
			h : '一小時',
			hh : '%d小時',
			d : '一天',
			dd : '%d天',
			M : '一個月',
			MM : '%d個月',
			y : '一年',
			yy : '%d年'
		}
	});

	var moment_with_locales = moment__default;
	moment_with_locales.locale('en');

	return moment_with_locales;

}));
/**
 * The OAuth library
 */
define('oauth',["jquery", "lodash", "browser/api"], function($, _, Browser) {
	/**
	 * The client constructor
	 *
	 * @constructor
	 * @api    public
	 * @param  {Object}  config                  The configuration
	 * @param  {String}  config.name             The name this configuration can be referenced by
	 * @param  {String}  config.id               Client ID, as provided by the service
	 * @param  {String}  config.secret           Client secret, as provided by the service
	 * @param  {String}  [config.scope]          The scope of this client should be authenticated for, optional
	 * @param  {String}  [config.authURL]        The URL at the service to send the user to for approval, defaults to Google's configuration
	 * @param  {String}  [config.tokenURL]       The URL at the service that the token can be retrieved from, defaults to Google's configuration
	 * @param  {String}  [config.codeParam]      The parameter that the authorization code should be parsed from in the redirectURL, defaults to code
	 * @param  {String}  [config.tokenParams]    The parameters to be POSTed to the tokenURL to retrieve the access token, defaults to Google's configuration
	 * @param  {String}  [config.redirectURL]    The redirect URL to be provided to the service, defaults to ichro.me/auth
	 * @param  {String}  [config.refreshParams]  The parameters to be POSTed to the tokenURL to refresh the access token, defaults to Google's configuration
	 */
	var OAuth = function(config) {
		if (!config || !config.name || !config.id || !config.secret) {
			return "Invalid config";
		}

		this.config = _.assign({
			scope: null,
			codeParam: "code",
			authURL: "https://accounts.google.com/o/oauth2/auth?" +
				"approval_prompt=force&client_id={{clientID}}&redirect_uri={{redirectURL}}&scope={{scope}}&access_type=offline&response_type=code",
			tokenURL: "https://www.googleapis.com/oauth2/v3/token",
			tokenParams: "code={{code}}&client_id={{clientID}}&client_secret={{secret}}&redirect_uri={{redirectURL}}&grant_type=authorization_code",
			refreshParams: "client_id={{clientID}}&client_secret={{secret}}&refresh_token={{refreshToken}}&grant_type=refresh_token",
			redirectURL: "https://ichro.me/auth"
		}, config);

		this.data = {};
	};


	OAuth.prototype = {
		/**
		 * Returns the token from storage, if it's available and valid or starts
		 * the authentication process.
		 *
		 * @api     public
		 * @param   {Function}  cb      The callback
		 * @param   {Boolean}   silent  Whether or not to retreive the key silently, i.e. just check
		 */
		getToken: function(cb, silent) {
			if (!cb) {
				return;
			}

			if (!this.data.token) {
				this.loadStorage();
			}

			if (this.data.token) {
				if (new Date().getTime() >= this.data.expiry) {
					if (this.data.refreshToken) {
						this.refreshToken(cb);
					}
					else if (!silent) {
						this.startAuthFlow(cb);
					}
					else {
						cb(false);
					}
				}
				else {
					cb(this.data.token, this.data);
				}
			}
			else if (!silent) {
				this.startAuthFlow(cb);
			}
			else {
				cb(false);
			}
		},


		/**
		 * Returns a boolean indicating if a token exists under this configuration
		 *
		 * @api     public
		 * @return  {Boolean}  Whether or not a token exists under this configuration name
		 */
		hasToken: function() {
			if (!this.data.token) {
				this.loadStorage();

				if (!this.data.token) {
					return false;
				}
			}

			return true;
		},


		/**
		 * Loads any stored keys under this configuration's name from the
		 * browser's storage and updates this.data with any available data
		 *
		 * @api     private
		 * @return  {Object}  The data retreived from the browser's storage
		 */
		loadStorage: function() {
			var data = Browser.storage.oauth;

			if (!data) {
				return {};
			}
			else {
				data = JSON.parse(data);

				if (data[this.config.name]) {
					this.data = data[this.config.name];
				}

				return this.data;
			}
		},


		/**
		 * Saves this.data under the configuration name in the browser's storage
		 *
		 * @api     private
		 */
		saveStorage: function() {
			if (this.data && Object.keys(this.data).length) {
				var data = Browser.storage.oauth;

				if (data) {
					data = JSON.parse(data);
				}
				else {
					data = {};
				}

				data[this.config.name] = this.data;

				Browser.storage.oauth = JSON.stringify(data);
			}
		},


		/**
		 * Requests a new token from the server using the refresh token
		 *
		 * @api     private
		 * @param   {Function}  cb  The callback, called with `this`
		 */
		refreshToken: function(cb) {
			var params = this.config.refreshParams
				.replace("{{clientID}}", encodeURIComponent(this.config.id))
				.replace("{{secret}}", encodeURIComponent(this.config.secret))
				.replace("{{refreshToken}}", encodeURIComponent(this.data.refreshToken));


			$.post(this.config.tokenURL, params, function(d) {
				if (typeof d !== "object") {
					d = JSON.parse(d);
				}

				if (!d.error && d.access_token) {
					var data = {
						token: d.access_token,
						type: d.token_type || "Bearer",
						expiry: new Date().getTime() + ((d.expires_in || 315569259) * 1000) // Defaults to +10 years if unavailable
					};

					if (d.refresh_token) {
						data.refreshToken = d.refresh_token;
					}

					// Add any extra data that's been included to the object
					_.assign(data, _.omit(d, "token_type", "access_token", "expires_in", "refresh_token", "type", "token", "expiry", "refreshToken"));

					_.assign(this.data, data);

					this.saveStorage();

					cb.call(this, data.token, data);
				}
			}.bind(this));
		},


		/**
		 * The ID of the currently opened window, false if none exists or true if one is being created.
		 *
		 * This is used to stop multiple windows from being opened on top of each other.
		 *
		 * @type  {Boolean|Number}
		 */
		openWindow: false,


		/**
		 * Opens a panel at the config authURL, starting the authorization process
		 *
		 * @api     private
		 * @param   {Function}  cb  The callback, called with `this`
		 */
		startAuthFlow: function(cb) {
			var redirectURL = this.config.redirectURL
				.replace("{{name}}", encodeURIComponent(this.config.name));

			var url = this.config.authURL
				.replace("{{clientID}}", encodeURIComponent(this.config.id))
				.replace("{{scope}}", encodeURIComponent(this.config.scope || ""))
				.replace("{{redirectURL}}", encodeURIComponent(redirectURL));


			var that = this;

			var createWindow = function() {
				that.openWindow = true;

				Browser.windows.create({
					url: url,
					width: 560,
					height: 600,
					type: "normal",
					focused: true,
					top: Math.round((screen.availHeight - 600) / 2),
					left: Math.round((screen.availWidth - 560) / 2)
				}, function(win) {
					that.openWindow = win.id;

					Browser.webRequest.onBeforeRequest.addListener(
						function(info) {
							// Adapted from http://stackoverflow.com/a/3855394/900747
							var params = {},
								idx;

							_.each(new URL(info.url).search.substr(1).split("&"), function(e) {
								idx = e.indexOf("=");

								if (idx === -1) {
									params[e] = "";
								}
								else {
									params[e.substring(0, idx)] = decodeURIComponent(e.substr(idx + 1).replace(/\+/g, " "));
								}
							});


							if (params[this.config.codeParam]) {
								this.exchangeCode(params[this.config.codeParam], cb);
							}

							Browser.windows.remove(win.id);

							return {
								cancel: true
							};
						}.bind(that),
						{
							windowId: win.id,
							types: ["main_frame"],
							urls: [redirectURL + "*"]
						},
						["blocking"]
					);
				});
			};

			if (typeof this.openWindow === "number") {
				Browser.windows.get(this.openWindow, function(win) {
					if (Browser.runtime.lastError) {
						createWindow();
					}
					else {
						Browser.windows.update(win.id, { focused: true });
					}
				});
			}
			else if (this.openWindow === true) {
				return;
			}
			else {
				createWindow();
			}
		},


		/**
		 * Requests a token set from the tokenURL using the received code
		 *
		 * @api     private
		 * @param   {String}    code         The code received from the server
		 * @param   {Function}  cb           The callback, called with `this`
		 */
		exchangeCode: function(code, cb) {
			var params = this.config.tokenParams
				.replace("{{code}}", encodeURIComponent(code))
				.replace("{{clientID}}", encodeURIComponent(this.config.id))
				.replace("{{secret}}", encodeURIComponent(this.config.secret))
				.replace("{{redirectURL}}", encodeURIComponent(this.config.redirectURL
					.replace("{{name}}", encodeURIComponent(this.config.name)))
				);


			$.post(this.config.tokenURL, params, function(d) {
				if (typeof d !== "object") {
					d = JSON.parse(d);
				}

				if (!d.error && d.access_token) {
					var data = {
						token: d.access_token,
						type: d.token_type || "Bearer",
						expiry: new Date().getTime() + ((d.expires_in || 315569259) * 1000) // Defaults to +10 years if unavailable
					};

					if (d.refresh_token) {
						data.refreshToken = d.refresh_token;
					}

					// Add any extra data that's been included to the object
					_.assign(data, _.omit(d, "token_type", "access_token", "expires_in", "refresh_token", "type", "token", "expiry", "refreshToken"));

					this.data = data;

					this.saveStorage();

					cb.call(this, data.token, data);
				}
			}.bind(this));
		},


		/**
		 * Proxies jQuery.ajax, initializing the authorization process if necessary
		 * and adding an Authorization header containing the access token
		 *
		 * @api    public
		 * @param  {Object} config The configuration to be passed to jQuery.ajax.
		 *                         If a beforeSend function is specified it will be
		 *                         called _after_ the authorization header is added.
		 */
		ajax: function(config) {
			this.getToken(function(token, data) {
				if (config.beforeSend) {
					var oldBS = config.beforeSend;
				}

				config.beforeSend = function(xhr) {
					xhr.setRequestHeader("Authorization", ((data && data.type) || "Bearer") + " " + token);

					if (oldBS) {
						oldBS.apply(config, arguments);
					}
				};

				$.ajax(config);
			});
		}
	};

	return OAuth;
});
/*!
 * FullCalendar v3.9.0
 * Docs & License: https://fullcalendar.io/
 * (c) 2018 Adam Shaw
 */
(function webpackUniversalModuleDefinition(root, factory) {
	if(typeof exports === 'object' && typeof module === 'object')
		module.exports = factory(require("moment"), require("jquery"));
	else if(typeof define === 'function' && define.amd)
		define('fullcalendar',["moment", "jquery"], factory);
	else if(typeof exports === 'object')
		exports["FullCalendar"] = factory(require("moment"), require("jquery"));
	else
		root["FullCalendar"] = factory(root["moment"], root["jQuery"]);
})(typeof self !== 'undefined' ? self : this, function(__WEBPACK_EXTERNAL_MODULE_0__, __WEBPACK_EXTERNAL_MODULE_3__) {
return /******/ (function(modules) { // webpackBootstrap
/******/ 	// The module cache
/******/ 	var installedModules = {};
/******/
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/
/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId]) {
/******/ 			return installedModules[moduleId].exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			i: moduleId,
/******/ 			l: false,
/******/ 			exports: {}
/******/ 		};
/******/
/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/
/******/ 		// Flag the module as loaded
/******/ 		module.l = true;
/******/
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/
/******/
/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;
/******/
/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;
/******/
/******/ 	// define getter function for harmony exports
/******/ 	__webpack_require__.d = function(exports, name, getter) {
/******/ 		if(!__webpack_require__.o(exports, name)) {
/******/ 			Object.defineProperty(exports, name, {
/******/ 				configurable: false,
/******/ 				enumerable: true,
/******/ 				get: getter
/******/ 			});
/******/ 		}
/******/ 	};
/******/
/******/ 	// getDefaultExport function for compatibility with non-harmony modules
/******/ 	__webpack_require__.n = function(module) {
/******/ 		var getter = module && module.__esModule ?
/******/ 			function getDefault() { return module['default']; } :
/******/ 			function getModuleExports() { return module; };
/******/ 		__webpack_require__.d(getter, 'a', getter);
/******/ 		return getter;
/******/ 	};
/******/
/******/ 	// Object.prototype.hasOwnProperty.call
/******/ 	__webpack_require__.o = function(object, property) { return Object.prototype.hasOwnProperty.call(object, property); };
/******/
/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "";
/******/
/******/ 	// Load entry module and return exports
/******/ 	return __webpack_require__(__webpack_require__.s = 236);
/******/ })
/************************************************************************/
/******/ ([
/* 0 */
/***/ (function(module, exports) {

module.exports = __WEBPACK_EXTERNAL_MODULE_0__;

/***/ }),
/* 1 */,
/* 2 */
/***/ (function(module, exports) {

/*
derived from:
https://github.com/Microsoft/tslib/blob/v1.6.0/tslib.js

only include the helpers we need, to keep down filesize
*/
var extendStatics = Object.setPrototypeOf ||
    ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
    function (d, b) { for (var p in b)
        if (b.hasOwnProperty(p))
            d[p] = b[p]; };
exports.__extends = function (d, b) {
    extendStatics(d, b);
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};


/***/ }),
/* 3 */
/***/ (function(module, exports) {

module.exports = __WEBPACK_EXTERNAL_MODULE_3__;

/***/ }),
/* 4 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var moment = __webpack_require__(0);
var $ = __webpack_require__(3);
/* FullCalendar-specific DOM Utilities
----------------------------------------------------------------------------------------------------------------------*/
// Given the scrollbar widths of some other container, create borders/margins on rowEls in order to match the left
// and right space that was offset by the scrollbars. A 1-pixel border first, then margin beyond that.
function compensateScroll(rowEls, scrollbarWidths) {
    if (scrollbarWidths.left) {
        rowEls.css({
            'border-left-width': 1,
            'margin-left': scrollbarWidths.left - 1
        });
    }
    if (scrollbarWidths.right) {
        rowEls.css({
            'border-right-width': 1,
            'margin-right': scrollbarWidths.right - 1
        });
    }
}
exports.compensateScroll = compensateScroll;
// Undoes compensateScroll and restores all borders/margins
function uncompensateScroll(rowEls) {
    rowEls.css({
        'margin-left': '',
        'margin-right': '',
        'border-left-width': '',
        'border-right-width': ''
    });
}
exports.uncompensateScroll = uncompensateScroll;
// Make the mouse cursor express that an event is not allowed in the current area
function disableCursor() {
    $('body').addClass('fc-not-allowed');
}
exports.disableCursor = disableCursor;
// Returns the mouse cursor to its original look
function enableCursor() {
    $('body').removeClass('fc-not-allowed');
}
exports.enableCursor = enableCursor;
// Given a total available height to fill, have `els` (essentially child rows) expand to accomodate.
// By default, all elements that are shorter than the recommended height are expanded uniformly, not considering
// any other els that are already too tall. if `shouldRedistribute` is on, it considers these tall rows and
// reduces the available height.
function distributeHeight(els, availableHeight, shouldRedistribute) {
    // *FLOORING NOTE*: we floor in certain places because zoom can give inaccurate floating-point dimensions,
    // and it is better to be shorter than taller, to avoid creating unnecessary scrollbars.
    var minOffset1 = Math.floor(availableHeight / els.length); // for non-last element
    var minOffset2 = Math.floor(availableHeight - minOffset1 * (els.length - 1)); // for last element *FLOORING NOTE*
    var flexEls = []; // elements that are allowed to expand. array of DOM nodes
    var flexOffsets = []; // amount of vertical space it takes up
    var flexHeights = []; // actual css height
    var usedHeight = 0;
    undistributeHeight(els); // give all elements their natural height
    // find elements that are below the recommended height (expandable).
    // important to query for heights in a single first pass (to avoid reflow oscillation).
    els.each(function (i, el) {
        var minOffset = i === els.length - 1 ? minOffset2 : minOffset1;
        var naturalOffset = $(el).outerHeight(true);
        if (naturalOffset < minOffset) {
            flexEls.push(el);
            flexOffsets.push(naturalOffset);
            flexHeights.push($(el).height());
        }
        else {
            // this element stretches past recommended height (non-expandable). mark the space as occupied.
            usedHeight += naturalOffset;
        }
    });
    // readjust the recommended height to only consider the height available to non-maxed-out rows.
    if (shouldRedistribute) {
        availableHeight -= usedHeight;
        minOffset1 = Math.floor(availableHeight / flexEls.length);
        minOffset2 = Math.floor(availableHeight - minOffset1 * (flexEls.length - 1)); // *FLOORING NOTE*
    }
    // assign heights to all expandable elements
    $(flexEls).each(function (i, el) {
        var minOffset = i === flexEls.length - 1 ? minOffset2 : minOffset1;
        var naturalOffset = flexOffsets[i];
        var naturalHeight = flexHeights[i];
        var newHeight = minOffset - (naturalOffset - naturalHeight); // subtract the margin/padding
        if (naturalOffset < minOffset) {
            $(el).height(newHeight);
        }
    });
}
exports.distributeHeight = distributeHeight;
// Undoes distrubuteHeight, restoring all els to their natural height
function undistributeHeight(els) {
    els.height('');
}
exports.undistributeHeight = undistributeHeight;
// Given `els`, a jQuery set of <td> cells, find the cell with the largest natural width and set the widths of all the
// cells to be that width.
// PREREQUISITE: if you want a cell to take up width, it needs to have a single inner element w/ display:inline
function matchCellWidths(els) {
    var maxInnerWidth = 0;
    els.find('> *').each(function (i, innerEl) {
        var innerWidth = $(innerEl).outerWidth();
        if (innerWidth > maxInnerWidth) {
            maxInnerWidth = innerWidth;
        }
    });
    maxInnerWidth++; // sometimes not accurate of width the text needs to stay on one line. insurance
    els.width(maxInnerWidth);
    return maxInnerWidth;
}
exports.matchCellWidths = matchCellWidths;
// Given one element that resides inside another,
// Subtracts the height of the inner element from the outer element.
function subtractInnerElHeight(outerEl, innerEl) {
    var both = outerEl.add(innerEl);
    var diff;
    // effin' IE8/9/10/11 sometimes returns 0 for dimensions. this weird hack was the only thing that worked
    both.css({
        position: 'relative',
        left: -1 // ensure reflow in case the el was already relative. negative is less likely to cause new scroll
    });
    diff = outerEl.outerHeight() - innerEl.outerHeight(); // grab the dimensions
    both.css({ position: '', left: '' }); // undo hack
    return diff;
}
exports.subtractInnerElHeight = subtractInnerElHeight;
/* Element Geom Utilities
----------------------------------------------------------------------------------------------------------------------*/
// borrowed from https://github.com/jquery/jquery-ui/blob/1.11.0/ui/core.js#L51
function getScrollParent(el) {
    var position = el.css('position');
    var scrollParent = el.parents().filter(function () {
        var parent = $(this);
        return (/(auto|scroll)/).test(parent.css('overflow') + parent.css('overflow-y') + parent.css('overflow-x'));
    }).eq(0);
    return position === 'fixed' || !scrollParent.length ? $(el[0].ownerDocument || document) : scrollParent;
}
exports.getScrollParent = getScrollParent;
// Queries the outer bounding area of a jQuery element.
// Returns a rectangle with absolute coordinates: left, right (exclusive), top, bottom (exclusive).
// Origin is optional.
function getOuterRect(el, origin) {
    var offset = el.offset();
    var left = offset.left - (origin ? origin.left : 0);
    var top = offset.top - (origin ? origin.top : 0);
    return {
        left: left,
        right: left + el.outerWidth(),
        top: top,
        bottom: top + el.outerHeight()
    };
}
exports.getOuterRect = getOuterRect;
// Queries the area within the margin/border/scrollbars of a jQuery element. Does not go within the padding.
// Returns a rectangle with absolute coordinates: left, right (exclusive), top, bottom (exclusive).
// Origin is optional.
// WARNING: given element can't have borders
// NOTE: should use clientLeft/clientTop, but very unreliable cross-browser.
function getClientRect(el, origin) {
    var offset = el.offset();
    var scrollbarWidths = getScrollbarWidths(el);
    var left = offset.left + getCssFloat(el, 'border-left-width') + scrollbarWidths.left - (origin ? origin.left : 0);
    var top = offset.top + getCssFloat(el, 'border-top-width') + scrollbarWidths.top - (origin ? origin.top : 0);
    return {
        left: left,
        right: left + el[0].clientWidth,
        top: top,
        bottom: top + el[0].clientHeight // clientHeight includes padding but NOT scrollbars
    };
}
exports.getClientRect = getClientRect;
// Queries the area within the margin/border/padding of a jQuery element. Assumed not to have scrollbars.
// Returns a rectangle with absolute coordinates: left, right (exclusive), top, bottom (exclusive).
// Origin is optional.
function getContentRect(el, origin) {
    var offset = el.offset(); // just outside of border, margin not included
    var left = offset.left + getCssFloat(el, 'border-left-width') + getCssFloat(el, 'padding-left') -
        (origin ? origin.left : 0);
    var top = offset.top + getCssFloat(el, 'border-top-width') + getCssFloat(el, 'padding-top') -
        (origin ? origin.top : 0);
    return {
        left: left,
        right: left + el.width(),
        top: top,
        bottom: top + el.height()
    };
}
exports.getContentRect = getContentRect;
// Returns the computed left/right/top/bottom scrollbar widths for the given jQuery element.
// WARNING: given element can't have borders (which will cause offsetWidth/offsetHeight to be larger).
// NOTE: should use clientLeft/clientTop, but very unreliable cross-browser.
function getScrollbarWidths(el) {
    var leftRightWidth = el[0].offsetWidth - el[0].clientWidth;
    var bottomWidth = el[0].offsetHeight - el[0].clientHeight;
    var widths;
    leftRightWidth = sanitizeScrollbarWidth(leftRightWidth);
    bottomWidth = sanitizeScrollbarWidth(bottomWidth);
    widths = { left: 0, right: 0, top: 0, bottom: bottomWidth };
    if (getIsLeftRtlScrollbars() && el.css('direction') === 'rtl') {
        widths.left = leftRightWidth;
    }
    else {
        widths.right = leftRightWidth;
    }
    return widths;
}
exports.getScrollbarWidths = getScrollbarWidths;
// The scrollbar width computations in getScrollbarWidths are sometimes flawed when it comes to
// retina displays, rounding, and IE11. Massage them into a usable value.
function sanitizeScrollbarWidth(width) {
    width = Math.max(0, width); // no negatives
    width = Math.round(width);
    return width;
}
// Logic for determining if, when the element is right-to-left, the scrollbar appears on the left side
var _isLeftRtlScrollbars = null;
function getIsLeftRtlScrollbars() {
    if (_isLeftRtlScrollbars === null) {
        _isLeftRtlScrollbars = computeIsLeftRtlScrollbars();
    }
    return _isLeftRtlScrollbars;
}
function computeIsLeftRtlScrollbars() {
    var el = $('<div><div/></div>')
        .css({
        position: 'absolute',
        top: -1000,
        left: 0,
        border: 0,
        padding: 0,
        overflow: 'scroll',
        direction: 'rtl'
    })
        .appendTo('body');
    var innerEl = el.children();
    var res = innerEl.offset().left > el.offset().left; // is the inner div shifted to accommodate a left scrollbar?
    el.remove();
    return res;
}
// Retrieves a jQuery element's computed CSS value as a floating-point number.
// If the queried value is non-numeric (ex: IE can return "medium" for border width), will just return zero.
function getCssFloat(el, prop) {
    return parseFloat(el.css(prop)) || 0;
}
/* Mouse / Touch Utilities
----------------------------------------------------------------------------------------------------------------------*/
// Returns a boolean whether this was a left mouse click and no ctrl key (which means right click on Mac)
function isPrimaryMouseButton(ev) {
    return ev.which === 1 && !ev.ctrlKey;
}
exports.isPrimaryMouseButton = isPrimaryMouseButton;
function getEvX(ev) {
    var touches = ev.originalEvent.touches;
    // on mobile FF, pageX for touch events is present, but incorrect,
    // so, look at touch coordinates first.
    if (touches && touches.length) {
        return touches[0].pageX;
    }
    return ev.pageX;
}
exports.getEvX = getEvX;
function getEvY(ev) {
    var touches = ev.originalEvent.touches;
    // on mobile FF, pageX for touch events is present, but incorrect,
    // so, look at touch coordinates first.
    if (touches && touches.length) {
        return touches[0].pageY;
    }
    return ev.pageY;
}
exports.getEvY = getEvY;
function getEvIsTouch(ev) {
    return /^touch/.test(ev.type);
}
exports.getEvIsTouch = getEvIsTouch;
function preventSelection(el) {
    el.addClass('fc-unselectable')
        .on('selectstart', preventDefault);
}
exports.preventSelection = preventSelection;
function allowSelection(el) {
    el.removeClass('fc-unselectable')
        .off('selectstart', preventDefault);
}
exports.allowSelection = allowSelection;
// Stops a mouse/touch event from doing it's native browser action
function preventDefault(ev) {
    ev.preventDefault();
}
exports.preventDefault = preventDefault;
/* General Geometry Utils
----------------------------------------------------------------------------------------------------------------------*/
// Returns a new rectangle that is the intersection of the two rectangles. If they don't intersect, returns false
function intersectRects(rect1, rect2) {
    var res = {
        left: Math.max(rect1.left, rect2.left),
        right: Math.min(rect1.right, rect2.right),
        top: Math.max(rect1.top, rect2.top),
        bottom: Math.min(rect1.bottom, rect2.bottom)
    };
    if (res.left < res.right && res.top < res.bottom) {
        return res;
    }
    return false;
}
exports.intersectRects = intersectRects;
// Returns a new point that will have been moved to reside within the given rectangle
function constrainPoint(point, rect) {
    return {
        left: Math.min(Math.max(point.left, rect.left), rect.right),
        top: Math.min(Math.max(point.top, rect.top), rect.bottom)
    };
}
exports.constrainPoint = constrainPoint;
// Returns a point that is the center of the given rectangle
function getRectCenter(rect) {
    return {
        left: (rect.left + rect.right) / 2,
        top: (rect.top + rect.bottom) / 2
    };
}
exports.getRectCenter = getRectCenter;
// Subtracts point2's coordinates from point1's coordinates, returning a delta
function diffPoints(point1, point2) {
    return {
        left: point1.left - point2.left,
        top: point1.top - point2.top
    };
}
exports.diffPoints = diffPoints;
/* Object Ordering by Field
----------------------------------------------------------------------------------------------------------------------*/
function parseFieldSpecs(input) {
    var specs = [];
    var tokens = [];
    var i;
    var token;
    if (typeof input === 'string') {
        tokens = input.split(/\s*,\s*/);
    }
    else if (typeof input === 'function') {
        tokens = [input];
    }
    else if ($.isArray(input)) {
        tokens = input;
    }
    for (i = 0; i < tokens.length; i++) {
        token = tokens[i];
        if (typeof token === 'string') {
            specs.push(token.charAt(0) === '-' ?
                { field: token.substring(1), order: -1 } :
                { field: token, order: 1 });
        }
        else if (typeof token === 'function') {
            specs.push({ func: token });
        }
    }
    return specs;
}
exports.parseFieldSpecs = parseFieldSpecs;
function compareByFieldSpecs(obj1, obj2, fieldSpecs, obj1fallback, obj2fallback) {
    var i;
    var cmp;
    for (i = 0; i < fieldSpecs.length; i++) {
        cmp = compareByFieldSpec(obj1, obj2, fieldSpecs[i], obj1fallback, obj2fallback);
        if (cmp) {
            return cmp;
        }
    }
    return 0;
}
exports.compareByFieldSpecs = compareByFieldSpecs;
function compareByFieldSpec(obj1, obj2, fieldSpec, obj1fallback, obj2fallback) {
    if (fieldSpec.func) {
        return fieldSpec.func(obj1, obj2);
    }
    var val1 = obj1[fieldSpec.field];
    var val2 = obj2[fieldSpec.field];
    if (val1 == null && obj1fallback) {
        val1 = obj1fallback[fieldSpec.field];
    }
    if (val2 == null && obj2fallback) {
        val2 = obj2fallback[fieldSpec.field];
    }
    return flexibleCompare(val1, val2) * (fieldSpec.order || 1);
}
exports.compareByFieldSpec = compareByFieldSpec;
function flexibleCompare(a, b) {
    if (!a && !b) {
        return 0;
    }
    if (b == null) {
        return -1;
    }
    if (a == null) {
        return 1;
    }
    if ($.type(a) === 'string' || $.type(b) === 'string') {
        return String(a).localeCompare(String(b));
    }
    return a - b;
}
exports.flexibleCompare = flexibleCompare;
/* Date Utilities
----------------------------------------------------------------------------------------------------------------------*/
exports.dayIDs = ['sun', 'mon', 'tue', 'wed', 'thu', 'fri', 'sat'];
exports.unitsDesc = ['year', 'month', 'week', 'day', 'hour', 'minute', 'second', 'millisecond']; // descending
// Diffs the two moments into a Duration where full-days are recorded first, then the remaining time.
// Moments will have their timezones normalized.
function diffDayTime(a, b) {
    return moment.duration({
        days: a.clone().stripTime().diff(b.clone().stripTime(), 'days'),
        ms: a.time() - b.time() // time-of-day from day start. disregards timezone
    });
}
exports.diffDayTime = diffDayTime;
// Diffs the two moments via their start-of-day (regardless of timezone). Produces whole-day durations.
function diffDay(a, b) {
    return moment.duration({
        days: a.clone().stripTime().diff(b.clone().stripTime(), 'days')
    });
}
exports.diffDay = diffDay;
// Diffs two moments, producing a duration, made of a whole-unit-increment of the given unit. Uses rounding.
function diffByUnit(a, b, unit) {
    return moment.duration(Math.round(a.diff(b, unit, true)), // returnFloat=true
    unit);
}
exports.diffByUnit = diffByUnit;
// Computes the unit name of the largest whole-unit period of time.
// For example, 48 hours will be "days" whereas 49 hours will be "hours".
// Accepts start/end, a range object, or an original duration object.
function computeGreatestUnit(start, end) {
    var i;
    var unit;
    var val;
    for (i = 0; i < exports.unitsDesc.length; i++) {
        unit = exports.unitsDesc[i];
        val = computeRangeAs(unit, start, end);
        if (val >= 1 && isInt(val)) {
            break;
        }
    }
    return unit; // will be "milliseconds" if nothing else matches
}
exports.computeGreatestUnit = computeGreatestUnit;
// like computeGreatestUnit, but has special abilities to interpret the source input for clues
function computeDurationGreatestUnit(duration, durationInput) {
    var unit = computeGreatestUnit(duration);
    // prevent days:7 from being interpreted as a week
    if (unit === 'week' && typeof durationInput === 'object' && durationInput.days) {
        unit = 'day';
    }
    return unit;
}
exports.computeDurationGreatestUnit = computeDurationGreatestUnit;
// Computes the number of units (like "hours") in the given range.
// Range can be a {start,end} object, separate start/end args, or a Duration.
// Results are based on Moment's .as() and .diff() methods, so results can depend on internal handling
// of month-diffing logic (which tends to vary from version to version).
function computeRangeAs(unit, start, end) {
    if (end != null) {
        return end.diff(start, unit, true);
    }
    else if (moment.isDuration(start)) {
        return start.as(unit);
    }
    else {
        return start.end.diff(start.start, unit, true);
    }
}
// Intelligently divides a range (specified by a start/end params) by a duration
function divideRangeByDuration(start, end, dur) {
    var months;
    if (durationHasTime(dur)) {
        return (end - start) / dur;
    }
    months = dur.asMonths();
    if (Math.abs(months) >= 1 && isInt(months)) {
        return end.diff(start, 'months', true) / months;
    }
    return end.diff(start, 'days', true) / dur.asDays();
}
exports.divideRangeByDuration = divideRangeByDuration;
// Intelligently divides one duration by another
function divideDurationByDuration(dur1, dur2) {
    var months1;
    var months2;
    if (durationHasTime(dur1) || durationHasTime(dur2)) {
        return dur1 / dur2;
    }
    months1 = dur1.asMonths();
    months2 = dur2.asMonths();
    if (Math.abs(months1) >= 1 && isInt(months1) &&
        Math.abs(months2) >= 1 && isInt(months2)) {
        return months1 / months2;
    }
    return dur1.asDays() / dur2.asDays();
}
exports.divideDurationByDuration = divideDurationByDuration;
// Intelligently multiplies a duration by a number
function multiplyDuration(dur, n) {
    var months;
    if (durationHasTime(dur)) {
        return moment.duration(dur * n);
    }
    months = dur.asMonths();
    if (Math.abs(months) >= 1 && isInt(months)) {
        return moment.duration({ months: months * n });
    }
    return moment.duration({ days: dur.asDays() * n });
}
exports.multiplyDuration = multiplyDuration;
// Returns a boolean about whether the given duration has any time parts (hours/minutes/seconds/ms)
function durationHasTime(dur) {
    return Boolean(dur.hours() || dur.minutes() || dur.seconds() || dur.milliseconds());
}
exports.durationHasTime = durationHasTime;
function isNativeDate(input) {
    return Object.prototype.toString.call(input) === '[object Date]' || input instanceof Date;
}
exports.isNativeDate = isNativeDate;
// Returns a boolean about whether the given input is a time string, like "06:40:00" or "06:00"
function isTimeString(str) {
    return typeof str === 'string' &&
        /^\d+\:\d+(?:\:\d+\.?(?:\d{3})?)?$/.test(str);
}
exports.isTimeString = isTimeString;
/* Logging and Debug
----------------------------------------------------------------------------------------------------------------------*/
function log() {
    var args = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
    }
    var console = window.console;
    if (console && console.log) {
        return console.log.apply(console, args);
    }
}
exports.log = log;
function warn() {
    var args = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
    }
    var console = window.console;
    if (console && console.warn) {
        return console.warn.apply(console, args);
    }
    else {
        return log.apply(null, args);
    }
}
exports.warn = warn;
/* General Utilities
----------------------------------------------------------------------------------------------------------------------*/
var hasOwnPropMethod = {}.hasOwnProperty;
// Merges an array of objects into a single object.
// The second argument allows for an array of property names who's object values will be merged together.
function mergeProps(propObjs, complexProps) {
    var dest = {};
    var i;
    var name;
    var complexObjs;
    var j;
    var val;
    var props;
    if (complexProps) {
        for (i = 0; i < complexProps.length; i++) {
            name = complexProps[i];
            complexObjs = [];
            // collect the trailing object values, stopping when a non-object is discovered
            for (j = propObjs.length - 1; j >= 0; j--) {
                val = propObjs[j][name];
                if (typeof val === 'object') {
                    complexObjs.unshift(val);
                }
                else if (val !== undefined) {
                    dest[name] = val; // if there were no objects, this value will be used
                    break;
                }
            }
            // if the trailing values were objects, use the merged value
            if (complexObjs.length) {
                dest[name] = mergeProps(complexObjs);
            }
        }
    }
    // copy values into the destination, going from last to first
    for (i = propObjs.length - 1; i >= 0; i--) {
        props = propObjs[i];
        for (name in props) {
            if (!(name in dest)) {
                dest[name] = props[name];
            }
        }
    }
    return dest;
}
exports.mergeProps = mergeProps;
function copyOwnProps(src, dest) {
    for (var name_1 in src) {
        if (hasOwnProp(src, name_1)) {
            dest[name_1] = src[name_1];
        }
    }
}
exports.copyOwnProps = copyOwnProps;
function hasOwnProp(obj, name) {
    return hasOwnPropMethod.call(obj, name);
}
exports.hasOwnProp = hasOwnProp;
function applyAll(functions, thisObj, args) {
    if ($.isFunction(functions)) {
        functions = [functions];
    }
    if (functions) {
        var i = void 0;
        var ret = void 0;
        for (i = 0; i < functions.length; i++) {
            ret = functions[i].apply(thisObj, args) || ret;
        }
        return ret;
    }
}
exports.applyAll = applyAll;
function removeMatching(array, testFunc) {
    var removeCnt = 0;
    var i = 0;
    while (i < array.length) {
        if (testFunc(array[i])) {
            array.splice(i, 1);
            removeCnt++;
        }
        else {
            i++;
        }
    }
    return removeCnt;
}
exports.removeMatching = removeMatching;
function removeExact(array, exactVal) {
    var removeCnt = 0;
    var i = 0;
    while (i < array.length) {
        if (array[i] === exactVal) {
            array.splice(i, 1);
            removeCnt++;
        }
        else {
            i++;
        }
    }
    return removeCnt;
}
exports.removeExact = removeExact;
function isArraysEqual(a0, a1) {
    var len = a0.length;
    var i;
    if (len == null || len !== a1.length) {
        return false;
    }
    for (i = 0; i < len; i++) {
        if (a0[i] !== a1[i]) {
            return false;
        }
    }
    return true;
}
exports.isArraysEqual = isArraysEqual;
function firstDefined() {
    var args = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
    }
    for (var i = 0; i < args.length; i++) {
        if (args[i] !== undefined) {
            return args[i];
        }
    }
}
exports.firstDefined = firstDefined;
function htmlEscape(s) {
    return (s + '').replace(/&/g, '&amp;')
        .replace(/</g, '&lt;')
        .replace(/>/g, '&gt;')
        .replace(/'/g, '&#039;')
        .replace(/"/g, '&quot;')
        .replace(/\n/g, '<br />');
}
exports.htmlEscape = htmlEscape;
function stripHtmlEntities(text) {
    return text.replace(/&.*?;/g, '');
}
exports.stripHtmlEntities = stripHtmlEntities;
// Given a hash of CSS properties, returns a string of CSS.
// Uses property names as-is (no camel-case conversion). Will not make statements for null/undefined values.
function cssToStr(cssProps) {
    var statements = [];
    $.each(cssProps, function (name, val) {
        if (val != null) {
            statements.push(name + ':' + val);
        }
    });
    return statements.join(';');
}
exports.cssToStr = cssToStr;
// Given an object hash of HTML attribute names to values,
// generates a string that can be injected between < > in HTML
function attrsToStr(attrs) {
    var parts = [];
    $.each(attrs, function (name, val) {
        if (val != null) {
            parts.push(name + '="' + htmlEscape(val) + '"');
        }
    });
    return parts.join(' ');
}
exports.attrsToStr = attrsToStr;
function capitaliseFirstLetter(str) {
    return str.charAt(0).toUpperCase() + str.slice(1);
}
exports.capitaliseFirstLetter = capitaliseFirstLetter;
function compareNumbers(a, b) {
    return a - b;
}
exports.compareNumbers = compareNumbers;
function isInt(n) {
    return n % 1 === 0;
}
exports.isInt = isInt;
// Returns a method bound to the given object context.
// Just like one of the jQuery.proxy signatures, but without the undesired behavior of treating the same method with
// different contexts as identical when binding/unbinding events.
function proxy(obj, methodName) {
    var method = obj[methodName];
    return function () {
        return method.apply(obj, arguments);
    };
}
exports.proxy = proxy;
// Returns a function, that, as long as it continues to be invoked, will not
// be triggered. The function will be called after it stops being called for
// N milliseconds. If `immediate` is passed, trigger the function on the
// leading edge, instead of the trailing.
// https://github.com/jashkenas/underscore/blob/1.6.0/underscore.js#L714
function debounce(func, wait, immediate) {
    if (immediate === void 0) { immediate = false; }
    var timeout;
    var args;
    var context;
    var timestamp;
    var result;
    var later = function () {
        var last = +new Date() - timestamp;
        if (last < wait) {
            timeout = setTimeout(later, wait - last);
        }
        else {
            timeout = null;
            if (!immediate) {
                result = func.apply(context, args);
                context = args = null;
            }
        }
    };
    return function () {
        context = this;
        args = arguments;
        timestamp = +new Date();
        var callNow = immediate && !timeout;
        if (!timeout) {
            timeout = setTimeout(later, wait);
        }
        if (callNow) {
            result = func.apply(context, args);
            context = args = null;
        }
        return result;
    };
}
exports.debounce = debounce;


/***/ }),
/* 5 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var moment = __webpack_require__(0);
var moment_ext_1 = __webpack_require__(10);
var UnzonedRange = /** @class */ (function () {
    function UnzonedRange(startInput, endInput) {
        // TODO: move these into footprint.
        // Especially, doesn't make sense for null startMs/endMs.
        this.isStart = true;
        this.isEnd = true;
        if (moment.isMoment(startInput)) {
            startInput = startInput.clone().stripZone();
        }
        if (moment.isMoment(endInput)) {
            endInput = endInput.clone().stripZone();
        }
        if (startInput) {
            this.startMs = startInput.valueOf();
        }
        if (endInput) {
            this.endMs = endInput.valueOf();
        }
    }
    /*
    SIDEEFFECT: will mutate eventRanges.
    Will return a new array result.
    Only works for non-open-ended ranges.
    */
    UnzonedRange.invertRanges = function (ranges, constraintRange) {
        var invertedRanges = [];
        var startMs = constraintRange.startMs; // the end of the previous range. the start of the new range
        var i;
        var dateRange;
        // ranges need to be in order. required for our date-walking algorithm
        ranges.sort(compareUnzonedRanges);
        for (i = 0; i < ranges.length; i++) {
            dateRange = ranges[i];
            // add the span of time before the event (if there is any)
            if (dateRange.startMs > startMs) {
                invertedRanges.push(new UnzonedRange(startMs, dateRange.startMs));
            }
            if (dateRange.endMs > startMs) {
                startMs = dateRange.endMs;
            }
        }
        // add the span of time after the last event (if there is any)
        if (startMs < constraintRange.endMs) {
            invertedRanges.push(new UnzonedRange(startMs, constraintRange.endMs));
        }
        return invertedRanges;
    };
    UnzonedRange.prototype.intersect = function (otherRange) {
        var startMs = this.startMs;
        var endMs = this.endMs;
        var newRange = null;
        if (otherRange.startMs != null) {
            if (startMs == null) {
                startMs = otherRange.startMs;
            }
            else {
                startMs = Math.max(startMs, otherRange.startMs);
            }
        }
        if (otherRange.endMs != null) {
            if (endMs == null) {
                endMs = otherRange.endMs;
            }
            else {
                endMs = Math.min(endMs, otherRange.endMs);
            }
        }
        if (startMs == null || endMs == null || startMs < endMs) {
            newRange = new UnzonedRange(startMs, endMs);
            newRange.isStart = this.isStart && startMs === this.startMs;
            newRange.isEnd = this.isEnd && endMs === this.endMs;
        }
        return newRange;
    };
    UnzonedRange.prototype.intersectsWith = function (otherRange) {
        return (this.endMs == null || otherRange.startMs == null || this.endMs > otherRange.startMs) &&
            (this.startMs == null || otherRange.endMs == null || this.startMs < otherRange.endMs);
    };
    UnzonedRange.prototype.containsRange = function (innerRange) {
        return (this.startMs == null || (innerRange.startMs != null && innerRange.startMs >= this.startMs)) &&
            (this.endMs == null || (innerRange.endMs != null && innerRange.endMs <= this.endMs));
    };
    // `date` can be a moment, a Date, or a millisecond time.
    UnzonedRange.prototype.containsDate = function (date) {
        var ms = date.valueOf();
        return (this.startMs == null || ms >= this.startMs) &&
            (this.endMs == null || ms < this.endMs);
    };
    // If the given date is not within the given range, move it inside.
    // (If it's past the end, make it one millisecond before the end).
    // `date` can be a moment, a Date, or a millisecond time.
    // Returns a MS-time.
    UnzonedRange.prototype.constrainDate = function (date) {
        var ms = date.valueOf();
        if (this.startMs != null && ms < this.startMs) {
            ms = this.startMs;
        }
        if (this.endMs != null && ms >= this.endMs) {
            ms = this.endMs - 1;
        }
        return ms;
    };
    UnzonedRange.prototype.equals = function (otherRange) {
        return this.startMs === otherRange.startMs && this.endMs === otherRange.endMs;
    };
    UnzonedRange.prototype.clone = function () {
        var range = new UnzonedRange(this.startMs, this.endMs);
        range.isStart = this.isStart;
        range.isEnd = this.isEnd;
        return range;
    };
    // Returns an ambig-zoned moment from startMs.
    // BEWARE: returned moment is not localized.
    // Formatting and start-of-week will be default.
    UnzonedRange.prototype.getStart = function () {
        if (this.startMs != null) {
            return moment_ext_1.default.utc(this.startMs).stripZone();
        }
        return null;
    };
    // Returns an ambig-zoned moment from startMs.
    // BEWARE: returned moment is not localized.
    // Formatting and start-of-week will be default.
    UnzonedRange.prototype.getEnd = function () {
        if (this.endMs != null) {
            return moment_ext_1.default.utc(this.endMs).stripZone();
        }
        return null;
    };
    UnzonedRange.prototype.as = function (unit) {
        return moment.utc(this.endMs).diff(moment.utc(this.startMs), unit, true);
    };
    return UnzonedRange;
}());
exports.default = UnzonedRange;
/*
Only works for non-open-ended ranges.
*/
function compareUnzonedRanges(range1, range2) {
    return range1.startMs - range2.startMs; // earlier ranges go first
}


/***/ }),
/* 6 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var $ = __webpack_require__(3);
var ParsableModelMixin_1 = __webpack_require__(208);
var Class_1 = __webpack_require__(33);
var EventDefParser_1 = __webpack_require__(49);
var EventSource = /** @class */ (function (_super) {
    tslib_1.__extends(EventSource, _super);
    // can we do away with calendar? at least for the abstract?
    // useful for buildEventDef
    function EventSource(calendar) {
        var _this = _super.call(this) || this;
        _this.calendar = calendar;
        _this.className = [];
        _this.uid = String(EventSource.uuid++);
        return _this;
    }
    /*
    rawInput can be any data type!
    */
    EventSource.parse = function (rawInput, calendar) {
        var source = new this(calendar);
        if (typeof rawInput === 'object') {
            if (source.applyProps(rawInput)) {
                return source;
            }
        }
        return false;
    };
    EventSource.normalizeId = function (id) {
        if (id) {
            return String(id);
        }
        return null;
    };
    EventSource.prototype.fetch = function (start, end, timezone) {
        // subclasses must implement. must return a promise.
    };
    EventSource.prototype.removeEventDefsById = function (eventDefId) {
        // optional for subclasses to implement
    };
    EventSource.prototype.removeAllEventDefs = function () {
        // optional for subclasses to implement
    };
    /*
    For compairing/matching
    */
    EventSource.prototype.getPrimitive = function (otherSource) {
        // subclasses must implement
    };
    EventSource.prototype.parseEventDefs = function (rawEventDefs) {
        var i;
        var eventDef;
        var eventDefs = [];
        for (i = 0; i < rawEventDefs.length; i++) {
            eventDef = this.parseEventDef(rawEventDefs[i]);
            if (eventDef) {
                eventDefs.push(eventDef);
            }
        }
        return eventDefs;
    };
    EventSource.prototype.parseEventDef = function (rawInput) {
        var calendarTransform = this.calendar.opt('eventDataTransform');
        var sourceTransform = this.eventDataTransform;
        if (calendarTransform) {
            rawInput = calendarTransform(rawInput, this.calendar);
        }
        if (sourceTransform) {
            rawInput = sourceTransform(rawInput, this.calendar);
        }
        return EventDefParser_1.default.parse(rawInput, this);
    };
    EventSource.prototype.applyManualStandardProps = function (rawProps) {
        if (rawProps.id != null) {
            this.id = EventSource.normalizeId(rawProps.id);
        }
        // TODO: converge with EventDef
        if ($.isArray(rawProps.className)) {
            this.className = rawProps.className;
        }
        else if (typeof rawProps.className === 'string') {
            this.className = rawProps.className.split(/\s+/);
        }
        return true;
    };
    EventSource.uuid = 0;
    EventSource.defineStandardProps = ParsableModelMixin_1.default.defineStandardProps;
    EventSource.copyVerbatimStandardProps = ParsableModelMixin_1.default.copyVerbatimStandardProps;
    return EventSource;
}(Class_1.default));
exports.default = EventSource;
ParsableModelMixin_1.default.mixInto(EventSource);
// Parsing
// ---------------------------------------------------------------------------------------------------------------------
EventSource.defineStandardProps({
    // manually process...
    id: false,
    className: false,
    // automatically transfer...
    color: true,
    backgroundColor: true,
    borderColor: true,
    textColor: true,
    editable: true,
    startEditable: true,
    durationEditable: true,
    rendering: true,
    overlap: true,
    constraint: true,
    allDayDefault: true,
    eventDataTransform: true
});


/***/ }),
/* 7 */
/***/ (function(module, exports, __webpack_require__) {

/*
Utility methods for easily listening to events on another object,
and more importantly, easily unlistening from them.

USAGE:
  import { default as ListenerMixin, ListenerInterface } from './ListenerMixin'
in class:
  listenTo: ListenerInterface['listenTo']
  stopListeningTo: ListenerInterface['stopListeningTo']
after class:
  ListenerMixin.mixInto(TheClass)
*/
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var $ = __webpack_require__(3);
var Mixin_1 = __webpack_require__(14);
var guid = 0;
var ListenerMixin = /** @class */ (function (_super) {
    tslib_1.__extends(ListenerMixin, _super);
    function ListenerMixin() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /*
    Given an `other` object that has on/off methods, bind the given `callback` to an event by the given name.
    The `callback` will be called with the `this` context of the object that .listenTo is being called on.
    Can be called:
      .listenTo(other, eventName, callback)
    OR
      .listenTo(other, {
        eventName1: callback1,
        eventName2: callback2
      })
    */
    ListenerMixin.prototype.listenTo = function (other, arg, callback) {
        if (typeof arg === 'object') {
            for (var eventName in arg) {
                if (arg.hasOwnProperty(eventName)) {
                    this.listenTo(other, eventName, arg[eventName]);
                }
            }
        }
        else if (typeof arg === 'string') {
            other.on(arg + '.' + this.getListenerNamespace(), // use event namespacing to identify this object
            $.proxy(callback, this) // always use `this` context
            // the usually-undesired jQuery guid behavior doesn't matter,
            // because we always unbind via namespace
            );
        }
    };
    /*
    Causes the current object to stop listening to events on the `other` object.
    `eventName` is optional. If omitted, will stop listening to ALL events on `other`.
    */
    ListenerMixin.prototype.stopListeningTo = function (other, eventName) {
        other.off((eventName || '') + '.' + this.getListenerNamespace());
    };
    /*
    Returns a string, unique to this object, to be used for event namespacing
    */
    ListenerMixin.prototype.getListenerNamespace = function () {
        if (this.listenerId == null) {
            this.listenerId = guid++;
        }
        return '_listener' + this.listenerId;
    };
    return ListenerMixin;
}(Mixin_1.default));
exports.default = ListenerMixin;


/***/ }),
/* 8 */,
/* 9 */,
/* 10 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var moment = __webpack_require__(0);
var $ = __webpack_require__(3);
var util_1 = __webpack_require__(4);
var ambigDateOfMonthRegex = /^\s*\d{4}-\d\d$/;
var ambigTimeOrZoneRegex = /^\s*\d{4}-(?:(\d\d-\d\d)|(W\d\d$)|(W\d\d-\d)|(\d\d\d))((T| )(\d\d(:\d\d(:\d\d(\.\d+)?)?)?)?)?$/;
var newMomentProto = moment.fn; // where we will attach our new methods
exports.newMomentProto = newMomentProto;
var oldMomentProto = $.extend({}, newMomentProto); // copy of original moment methods
exports.oldMomentProto = oldMomentProto;
// tell momentjs to transfer these properties upon clone
var momentProperties = moment.momentProperties;
momentProperties.push('_fullCalendar');
momentProperties.push('_ambigTime');
momentProperties.push('_ambigZone');
/*
Call this if you want Moment's original format method to be used
*/
function oldMomentFormat(mom, formatStr) {
    return oldMomentProto.format.call(mom, formatStr); // oldMomentProto defined in moment-ext.js
}
exports.oldMomentFormat = oldMomentFormat;
// Creating
// -------------------------------------------------------------------------------------------------
// Creates a new moment, similar to the vanilla moment(...) constructor, but with
// extra features (ambiguous time, enhanced formatting). When given an existing moment,
// it will function as a clone (and retain the zone of the moment). Anything else will
// result in a moment in the local zone.
var momentExt = function () {
    return makeMoment(arguments);
};
exports.default = momentExt;
// Sames as momentExt, but forces the resulting moment to be in the UTC timezone.
momentExt.utc = function () {
    var mom = makeMoment(arguments, true);
    // Force it into UTC because makeMoment doesn't guarantee it
    // (if given a pre-existing moment for example)
    if (mom.hasTime()) {
        mom.utc();
    }
    return mom;
};
// Same as momentExt, but when given an ISO8601 string, the timezone offset is preserved.
// ISO8601 strings with no timezone offset will become ambiguously zoned.
momentExt.parseZone = function () {
    return makeMoment(arguments, true, true);
};
// Builds an enhanced moment from args. When given an existing moment, it clones. When given a
// native Date, or called with no arguments (the current time), the resulting moment will be local.
// Anything else needs to be "parsed" (a string or an array), and will be affected by:
//    parseAsUTC - if there is no zone information, should we parse the input in UTC?
//    parseZone - if there is zone information, should we force the zone of the moment?
function makeMoment(args, parseAsUTC, parseZone) {
    if (parseAsUTC === void 0) { parseAsUTC = false; }
    if (parseZone === void 0) { parseZone = false; }
    var input = args[0];
    var isSingleString = args.length === 1 && typeof input === 'string';
    var isAmbigTime;
    var isAmbigZone;
    var ambigMatch;
    var mom;
    if (moment.isMoment(input) || util_1.isNativeDate(input) || input === undefined) {
        mom = moment.apply(null, args);
    }
    else {
        isAmbigTime = false;
        isAmbigZone = false;
        if (isSingleString) {
            if (ambigDateOfMonthRegex.test(input)) {
                // accept strings like '2014-05', but convert to the first of the month
                input += '-01';
                args = [input]; // for when we pass it on to moment's constructor
                isAmbigTime = true;
                isAmbigZone = true;
            }
            else if ((ambigMatch = ambigTimeOrZoneRegex.exec(input))) {
                isAmbigTime = !ambigMatch[5]; // no time part?
                isAmbigZone = true;
            }
        }
        else if ($.isArray(input)) {
            // arrays have no timezone information, so assume ambiguous zone
            isAmbigZone = true;
        }
        // otherwise, probably a string with a format
        if (parseAsUTC || isAmbigTime) {
            mom = moment.utc.apply(moment, args);
        }
        else {
            mom = moment.apply(null, args);
        }
        if (isAmbigTime) {
            mom._ambigTime = true;
            mom._ambigZone = true; // ambiguous time always means ambiguous zone
        }
        else if (parseZone) {
            if (isAmbigZone) {
                mom._ambigZone = true;
            }
            else if (isSingleString) {
                mom.utcOffset(input); // if not a valid zone, will assign UTC
            }
        }
    }
    mom._fullCalendar = true; // flag for extended functionality
    return mom;
}
// Week Number
// -------------------------------------------------------------------------------------------------
// Returns the week number, considering the locale's custom week number calcuation
// `weeks` is an alias for `week`
newMomentProto.week = newMomentProto.weeks = function (input) {
    var weekCalc = this._locale._fullCalendar_weekCalc;
    if (input == null && typeof weekCalc === 'function') {
        return weekCalc(this);
    }
    else if (weekCalc === 'ISO') {
        return oldMomentProto.isoWeek.apply(this, arguments); // ISO getter/setter
    }
    return oldMomentProto.week.apply(this, arguments); // local getter/setter
};
// Time-of-day
// -------------------------------------------------------------------------------------------------
// GETTER
// Returns a Duration with the hours/minutes/seconds/ms values of the moment.
// If the moment has an ambiguous time, a duration of 00:00 will be returned.
//
// SETTER
// You can supply a Duration, a Moment, or a Duration-like argument.
// When setting the time, and the moment has an ambiguous time, it then becomes unambiguous.
newMomentProto.time = function (time) {
    // Fallback to the original method (if there is one) if this moment wasn't created via FullCalendar.
    // `time` is a generic enough method name where this precaution is necessary to avoid collisions w/ other plugins.
    if (!this._fullCalendar) {
        return oldMomentProto.time.apply(this, arguments);
    }
    if (time == null) {
        return moment.duration({
            hours: this.hours(),
            minutes: this.minutes(),
            seconds: this.seconds(),
            milliseconds: this.milliseconds()
        });
    }
    else {
        this._ambigTime = false; // mark that the moment now has a time
        if (!moment.isDuration(time) && !moment.isMoment(time)) {
            time = moment.duration(time);
        }
        // The day value should cause overflow (so 24 hours becomes 00:00:00 of next day).
        // Only for Duration times, not Moment times.
        var dayHours = 0;
        if (moment.isDuration(time)) {
            dayHours = Math.floor(time.asDays()) * 24;
        }
        // We need to set the individual fields.
        // Can't use startOf('day') then add duration. In case of DST at start of day.
        return this.hours(dayHours + time.hours())
            .minutes(time.minutes())
            .seconds(time.seconds())
            .milliseconds(time.milliseconds());
    }
};
// Converts the moment to UTC, stripping out its time-of-day and timezone offset,
// but preserving its YMD. A moment with a stripped time will display no time
// nor timezone offset when .format() is called.
newMomentProto.stripTime = function () {
    if (!this._ambigTime) {
        this.utc(true); // keepLocalTime=true (for keeping *date* value)
        // set time to zero
        this.set({
            hours: 0,
            minutes: 0,
            seconds: 0,
            ms: 0
        });
        // Mark the time as ambiguous. This needs to happen after the .utc() call, which might call .utcOffset(),
        // which clears all ambig flags.
        this._ambigTime = true;
        this._ambigZone = true; // if ambiguous time, also ambiguous timezone offset
    }
    return this; // for chaining
};
// Returns if the moment has a non-ambiguous time (boolean)
newMomentProto.hasTime = function () {
    return !this._ambigTime;
};
// Timezone
// -------------------------------------------------------------------------------------------------
// Converts the moment to UTC, stripping out its timezone offset, but preserving its
// YMD and time-of-day. A moment with a stripped timezone offset will display no
// timezone offset when .format() is called.
newMomentProto.stripZone = function () {
    var wasAmbigTime;
    if (!this._ambigZone) {
        wasAmbigTime = this._ambigTime;
        this.utc(true); // keepLocalTime=true (for keeping date and time values)
        // the above call to .utc()/.utcOffset() unfortunately might clear the ambig flags, so restore
        this._ambigTime = wasAmbigTime || false;
        // Mark the zone as ambiguous. This needs to happen after the .utc() call, which might call .utcOffset(),
        // which clears the ambig flags.
        this._ambigZone = true;
    }
    return this; // for chaining
};
// Returns of the moment has a non-ambiguous timezone offset (boolean)
newMomentProto.hasZone = function () {
    return !this._ambigZone;
};
// implicitly marks a zone
newMomentProto.local = function (keepLocalTime) {
    // for when converting from ambiguously-zoned to local,
    // keep the time values when converting from UTC -> local
    oldMomentProto.local.call(this, this._ambigZone || keepLocalTime);
    // ensure non-ambiguous
    // this probably already happened via local() -> utcOffset(), but don't rely on Moment's internals
    this._ambigTime = false;
    this._ambigZone = false;
    return this; // for chaining
};
// implicitly marks a zone
newMomentProto.utc = function (keepLocalTime) {
    oldMomentProto.utc.call(this, keepLocalTime);
    // ensure non-ambiguous
    // this probably already happened via utc() -> utcOffset(), but don't rely on Moment's internals
    this._ambigTime = false;
    this._ambigZone = false;
    return this;
};
// implicitly marks a zone (will probably get called upon .utc() and .local())
newMomentProto.utcOffset = function (tzo) {
    if (tzo != null) {
        // these assignments needs to happen before the original zone method is called.
        // I forget why, something to do with a browser crash.
        this._ambigTime = false;
        this._ambigZone = false;
    }
    return oldMomentProto.utcOffset.apply(this, arguments);
};


/***/ }),
/* 11 */
/***/ (function(module, exports, __webpack_require__) {

/*
USAGE:
  import { default as EmitterMixin, EmitterInterface } from './EmitterMixin'
in class:
  on: EmitterInterface['on']
  one: EmitterInterface['one']
  off: EmitterInterface['off']
  trigger: EmitterInterface['trigger']
  triggerWith: EmitterInterface['triggerWith']
  hasHandlers: EmitterInterface['hasHandlers']
after class:
  EmitterMixin.mixInto(TheClass)
*/
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var $ = __webpack_require__(3);
var Mixin_1 = __webpack_require__(14);
var EmitterMixin = /** @class */ (function (_super) {
    tslib_1.__extends(EmitterMixin, _super);
    function EmitterMixin() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    // jQuery-ification via $(this) allows a non-DOM object to have
    // the same event handling capabilities (including namespaces).
    EmitterMixin.prototype.on = function (types, handler) {
        $(this).on(types, this._prepareIntercept(handler));
        return this; // for chaining
    };
    EmitterMixin.prototype.one = function (types, handler) {
        $(this).one(types, this._prepareIntercept(handler));
        return this; // for chaining
    };
    EmitterMixin.prototype._prepareIntercept = function (handler) {
        // handlers are always called with an "event" object as their first param.
        // sneak the `this` context and arguments into the extra parameter object
        // and forward them on to the original handler.
        var intercept = function (ev, extra) {
            return handler.apply(extra.context || this, extra.args || []);
        };
        // mimick jQuery's internal "proxy" system (risky, I know)
        // causing all functions with the same .guid to appear to be the same.
        // https://github.com/jquery/jquery/blob/2.2.4/src/core.js#L448
        // this is needed for calling .off with the original non-intercept handler.
        if (!handler.guid) {
            handler.guid = $.guid++;
        }
        intercept.guid = handler.guid;
        return intercept;
    };
    EmitterMixin.prototype.off = function (types, handler) {
        $(this).off(types, handler);
        return this; // for chaining
    };
    EmitterMixin.prototype.trigger = function (types) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        // pass in "extra" info to the intercept
        $(this).triggerHandler(types, { args: args });
        return this; // for chaining
    };
    EmitterMixin.prototype.triggerWith = function (types, context, args) {
        // `triggerHandler` is less reliant on the DOM compared to `trigger`.
        // pass in "extra" info to the intercept.
        $(this).triggerHandler(types, { context: context, args: args });
        return this; // for chaining
    };
    EmitterMixin.prototype.hasHandlers = function (type) {
        var hash = $._data(this, 'events'); // http://blog.jquery.com/2012/08/09/jquery-1-8-released/
        return hash && hash[type] && hash[type].length > 0;
    };
    return EmitterMixin;
}(Mixin_1.default));
exports.default = EmitterMixin;


/***/ }),
/* 12 */
/***/ (function(module, exports) {

Object.defineProperty(exports, "__esModule", { value: true });
/*
Meant to be immutable
*/
var ComponentFootprint = /** @class */ (function () {
    function ComponentFootprint(unzonedRange, isAllDay) {
        this.isAllDay = false; // component can choose to ignore this
        this.unzonedRange = unzonedRange;
        this.isAllDay = isAllDay;
    }
    /*
    Only works for non-open-ended ranges.
    */
    ComponentFootprint.prototype.toLegacy = function (calendar) {
        return {
            start: calendar.msToMoment(this.unzonedRange.startMs, this.isAllDay),
            end: calendar.msToMoment(this.unzonedRange.endMs, this.isAllDay)
        };
    };
    return ComponentFootprint;
}());
exports.default = ComponentFootprint;


/***/ }),
/* 13 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var EventDef_1 = __webpack_require__(34);
var EventInstance_1 = __webpack_require__(209);
var EventDateProfile_1 = __webpack_require__(17);
var SingleEventDef = /** @class */ (function (_super) {
    tslib_1.__extends(SingleEventDef, _super);
    function SingleEventDef() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /*
    Will receive start/end params, but will be ignored.
    */
    SingleEventDef.prototype.buildInstances = function () {
        return [this.buildInstance()];
    };
    SingleEventDef.prototype.buildInstance = function () {
        return new EventInstance_1.default(this, // definition
        this.dateProfile);
    };
    SingleEventDef.prototype.isAllDay = function () {
        return this.dateProfile.isAllDay();
    };
    SingleEventDef.prototype.clone = function () {
        var def = _super.prototype.clone.call(this);
        def.dateProfile = this.dateProfile;
        return def;
    };
    SingleEventDef.prototype.rezone = function () {
        var calendar = this.source.calendar;
        var dateProfile = this.dateProfile;
        this.dateProfile = new EventDateProfile_1.default(calendar.moment(dateProfile.start), dateProfile.end ? calendar.moment(dateProfile.end) : null, calendar);
    };
    /*
    NOTE: if super-method fails, should still attempt to apply
    */
    SingleEventDef.prototype.applyManualStandardProps = function (rawProps) {
        var superSuccess = _super.prototype.applyManualStandardProps.call(this, rawProps);
        var dateProfile = EventDateProfile_1.default.parse(rawProps, this.source); // returns null on failure
        if (dateProfile) {
            this.dateProfile = dateProfile;
            // make sure `date` shows up in the legacy event objects as-is
            if (rawProps.date != null) {
                this.miscProps.date = rawProps.date;
            }
            return superSuccess;
        }
        else {
            return false;
        }
    };
    return SingleEventDef;
}(EventDef_1.default));
exports.default = SingleEventDef;
// Parsing
// ---------------------------------------------------------------------------------------------------------------------
SingleEventDef.defineStandardProps({
    start: false,
    date: false,
    end: false,
    allDay: false
});


/***/ }),
/* 14 */
/***/ (function(module, exports) {

Object.defineProperty(exports, "__esModule", { value: true });
var Mixin = /** @class */ (function () {
    function Mixin() {
    }
    Mixin.mixInto = function (destClass) {
        var _this = this;
        Object.getOwnPropertyNames(this.prototype).forEach(function (name) {
            if (!destClass.prototype[name]) {
                destClass.prototype[name] = _this.prototype[name];
            }
        });
    };
    /*
    will override existing methods
    TODO: remove! not used anymore
    */
    Mixin.mixOver = function (destClass) {
        var _this = this;
        Object.getOwnPropertyNames(this.prototype).forEach(function (name) {
            destClass.prototype[name] = _this.prototype[name];
        });
    };
    return Mixin;
}());
exports.default = Mixin;


/***/ }),
/* 15 */
/***/ (function(module, exports) {

Object.defineProperty(exports, "__esModule", { value: true });
var Interaction = /** @class */ (function () {
    function Interaction(component) {
        this.view = component._getView();
        this.component = component;
    }
    Interaction.prototype.opt = function (name) {
        return this.view.opt(name);
    };
    Interaction.prototype.end = function () {
        // subclasses can implement
    };
    return Interaction;
}());
exports.default = Interaction;


/***/ }),
/* 16 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
exports.version = '3.9.0';
// When introducing internal API incompatibilities (where fullcalendar plugins would break),
// the minor version of the calendar should be upped (ex: 2.7.2 -> 2.8.0)
// and the below integer should be incremented.
exports.internalApiVersion = 12;
var util_1 = __webpack_require__(4);
exports.applyAll = util_1.applyAll;
exports.debounce = util_1.debounce;
exports.isInt = util_1.isInt;
exports.htmlEscape = util_1.htmlEscape;
exports.cssToStr = util_1.cssToStr;
exports.proxy = util_1.proxy;
exports.capitaliseFirstLetter = util_1.capitaliseFirstLetter;
exports.getOuterRect = util_1.getOuterRect;
exports.getClientRect = util_1.getClientRect;
exports.getContentRect = util_1.getContentRect;
exports.getScrollbarWidths = util_1.getScrollbarWidths;
exports.preventDefault = util_1.preventDefault;
exports.parseFieldSpecs = util_1.parseFieldSpecs;
exports.compareByFieldSpecs = util_1.compareByFieldSpecs;
exports.compareByFieldSpec = util_1.compareByFieldSpec;
exports.flexibleCompare = util_1.flexibleCompare;
exports.computeGreatestUnit = util_1.computeGreatestUnit;
exports.divideRangeByDuration = util_1.divideRangeByDuration;
exports.divideDurationByDuration = util_1.divideDurationByDuration;
exports.multiplyDuration = util_1.multiplyDuration;
exports.durationHasTime = util_1.durationHasTime;
exports.log = util_1.log;
exports.warn = util_1.warn;
exports.removeExact = util_1.removeExact;
exports.intersectRects = util_1.intersectRects;
var date_formatting_1 = __webpack_require__(47);
exports.formatDate = date_formatting_1.formatDate;
exports.formatRange = date_formatting_1.formatRange;
exports.queryMostGranularFormatUnit = date_formatting_1.queryMostGranularFormatUnit;
var locale_1 = __webpack_require__(31);
exports.datepickerLocale = locale_1.datepickerLocale;
exports.locale = locale_1.locale;
var moment_ext_1 = __webpack_require__(10);
exports.moment = moment_ext_1.default;
var EmitterMixin_1 = __webpack_require__(11);
exports.EmitterMixin = EmitterMixin_1.default;
var ListenerMixin_1 = __webpack_require__(7);
exports.ListenerMixin = ListenerMixin_1.default;
var Model_1 = __webpack_require__(48);
exports.Model = Model_1.default;
var Constraints_1 = __webpack_require__(207);
exports.Constraints = Constraints_1.default;
var UnzonedRange_1 = __webpack_require__(5);
exports.UnzonedRange = UnzonedRange_1.default;
var ComponentFootprint_1 = __webpack_require__(12);
exports.ComponentFootprint = ComponentFootprint_1.default;
var BusinessHourGenerator_1 = __webpack_require__(212);
exports.BusinessHourGenerator = BusinessHourGenerator_1.default;
var EventDef_1 = __webpack_require__(34);
exports.EventDef = EventDef_1.default;
var EventDefMutation_1 = __webpack_require__(37);
exports.EventDefMutation = EventDefMutation_1.default;
var EventSourceParser_1 = __webpack_require__(38);
exports.EventSourceParser = EventSourceParser_1.default;
var EventSource_1 = __webpack_require__(6);
exports.EventSource = EventSource_1.default;
var ThemeRegistry_1 = __webpack_require__(51);
exports.defineThemeSystem = ThemeRegistry_1.defineThemeSystem;
var EventInstanceGroup_1 = __webpack_require__(18);
exports.EventInstanceGroup = EventInstanceGroup_1.default;
var ArrayEventSource_1 = __webpack_require__(52);
exports.ArrayEventSource = ArrayEventSource_1.default;
var FuncEventSource_1 = __webpack_require__(215);
exports.FuncEventSource = FuncEventSource_1.default;
var JsonFeedEventSource_1 = __webpack_require__(216);
exports.JsonFeedEventSource = JsonFeedEventSource_1.default;
var EventFootprint_1 = __webpack_require__(36);
exports.EventFootprint = EventFootprint_1.default;
var Class_1 = __webpack_require__(33);
exports.Class = Class_1.default;
var Mixin_1 = __webpack_require__(14);
exports.Mixin = Mixin_1.default;
var CoordCache_1 = __webpack_require__(53);
exports.CoordCache = CoordCache_1.default;
var DragListener_1 = __webpack_require__(54);
exports.DragListener = DragListener_1.default;
var Promise_1 = __webpack_require__(20);
exports.Promise = Promise_1.default;
var TaskQueue_1 = __webpack_require__(217);
exports.TaskQueue = TaskQueue_1.default;
var RenderQueue_1 = __webpack_require__(218);
exports.RenderQueue = RenderQueue_1.default;
var Scroller_1 = __webpack_require__(39);
exports.Scroller = Scroller_1.default;
var Theme_1 = __webpack_require__(19);
exports.Theme = Theme_1.default;
var DateComponent_1 = __webpack_require__(219);
exports.DateComponent = DateComponent_1.default;
var InteractiveDateComponent_1 = __webpack_require__(40);
exports.InteractiveDateComponent = InteractiveDateComponent_1.default;
var Calendar_1 = __webpack_require__(220);
exports.Calendar = Calendar_1.default;
var View_1 = __webpack_require__(41);
exports.View = View_1.default;
var ViewRegistry_1 = __webpack_require__(22);
exports.defineView = ViewRegistry_1.defineView;
exports.getViewConfig = ViewRegistry_1.getViewConfig;
var DayTableMixin_1 = __webpack_require__(55);
exports.DayTableMixin = DayTableMixin_1.default;
var BusinessHourRenderer_1 = __webpack_require__(56);
exports.BusinessHourRenderer = BusinessHourRenderer_1.default;
var EventRenderer_1 = __webpack_require__(42);
exports.EventRenderer = EventRenderer_1.default;
var FillRenderer_1 = __webpack_require__(57);
exports.FillRenderer = FillRenderer_1.default;
var HelperRenderer_1 = __webpack_require__(58);
exports.HelperRenderer = HelperRenderer_1.default;
var ExternalDropping_1 = __webpack_require__(222);
exports.ExternalDropping = ExternalDropping_1.default;
var EventResizing_1 = __webpack_require__(223);
exports.EventResizing = EventResizing_1.default;
var EventPointing_1 = __webpack_require__(59);
exports.EventPointing = EventPointing_1.default;
var EventDragging_1 = __webpack_require__(224);
exports.EventDragging = EventDragging_1.default;
var DateSelecting_1 = __webpack_require__(225);
exports.DateSelecting = DateSelecting_1.default;
var StandardInteractionsMixin_1 = __webpack_require__(60);
exports.StandardInteractionsMixin = StandardInteractionsMixin_1.default;
var AgendaView_1 = __webpack_require__(226);
exports.AgendaView = AgendaView_1.default;
var TimeGrid_1 = __webpack_require__(227);
exports.TimeGrid = TimeGrid_1.default;
var DayGrid_1 = __webpack_require__(61);
exports.DayGrid = DayGrid_1.default;
var BasicView_1 = __webpack_require__(62);
exports.BasicView = BasicView_1.default;
var MonthView_1 = __webpack_require__(229);
exports.MonthView = MonthView_1.default;
var ListView_1 = __webpack_require__(230);
exports.ListView = ListView_1.default;


/***/ }),
/* 17 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var UnzonedRange_1 = __webpack_require__(5);
/*
Meant to be immutable
*/
var EventDateProfile = /** @class */ (function () {
    function EventDateProfile(start, end, calendar) {
        this.start = start;
        this.end = end || null;
        this.unzonedRange = this.buildUnzonedRange(calendar);
    }
    /*
    Needs an EventSource object
    */
    EventDateProfile.parse = function (rawProps, source) {
        var startInput = rawProps.start || rawProps.date;
        var endInput = rawProps.end;
        if (!startInput) {
            return false;
        }
        var calendar = source.calendar;
        var start = calendar.moment(startInput);
        var end = endInput ? calendar.moment(endInput) : null;
        var forcedAllDay = rawProps.allDay;
        var forceEventDuration = calendar.opt('forceEventDuration');
        if (!start.isValid()) {
            return false;
        }
        if (end && (!end.isValid() || !end.isAfter(start))) {
            end = null;
        }
        if (forcedAllDay == null) {
            forcedAllDay = source.allDayDefault;
            if (forcedAllDay == null) {
                forcedAllDay = calendar.opt('allDayDefault');
            }
        }
        if (forcedAllDay === true) {
            start.stripTime();
            if (end) {
                end.stripTime();
            }
        }
        else if (forcedAllDay === false) {
            if (!start.hasTime()) {
                start.time(0);
            }
            if (end && !end.hasTime()) {
                end.time(0);
            }
        }
        if (!end && forceEventDuration) {
            end = calendar.getDefaultEventEnd(!start.hasTime(), start);
        }
        return new EventDateProfile(start, end, calendar);
    };
    EventDateProfile.isStandardProp = function (propName) {
        return propName === 'start' || propName === 'date' || propName === 'end' || propName === 'allDay';
    };
    EventDateProfile.prototype.isAllDay = function () {
        return !(this.start.hasTime() || (this.end && this.end.hasTime()));
    };
    /*
    Needs a Calendar object
    */
    EventDateProfile.prototype.buildUnzonedRange = function (calendar) {
        var startMs = this.start.clone().stripZone().valueOf();
        var endMs = this.getEnd(calendar).stripZone().valueOf();
        return new UnzonedRange_1.default(startMs, endMs);
    };
    /*
    Needs a Calendar object
    */
    EventDateProfile.prototype.getEnd = function (calendar) {
        return this.end ?
            this.end.clone() :
            // derive the end from the start and allDay. compute allDay if necessary
            calendar.getDefaultEventEnd(this.isAllDay(), this.start);
    };
    return EventDateProfile;
}());
exports.default = EventDateProfile;


/***/ }),
/* 18 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var UnzonedRange_1 = __webpack_require__(5);
var util_1 = __webpack_require__(35);
var EventRange_1 = __webpack_require__(211);
/*
It's expected that there will be at least one EventInstance,
OR that an explicitEventDef is assigned.
*/
var EventInstanceGroup = /** @class */ (function () {
    function EventInstanceGroup(eventInstances) {
        this.eventInstances = eventInstances || [];
    }
    EventInstanceGroup.prototype.getAllEventRanges = function (constraintRange) {
        if (constraintRange) {
            return this.sliceNormalRenderRanges(constraintRange);
        }
        else {
            return this.eventInstances.map(util_1.eventInstanceToEventRange);
        }
    };
    EventInstanceGroup.prototype.sliceRenderRanges = function (constraintRange) {
        if (this.isInverse()) {
            return this.sliceInverseRenderRanges(constraintRange);
        }
        else {
            return this.sliceNormalRenderRanges(constraintRange);
        }
    };
    EventInstanceGroup.prototype.sliceNormalRenderRanges = function (constraintRange) {
        var eventInstances = this.eventInstances;
        var i;
        var eventInstance;
        var slicedRange;
        var slicedEventRanges = [];
        for (i = 0; i < eventInstances.length; i++) {
            eventInstance = eventInstances[i];
            slicedRange = eventInstance.dateProfile.unzonedRange.intersect(constraintRange);
            if (slicedRange) {
                slicedEventRanges.push(new EventRange_1.default(slicedRange, eventInstance.def, eventInstance));
            }
        }
        return slicedEventRanges;
    };
    EventInstanceGroup.prototype.sliceInverseRenderRanges = function (constraintRange) {
        var unzonedRanges = this.eventInstances.map(util_1.eventInstanceToUnzonedRange);
        var ownerDef = this.getEventDef();
        unzonedRanges = UnzonedRange_1.default.invertRanges(unzonedRanges, constraintRange);
        return unzonedRanges.map(function (unzonedRange) {
            return new EventRange_1.default(unzonedRange, ownerDef); // don't give an EventInstance
        });
    };
    EventInstanceGroup.prototype.isInverse = function () {
        return this.getEventDef().hasInverseRendering();
    };
    EventInstanceGroup.prototype.getEventDef = function () {
        return this.explicitEventDef || this.eventInstances[0].def;
    };
    return EventInstanceGroup;
}());
exports.default = EventInstanceGroup;


/***/ }),
/* 19 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var $ = __webpack_require__(3);
var Theme = /** @class */ (function () {
    function Theme(optionsManager) {
        this.optionsManager = optionsManager;
        this.processIconOverride();
    }
    Theme.prototype.processIconOverride = function () {
        if (this.iconOverrideOption) {
            this.setIconOverride(this.optionsManager.get(this.iconOverrideOption));
        }
    };
    Theme.prototype.setIconOverride = function (iconOverrideHash) {
        var iconClassesCopy;
        var buttonName;
        if ($.isPlainObject(iconOverrideHash)) {
            iconClassesCopy = $.extend({}, this.iconClasses);
            for (buttonName in iconOverrideHash) {
                iconClassesCopy[buttonName] = this.applyIconOverridePrefix(iconOverrideHash[buttonName]);
            }
            this.iconClasses = iconClassesCopy;
        }
        else if (iconOverrideHash === false) {
            this.iconClasses = {};
        }
    };
    Theme.prototype.applyIconOverridePrefix = function (className) {
        var prefix = this.iconOverridePrefix;
        if (prefix && className.indexOf(prefix) !== 0) {
            className = prefix + className;
        }
        return className;
    };
    Theme.prototype.getClass = function (key) {
        return this.classes[key] || '';
    };
    Theme.prototype.getIconClass = function (buttonName) {
        var className = this.iconClasses[buttonName];
        if (className) {
            return this.baseIconClass + ' ' + className;
        }
        return '';
    };
    Theme.prototype.getCustomButtonIconClass = function (customButtonProps) {
        var className;
        if (this.iconOverrideCustomButtonOption) {
            className = customButtonProps[this.iconOverrideCustomButtonOption];
            if (className) {
                return this.baseIconClass + ' ' + this.applyIconOverridePrefix(className);
            }
        }
        return '';
    };
    return Theme;
}());
exports.default = Theme;
Theme.prototype.classes = {};
Theme.prototype.iconClasses = {};
Theme.prototype.baseIconClass = '';
Theme.prototype.iconOverridePrefix = '';


/***/ }),
/* 20 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var $ = __webpack_require__(3);
var PromiseStub = {
    construct: function (executor) {
        var deferred = $.Deferred();
        var promise = deferred.promise();
        if (typeof executor === 'function') {
            executor(function (val) {
                deferred.resolve(val);
                attachImmediatelyResolvingThen(promise, val);
            }, function () {
                deferred.reject();
                attachImmediatelyRejectingThen(promise);
            });
        }
        return promise;
    },
    resolve: function (val) {
        var deferred = $.Deferred().resolve(val);
        var promise = deferred.promise();
        attachImmediatelyResolvingThen(promise, val);
        return promise;
    },
    reject: function () {
        var deferred = $.Deferred().reject();
        var promise = deferred.promise();
        attachImmediatelyRejectingThen(promise);
        return promise;
    }
};
exports.default = PromiseStub;
function attachImmediatelyResolvingThen(promise, val) {
    promise.then = function (onResolve) {
        if (typeof onResolve === 'function') {
            return PromiseStub.resolve(onResolve(val));
        }
        return promise;
    };
}
function attachImmediatelyRejectingThen(promise) {
    promise.then = function (onResolve, onReject) {
        if (typeof onReject === 'function') {
            onReject();
        }
        return promise;
    };
}


/***/ }),
/* 21 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var $ = __webpack_require__(3);
var exportHooks = __webpack_require__(16);
var EmitterMixin_1 = __webpack_require__(11);
var ListenerMixin_1 = __webpack_require__(7);
exportHooks.touchMouseIgnoreWait = 500;
var globalEmitter = null;
var neededCount = 0;
/*
Listens to document and window-level user-interaction events, like touch events and mouse events,
and fires these events as-is to whoever is observing a GlobalEmitter.
Best when used as a singleton via GlobalEmitter.get()

Normalizes mouse/touch events. For examples:
- ignores the the simulated mouse events that happen after a quick tap: mousemove+mousedown+mouseup+click
- compensates for various buggy scenarios where a touchend does not fire
*/
var GlobalEmitter = /** @class */ (function () {
    function GlobalEmitter() {
        this.isTouching = false;
        this.mouseIgnoreDepth = 0;
    }
    // gets the singleton
    GlobalEmitter.get = function () {
        if (!globalEmitter) {
            globalEmitter = new GlobalEmitter();
            globalEmitter.bind();
        }
        return globalEmitter;
    };
    // called when an object knows it will need a GlobalEmitter in the near future.
    GlobalEmitter.needed = function () {
        GlobalEmitter.get(); // ensures globalEmitter
        neededCount++;
    };
    // called when the object that originally called needed() doesn't need a GlobalEmitter anymore.
    GlobalEmitter.unneeded = function () {
        neededCount--;
        if (!neededCount) {
            globalEmitter.unbind();
            globalEmitter = null;
        }
    };
    GlobalEmitter.prototype.bind = function () {
        var _this = this;
        this.listenTo($(document), {
            touchstart: this.handleTouchStart,
            touchcancel: this.handleTouchCancel,
            touchend: this.handleTouchEnd,
            mousedown: this.handleMouseDown,
            mousemove: this.handleMouseMove,
            mouseup: this.handleMouseUp,
            click: this.handleClick,
            selectstart: this.handleSelectStart,
            contextmenu: this.handleContextMenu
        });
        // because we need to call preventDefault
        // because https://www.chromestatus.com/features/5093566007214080
        // TODO: investigate performance because this is a global handler
        window.addEventListener('touchmove', this.handleTouchMoveProxy = function (ev) {
            _this.handleTouchMove($.Event(ev));
        }, { passive: false } // allows preventDefault()
        );
        // attach a handler to get called when ANY scroll action happens on the page.
        // this was impossible to do with normal on/off because 'scroll' doesn't bubble.
        // http://stackoverflow.com/a/32954565/96342
        window.addEventListener('scroll', this.handleScrollProxy = function (ev) {
            _this.handleScroll($.Event(ev));
        }, true // useCapture
        );
    };
    GlobalEmitter.prototype.unbind = function () {
        this.stopListeningTo($(document));
        window.removeEventListener('touchmove', this.handleTouchMoveProxy);
        window.removeEventListener('scroll', this.handleScrollProxy, true // useCapture
        );
    };
    // Touch Handlers
    // -----------------------------------------------------------------------------------------------------------------
    GlobalEmitter.prototype.handleTouchStart = function (ev) {
        // if a previous touch interaction never ended with a touchend, then implicitly end it,
        // but since a new touch interaction is about to begin, don't start the mouse ignore period.
        this.stopTouch(ev, true); // skipMouseIgnore=true
        this.isTouching = true;
        this.trigger('touchstart', ev);
    };
    GlobalEmitter.prototype.handleTouchMove = function (ev) {
        if (this.isTouching) {
            this.trigger('touchmove', ev);
        }
    };
    GlobalEmitter.prototype.handleTouchCancel = function (ev) {
        if (this.isTouching) {
            this.trigger('touchcancel', ev);
            // Have touchcancel fire an artificial touchend. That way, handlers won't need to listen to both.
            // If touchend fires later, it won't have any effect b/c isTouching will be false.
            this.stopTouch(ev);
        }
    };
    GlobalEmitter.prototype.handleTouchEnd = function (ev) {
        this.stopTouch(ev);
    };
    // Mouse Handlers
    // -----------------------------------------------------------------------------------------------------------------
    GlobalEmitter.prototype.handleMouseDown = function (ev) {
        if (!this.shouldIgnoreMouse()) {
            this.trigger('mousedown', ev);
        }
    };
    GlobalEmitter.prototype.handleMouseMove = function (ev) {
        if (!this.shouldIgnoreMouse()) {
            this.trigger('mousemove', ev);
        }
    };
    GlobalEmitter.prototype.handleMouseUp = function (ev) {
        if (!this.shouldIgnoreMouse()) {
            this.trigger('mouseup', ev);
        }
    };
    GlobalEmitter.prototype.handleClick = function (ev) {
        if (!this.shouldIgnoreMouse()) {
            this.trigger('click', ev);
        }
    };
    // Misc Handlers
    // -----------------------------------------------------------------------------------------------------------------
    GlobalEmitter.prototype.handleSelectStart = function (ev) {
        this.trigger('selectstart', ev);
    };
    GlobalEmitter.prototype.handleContextMenu = function (ev) {
        this.trigger('contextmenu', ev);
    };
    GlobalEmitter.prototype.handleScroll = function (ev) {
        this.trigger('scroll', ev);
    };
    // Utils
    // -----------------------------------------------------------------------------------------------------------------
    GlobalEmitter.prototype.stopTouch = function (ev, skipMouseIgnore) {
        if (skipMouseIgnore === void 0) { skipMouseIgnore = false; }
        if (this.isTouching) {
            this.isTouching = false;
            this.trigger('touchend', ev);
            if (!skipMouseIgnore) {
                this.startTouchMouseIgnore();
            }
        }
    };
    GlobalEmitter.prototype.startTouchMouseIgnore = function () {
        var _this = this;
        var wait = exportHooks.touchMouseIgnoreWait;
        if (wait) {
            this.mouseIgnoreDepth++;
            setTimeout(function () {
                _this.mouseIgnoreDepth--;
            }, wait);
        }
    };
    GlobalEmitter.prototype.shouldIgnoreMouse = function () {
        return this.isTouching || Boolean(this.mouseIgnoreDepth);
    };
    return GlobalEmitter;
}());
exports.default = GlobalEmitter;
ListenerMixin_1.default.mixInto(GlobalEmitter);
EmitterMixin_1.default.mixInto(GlobalEmitter);


/***/ }),
/* 22 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var exportHooks = __webpack_require__(16);
exports.viewHash = {};
exportHooks.views = exports.viewHash;
function defineView(viewName, viewConfig) {
    exports.viewHash[viewName] = viewConfig;
}
exports.defineView = defineView;
function getViewConfig(viewName) {
    return exports.viewHash[viewName];
}
exports.getViewConfig = getViewConfig;


/***/ }),
/* 23 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var util_1 = __webpack_require__(4);
var DragListener_1 = __webpack_require__(54);
/* Tracks mouse movements over a component and raises events about which hit the mouse is over.
------------------------------------------------------------------------------------------------------------------------
options:
- subjectEl
- subjectCenter
*/
var HitDragListener = /** @class */ (function (_super) {
    tslib_1.__extends(HitDragListener, _super);
    function HitDragListener(component, options) {
        var _this = _super.call(this, options) || this;
        _this.component = component;
        return _this;
    }
    // Called when drag listening starts (but a real drag has not necessarily began).
    // ev might be undefined if dragging was started manually.
    HitDragListener.prototype.handleInteractionStart = function (ev) {
        var subjectEl = this.subjectEl;
        var subjectRect;
        var origPoint;
        var point;
        this.component.hitsNeeded();
        this.computeScrollBounds(); // for autoscroll
        if (ev) {
            origPoint = { left: util_1.getEvX(ev), top: util_1.getEvY(ev) };
            point = origPoint;
            // constrain the point to bounds of the element being dragged
            if (subjectEl) {
                subjectRect = util_1.getOuterRect(subjectEl); // used for centering as well
                point = util_1.constrainPoint(point, subjectRect);
            }
            this.origHit = this.queryHit(point.left, point.top);
            // treat the center of the subject as the collision point?
            if (subjectEl && this.options.subjectCenter) {
                // only consider the area the subject overlaps the hit. best for large subjects.
                // TODO: skip this if hit didn't supply left/right/top/bottom
                if (this.origHit) {
                    subjectRect = util_1.intersectRects(this.origHit, subjectRect) ||
                        subjectRect; // in case there is no intersection
                }
                point = util_1.getRectCenter(subjectRect);
            }
            this.coordAdjust = util_1.diffPoints(point, origPoint); // point - origPoint
        }
        else {
            this.origHit = null;
            this.coordAdjust = null;
        }
        // call the super-method. do it after origHit has been computed
        _super.prototype.handleInteractionStart.call(this, ev);
    };
    // Called when the actual drag has started
    HitDragListener.prototype.handleDragStart = function (ev) {
        var hit;
        _super.prototype.handleDragStart.call(this, ev);
        // might be different from this.origHit if the min-distance is large
        hit = this.queryHit(util_1.getEvX(ev), util_1.getEvY(ev));
        // report the initial hit the mouse is over
        // especially important if no min-distance and drag starts immediately
        if (hit) {
            this.handleHitOver(hit);
        }
    };
    // Called when the drag moves
    HitDragListener.prototype.handleDrag = function (dx, dy, ev) {
        var hit;
        _super.prototype.handleDrag.call(this, dx, dy, ev);
        hit = this.queryHit(util_1.getEvX(ev), util_1.getEvY(ev));
        if (!isHitsEqual(hit, this.hit)) {
            if (this.hit) {
                this.handleHitOut();
            }
            if (hit) {
                this.handleHitOver(hit);
            }
        }
    };
    // Called when dragging has been stopped
    HitDragListener.prototype.handleDragEnd = function (ev) {
        this.handleHitDone();
        _super.prototype.handleDragEnd.call(this, ev);
    };
    // Called when a the mouse has just moved over a new hit
    HitDragListener.prototype.handleHitOver = function (hit) {
        var isOrig = isHitsEqual(hit, this.origHit);
        this.hit = hit;
        this.trigger('hitOver', this.hit, isOrig, this.origHit);
    };
    // Called when the mouse has just moved out of a hit
    HitDragListener.prototype.handleHitOut = function () {
        if (this.hit) {
            this.trigger('hitOut', this.hit);
            this.handleHitDone();
            this.hit = null;
        }
    };
    // Called after a hitOut. Also called before a dragStop
    HitDragListener.prototype.handleHitDone = function () {
        if (this.hit) {
            this.trigger('hitDone', this.hit);
        }
    };
    // Called when the interaction ends, whether there was a real drag or not
    HitDragListener.prototype.handleInteractionEnd = function (ev, isCancelled) {
        _super.prototype.handleInteractionEnd.call(this, ev, isCancelled);
        this.origHit = null;
        this.hit = null;
        this.component.hitsNotNeeded();
    };
    // Called when scrolling has stopped, whether through auto scroll, or the user scrolling
    HitDragListener.prototype.handleScrollEnd = function () {
        _super.prototype.handleScrollEnd.call(this);
        // hits' absolute positions will be in new places after a user's scroll.
        // HACK for recomputing.
        if (this.isDragging) {
            this.component.releaseHits();
            this.component.prepareHits();
        }
    };
    // Gets the hit underneath the coordinates for the given mouse event
    HitDragListener.prototype.queryHit = function (left, top) {
        if (this.coordAdjust) {
            left += this.coordAdjust.left;
            top += this.coordAdjust.top;
        }
        return this.component.queryHit(left, top);
    };
    return HitDragListener;
}(DragListener_1.default));
exports.default = HitDragListener;
// Returns `true` if the hits are identically equal. `false` otherwise. Must be from the same component.
// Two null values will be considered equal, as two "out of the component" states are the same.
function isHitsEqual(hit0, hit1) {
    if (!hit0 && !hit1) {
        return true;
    }
    if (hit0 && hit1) {
        return hit0.component === hit1.component &&
            isHitPropsWithin(hit0, hit1) &&
            isHitPropsWithin(hit1, hit0); // ensures all props are identical
    }
    return false;
}
// Returns true if all of subHit's non-standard properties are within superHit
function isHitPropsWithin(subHit, superHit) {
    for (var propName in subHit) {
        if (!/^(component|left|right|top|bottom)$/.test(propName)) {
            if (subHit[propName] !== superHit[propName]) {
                return false;
            }
        }
    }
    return true;
}


/***/ }),
/* 24 */,
/* 25 */,
/* 26 */,
/* 27 */,
/* 28 */,
/* 29 */,
/* 30 */,
/* 31 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var $ = __webpack_require__(3);
var moment = __webpack_require__(0);
var exportHooks = __webpack_require__(16);
var options_1 = __webpack_require__(32);
var util_1 = __webpack_require__(4);
exports.localeOptionHash = {};
exportHooks.locales = exports.localeOptionHash;
// NOTE: can't guarantee any of these computations will run because not every locale has datepicker
// configs, so make sure there are English fallbacks for these in the defaults file.
var dpComputableOptions = {
    buttonText: function (dpOptions) {
        return {
            // the translations sometimes wrongly contain HTML entities
            prev: util_1.stripHtmlEntities(dpOptions.prevText),
            next: util_1.stripHtmlEntities(dpOptions.nextText),
            today: util_1.stripHtmlEntities(dpOptions.currentText)
        };
    },
    // Produces format strings like "MMMM YYYY" -> "September 2014"
    monthYearFormat: function (dpOptions) {
        return dpOptions.showMonthAfterYear ?
            'YYYY[' + dpOptions.yearSuffix + '] MMMM' :
            'MMMM YYYY[' + dpOptions.yearSuffix + ']';
    }
};
var momComputableOptions = {
    // Produces format strings like "ddd M/D" -> "Fri 9/15"
    dayOfMonthFormat: function (momOptions, fcOptions) {
        var format = momOptions.longDateFormat('l'); // for the format like "M/D/YYYY"
        // strip the year off the edge, as well as other misc non-whitespace chars
        format = format.replace(/^Y+[^\w\s]*|[^\w\s]*Y+$/g, '');
        if (fcOptions.isRTL) {
            format += ' ddd'; // for RTL, add day-of-week to end
        }
        else {
            format = 'ddd ' + format; // for LTR, add day-of-week to beginning
        }
        return format;
    },
    // Produces format strings like "h:mma" -> "6:00pm"
    mediumTimeFormat: function (momOptions) {
        return momOptions.longDateFormat('LT')
            .replace(/\s*a$/i, 'a'); // convert AM/PM/am/pm to lowercase. remove any spaces beforehand
    },
    // Produces format strings like "h(:mm)a" -> "6pm" / "6:30pm"
    smallTimeFormat: function (momOptions) {
        return momOptions.longDateFormat('LT')
            .replace(':mm', '(:mm)')
            .replace(/(\Wmm)$/, '($1)') // like above, but for foreign locales
            .replace(/\s*a$/i, 'a'); // convert AM/PM/am/pm to lowercase. remove any spaces beforehand
    },
    // Produces format strings like "h(:mm)t" -> "6p" / "6:30p"
    extraSmallTimeFormat: function (momOptions) {
        return momOptions.longDateFormat('LT')
            .replace(':mm', '(:mm)')
            .replace(/(\Wmm)$/, '($1)') // like above, but for foreign locales
            .replace(/\s*a$/i, 't'); // convert to AM/PM/am/pm to lowercase one-letter. remove any spaces beforehand
    },
    // Produces format strings like "ha" / "H" -> "6pm" / "18"
    hourFormat: function (momOptions) {
        return momOptions.longDateFormat('LT')
            .replace(':mm', '')
            .replace(/(\Wmm)$/, '') // like above, but for foreign locales
            .replace(/\s*a$/i, 'a'); // convert AM/PM/am/pm to lowercase. remove any spaces beforehand
    },
    // Produces format strings like "h:mm" -> "6:30" (with no AM/PM)
    noMeridiemTimeFormat: function (momOptions) {
        return momOptions.longDateFormat('LT')
            .replace(/\s*a$/i, ''); // remove trailing AM/PM
    }
};
// options that should be computed off live calendar options (considers override options)
// TODO: best place for this? related to locale?
// TODO: flipping text based on isRTL is a bad idea because the CSS `direction` might want to handle it
var instanceComputableOptions = {
    // Produces format strings for results like "Mo 16"
    smallDayDateFormat: function (options) {
        return options.isRTL ?
            'D dd' :
            'dd D';
    },
    // Produces format strings for results like "Wk 5"
    weekFormat: function (options) {
        return options.isRTL ?
            'w[ ' + options.weekNumberTitle + ']' :
            '[' + options.weekNumberTitle + ' ]w';
    },
    // Produces format strings for results like "Wk5"
    smallWeekFormat: function (options) {
        return options.isRTL ?
            'w[' + options.weekNumberTitle + ']' :
            '[' + options.weekNumberTitle + ']w';
    }
};
// TODO: make these computable properties in optionsManager
function populateInstanceComputableOptions(options) {
    $.each(instanceComputableOptions, function (name, func) {
        if (options[name] == null) {
            options[name] = func(options);
        }
    });
}
exports.populateInstanceComputableOptions = populateInstanceComputableOptions;
// Initialize jQuery UI datepicker translations while using some of the translations
// Will set this as the default locales for datepicker.
function datepickerLocale(localeCode, dpLocaleCode, dpOptions) {
    // get the FullCalendar internal option hash for this locale. create if necessary
    var fcOptions = exports.localeOptionHash[localeCode] || (exports.localeOptionHash[localeCode] = {});
    // transfer some simple options from datepicker to fc
    fcOptions.isRTL = dpOptions.isRTL;
    fcOptions.weekNumberTitle = dpOptions.weekHeader;
    // compute some more complex options from datepicker
    $.each(dpComputableOptions, function (name, func) {
        fcOptions[name] = func(dpOptions);
    });
    var jqDatePicker = $.datepicker;
    // is jQuery UI Datepicker is on the page?
    if (jqDatePicker) {
        // Register the locale data.
        // FullCalendar and MomentJS use locale codes like "pt-br" but Datepicker
        // does it like "pt-BR" or if it doesn't have the locale, maybe just "pt".
        // Make an alias so the locale can be referenced either way.
        jqDatePicker.regional[dpLocaleCode] =
            jqDatePicker.regional[localeCode] = // alias
                dpOptions;
        // Alias 'en' to the default locale data. Do this every time.
        jqDatePicker.regional.en = jqDatePicker.regional[''];
        // Set as Datepicker's global defaults.
        jqDatePicker.setDefaults(dpOptions);
    }
}
exports.datepickerLocale = datepickerLocale;
// Sets FullCalendar-specific translations. Will set the locales as the global default.
function locale(localeCode, newFcOptions) {
    var fcOptions;
    var momOptions;
    // get the FullCalendar internal option hash for this locale. create if necessary
    fcOptions = exports.localeOptionHash[localeCode] || (exports.localeOptionHash[localeCode] = {});
    // provided new options for this locales? merge them in
    if (newFcOptions) {
        fcOptions = exports.localeOptionHash[localeCode] = options_1.mergeOptions([fcOptions, newFcOptions]);
    }
    // compute locale options that weren't defined.
    // always do this. newFcOptions can be undefined when initializing from i18n file,
    // so no way to tell if this is an initialization or a default-setting.
    momOptions = getMomentLocaleData(localeCode); // will fall back to en
    $.each(momComputableOptions, function (name, func) {
        if (fcOptions[name] == null) {
            fcOptions[name] = (func)(momOptions, fcOptions);
        }
    });
    // set it as the default locale for FullCalendar
    options_1.globalDefaults.locale = localeCode;
}
exports.locale = locale;
// Returns moment's internal locale data. If doesn't exist, returns English.
function getMomentLocaleData(localeCode) {
    return moment.localeData(localeCode) || moment.localeData('en');
}
exports.getMomentLocaleData = getMomentLocaleData;
// Initialize English by forcing computation of moment-derived options.
// Also, sets it as the default.
locale('en', options_1.englishDefaults);


/***/ }),
/* 32 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var util_1 = __webpack_require__(4);
exports.globalDefaults = {
    titleRangeSeparator: ' \u2013 ',
    monthYearFormat: 'MMMM YYYY',
    defaultTimedEventDuration: '02:00:00',
    defaultAllDayEventDuration: { days: 1 },
    forceEventDuration: false,
    nextDayThreshold: '09:00:00',
    // display
    columnHeader: true,
    defaultView: 'month',
    aspectRatio: 1.35,
    header: {
        left: 'title',
        center: '',
        right: 'today prev,next'
    },
    weekends: true,
    weekNumbers: false,
    weekNumberTitle: 'W',
    weekNumberCalculation: 'local',
    // editable: false,
    // nowIndicator: false,
    scrollTime: '06:00:00',
    minTime: '00:00:00',
    maxTime: '24:00:00',
    showNonCurrentDates: true,
    // event ajax
    lazyFetching: true,
    startParam: 'start',
    endParam: 'end',
    timezoneParam: 'timezone',
    timezone: false,
    // allDayDefault: undefined,
    // locale
    locale: null,
    isRTL: false,
    buttonText: {
        prev: 'prev',
        next: 'next',
        prevYear: 'prev year',
        nextYear: 'next year',
        year: 'year',
        today: 'today',
        month: 'month',
        week: 'week',
        day: 'day'
    },
    // buttonIcons: null,
    allDayText: 'all-day',
    // allows setting a min-height to the event segment to prevent short events overlapping each other
    agendaEventMinHeight: 0,
    // jquery-ui theming
    theme: false,
    // themeButtonIcons: null,
    // eventResizableFromStart: false,
    dragOpacity: .75,
    dragRevertDuration: 500,
    dragScroll: true,
    // selectable: false,
    unselectAuto: true,
    // selectMinDistance: 0,
    dropAccept: '*',
    eventOrder: 'title',
    // eventRenderWait: null,
    eventLimit: false,
    eventLimitText: 'more',
    eventLimitClick: 'popover',
    dayPopoverFormat: 'LL',
    handleWindowResize: true,
    windowResizeDelay: 100,
    longPressDelay: 1000
};
exports.englishDefaults = {
    dayPopoverFormat: 'dddd, MMMM D'
};
exports.rtlDefaults = {
    header: {
        left: 'next,prev today',
        center: '',
        right: 'title'
    },
    buttonIcons: {
        prev: 'right-single-arrow',
        next: 'left-single-arrow',
        prevYear: 'right-double-arrow',
        nextYear: 'left-double-arrow'
    },
    themeButtonIcons: {
        prev: 'circle-triangle-e',
        next: 'circle-triangle-w',
        nextYear: 'seek-prev',
        prevYear: 'seek-next'
    }
};
var complexOptions = [
    'header',
    'footer',
    'buttonText',
    'buttonIcons',
    'themeButtonIcons'
];
// Merges an array of option objects into a single object
function mergeOptions(optionObjs) {
    return util_1.mergeProps(optionObjs, complexOptions);
}
exports.mergeOptions = mergeOptions;


/***/ }),
/* 33 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var util_1 = __webpack_require__(4);
// Class that all other classes will inherit from
var Class = /** @class */ (function () {
    function Class() {
    }
    // Called on a class to create a subclass.
    // LIMITATION: cannot provide a constructor!
    Class.extend = function (members) {
        var SubClass = /** @class */ (function (_super) {
            tslib_1.__extends(SubClass, _super);
            function SubClass() {
                return _super !== null && _super.apply(this, arguments) || this;
            }
            return SubClass;
        }(this));
        util_1.copyOwnProps(members, SubClass.prototype);
        return SubClass;
    };
    // Adds new member variables/methods to the class's prototype.
    // Can be called with another class, or a plain object hash containing new members.
    Class.mixin = function (members) {
        util_1.copyOwnProps(members, this.prototype);
    };
    return Class;
}());
exports.default = Class;


/***/ }),
/* 34 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var $ = __webpack_require__(3);
var ParsableModelMixin_1 = __webpack_require__(208);
var EventDef = /** @class */ (function () {
    function EventDef(source) {
        this.source = source;
        this.className = [];
        this.miscProps = {};
    }
    EventDef.parse = function (rawInput, source) {
        var def = new this(source);
        if (def.applyProps(rawInput)) {
            return def;
        }
        return false;
    };
    EventDef.normalizeId = function (id) {
        return String(id);
    };
    EventDef.generateId = function () {
        return '_fc' + (EventDef.uuid++);
    };
    EventDef.prototype.clone = function () {
        var copy = new this.constructor(this.source);
        copy.id = this.id;
        copy.rawId = this.rawId;
        copy.uid = this.uid; // not really unique anymore :(
        EventDef.copyVerbatimStandardProps(this, copy);
        copy.className = this.className.slice(); // copy
        copy.miscProps = $.extend({}, this.miscProps);
        return copy;
    };
    EventDef.prototype.hasInverseRendering = function () {
        return this.getRendering() === 'inverse-background';
    };
    EventDef.prototype.hasBgRendering = function () {
        var rendering = this.getRendering();
        return rendering === 'inverse-background' || rendering === 'background';
    };
    EventDef.prototype.getRendering = function () {
        if (this.rendering != null) {
            return this.rendering;
        }
        return this.source.rendering;
    };
    EventDef.prototype.getConstraint = function () {
        if (this.constraint != null) {
            return this.constraint;
        }
        if (this.source.constraint != null) {
            return this.source.constraint;
        }
        return this.source.calendar.opt('eventConstraint'); // what about View option?
    };
    EventDef.prototype.getOverlap = function () {
        if (this.overlap != null) {
            return this.overlap;
        }
        if (this.source.overlap != null) {
            return this.source.overlap;
        }
        return this.source.calendar.opt('eventOverlap'); // what about View option?
    };
    EventDef.prototype.isStartExplicitlyEditable = function () {
        if (this.startEditable != null) {
            return this.startEditable;
        }
        return this.source.startEditable;
    };
    EventDef.prototype.isDurationExplicitlyEditable = function () {
        if (this.durationEditable != null) {
            return this.durationEditable;
        }
        return this.source.durationEditable;
    };
    EventDef.prototype.isExplicitlyEditable = function () {
        if (this.editable != null) {
            return this.editable;
        }
        return this.source.editable;
    };
    EventDef.prototype.toLegacy = function () {
        var obj = $.extend({}, this.miscProps);
        obj._id = this.uid;
        obj.source = this.source;
        obj.className = this.className.slice(); // copy
        obj.allDay = this.isAllDay();
        if (this.rawId != null) {
            obj.id = this.rawId;
        }
        EventDef.copyVerbatimStandardProps(this, obj);
        return obj;
    };
    EventDef.prototype.applyManualStandardProps = function (rawProps) {
        if (rawProps.id != null) {
            this.id = EventDef.normalizeId((this.rawId = rawProps.id));
        }
        else {
            this.id = EventDef.generateId();
        }
        if (rawProps._id != null) {
            this.uid = String(rawProps._id);
        }
        else {
            this.uid = EventDef.generateId();
        }
        // TODO: converge with EventSource
        if ($.isArray(rawProps.className)) {
            this.className = rawProps.className;
        }
        if (typeof rawProps.className === 'string') {
            this.className = rawProps.className.split(/\s+/);
        }
        return true;
    };
    EventDef.prototype.applyMiscProps = function (rawProps) {
        $.extend(this.miscProps, rawProps);
    };
    EventDef.uuid = 0;
    EventDef.defineStandardProps = ParsableModelMixin_1.default.defineStandardProps;
    EventDef.copyVerbatimStandardProps = ParsableModelMixin_1.default.copyVerbatimStandardProps;
    return EventDef;
}());
exports.default = EventDef;
ParsableModelMixin_1.default.mixInto(EventDef);
EventDef.defineStandardProps({
    // not automatically assigned (`false`)
    _id: false,
    id: false,
    className: false,
    source: false,
    // automatically assigned (`true`)
    title: true,
    url: true,
    rendering: true,
    constraint: true,
    overlap: true,
    editable: true,
    startEditable: true,
    durationEditable: true,
    color: true,
    backgroundColor: true,
    borderColor: true,
    textColor: true
});


/***/ }),
/* 35 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var EventRange_1 = __webpack_require__(211);
var EventFootprint_1 = __webpack_require__(36);
var ComponentFootprint_1 = __webpack_require__(12);
function eventDefsToEventInstances(eventDefs, unzonedRange) {
    var eventInstances = [];
    var i;
    for (i = 0; i < eventDefs.length; i++) {
        eventInstances.push.apply(eventInstances, // append
        eventDefs[i].buildInstances(unzonedRange));
    }
    return eventInstances;
}
exports.eventDefsToEventInstances = eventDefsToEventInstances;
function eventInstanceToEventRange(eventInstance) {
    return new EventRange_1.default(eventInstance.dateProfile.unzonedRange, eventInstance.def, eventInstance);
}
exports.eventInstanceToEventRange = eventInstanceToEventRange;
function eventRangeToEventFootprint(eventRange) {
    return new EventFootprint_1.default(new ComponentFootprint_1.default(eventRange.unzonedRange, eventRange.eventDef.isAllDay()), eventRange.eventDef, eventRange.eventInstance // might not exist
    );
}
exports.eventRangeToEventFootprint = eventRangeToEventFootprint;
function eventInstanceToUnzonedRange(eventInstance) {
    return eventInstance.dateProfile.unzonedRange;
}
exports.eventInstanceToUnzonedRange = eventInstanceToUnzonedRange;
function eventFootprintToComponentFootprint(eventFootprint) {
    return eventFootprint.componentFootprint;
}
exports.eventFootprintToComponentFootprint = eventFootprintToComponentFootprint;


/***/ }),
/* 36 */
/***/ (function(module, exports) {

Object.defineProperty(exports, "__esModule", { value: true });
var EventFootprint = /** @class */ (function () {
    function EventFootprint(componentFootprint, eventDef, eventInstance) {
        this.componentFootprint = componentFootprint;
        this.eventDef = eventDef;
        if (eventInstance) {
            this.eventInstance = eventInstance;
        }
    }
    EventFootprint.prototype.getEventLegacy = function () {
        return (this.eventInstance || this.eventDef).toLegacy();
    };
    return EventFootprint;
}());
exports.default = EventFootprint;


/***/ }),
/* 37 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var util_1 = __webpack_require__(4);
var EventDateProfile_1 = __webpack_require__(17);
var EventDef_1 = __webpack_require__(34);
var EventDefDateMutation_1 = __webpack_require__(50);
var SingleEventDef_1 = __webpack_require__(13);
var EventDefMutation = /** @class */ (function () {
    function EventDefMutation() {
    }
    EventDefMutation.createFromRawProps = function (eventInstance, rawProps, largeUnit) {
        var eventDef = eventInstance.def;
        var dateProps = {};
        var standardProps = {};
        var miscProps = {};
        var verbatimStandardProps = {};
        var eventDefId = null;
        var className = null;
        var propName;
        var dateProfile;
        var dateMutation;
        var defMutation;
        for (propName in rawProps) {
            if (EventDateProfile_1.default.isStandardProp(propName)) {
                dateProps[propName] = rawProps[propName];
            }
            else if (eventDef.isStandardProp(propName)) {
                standardProps[propName] = rawProps[propName];
            }
            else if (eventDef.miscProps[propName] !== rawProps[propName]) {
                miscProps[propName] = rawProps[propName];
            }
        }
        dateProfile = EventDateProfile_1.default.parse(dateProps, eventDef.source);
        if (dateProfile) {
            dateMutation = EventDefDateMutation_1.default.createFromDiff(eventInstance.dateProfile, dateProfile, largeUnit);
        }
        if (standardProps.id !== eventDef.id) {
            eventDefId = standardProps.id; // only apply if there's a change
        }
        if (!util_1.isArraysEqual(standardProps.className, eventDef.className)) {
            className = standardProps.className; // only apply if there's a change
        }
        EventDef_1.default.copyVerbatimStandardProps(standardProps, // src
        verbatimStandardProps // dest
        );
        defMutation = new EventDefMutation();
        defMutation.eventDefId = eventDefId;
        defMutation.className = className;
        defMutation.verbatimStandardProps = verbatimStandardProps;
        defMutation.miscProps = miscProps;
        if (dateMutation) {
            defMutation.dateMutation = dateMutation;
        }
        return defMutation;
    };
    /*
    eventDef assumed to be a SingleEventDef.
    returns an undo function.
    */
    EventDefMutation.prototype.mutateSingle = function (eventDef) {
        var origDateProfile;
        if (this.dateMutation) {
            origDateProfile = eventDef.dateProfile;
            eventDef.dateProfile = this.dateMutation.buildNewDateProfile(origDateProfile, eventDef.source.calendar);
        }
        // can't undo
        // TODO: more DRY with EventDef::applyManualStandardProps
        if (this.eventDefId != null) {
            eventDef.id = EventDef_1.default.normalizeId((eventDef.rawId = this.eventDefId));
        }
        // can't undo
        // TODO: more DRY with EventDef::applyManualStandardProps
        if (this.className) {
            eventDef.className = this.className;
        }
        // can't undo
        if (this.verbatimStandardProps) {
            SingleEventDef_1.default.copyVerbatimStandardProps(this.verbatimStandardProps, // src
            eventDef // dest
            );
        }
        // can't undo
        if (this.miscProps) {
            eventDef.applyMiscProps(this.miscProps);
        }
        if (origDateProfile) {
            return function () {
                eventDef.dateProfile = origDateProfile;
            };
        }
        else {
            return function () { };
        }
    };
    EventDefMutation.prototype.setDateMutation = function (dateMutation) {
        if (dateMutation && !dateMutation.isEmpty()) {
            this.dateMutation = dateMutation;
        }
        else {
            this.dateMutation = null;
        }
    };
    EventDefMutation.prototype.isEmpty = function () {
        return !this.dateMutation;
    };
    return EventDefMutation;
}());
exports.default = EventDefMutation;


/***/ }),
/* 38 */
/***/ (function(module, exports) {

Object.defineProperty(exports, "__esModule", { value: true });
exports.default = {
    sourceClasses: [],
    registerClass: function (EventSourceClass) {
        this.sourceClasses.unshift(EventSourceClass); // give highest priority
    },
    parse: function (rawInput, calendar) {
        var sourceClasses = this.sourceClasses;
        var i;
        var eventSource;
        for (i = 0; i < sourceClasses.length; i++) {
            eventSource = sourceClasses[i].parse(rawInput, calendar);
            if (eventSource) {
                return eventSource;
            }
        }
    }
};


/***/ }),
/* 39 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var $ = __webpack_require__(3);
var util_1 = __webpack_require__(4);
var Class_1 = __webpack_require__(33);
/*
Embodies a div that has potential scrollbars
*/
var Scroller = /** @class */ (function (_super) {
    tslib_1.__extends(Scroller, _super);
    function Scroller(options) {
        var _this = _super.call(this) || this;
        options = options || {};
        _this.overflowX = options.overflowX || options.overflow || 'auto';
        _this.overflowY = options.overflowY || options.overflow || 'auto';
        return _this;
    }
    Scroller.prototype.render = function () {
        this.el = this.renderEl();
        this.applyOverflow();
    };
    Scroller.prototype.renderEl = function () {
        return (this.scrollEl = $('<div class="fc-scroller"></div>'));
    };
    // sets to natural height, unlocks overflow
    Scroller.prototype.clear = function () {
        this.setHeight('auto');
        this.applyOverflow();
    };
    Scroller.prototype.destroy = function () {
        this.el.remove();
    };
    // Overflow
    // -----------------------------------------------------------------------------------------------------------------
    Scroller.prototype.applyOverflow = function () {
        this.scrollEl.css({
            'overflow-x': this.overflowX,
            'overflow-y': this.overflowY
        });
    };
    // Causes any 'auto' overflow values to resolves to 'scroll' or 'hidden'.
    // Useful for preserving scrollbar widths regardless of future resizes.
    // Can pass in scrollbarWidths for optimization.
    Scroller.prototype.lockOverflow = function (scrollbarWidths) {
        var overflowX = this.overflowX;
        var overflowY = this.overflowY;
        scrollbarWidths = scrollbarWidths || this.getScrollbarWidths();
        if (overflowX === 'auto') {
            overflowX = (scrollbarWidths.top || scrollbarWidths.bottom || // horizontal scrollbars?
                // OR scrolling pane with massless scrollbars?
                this.scrollEl[0].scrollWidth - 1 > this.scrollEl[0].clientWidth) ? 'scroll' : 'hidden';
        }
        if (overflowY === 'auto') {
            overflowY = (scrollbarWidths.left || scrollbarWidths.right || // vertical scrollbars?
                // OR scrolling pane with massless scrollbars?
                this.scrollEl[0].scrollHeight - 1 > this.scrollEl[0].clientHeight) ? 'scroll' : 'hidden';
        }
        this.scrollEl.css({ 'overflow-x': overflowX, 'overflow-y': overflowY });
    };
    // Getters / Setters
    // -----------------------------------------------------------------------------------------------------------------
    Scroller.prototype.setHeight = function (height) {
        this.scrollEl.height(height);
    };
    Scroller.prototype.getScrollTop = function () {
        return this.scrollEl.scrollTop();
    };
    Scroller.prototype.setScrollTop = function (top) {
        this.scrollEl.scrollTop(top);
    };
    Scroller.prototype.getClientWidth = function () {
        return this.scrollEl[0].clientWidth;
    };
    Scroller.prototype.getClientHeight = function () {
        return this.scrollEl[0].clientHeight;
    };
    Scroller.prototype.getScrollbarWidths = function () {
        return util_1.getScrollbarWidths(this.scrollEl);
    };
    return Scroller;
}(Class_1.default));
exports.default = Scroller;


/***/ }),
/* 40 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var $ = __webpack_require__(3);
var util_1 = __webpack_require__(4);
var DateComponent_1 = __webpack_require__(219);
var GlobalEmitter_1 = __webpack_require__(21);
var InteractiveDateComponent = /** @class */ (function (_super) {
    tslib_1.__extends(InteractiveDateComponent, _super);
    function InteractiveDateComponent(_view, _options) {
        var _this = _super.call(this, _view, _options) || this;
        // self-config, overridable by subclasses
        _this.segSelector = '.fc-event-container > *'; // what constitutes an event element?
        if (_this.dateSelectingClass) {
            _this.dateClicking = new _this.dateClickingClass(_this);
        }
        if (_this.dateSelectingClass) {
            _this.dateSelecting = new _this.dateSelectingClass(_this);
        }
        if (_this.eventPointingClass) {
            _this.eventPointing = new _this.eventPointingClass(_this);
        }
        if (_this.eventDraggingClass && _this.eventPointing) {
            _this.eventDragging = new _this.eventDraggingClass(_this, _this.eventPointing);
        }
        if (_this.eventResizingClass && _this.eventPointing) {
            _this.eventResizing = new _this.eventResizingClass(_this, _this.eventPointing);
        }
        if (_this.externalDroppingClass) {
            _this.externalDropping = new _this.externalDroppingClass(_this);
        }
        return _this;
    }
    // Sets the container element that the view should render inside of, does global DOM-related initializations,
    // and renders all the non-date-related content inside.
    InteractiveDateComponent.prototype.setElement = function (el) {
        _super.prototype.setElement.call(this, el);
        if (this.dateClicking) {
            this.dateClicking.bindToEl(el);
        }
        if (this.dateSelecting) {
            this.dateSelecting.bindToEl(el);
        }
        this.bindAllSegHandlersToEl(el);
    };
    InteractiveDateComponent.prototype.removeElement = function () {
        this.endInteractions();
        _super.prototype.removeElement.call(this);
    };
    InteractiveDateComponent.prototype.executeEventUnrender = function () {
        this.endInteractions();
        _super.prototype.executeEventUnrender.call(this);
    };
    InteractiveDateComponent.prototype.bindGlobalHandlers = function () {
        _super.prototype.bindGlobalHandlers.call(this);
        if (this.externalDropping) {
            this.externalDropping.bindToDocument();
        }
    };
    InteractiveDateComponent.prototype.unbindGlobalHandlers = function () {
        _super.prototype.unbindGlobalHandlers.call(this);
        if (this.externalDropping) {
            this.externalDropping.unbindFromDocument();
        }
    };
    InteractiveDateComponent.prototype.bindDateHandlerToEl = function (el, name, handler) {
        var _this = this;
        // attach a handler to the grid's root element.
        // jQuery will take care of unregistering them when removeElement gets called.
        this.el.on(name, function (ev) {
            if (!$(ev.target).is(_this.segSelector + ':not(.fc-helper),' + // directly on an event element
                _this.segSelector + ':not(.fc-helper) *,' + // within an event element
                '.fc-more,' + // a "more.." link
                'a[data-goto]' // a clickable nav link
            )) {
                return handler.call(_this, ev);
            }
        });
    };
    InteractiveDateComponent.prototype.bindAllSegHandlersToEl = function (el) {
        [
            this.eventPointing,
            this.eventDragging,
            this.eventResizing
        ].forEach(function (eventInteraction) {
            if (eventInteraction) {
                eventInteraction.bindToEl(el);
            }
        });
    };
    InteractiveDateComponent.prototype.bindSegHandlerToEl = function (el, name, handler) {
        var _this = this;
        el.on(name, this.segSelector, function (ev) {
            var segEl = $(ev.currentTarget);
            if (!segEl.is('.fc-helper')) {
                var seg = segEl.data('fc-seg'); // grab segment data. put there by View::renderEventsPayload
                if (seg && !_this.shouldIgnoreEventPointing()) {
                    return handler.call(_this, seg, ev); // context will be the Grid
                }
            }
        });
    };
    InteractiveDateComponent.prototype.shouldIgnoreMouse = function () {
        // HACK
        // This will still work even though bindDateHandlerToEl doesn't use GlobalEmitter.
        return GlobalEmitter_1.default.get().shouldIgnoreMouse();
    };
    InteractiveDateComponent.prototype.shouldIgnoreTouch = function () {
        var view = this._getView();
        // On iOS (and Android?) when a new selection is initiated overtop another selection,
        // the touchend never fires because the elements gets removed mid-touch-interaction (my theory).
        // HACK: simply don't allow this to happen.
        // ALSO: prevent selection when an *event* is already raised.
        return view.isSelected || view.selectedEvent;
    };
    InteractiveDateComponent.prototype.shouldIgnoreEventPointing = function () {
        // only call the handlers if there is not a drag/resize in progress
        return (this.eventDragging && this.eventDragging.isDragging) ||
            (this.eventResizing && this.eventResizing.isResizing);
    };
    InteractiveDateComponent.prototype.canStartSelection = function (seg, ev) {
        return util_1.getEvIsTouch(ev) &&
            !this.canStartResize(seg, ev) &&
            (this.isEventDefDraggable(seg.footprint.eventDef) ||
                this.isEventDefResizable(seg.footprint.eventDef));
    };
    InteractiveDateComponent.prototype.canStartDrag = function (seg, ev) {
        return !this.canStartResize(seg, ev) &&
            this.isEventDefDraggable(seg.footprint.eventDef);
    };
    InteractiveDateComponent.prototype.canStartResize = function (seg, ev) {
        var view = this._getView();
        var eventDef = seg.footprint.eventDef;
        return (!util_1.getEvIsTouch(ev) || view.isEventDefSelected(eventDef)) &&
            this.isEventDefResizable(eventDef) &&
            $(ev.target).is('.fc-resizer');
    };
    // Kills all in-progress dragging.
    // Useful for when public API methods that result in re-rendering are invoked during a drag.
    // Also useful for when touch devices misbehave and don't fire their touchend.
    InteractiveDateComponent.prototype.endInteractions = function () {
        [
            this.dateClicking,
            this.dateSelecting,
            this.eventPointing,
            this.eventDragging,
            this.eventResizing
        ].forEach(function (interaction) {
            if (interaction) {
                interaction.end();
            }
        });
    };
    // Event Drag-n-Drop
    // ---------------------------------------------------------------------------------------------------------------
    // Computes if the given event is allowed to be dragged by the user
    InteractiveDateComponent.prototype.isEventDefDraggable = function (eventDef) {
        return this.isEventDefStartEditable(eventDef);
    };
    InteractiveDateComponent.prototype.isEventDefStartEditable = function (eventDef) {
        var isEditable = eventDef.isStartExplicitlyEditable();
        if (isEditable == null) {
            isEditable = this.opt('eventStartEditable');
            if (isEditable == null) {
                isEditable = this.isEventDefGenerallyEditable(eventDef);
            }
        }
        return isEditable;
    };
    InteractiveDateComponent.prototype.isEventDefGenerallyEditable = function (eventDef) {
        var isEditable = eventDef.isExplicitlyEditable();
        if (isEditable == null) {
            isEditable = this.opt('editable');
        }
        return isEditable;
    };
    // Event Resizing
    // ---------------------------------------------------------------------------------------------------------------
    // Computes if the given event is allowed to be resized from its starting edge
    InteractiveDateComponent.prototype.isEventDefResizableFromStart = function (eventDef) {
        return this.opt('eventResizableFromStart') && this.isEventDefResizable(eventDef);
    };
    // Computes if the given event is allowed to be resized from its ending edge
    InteractiveDateComponent.prototype.isEventDefResizableFromEnd = function (eventDef) {
        return this.isEventDefResizable(eventDef);
    };
    // Computes if the given event is allowed to be resized by the user at all
    InteractiveDateComponent.prototype.isEventDefResizable = function (eventDef) {
        var isResizable = eventDef.isDurationExplicitlyEditable();
        if (isResizable == null) {
            isResizable = this.opt('eventDurationEditable');
            if (isResizable == null) {
                isResizable = this.isEventDefGenerallyEditable(eventDef);
            }
        }
        return isResizable;
    };
    // Event Mutation / Constraints
    // ---------------------------------------------------------------------------------------------------------------
    // Diffs the two dates, returning a duration, based on granularity of the grid
    // TODO: port isTimeScale into this system?
    InteractiveDateComponent.prototype.diffDates = function (a, b) {
        if (this.largeUnit) {
            return util_1.diffByUnit(a, b, this.largeUnit);
        }
        else {
            return util_1.diffDayTime(a, b);
        }
    };
    // is it allowed, in relation to the view's validRange?
    // NOTE: very similar to isExternalInstanceGroupAllowed
    InteractiveDateComponent.prototype.isEventInstanceGroupAllowed = function (eventInstanceGroup) {
        var view = this._getView();
        var dateProfile = this.dateProfile;
        var eventFootprints = this.eventRangesToEventFootprints(eventInstanceGroup.getAllEventRanges());
        var i;
        for (i = 0; i < eventFootprints.length; i++) {
            // TODO: just use getAllEventRanges directly
            if (!dateProfile.validUnzonedRange.containsRange(eventFootprints[i].componentFootprint.unzonedRange)) {
                return false;
            }
        }
        return view.calendar.constraints.isEventInstanceGroupAllowed(eventInstanceGroup);
    };
    // NOTE: very similar to isEventInstanceGroupAllowed
    // when it's a completely anonymous external drag, no event.
    InteractiveDateComponent.prototype.isExternalInstanceGroupAllowed = function (eventInstanceGroup) {
        var view = this._getView();
        var dateProfile = this.dateProfile;
        var eventFootprints = this.eventRangesToEventFootprints(eventInstanceGroup.getAllEventRanges());
        var i;
        for (i = 0; i < eventFootprints.length; i++) {
            if (!dateProfile.validUnzonedRange.containsRange(eventFootprints[i].componentFootprint.unzonedRange)) {
                return false;
            }
        }
        for (i = 0; i < eventFootprints.length; i++) {
            // treat it as a selection
            // TODO: pass in eventInstanceGroup instead
            //  because we don't want calendar's constraint system to depend on a component's
            //  determination of footprints.
            if (!view.calendar.constraints.isSelectionFootprintAllowed(eventFootprints[i].componentFootprint)) {
                return false;
            }
        }
        return true;
    };
    return InteractiveDateComponent;
}(DateComponent_1.default));
exports.default = InteractiveDateComponent;


/***/ }),
/* 41 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var $ = __webpack_require__(3);
var moment = __webpack_require__(0);
var util_1 = __webpack_require__(4);
var RenderQueue_1 = __webpack_require__(218);
var DateProfileGenerator_1 = __webpack_require__(221);
var InteractiveDateComponent_1 = __webpack_require__(40);
var GlobalEmitter_1 = __webpack_require__(21);
var UnzonedRange_1 = __webpack_require__(5);
/* An abstract class from which other views inherit from
----------------------------------------------------------------------------------------------------------------------*/
var View = /** @class */ (function (_super) {
    tslib_1.__extends(View, _super);
    function View(calendar, viewSpec) {
        var _this = _super.call(this, null, viewSpec.options) || this;
        _this.batchRenderDepth = 0;
        _this.isSelected = false; // boolean whether a range of time is user-selected or not
        _this.calendar = calendar;
        _this.viewSpec = viewSpec;
        // shortcuts
        _this.type = viewSpec.type;
        // .name is deprecated
        _this.name = _this.type;
        _this.initRenderQueue();
        _this.initHiddenDays();
        _this.dateProfileGenerator = new _this.dateProfileGeneratorClass(_this);
        _this.bindBaseRenderHandlers();
        _this.eventOrderSpecs = util_1.parseFieldSpecs(_this.opt('eventOrder'));
        // legacy
        if (_this['initialize']) {
            _this['initialize']();
        }
        return _this;
    }
    View.prototype._getView = function () {
        return this;
    };
    // Retrieves an option with the given name
    View.prototype.opt = function (name) {
        return this.options[name];
    };
    /* Render Queue
    ------------------------------------------------------------------------------------------------------------------*/
    View.prototype.initRenderQueue = function () {
        this.renderQueue = new RenderQueue_1.default({
            event: this.opt('eventRenderWait')
        });
        this.renderQueue.on('start', this.onRenderQueueStart.bind(this));
        this.renderQueue.on('stop', this.onRenderQueueStop.bind(this));
        this.on('before:change', this.startBatchRender);
        this.on('change', this.stopBatchRender);
    };
    View.prototype.onRenderQueueStart = function () {
        this.calendar.freezeContentHeight();
        this.addScroll(this.queryScroll());
    };
    View.prototype.onRenderQueueStop = function () {
        if (this.calendar.updateViewSize()) {
            this.popScroll();
        }
        this.calendar.thawContentHeight();
    };
    View.prototype.startBatchRender = function () {
        if (!(this.batchRenderDepth++)) {
            this.renderQueue.pause();
        }
    };
    View.prototype.stopBatchRender = function () {
        if (!(--this.batchRenderDepth)) {
            this.renderQueue.resume();
        }
    };
    View.prototype.requestRender = function (func, namespace, actionType) {
        this.renderQueue.queue(func, namespace, actionType);
    };
    // given func will auto-bind to `this`
    View.prototype.whenSizeUpdated = function (func) {
        if (this.renderQueue.isRunning) {
            this.renderQueue.one('stop', func.bind(this));
        }
        else {
            func.call(this);
        }
    };
    /* Title and Date Formatting
    ------------------------------------------------------------------------------------------------------------------*/
    // Computes what the title at the top of the calendar should be for this view
    View.prototype.computeTitle = function (dateProfile) {
        var unzonedRange;
        // for views that span a large unit of time, show the proper interval, ignoring stray days before and after
        if (/^(year|month)$/.test(dateProfile.currentRangeUnit)) {
            unzonedRange = dateProfile.currentUnzonedRange;
        }
        else {
            unzonedRange = dateProfile.activeUnzonedRange;
        }
        return this.formatRange({
            start: this.calendar.msToMoment(unzonedRange.startMs, dateProfile.isRangeAllDay),
            end: this.calendar.msToMoment(unzonedRange.endMs, dateProfile.isRangeAllDay)
        }, dateProfile.isRangeAllDay, this.opt('titleFormat') || this.computeTitleFormat(dateProfile), this.opt('titleRangeSeparator'));
    };
    // Generates the format string that should be used to generate the title for the current date range.
    // Attempts to compute the most appropriate format if not explicitly specified with `titleFormat`.
    View.prototype.computeTitleFormat = function (dateProfile) {
        var currentRangeUnit = dateProfile.currentRangeUnit;
        if (currentRangeUnit === 'year') {
            return 'YYYY';
        }
        else if (currentRangeUnit === 'month') {
            return this.opt('monthYearFormat'); // like "September 2014"
        }
        else if (dateProfile.currentUnzonedRange.as('days') > 1) {
            return 'll'; // multi-day range. shorter, like "Sep 9 - 10 2014"
        }
        else {
            return 'LL'; // one day. longer, like "September 9 2014"
        }
    };
    // Date Setting/Unsetting
    // -----------------------------------------------------------------------------------------------------------------
    View.prototype.setDate = function (date) {
        var currentDateProfile = this.get('dateProfile');
        var newDateProfile = this.dateProfileGenerator.build(date, undefined, true); // forceToValid=true
        if (!currentDateProfile ||
            !currentDateProfile.activeUnzonedRange.equals(newDateProfile.activeUnzonedRange)) {
            this.set('dateProfile', newDateProfile);
        }
    };
    View.prototype.unsetDate = function () {
        this.unset('dateProfile');
    };
    // Event Data
    // -----------------------------------------------------------------------------------------------------------------
    View.prototype.fetchInitialEvents = function (dateProfile) {
        var calendar = this.calendar;
        var forceAllDay = dateProfile.isRangeAllDay && !this.usesMinMaxTime;
        return calendar.requestEvents(calendar.msToMoment(dateProfile.activeUnzonedRange.startMs, forceAllDay), calendar.msToMoment(dateProfile.activeUnzonedRange.endMs, forceAllDay));
    };
    View.prototype.bindEventChanges = function () {
        this.listenTo(this.calendar, 'eventsReset', this.resetEvents); // TODO: make this a real event
    };
    View.prototype.unbindEventChanges = function () {
        this.stopListeningTo(this.calendar, 'eventsReset');
    };
    View.prototype.setEvents = function (eventsPayload) {
        this.set('currentEvents', eventsPayload);
        this.set('hasEvents', true);
    };
    View.prototype.unsetEvents = function () {
        this.unset('currentEvents');
        this.unset('hasEvents');
    };
    View.prototype.resetEvents = function (eventsPayload) {
        this.startBatchRender();
        this.unsetEvents();
        this.setEvents(eventsPayload);
        this.stopBatchRender();
    };
    // Date High-level Rendering
    // -----------------------------------------------------------------------------------------------------------------
    View.prototype.requestDateRender = function (dateProfile) {
        var _this = this;
        this.requestRender(function () {
            _this.executeDateRender(dateProfile);
        }, 'date', 'init');
    };
    View.prototype.requestDateUnrender = function () {
        var _this = this;
        this.requestRender(function () {
            _this.executeDateUnrender();
        }, 'date', 'destroy');
    };
    // if dateProfile not specified, uses current
    View.prototype.executeDateRender = function (dateProfile) {
        _super.prototype.executeDateRender.call(this, dateProfile);
        if (this['render']) {
            this['render'](); // TODO: deprecate
        }
        this.trigger('datesRendered');
        this.addScroll({ isDateInit: true });
        this.startNowIndicator(); // shouldn't render yet because updateSize will be called soon
    };
    View.prototype.executeDateUnrender = function () {
        this.unselect();
        this.stopNowIndicator();
        this.trigger('before:datesUnrendered');
        if (this['destroy']) {
            this['destroy'](); // TODO: deprecate
        }
        _super.prototype.executeDateUnrender.call(this);
    };
    // "Base" rendering
    // -----------------------------------------------------------------------------------------------------------------
    View.prototype.bindBaseRenderHandlers = function () {
        var _this = this;
        this.on('datesRendered', function () {
            _this.whenSizeUpdated(_this.triggerViewRender);
        });
        this.on('before:datesUnrendered', function () {
            _this.triggerViewDestroy();
        });
    };
    View.prototype.triggerViewRender = function () {
        this.publiclyTrigger('viewRender', {
            context: this,
            args: [this, this.el]
        });
    };
    View.prototype.triggerViewDestroy = function () {
        this.publiclyTrigger('viewDestroy', {
            context: this,
            args: [this, this.el]
        });
    };
    // Event High-level Rendering
    // -----------------------------------------------------------------------------------------------------------------
    View.prototype.requestEventsRender = function (eventsPayload) {
        var _this = this;
        this.requestRender(function () {
            _this.executeEventRender(eventsPayload);
            _this.whenSizeUpdated(_this.triggerAfterEventsRendered);
        }, 'event', 'init');
    };
    View.prototype.requestEventsUnrender = function () {
        var _this = this;
        this.requestRender(function () {
            _this.triggerBeforeEventsDestroyed();
            _this.executeEventUnrender();
        }, 'event', 'destroy');
    };
    // Business Hour High-level Rendering
    // -----------------------------------------------------------------------------------------------------------------
    View.prototype.requestBusinessHoursRender = function (businessHourGenerator) {
        var _this = this;
        this.requestRender(function () {
            _this.renderBusinessHours(businessHourGenerator);
        }, 'businessHours', 'init');
    };
    View.prototype.requestBusinessHoursUnrender = function () {
        var _this = this;
        this.requestRender(function () {
            _this.unrenderBusinessHours();
        }, 'businessHours', 'destroy');
    };
    // Misc view rendering utils
    // -----------------------------------------------------------------------------------------------------------------
    // Binds DOM handlers to elements that reside outside the view container, such as the document
    View.prototype.bindGlobalHandlers = function () {
        _super.prototype.bindGlobalHandlers.call(this);
        this.listenTo(GlobalEmitter_1.default.get(), {
            touchstart: this.processUnselect,
            mousedown: this.handleDocumentMousedown
        });
    };
    // Unbinds DOM handlers from elements that reside outside the view container
    View.prototype.unbindGlobalHandlers = function () {
        _super.prototype.unbindGlobalHandlers.call(this);
        this.stopListeningTo(GlobalEmitter_1.default.get());
    };
    /* Now Indicator
    ------------------------------------------------------------------------------------------------------------------*/
    // Immediately render the current time indicator and begins re-rendering it at an interval,
    // which is defined by this.getNowIndicatorUnit().
    // TODO: somehow do this for the current whole day's background too
    View.prototype.startNowIndicator = function () {
        var _this = this;
        var unit;
        var update;
        var delay; // ms wait value
        if (this.opt('nowIndicator')) {
            unit = this.getNowIndicatorUnit();
            if (unit) {
                update = util_1.proxy(this, 'updateNowIndicator'); // bind to `this`
                this.initialNowDate = this.calendar.getNow();
                this.initialNowQueriedMs = new Date().valueOf();
                // wait until the beginning of the next interval
                delay = this.initialNowDate.clone().startOf(unit).add(1, unit).valueOf() - this.initialNowDate.valueOf();
                this.nowIndicatorTimeoutID = setTimeout(function () {
                    _this.nowIndicatorTimeoutID = null;
                    update();
                    delay = +moment.duration(1, unit);
                    delay = Math.max(100, delay); // prevent too frequent
                    _this.nowIndicatorIntervalID = setInterval(update, delay); // update every interval
                }, delay);
            }
            // rendering will be initiated in updateSize
        }
    };
    // rerenders the now indicator, computing the new current time from the amount of time that has passed
    // since the initial getNow call.
    View.prototype.updateNowIndicator = function () {
        if (this.isDatesRendered &&
            this.initialNowDate // activated before?
        ) {
            this.unrenderNowIndicator(); // won't unrender if unnecessary
            this.renderNowIndicator(this.initialNowDate.clone().add(new Date().valueOf() - this.initialNowQueriedMs) // add ms
            );
            this.isNowIndicatorRendered = true;
        }
    };
    // Immediately unrenders the view's current time indicator and stops any re-rendering timers.
    // Won't cause side effects if indicator isn't rendered.
    View.prototype.stopNowIndicator = function () {
        if (this.isNowIndicatorRendered) {
            if (this.nowIndicatorTimeoutID) {
                clearTimeout(this.nowIndicatorTimeoutID);
                this.nowIndicatorTimeoutID = null;
            }
            if (this.nowIndicatorIntervalID) {
                clearInterval(this.nowIndicatorIntervalID);
                this.nowIndicatorIntervalID = null;
            }
            this.unrenderNowIndicator();
            this.isNowIndicatorRendered = false;
        }
    };
    /* Dimensions
    ------------------------------------------------------------------------------------------------------------------*/
    View.prototype.updateSize = function (totalHeight, isAuto, isResize) {
        if (this['setHeight']) {
            this['setHeight'](totalHeight, isAuto);
        }
        else {
            _super.prototype.updateSize.call(this, totalHeight, isAuto, isResize);
        }
        this.updateNowIndicator();
    };
    /* Scroller
    ------------------------------------------------------------------------------------------------------------------*/
    View.prototype.addScroll = function (scroll) {
        var queuedScroll = this.queuedScroll || (this.queuedScroll = {});
        $.extend(queuedScroll, scroll);
    };
    View.prototype.popScroll = function () {
        this.applyQueuedScroll();
        this.queuedScroll = null;
    };
    View.prototype.applyQueuedScroll = function () {
        if (this.queuedScroll) {
            this.applyScroll(this.queuedScroll);
        }
    };
    View.prototype.queryScroll = function () {
        var scroll = {};
        if (this.isDatesRendered) {
            $.extend(scroll, this.queryDateScroll());
        }
        return scroll;
    };
    View.prototype.applyScroll = function (scroll) {
        if (scroll.isDateInit && this.isDatesRendered) {
            $.extend(scroll, this.computeInitialDateScroll());
        }
        if (this.isDatesRendered) {
            this.applyDateScroll(scroll);
        }
    };
    View.prototype.computeInitialDateScroll = function () {
        return {}; // subclasses must implement
    };
    View.prototype.queryDateScroll = function () {
        return {}; // subclasses must implement
    };
    View.prototype.applyDateScroll = function (scroll) {
        // subclasses must implement
    };
    /* Event Drag-n-Drop
    ------------------------------------------------------------------------------------------------------------------*/
    View.prototype.reportEventDrop = function (eventInstance, eventMutation, el, ev) {
        var eventManager = this.calendar.eventManager;
        var undoFunc = eventManager.mutateEventsWithId(eventInstance.def.id, eventMutation);
        var dateMutation = eventMutation.dateMutation;
        // update the EventInstance, for handlers
        if (dateMutation) {
            eventInstance.dateProfile = dateMutation.buildNewDateProfile(eventInstance.dateProfile, this.calendar);
        }
        this.triggerEventDrop(eventInstance, 
        // a drop doesn't necessarily mean a date mutation (ex: resource change)
        (dateMutation && dateMutation.dateDelta) || moment.duration(), undoFunc, el, ev);
    };
    // Triggers event-drop handlers that have subscribed via the API
    View.prototype.triggerEventDrop = function (eventInstance, dateDelta, undoFunc, el, ev) {
        this.publiclyTrigger('eventDrop', {
            context: el[0],
            args: [
                eventInstance.toLegacy(),
                dateDelta,
                undoFunc,
                ev,
                {},
                this
            ]
        });
    };
    /* External Element Drag-n-Drop
    ------------------------------------------------------------------------------------------------------------------*/
    // Must be called when an external element, via jQuery UI, has been dropped onto the calendar.
    // `meta` is the parsed data that has been embedded into the dragging event.
    // `dropLocation` is an object that contains the new zoned start/end/allDay values for the event.
    View.prototype.reportExternalDrop = function (singleEventDef, isEvent, isSticky, el, ev, ui) {
        if (isEvent) {
            this.calendar.eventManager.addEventDef(singleEventDef, isSticky);
        }
        this.triggerExternalDrop(singleEventDef, isEvent, el, ev, ui);
    };
    // Triggers external-drop handlers that have subscribed via the API
    View.prototype.triggerExternalDrop = function (singleEventDef, isEvent, el, ev, ui) {
        // trigger 'drop' regardless of whether element represents an event
        this.publiclyTrigger('drop', {
            context: el[0],
            args: [
                singleEventDef.dateProfile.start.clone(),
                ev,
                ui,
                this
            ]
        });
        if (isEvent) {
            // signal an external event landed
            this.publiclyTrigger('eventReceive', {
                context: this,
                args: [
                    singleEventDef.buildInstance().toLegacy(),
                    this
                ]
            });
        }
    };
    /* Event Resizing
    ------------------------------------------------------------------------------------------------------------------*/
    // Must be called when an event in the view has been resized to a new length
    View.prototype.reportEventResize = function (eventInstance, eventMutation, el, ev) {
        var eventManager = this.calendar.eventManager;
        var undoFunc = eventManager.mutateEventsWithId(eventInstance.def.id, eventMutation);
        // update the EventInstance, for handlers
        eventInstance.dateProfile = eventMutation.dateMutation.buildNewDateProfile(eventInstance.dateProfile, this.calendar);
        this.triggerEventResize(eventInstance, eventMutation.dateMutation.endDelta, undoFunc, el, ev);
    };
    // Triggers event-resize handlers that have subscribed via the API
    View.prototype.triggerEventResize = function (eventInstance, durationDelta, undoFunc, el, ev) {
        this.publiclyTrigger('eventResize', {
            context: el[0],
            args: [
                eventInstance.toLegacy(),
                durationDelta,
                undoFunc,
                ev,
                {},
                this
            ]
        });
    };
    /* Selection (time range)
    ------------------------------------------------------------------------------------------------------------------*/
    // Selects a date span on the view. `start` and `end` are both Moments.
    // `ev` is the native mouse event that begin the interaction.
    View.prototype.select = function (footprint, ev) {
        this.unselect(ev);
        this.renderSelectionFootprint(footprint);
        this.reportSelection(footprint, ev);
    };
    View.prototype.renderSelectionFootprint = function (footprint) {
        if (this['renderSelection']) {
            this['renderSelection'](footprint.toLegacy(this.calendar));
        }
        else {
            _super.prototype.renderSelectionFootprint.call(this, footprint);
        }
    };
    // Called when a new selection is made. Updates internal state and triggers handlers.
    View.prototype.reportSelection = function (footprint, ev) {
        this.isSelected = true;
        this.triggerSelect(footprint, ev);
    };
    // Triggers handlers to 'select'
    View.prototype.triggerSelect = function (footprint, ev) {
        var dateProfile = this.calendar.footprintToDateProfile(footprint); // abuse of "Event"DateProfile?
        this.publiclyTrigger('select', {
            context: this,
            args: [
                dateProfile.start,
                dateProfile.end,
                ev,
                this
            ]
        });
    };
    // Undoes a selection. updates in the internal state and triggers handlers.
    // `ev` is the native mouse event that began the interaction.
    View.prototype.unselect = function (ev) {
        if (this.isSelected) {
            this.isSelected = false;
            if (this['destroySelection']) {
                this['destroySelection'](); // TODO: deprecate
            }
            this.unrenderSelection();
            this.publiclyTrigger('unselect', {
                context: this,
                args: [ev, this]
            });
        }
    };
    /* Event Selection
    ------------------------------------------------------------------------------------------------------------------*/
    View.prototype.selectEventInstance = function (eventInstance) {
        if (!this.selectedEventInstance ||
            this.selectedEventInstance !== eventInstance) {
            this.unselectEventInstance();
            this.getEventSegs().forEach(function (seg) {
                if (seg.footprint.eventInstance === eventInstance &&
                    seg.el // necessary?
                ) {
                    seg.el.addClass('fc-selected');
                }
            });
            this.selectedEventInstance = eventInstance;
        }
    };
    View.prototype.unselectEventInstance = function () {
        if (this.selectedEventInstance) {
            this.getEventSegs().forEach(function (seg) {
                if (seg.el) {
                    seg.el.removeClass('fc-selected');
                }
            });
            this.selectedEventInstance = null;
        }
    };
    View.prototype.isEventDefSelected = function (eventDef) {
        // event references might change on refetchEvents(), while selectedEventInstance doesn't,
        // so compare IDs
        return this.selectedEventInstance && this.selectedEventInstance.def.id === eventDef.id;
    };
    /* Mouse / Touch Unselecting (time range & event unselection)
    ------------------------------------------------------------------------------------------------------------------*/
    // TODO: move consistently to down/start or up/end?
    // TODO: don't kill previous selection if touch scrolling
    View.prototype.handleDocumentMousedown = function (ev) {
        if (util_1.isPrimaryMouseButton(ev)) {
            this.processUnselect(ev);
        }
    };
    View.prototype.processUnselect = function (ev) {
        this.processRangeUnselect(ev);
        this.processEventUnselect(ev);
    };
    View.prototype.processRangeUnselect = function (ev) {
        var ignore;
        // is there a time-range selection?
        if (this.isSelected && this.opt('unselectAuto')) {
            // only unselect if the clicked element is not identical to or inside of an 'unselectCancel' element
            ignore = this.opt('unselectCancel');
            if (!ignore || !$(ev.target).closest(ignore).length) {
                this.unselect(ev);
            }
        }
    };
    View.prototype.processEventUnselect = function (ev) {
        if (this.selectedEventInstance) {
            if (!$(ev.target).closest('.fc-selected').length) {
                this.unselectEventInstance();
            }
        }
    };
    /* Triggers
    ------------------------------------------------------------------------------------------------------------------*/
    View.prototype.triggerBaseRendered = function () {
        this.publiclyTrigger('viewRender', {
            context: this,
            args: [this, this.el]
        });
    };
    View.prototype.triggerBaseUnrendered = function () {
        this.publiclyTrigger('viewDestroy', {
            context: this,
            args: [this, this.el]
        });
    };
    // Triggers handlers to 'dayClick'
    // Span has start/end of the clicked area. Only the start is useful.
    View.prototype.triggerDayClick = function (footprint, dayEl, ev) {
        var dateProfile = this.calendar.footprintToDateProfile(footprint); // abuse of "Event"DateProfile?
        this.publiclyTrigger('dayClick', {
            context: dayEl,
            args: [dateProfile.start, ev, this]
        });
    };
    /* Date Utils
    ------------------------------------------------------------------------------------------------------------------*/
    // For DateComponent::getDayClasses
    View.prototype.isDateInOtherMonth = function (date, dateProfile) {
        return false;
    };
    // Arguments after name will be forwarded to a hypothetical function value
    // WARNING: passed-in arguments will be given to generator functions as-is and can cause side-effects.
    // Always clone your objects if you fear mutation.
    View.prototype.getUnzonedRangeOption = function (name) {
        var val = this.opt(name);
        if (typeof val === 'function') {
            val = val.apply(null, Array.prototype.slice.call(arguments, 1));
        }
        if (val) {
            return this.calendar.parseUnzonedRange(val);
        }
    };
    /* Hidden Days
    ------------------------------------------------------------------------------------------------------------------*/
    // Initializes internal variables related to calculating hidden days-of-week
    View.prototype.initHiddenDays = function () {
        var hiddenDays = this.opt('hiddenDays') || []; // array of day-of-week indices that are hidden
        var isHiddenDayHash = []; // is the day-of-week hidden? (hash with day-of-week-index -> bool)
        var dayCnt = 0;
        var i;
        if (this.opt('weekends') === false) {
            hiddenDays.push(0, 6); // 0=sunday, 6=saturday
        }
        for (i = 0; i < 7; i++) {
            if (!(isHiddenDayHash[i] = $.inArray(i, hiddenDays) !== -1)) {
                dayCnt++;
            }
        }
        if (!dayCnt) {
            throw new Error('invalid hiddenDays'); // all days were hidden? bad.
        }
        this.isHiddenDayHash = isHiddenDayHash;
    };
    // Remove days from the beginning and end of the range that are computed as hidden.
    // If the whole range is trimmed off, returns null
    View.prototype.trimHiddenDays = function (inputUnzonedRange) {
        var start = inputUnzonedRange.getStart();
        var end = inputUnzonedRange.getEnd();
        if (start) {
            start = this.skipHiddenDays(start);
        }
        if (end) {
            end = this.skipHiddenDays(end, -1, true);
        }
        if (start === null || end === null || start < end) {
            return new UnzonedRange_1.default(start, end);
        }
        return null;
    };
    // Is the current day hidden?
    // `day` is a day-of-week index (0-6), or a Moment
    View.prototype.isHiddenDay = function (day) {
        if (moment.isMoment(day)) {
            day = day.day();
        }
        return this.isHiddenDayHash[day];
    };
    // Incrementing the current day until it is no longer a hidden day, returning a copy.
    // DOES NOT CONSIDER validUnzonedRange!
    // If the initial value of `date` is not a hidden day, don't do anything.
    // Pass `isExclusive` as `true` if you are dealing with an end date.
    // `inc` defaults to `1` (increment one day forward each time)
    View.prototype.skipHiddenDays = function (date, inc, isExclusive) {
        if (inc === void 0) { inc = 1; }
        if (isExclusive === void 0) { isExclusive = false; }
        var out = date.clone();
        while (this.isHiddenDayHash[(out.day() + (isExclusive ? inc : 0) + 7) % 7]) {
            out.add(inc, 'days');
        }
        return out;
    };
    return View;
}(InteractiveDateComponent_1.default));
exports.default = View;
View.prototype.usesMinMaxTime = false;
View.prototype.dateProfileGeneratorClass = DateProfileGenerator_1.default;
View.watch('displayingDates', ['isInDom', 'dateProfile'], function (deps) {
    this.requestDateRender(deps.dateProfile);
}, function () {
    this.requestDateUnrender();
});
View.watch('displayingBusinessHours', ['displayingDates', 'businessHourGenerator'], function (deps) {
    this.requestBusinessHoursRender(deps.businessHourGenerator);
}, function () {
    this.requestBusinessHoursUnrender();
});
View.watch('initialEvents', ['dateProfile'], function (deps) {
    return this.fetchInitialEvents(deps.dateProfile);
});
View.watch('bindingEvents', ['initialEvents'], function (deps) {
    this.setEvents(deps.initialEvents);
    this.bindEventChanges();
}, function () {
    this.unbindEventChanges();
    this.unsetEvents();
});
View.watch('displayingEvents', ['displayingDates', 'hasEvents'], function () {
    this.requestEventsRender(this.get('currentEvents'));
}, function () {
    this.requestEventsUnrender();
});
View.watch('title', ['dateProfile'], function (deps) {
    return (this.title = this.computeTitle(deps.dateProfile)); // assign to View for legacy reasons
});
View.watch('legacyDateProps', ['dateProfile'], function (deps) {
    var calendar = this.calendar;
    var dateProfile = deps.dateProfile;
    // DEPRECATED, but we need to keep it updated...
    this.start = calendar.msToMoment(dateProfile.activeUnzonedRange.startMs, dateProfile.isRangeAllDay);
    this.end = calendar.msToMoment(dateProfile.activeUnzonedRange.endMs, dateProfile.isRangeAllDay);
    this.intervalStart = calendar.msToMoment(dateProfile.currentUnzonedRange.startMs, dateProfile.isRangeAllDay);
    this.intervalEnd = calendar.msToMoment(dateProfile.currentUnzonedRange.endMs, dateProfile.isRangeAllDay);
});


/***/ }),
/* 42 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var $ = __webpack_require__(3);
var util_1 = __webpack_require__(4);
var EventRenderer = /** @class */ (function () {
    function EventRenderer(component, fillRenderer) {
        this.view = component._getView();
        this.component = component;
        this.fillRenderer = fillRenderer;
    }
    EventRenderer.prototype.opt = function (name) {
        return this.view.opt(name);
    };
    // Updates values that rely on options and also relate to range
    EventRenderer.prototype.rangeUpdated = function () {
        var displayEventTime;
        var displayEventEnd;
        this.eventTimeFormat =
            this.opt('eventTimeFormat') ||
                this.opt('timeFormat') || // deprecated
                this.computeEventTimeFormat();
        displayEventTime = this.opt('displayEventTime');
        if (displayEventTime == null) {
            displayEventTime = this.computeDisplayEventTime(); // might be based off of range
        }
        displayEventEnd = this.opt('displayEventEnd');
        if (displayEventEnd == null) {
            displayEventEnd = this.computeDisplayEventEnd(); // might be based off of range
        }
        this.displayEventTime = displayEventTime;
        this.displayEventEnd = displayEventEnd;
    };
    EventRenderer.prototype.render = function (eventsPayload) {
        var dateProfile = this.component._getDateProfile();
        var eventDefId;
        var instanceGroup;
        var eventRanges;
        var bgRanges = [];
        var fgRanges = [];
        for (eventDefId in eventsPayload) {
            instanceGroup = eventsPayload[eventDefId];
            eventRanges = instanceGroup.sliceRenderRanges(dateProfile.activeUnzonedRange);
            if (instanceGroup.getEventDef().hasBgRendering()) {
                bgRanges.push.apply(bgRanges, eventRanges);
            }
            else {
                fgRanges.push.apply(fgRanges, eventRanges);
            }
        }
        this.renderBgRanges(bgRanges);
        this.renderFgRanges(fgRanges);
    };
    EventRenderer.prototype.unrender = function () {
        this.unrenderBgRanges();
        this.unrenderFgRanges();
    };
    EventRenderer.prototype.renderFgRanges = function (eventRanges) {
        var eventFootprints = this.component.eventRangesToEventFootprints(eventRanges);
        var segs = this.component.eventFootprintsToSegs(eventFootprints);
        // render an `.el` on each seg
        // returns a subset of the segs. segs that were actually rendered
        segs = this.renderFgSegEls(segs);
        if (this.renderFgSegs(segs) !== false) {
            this.fgSegs = segs;
        }
    };
    EventRenderer.prototype.unrenderFgRanges = function () {
        this.unrenderFgSegs(this.fgSegs || []);
        this.fgSegs = null;
    };
    EventRenderer.prototype.renderBgRanges = function (eventRanges) {
        var eventFootprints = this.component.eventRangesToEventFootprints(eventRanges);
        var segs = this.component.eventFootprintsToSegs(eventFootprints);
        if (this.renderBgSegs(segs) !== false) {
            this.bgSegs = segs;
        }
    };
    EventRenderer.prototype.unrenderBgRanges = function () {
        this.unrenderBgSegs();
        this.bgSegs = null;
    };
    EventRenderer.prototype.getSegs = function () {
        return (this.bgSegs || []).concat(this.fgSegs || []);
    };
    // Renders foreground event segments onto the grid
    EventRenderer.prototype.renderFgSegs = function (segs) {
        // subclasses must implement
        // segs already has rendered els, and has been filtered.
        return false; // signal failure if not implemented
    };
    // Unrenders all currently rendered foreground segments
    EventRenderer.prototype.unrenderFgSegs = function (segs) {
        // subclasses must implement
    };
    EventRenderer.prototype.renderBgSegs = function (segs) {
        var _this = this;
        if (this.fillRenderer) {
            this.fillRenderer.renderSegs('bgEvent', segs, {
                getClasses: function (seg) {
                    return _this.getBgClasses(seg.footprint.eventDef);
                },
                getCss: function (seg) {
                    return {
                        'background-color': _this.getBgColor(seg.footprint.eventDef)
                    };
                },
                filterEl: function (seg, el) {
                    return _this.filterEventRenderEl(seg.footprint, el);
                }
            });
        }
        else {
            return false; // signal failure if no fillRenderer
        }
    };
    EventRenderer.prototype.unrenderBgSegs = function () {
        if (this.fillRenderer) {
            this.fillRenderer.unrender('bgEvent');
        }
    };
    // Renders and assigns an `el` property for each foreground event segment.
    // Only returns segments that successfully rendered.
    EventRenderer.prototype.renderFgSegEls = function (segs, disableResizing) {
        var _this = this;
        if (disableResizing === void 0) { disableResizing = false; }
        var hasEventRenderHandlers = this.view.hasPublicHandlers('eventRender');
        var html = '';
        var renderedSegs = [];
        var i;
        if (segs.length) {
            // build a large concatenation of event segment HTML
            for (i = 0; i < segs.length; i++) {
                this.beforeFgSegHtml(segs[i]);
                html += this.fgSegHtml(segs[i], disableResizing);
            }
            // Grab individual elements from the combined HTML string. Use each as the default rendering.
            // Then, compute the 'el' for each segment. An el might be null if the eventRender callback returned false.
            $(html).each(function (i, node) {
                var seg = segs[i];
                var el = $(node);
                if (hasEventRenderHandlers) {
                    el = _this.filterEventRenderEl(seg.footprint, el);
                }
                if (el) {
                    el.data('fc-seg', seg); // used by handlers
                    seg.el = el;
                    renderedSegs.push(seg);
                }
            });
        }
        return renderedSegs;
    };
    EventRenderer.prototype.beforeFgSegHtml = function (seg) {
    };
    // Generates the HTML for the default rendering of a foreground event segment. Used by renderFgSegEls()
    EventRenderer.prototype.fgSegHtml = function (seg, disableResizing) {
        // subclasses should implement
    };
    // Generic utility for generating the HTML classNames for an event segment's element
    EventRenderer.prototype.getSegClasses = function (seg, isDraggable, isResizable) {
        var classes = [
            'fc-event',
            seg.isStart ? 'fc-start' : 'fc-not-start',
            seg.isEnd ? 'fc-end' : 'fc-not-end'
        ].concat(this.getClasses(seg.footprint.eventDef));
        if (isDraggable) {
            classes.push('fc-draggable');
        }
        if (isResizable) {
            classes.push('fc-resizable');
        }
        // event is currently selected? attach a className.
        if (this.view.isEventDefSelected(seg.footprint.eventDef)) {
            classes.push('fc-selected');
        }
        return classes;
    };
    // Given an event and the default element used for rendering, returns the element that should actually be used.
    // Basically runs events and elements through the eventRender hook.
    EventRenderer.prototype.filterEventRenderEl = function (eventFootprint, el) {
        var legacy = eventFootprint.getEventLegacy();
        var custom = this.view.publiclyTrigger('eventRender', {
            context: legacy,
            args: [legacy, el, this.view]
        });
        if (custom === false) {
            el = null;
        }
        else if (custom && custom !== true) {
            el = $(custom);
        }
        return el;
    };
    // Compute the text that should be displayed on an event's element.
    // `range` can be the Event object itself, or something range-like, with at least a `start`.
    // If event times are disabled, or the event has no time, will return a blank string.
    // If not specified, formatStr will default to the eventTimeFormat setting,
    // and displayEnd will default to the displayEventEnd setting.
    EventRenderer.prototype.getTimeText = function (eventFootprint, formatStr, displayEnd) {
        return this._getTimeText(eventFootprint.eventInstance.dateProfile.start, eventFootprint.eventInstance.dateProfile.end, eventFootprint.componentFootprint.isAllDay, formatStr, displayEnd);
    };
    EventRenderer.prototype._getTimeText = function (start, end, isAllDay, formatStr, displayEnd) {
        if (formatStr == null) {
            formatStr = this.eventTimeFormat;
        }
        if (displayEnd == null) {
            displayEnd = this.displayEventEnd;
        }
        if (this.displayEventTime && !isAllDay) {
            if (displayEnd && end) {
                return this.view.formatRange({ start: start, end: end }, false, // allDay
                formatStr);
            }
            else {
                return start.format(formatStr);
            }
        }
        return '';
    };
    EventRenderer.prototype.computeEventTimeFormat = function () {
        return this.opt('smallTimeFormat');
    };
    EventRenderer.prototype.computeDisplayEventTime = function () {
        return true;
    };
    EventRenderer.prototype.computeDisplayEventEnd = function () {
        return true;
    };
    EventRenderer.prototype.getBgClasses = function (eventDef) {
        var classNames = this.getClasses(eventDef);
        classNames.push('fc-bgevent');
        return classNames;
    };
    EventRenderer.prototype.getClasses = function (eventDef) {
        var objs = this.getStylingObjs(eventDef);
        var i;
        var classNames = [];
        for (i = 0; i < objs.length; i++) {
            classNames.push.apply(// append
            classNames, objs[i].eventClassName || objs[i].className || []);
        }
        return classNames;
    };
    // Utility for generating event skin-related CSS properties
    EventRenderer.prototype.getSkinCss = function (eventDef) {
        return {
            'background-color': this.getBgColor(eventDef),
            'border-color': this.getBorderColor(eventDef),
            color: this.getTextColor(eventDef)
        };
    };
    // Queries for caller-specified color, then falls back to default
    EventRenderer.prototype.getBgColor = function (eventDef) {
        var objs = this.getStylingObjs(eventDef);
        var i;
        var val;
        for (i = 0; i < objs.length && !val; i++) {
            val = objs[i].eventBackgroundColor || objs[i].eventColor ||
                objs[i].backgroundColor || objs[i].color;
        }
        if (!val) {
            val = this.opt('eventBackgroundColor') || this.opt('eventColor');
        }
        return val;
    };
    // Queries for caller-specified color, then falls back to default
    EventRenderer.prototype.getBorderColor = function (eventDef) {
        var objs = this.getStylingObjs(eventDef);
        var i;
        var val;
        for (i = 0; i < objs.length && !val; i++) {
            val = objs[i].eventBorderColor || objs[i].eventColor ||
                objs[i].borderColor || objs[i].color;
        }
        if (!val) {
            val = this.opt('eventBorderColor') || this.opt('eventColor');
        }
        return val;
    };
    // Queries for caller-specified color, then falls back to default
    EventRenderer.prototype.getTextColor = function (eventDef) {
        var objs = this.getStylingObjs(eventDef);
        var i;
        var val;
        for (i = 0; i < objs.length && !val; i++) {
            val = objs[i].eventTextColor ||
                objs[i].textColor;
        }
        if (!val) {
            val = this.opt('eventTextColor');
        }
        return val;
    };
    EventRenderer.prototype.getStylingObjs = function (eventDef) {
        var objs = this.getFallbackStylingObjs(eventDef);
        objs.unshift(eventDef);
        return objs;
    };
    EventRenderer.prototype.getFallbackStylingObjs = function (eventDef) {
        return [eventDef.source];
    };
    EventRenderer.prototype.sortEventSegs = function (segs) {
        segs.sort(util_1.proxy(this, 'compareEventSegs'));
    };
    // A cmp function for determining which segments should take visual priority
    EventRenderer.prototype.compareEventSegs = function (seg1, seg2) {
        var f1 = seg1.footprint;
        var f2 = seg2.footprint;
        var cf1 = f1.componentFootprint;
        var cf2 = f2.componentFootprint;
        var r1 = cf1.unzonedRange;
        var r2 = cf2.unzonedRange;
        return r1.startMs - r2.startMs || // earlier events go first
            (r2.endMs - r2.startMs) - (r1.endMs - r1.startMs) || // tie? longer events go first
            cf2.isAllDay - cf1.isAllDay || // tie? put all-day events first (booleans cast to 0/1)
            util_1.compareByFieldSpecs(f1.eventDef, f2.eventDef, this.view.eventOrderSpecs, f1.eventDef.miscProps, f2.eventDef.miscProps);
    };
    return EventRenderer;
}());
exports.default = EventRenderer;


/***/ }),
/* 43 */,
/* 44 */,
/* 45 */,
/* 46 */,
/* 47 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var moment_ext_1 = __webpack_require__(10);
// Plugin
// -------------------------------------------------------------------------------------------------
moment_ext_1.newMomentProto.format = function () {
    if (this._fullCalendar && arguments[0]) {
        return formatDate(this, arguments[0]); // our extended formatting
    }
    if (this._ambigTime) {
        return moment_ext_1.oldMomentFormat(englishMoment(this), 'YYYY-MM-DD');
    }
    if (this._ambigZone) {
        return moment_ext_1.oldMomentFormat(englishMoment(this), 'YYYY-MM-DD[T]HH:mm:ss');
    }
    if (this._fullCalendar) {
        // moment.format() doesn't ensure english, but we want to.
        return moment_ext_1.oldMomentFormat(englishMoment(this));
    }
    return moment_ext_1.oldMomentProto.format.apply(this, arguments);
};
moment_ext_1.newMomentProto.toISOString = function () {
    if (this._ambigTime) {
        return moment_ext_1.oldMomentFormat(englishMoment(this), 'YYYY-MM-DD');
    }
    if (this._ambigZone) {
        return moment_ext_1.oldMomentFormat(englishMoment(this), 'YYYY-MM-DD[T]HH:mm:ss');
    }
    if (this._fullCalendar) {
        // depending on browser, moment might not output english. ensure english.
        // https://github.com/moment/moment/blob/2.18.1/src/lib/moment/format.js#L22
        return moment_ext_1.oldMomentProto.toISOString.apply(englishMoment(this), arguments);
    }
    return moment_ext_1.oldMomentProto.toISOString.apply(this, arguments);
};
function englishMoment(mom) {
    if (mom.locale() !== 'en') {
        return mom.clone().locale('en');
    }
    return mom;
}
// Config
// ---------------------------------------------------------------------------------------------------------------------
/*
Inserted between chunks in the fake ("intermediate") formatting string.
Important that it passes as whitespace (\s) because moment often identifies non-standalone months
via a regexp with an \s.
*/
var PART_SEPARATOR = '\u000b'; // vertical tab
/*
Inserted as the first character of a literal-text chunk to indicate that the literal text is not actually literal text,
but rather, a "special" token that has custom rendering (see specialTokens map).
*/
var SPECIAL_TOKEN_MARKER = '\u001f'; // information separator 1
/*
Inserted at the beginning and end of a span of text that must have non-zero numeric characters.
Handling of these markers is done in a post-processing step at the very end of text rendering.
*/
var MAYBE_MARKER = '\u001e'; // information separator 2
var MAYBE_REGEXP = new RegExp(MAYBE_MARKER + '([^' + MAYBE_MARKER + ']*)' + MAYBE_MARKER, 'g'); // must be global
/*
Addition formatting tokens we want recognized
*/
var specialTokens = {
    t: function (date) {
        return moment_ext_1.oldMomentFormat(date, 'a').charAt(0);
    },
    T: function (date) {
        return moment_ext_1.oldMomentFormat(date, 'A').charAt(0);
    }
};
/*
The first characters of formatting tokens for units that are 1 day or larger.
`value` is for ranking relative size (lower means bigger).
`unit` is a normalized unit, used for comparing moments.
*/
var largeTokenMap = {
    Y: { value: 1, unit: 'year' },
    M: { value: 2, unit: 'month' },
    W: { value: 3, unit: 'week' },
    w: { value: 3, unit: 'week' },
    D: { value: 4, unit: 'day' },
    d: { value: 4, unit: 'day' } // day of week
};
// Single Date Formatting
// ---------------------------------------------------------------------------------------------------------------------
/*
Formats `date` with a Moment formatting string, but allow our non-zero areas and special token
*/
function formatDate(date, formatStr) {
    return renderFakeFormatString(getParsedFormatString(formatStr).fakeFormatString, date);
}
exports.formatDate = formatDate;
// Date Range Formatting
// -------------------------------------------------------------------------------------------------
// TODO: make it work with timezone offset
/*
Using a formatting string meant for a single date, generate a range string, like
"Sep 2 - 9 2013", that intelligently inserts a separator where the dates differ.
If the dates are the same as far as the format string is concerned, just return a single
rendering of one date, without any separator.
*/
function formatRange(date1, date2, formatStr, separator, isRTL) {
    var localeData;
    date1 = moment_ext_1.default.parseZone(date1);
    date2 = moment_ext_1.default.parseZone(date2);
    localeData = date1.localeData();
    // Expand localized format strings, like "LL" -> "MMMM D YYYY".
    // BTW, this is not important for `formatDate` because it is impossible to put custom tokens
    // or non-zero areas in Moment's localized format strings.
    formatStr = localeData.longDateFormat(formatStr) || formatStr;
    return renderParsedFormat(getParsedFormatString(formatStr), date1, date2, separator || ' - ', isRTL);
}
exports.formatRange = formatRange;
/*
Renders a range with an already-parsed format string.
*/
function renderParsedFormat(parsedFormat, date1, date2, separator, isRTL) {
    var sameUnits = parsedFormat.sameUnits;
    var unzonedDate1 = date1.clone().stripZone(); // for same-unit comparisons
    var unzonedDate2 = date2.clone().stripZone(); // "
    var renderedParts1 = renderFakeFormatStringParts(parsedFormat.fakeFormatString, date1);
    var renderedParts2 = renderFakeFormatStringParts(parsedFormat.fakeFormatString, date2);
    var leftI;
    var leftStr = '';
    var rightI;
    var rightStr = '';
    var middleI;
    var middleStr1 = '';
    var middleStr2 = '';
    var middleStr = '';
    // Start at the leftmost side of the formatting string and continue until you hit a token
    // that is not the same between dates.
    for (leftI = 0; leftI < sameUnits.length && (!sameUnits[leftI] || unzonedDate1.isSame(unzonedDate2, sameUnits[leftI])); leftI++) {
        leftStr += renderedParts1[leftI];
    }
    // Similarly, start at the rightmost side of the formatting string and move left
    for (rightI = sameUnits.length - 1; rightI > leftI && (!sameUnits[rightI] || unzonedDate1.isSame(unzonedDate2, sameUnits[rightI])); rightI--) {
        // If current chunk is on the boundary of unique date-content, and is a special-case
        // date-formatting postfix character, then don't consume it. Consider it unique date-content.
        // TODO: make configurable
        if (rightI - 1 === leftI && renderedParts1[rightI] === '.') {
            break;
        }
        rightStr = renderedParts1[rightI] + rightStr;
    }
    // The area in the middle is different for both of the dates.
    // Collect them distinctly so we can jam them together later.
    for (middleI = leftI; middleI <= rightI; middleI++) {
        middleStr1 += renderedParts1[middleI];
        middleStr2 += renderedParts2[middleI];
    }
    if (middleStr1 || middleStr2) {
        if (isRTL) {
            middleStr = middleStr2 + separator + middleStr1;
        }
        else {
            middleStr = middleStr1 + separator + middleStr2;
        }
    }
    return processMaybeMarkers(leftStr + middleStr + rightStr);
}
// Format String Parsing
// ---------------------------------------------------------------------------------------------------------------------
var parsedFormatStrCache = {};
/*
Returns a parsed format string, leveraging a cache.
*/
function getParsedFormatString(formatStr) {
    return parsedFormatStrCache[formatStr] ||
        (parsedFormatStrCache[formatStr] = parseFormatString(formatStr));
}
/*
Parses a format string into the following:
- fakeFormatString: a momentJS formatting string, littered with special control characters that get post-processed.
- sameUnits: for every part in fakeFormatString, if the part is a token, the value will be a unit string (like "day"),
  that indicates how similar a range's start & end must be in order to share the same formatted text.
  If not a token, then the value is null.
  Always a flat array (not nested liked "chunks").
*/
function parseFormatString(formatStr) {
    var chunks = chunkFormatString(formatStr);
    return {
        fakeFormatString: buildFakeFormatString(chunks),
        sameUnits: buildSameUnits(chunks)
    };
}
/*
Break the formatting string into an array of chunks.
A 'maybe' chunk will have nested chunks.
*/
function chunkFormatString(formatStr) {
    var chunks = [];
    var match;
    // TODO: more descrimination
    // \4 is a backreference to the first character of a multi-character set.
    var chunker = /\[([^\]]*)\]|\(([^\)]*)\)|(LTS|LT|(\w)\4*o?)|([^\w\[\(]+)/g;
    while ((match = chunker.exec(formatStr))) {
        if (match[1]) {
            chunks.push.apply(chunks, // append
            splitStringLiteral(match[1]));
        }
        else if (match[2]) {
            chunks.push({ maybe: chunkFormatString(match[2]) });
        }
        else if (match[3]) {
            chunks.push({ token: match[3] });
        }
        else if (match[5]) {
            chunks.push.apply(chunks, // append
            splitStringLiteral(match[5]));
        }
    }
    return chunks;
}
/*
Potentially splits a literal-text string into multiple parts. For special cases.
*/
function splitStringLiteral(s) {
    if (s === '. ') {
        return ['.', ' ']; // for locales with periods bound to the end of each year/month/date
    }
    else {
        return [s];
    }
}
/*
Given chunks parsed from a real format string, generate a fake (aka "intermediate") format string with special control
characters that will eventually be given to moment for formatting, and then post-processed.
*/
function buildFakeFormatString(chunks) {
    var parts = [];
    var i;
    var chunk;
    for (i = 0; i < chunks.length; i++) {
        chunk = chunks[i];
        if (typeof chunk === 'string') {
            parts.push('[' + chunk + ']');
        }
        else if (chunk.token) {
            if (chunk.token in specialTokens) {
                parts.push(SPECIAL_TOKEN_MARKER + // useful during post-processing
                    '[' + chunk.token + ']' // preserve as literal text
                );
            }
            else {
                parts.push(chunk.token); // unprotected text implies a format string
            }
        }
        else if (chunk.maybe) {
            parts.push(MAYBE_MARKER + // useful during post-processing
                buildFakeFormatString(chunk.maybe) +
                MAYBE_MARKER);
        }
    }
    return parts.join(PART_SEPARATOR);
}
/*
Given parsed chunks from a real formatting string, generates an array of unit strings (like "day") that indicate
in which regard two dates must be similar in order to share range formatting text.
The `chunks` can be nested (because of "maybe" chunks), however, the returned array will be flat.
*/
function buildSameUnits(chunks) {
    var units = [];
    var i;
    var chunk;
    var tokenInfo;
    for (i = 0; i < chunks.length; i++) {
        chunk = chunks[i];
        if (chunk.token) {
            tokenInfo = largeTokenMap[chunk.token.charAt(0)];
            units.push(tokenInfo ? tokenInfo.unit : 'second'); // default to a very strict same-second
        }
        else if (chunk.maybe) {
            units.push.apply(units, // append
            buildSameUnits(chunk.maybe));
        }
        else {
            units.push(null);
        }
    }
    return units;
}
// Rendering to text
// ---------------------------------------------------------------------------------------------------------------------
/*
Formats a date with a fake format string, post-processes the control characters, then returns.
*/
function renderFakeFormatString(fakeFormatString, date) {
    return processMaybeMarkers(renderFakeFormatStringParts(fakeFormatString, date).join(''));
}
/*
Formats a date into parts that will have been post-processed, EXCEPT for the "maybe" markers.
*/
function renderFakeFormatStringParts(fakeFormatString, date) {
    var parts = [];
    var fakeRender = moment_ext_1.oldMomentFormat(date, fakeFormatString);
    var fakeParts = fakeRender.split(PART_SEPARATOR);
    var i;
    var fakePart;
    for (i = 0; i < fakeParts.length; i++) {
        fakePart = fakeParts[i];
        if (fakePart.charAt(0) === SPECIAL_TOKEN_MARKER) {
            parts.push(
            // the literal string IS the token's name.
            // call special token's registered function.
            specialTokens[fakePart.substring(1)](date));
        }
        else {
            parts.push(fakePart);
        }
    }
    return parts;
}
/*
Accepts an almost-finally-formatted string and processes the "maybe" control characters, returning a new string.
*/
function processMaybeMarkers(s) {
    return s.replace(MAYBE_REGEXP, function (m0, m1) {
        if (m1.match(/[1-9]/)) {
            return m1;
        }
        else {
            return '';
        }
    });
}
// Misc Utils
// -------------------------------------------------------------------------------------------------
/*
Returns a unit string, either 'year', 'month', 'day', or null for the most granular formatting token in the string.
*/
function queryMostGranularFormatUnit(formatStr) {
    var chunks = chunkFormatString(formatStr);
    var i;
    var chunk;
    var candidate;
    var best;
    for (i = 0; i < chunks.length; i++) {
        chunk = chunks[i];
        if (chunk.token) {
            candidate = largeTokenMap[chunk.token.charAt(0)];
            if (candidate) {
                if (!best || candidate.value > best.value) {
                    best = candidate;
                }
            }
        }
    }
    if (best) {
        return best.unit;
    }
    return null;
}
exports.queryMostGranularFormatUnit = queryMostGranularFormatUnit;


/***/ }),
/* 48 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var Class_1 = __webpack_require__(33);
var EmitterMixin_1 = __webpack_require__(11);
var ListenerMixin_1 = __webpack_require__(7);
var Model = /** @class */ (function (_super) {
    tslib_1.__extends(Model, _super);
    function Model() {
        var _this = _super.call(this) || this;
        _this._watchers = {};
        _this._props = {};
        _this.applyGlobalWatchers();
        _this.constructed();
        return _this;
    }
    Model.watch = function (name) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        // subclasses should make a masked-copy of the superclass's map
        // TODO: write test
        if (!this.prototype.hasOwnProperty('_globalWatchArgs')) {
            this.prototype._globalWatchArgs = Object.create(this.prototype._globalWatchArgs);
        }
        this.prototype._globalWatchArgs[name] = args;
    };
    Model.prototype.constructed = function () {
        // useful for monkeypatching. TODO: BaseClass?
    };
    Model.prototype.applyGlobalWatchers = function () {
        var map = this._globalWatchArgs;
        var name;
        for (name in map) {
            this.watch.apply(this, [name].concat(map[name]));
        }
    };
    Model.prototype.has = function (name) {
        return name in this._props;
    };
    Model.prototype.get = function (name) {
        if (name === undefined) {
            return this._props;
        }
        return this._props[name];
    };
    Model.prototype.set = function (name, val) {
        var newProps;
        if (typeof name === 'string') {
            newProps = {};
            newProps[name] = val === undefined ? null : val;
        }
        else {
            newProps = name;
        }
        this.setProps(newProps);
    };
    Model.prototype.reset = function (newProps) {
        var oldProps = this._props;
        var changeset = {}; // will have undefined's to signal unsets
        var name;
        for (name in oldProps) {
            changeset[name] = undefined;
        }
        for (name in newProps) {
            changeset[name] = newProps[name];
        }
        this.setProps(changeset);
    };
    Model.prototype.unset = function (name) {
        var newProps = {};
        var names;
        var i;
        if (typeof name === 'string') {
            names = [name];
        }
        else {
            names = name;
        }
        for (i = 0; i < names.length; i++) {
            newProps[names[i]] = undefined;
        }
        this.setProps(newProps);
    };
    Model.prototype.setProps = function (newProps) {
        var changedProps = {};
        var changedCnt = 0;
        var name;
        var val;
        for (name in newProps) {
            val = newProps[name];
            // a change in value?
            // if an object, don't check equality, because might have been mutated internally.
            // TODO: eventually enforce immutability.
            if (typeof val === 'object' ||
                val !== this._props[name]) {
                changedProps[name] = val;
                changedCnt++;
            }
        }
        if (changedCnt) {
            this.trigger('before:batchChange', changedProps);
            for (name in changedProps) {
                val = changedProps[name];
                this.trigger('before:change', name, val);
                this.trigger('before:change:' + name, val);
            }
            for (name in changedProps) {
                val = changedProps[name];
                if (val === undefined) {
                    delete this._props[name];
                }
                else {
                    this._props[name] = val;
                }
                this.trigger('change:' + name, val);
                this.trigger('change', name, val);
            }
            this.trigger('batchChange', changedProps);
        }
    };
    Model.prototype.watch = function (name, depList, startFunc, stopFunc) {
        var _this = this;
        this.unwatch(name);
        this._watchers[name] = this._watchDeps(depList, function (deps) {
            var res = startFunc.call(_this, deps);
            if (res && res.then) {
                _this.unset(name); // put in an unset state while resolving
                res.then(function (val) {
                    _this.set(name, val);
                });
            }
            else {
                _this.set(name, res);
            }
        }, function (deps) {
            _this.unset(name);
            if (stopFunc) {
                stopFunc.call(_this, deps);
            }
        });
    };
    Model.prototype.unwatch = function (name) {
        var watcher = this._watchers[name];
        if (watcher) {
            delete this._watchers[name];
            watcher.teardown();
        }
    };
    Model.prototype._watchDeps = function (depList, startFunc, stopFunc) {
        var _this = this;
        var queuedChangeCnt = 0;
        var depCnt = depList.length;
        var satisfyCnt = 0;
        var values = {}; // what's passed as the `deps` arguments
        var bindTuples = []; // array of [ eventName, handlerFunc ] arrays
        var isCallingStop = false;
        var onBeforeDepChange = function (depName, val, isOptional) {
            queuedChangeCnt++;
            if (queuedChangeCnt === 1) {
                if (satisfyCnt === depCnt) {
                    isCallingStop = true;
                    stopFunc(values);
                    isCallingStop = false;
                }
            }
        };
        var onDepChange = function (depName, val, isOptional) {
            if (val === undefined) {
                // required dependency that was previously set?
                if (!isOptional && values[depName] !== undefined) {
                    satisfyCnt--;
                }
                delete values[depName];
            }
            else {
                // required dependency that was previously unset?
                if (!isOptional && values[depName] === undefined) {
                    satisfyCnt++;
                }
                values[depName] = val;
            }
            queuedChangeCnt--;
            if (!queuedChangeCnt) {
                // now finally satisfied or satisfied all along?
                if (satisfyCnt === depCnt) {
                    // if the stopFunc initiated another value change, ignore it.
                    // it will be processed by another change event anyway.
                    if (!isCallingStop) {
                        startFunc(values);
                    }
                }
            }
        };
        // intercept for .on() that remembers handlers
        var bind = function (eventName, handler) {
            _this.on(eventName, handler);
            bindTuples.push([eventName, handler]);
        };
        // listen to dependency changes
        depList.forEach(function (depName) {
            var isOptional = false;
            if (depName.charAt(0) === '?') {
                depName = depName.substring(1);
                isOptional = true;
            }
            bind('before:change:' + depName, function (val) {
                onBeforeDepChange(depName, val, isOptional);
            });
            bind('change:' + depName, function (val) {
                onDepChange(depName, val, isOptional);
            });
        });
        // process current dependency values
        depList.forEach(function (depName) {
            var isOptional = false;
            if (depName.charAt(0) === '?') {
                depName = depName.substring(1);
                isOptional = true;
            }
            if (_this.has(depName)) {
                values[depName] = _this.get(depName);
                satisfyCnt++;
            }
            else if (isOptional) {
                satisfyCnt++;
            }
        });
        // initially satisfied
        if (satisfyCnt === depCnt) {
            startFunc(values);
        }
        return {
            teardown: function () {
                // remove all handlers
                for (var i = 0; i < bindTuples.length; i++) {
                    _this.off(bindTuples[i][0], bindTuples[i][1]);
                }
                bindTuples = null;
                // was satisfied, so call stopFunc
                if (satisfyCnt === depCnt) {
                    stopFunc();
                }
            },
            flash: function () {
                if (satisfyCnt === depCnt) {
                    stopFunc();
                    startFunc(values);
                }
            }
        };
    };
    Model.prototype.flash = function (name) {
        var watcher = this._watchers[name];
        if (watcher) {
            watcher.flash();
        }
    };
    return Model;
}(Class_1.default));
exports.default = Model;
Model.prototype._globalWatchArgs = {}; // mutation protection in Model.watch
EmitterMixin_1.default.mixInto(Model);
ListenerMixin_1.default.mixInto(Model);


/***/ }),
/* 49 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var moment = __webpack_require__(0);
var util_1 = __webpack_require__(4);
var SingleEventDef_1 = __webpack_require__(13);
var RecurringEventDef_1 = __webpack_require__(210);
exports.default = {
    parse: function (eventInput, source) {
        if (util_1.isTimeString(eventInput.start) || moment.isDuration(eventInput.start) ||
            util_1.isTimeString(eventInput.end) || moment.isDuration(eventInput.end)) {
            return RecurringEventDef_1.default.parse(eventInput, source);
        }
        else {
            return SingleEventDef_1.default.parse(eventInput, source);
        }
    }
};


/***/ }),
/* 50 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var util_1 = __webpack_require__(4);
var EventDateProfile_1 = __webpack_require__(17);
var EventDefDateMutation = /** @class */ (function () {
    function EventDefDateMutation() {
        this.clearEnd = false;
        this.forceTimed = false;
        this.forceAllDay = false;
    }
    EventDefDateMutation.createFromDiff = function (dateProfile0, dateProfile1, largeUnit) {
        var clearEnd = dateProfile0.end && !dateProfile1.end;
        var forceTimed = dateProfile0.isAllDay() && !dateProfile1.isAllDay();
        var forceAllDay = !dateProfile0.isAllDay() && dateProfile1.isAllDay();
        var dateDelta;
        var endDiff;
        var endDelta;
        var mutation;
        // subtracts the dates in the appropriate way, returning a duration
        function subtractDates(date1, date0) {
            if (largeUnit) {
                return util_1.diffByUnit(date1, date0, largeUnit); // poorly named
            }
            else if (dateProfile1.isAllDay()) {
                return util_1.diffDay(date1, date0); // poorly named
            }
            else {
                return util_1.diffDayTime(date1, date0); // poorly named
            }
        }
        dateDelta = subtractDates(dateProfile1.start, dateProfile0.start);
        if (dateProfile1.end) {
            // use unzonedRanges because dateProfile0.end might be null
            endDiff = subtractDates(dateProfile1.unzonedRange.getEnd(), dateProfile0.unzonedRange.getEnd());
            endDelta = endDiff.subtract(dateDelta);
        }
        mutation = new EventDefDateMutation();
        mutation.clearEnd = clearEnd;
        mutation.forceTimed = forceTimed;
        mutation.forceAllDay = forceAllDay;
        mutation.setDateDelta(dateDelta);
        mutation.setEndDelta(endDelta);
        return mutation;
    };
    /*
    returns an undo function.
    */
    EventDefDateMutation.prototype.buildNewDateProfile = function (eventDateProfile, calendar) {
        var start = eventDateProfile.start.clone();
        var end = null;
        var shouldRezone = false;
        if (eventDateProfile.end && !this.clearEnd) {
            end = eventDateProfile.end.clone();
        }
        else if (this.endDelta && !end) {
            end = calendar.getDefaultEventEnd(eventDateProfile.isAllDay(), start);
        }
        if (this.forceTimed) {
            shouldRezone = true;
            if (!start.hasTime()) {
                start.time(0);
            }
            if (end && !end.hasTime()) {
                end.time(0);
            }
        }
        else if (this.forceAllDay) {
            if (start.hasTime()) {
                start.stripTime();
            }
            if (end && end.hasTime()) {
                end.stripTime();
            }
        }
        if (this.dateDelta) {
            shouldRezone = true;
            start.add(this.dateDelta);
            if (end) {
                end.add(this.dateDelta);
            }
        }
        // do this before adding startDelta to start, so we can work off of start
        if (this.endDelta) {
            shouldRezone = true;
            end.add(this.endDelta);
        }
        if (this.startDelta) {
            shouldRezone = true;
            start.add(this.startDelta);
        }
        if (shouldRezone) {
            start = calendar.applyTimezone(start);
            if (end) {
                end = calendar.applyTimezone(end);
            }
        }
        // TODO: okay to access calendar option?
        if (!end && calendar.opt('forceEventDuration')) {
            end = calendar.getDefaultEventEnd(eventDateProfile.isAllDay(), start);
        }
        return new EventDateProfile_1.default(start, end, calendar);
    };
    EventDefDateMutation.prototype.setDateDelta = function (dateDelta) {
        if (dateDelta && dateDelta.valueOf()) {
            this.dateDelta = dateDelta;
        }
        else {
            this.dateDelta = null;
        }
    };
    EventDefDateMutation.prototype.setStartDelta = function (startDelta) {
        if (startDelta && startDelta.valueOf()) {
            this.startDelta = startDelta;
        }
        else {
            this.startDelta = null;
        }
    };
    EventDefDateMutation.prototype.setEndDelta = function (endDelta) {
        if (endDelta && endDelta.valueOf()) {
            this.endDelta = endDelta;
        }
        else {
            this.endDelta = null;
        }
    };
    EventDefDateMutation.prototype.isEmpty = function () {
        return !this.clearEnd && !this.forceTimed && !this.forceAllDay &&
            !this.dateDelta && !this.startDelta && !this.endDelta;
    };
    return EventDefDateMutation;
}());
exports.default = EventDefDateMutation;


/***/ }),
/* 51 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var StandardTheme_1 = __webpack_require__(213);
var JqueryUiTheme_1 = __webpack_require__(214);
var themeClassHash = {};
function defineThemeSystem(themeName, themeClass) {
    themeClassHash[themeName] = themeClass;
}
exports.defineThemeSystem = defineThemeSystem;
function getThemeSystemClass(themeSetting) {
    if (!themeSetting) {
        return StandardTheme_1.default;
    }
    else if (themeSetting === true) {
        return JqueryUiTheme_1.default;
    }
    else {
        return themeClassHash[themeSetting];
    }
}
exports.getThemeSystemClass = getThemeSystemClass;


/***/ }),
/* 52 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var $ = __webpack_require__(3);
var util_1 = __webpack_require__(4);
var Promise_1 = __webpack_require__(20);
var EventSource_1 = __webpack_require__(6);
var SingleEventDef_1 = __webpack_require__(13);
var ArrayEventSource = /** @class */ (function (_super) {
    tslib_1.__extends(ArrayEventSource, _super);
    function ArrayEventSource(calendar) {
        var _this = _super.call(this, calendar) || this;
        _this.eventDefs = []; // for if setRawEventDefs is never called
        return _this;
    }
    ArrayEventSource.parse = function (rawInput, calendar) {
        var rawProps;
        // normalize raw input
        if ($.isArray(rawInput.events)) {
            rawProps = rawInput;
        }
        else if ($.isArray(rawInput)) {
            rawProps = { events: rawInput };
        }
        if (rawProps) {
            return EventSource_1.default.parse.call(this, rawProps, calendar);
        }
        return false;
    };
    ArrayEventSource.prototype.setRawEventDefs = function (rawEventDefs) {
        this.rawEventDefs = rawEventDefs;
        this.eventDefs = this.parseEventDefs(rawEventDefs);
    };
    ArrayEventSource.prototype.fetch = function (start, end, timezone) {
        var eventDefs = this.eventDefs;
        var i;
        if (this.currentTimezone != null &&
            this.currentTimezone !== timezone) {
            for (i = 0; i < eventDefs.length; i++) {
                if (eventDefs[i] instanceof SingleEventDef_1.default) {
                    eventDefs[i].rezone();
                }
            }
        }
        this.currentTimezone = timezone;
        return Promise_1.default.resolve(eventDefs);
    };
    ArrayEventSource.prototype.addEventDef = function (eventDef) {
        this.eventDefs.push(eventDef);
    };
    /*
    eventDefId already normalized to a string
    */
    ArrayEventSource.prototype.removeEventDefsById = function (eventDefId) {
        return util_1.removeMatching(this.eventDefs, function (eventDef) {
            return eventDef.id === eventDefId;
        });
    };
    ArrayEventSource.prototype.removeAllEventDefs = function () {
        this.eventDefs = [];
    };
    ArrayEventSource.prototype.getPrimitive = function () {
        return this.rawEventDefs;
    };
    ArrayEventSource.prototype.applyManualStandardProps = function (rawProps) {
        var superSuccess = _super.prototype.applyManualStandardProps.call(this, rawProps);
        this.setRawEventDefs(rawProps.events);
        return superSuccess;
    };
    return ArrayEventSource;
}(EventSource_1.default));
exports.default = ArrayEventSource;
ArrayEventSource.defineStandardProps({
    events: false // don't automatically transfer
});


/***/ }),
/* 53 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var $ = __webpack_require__(3);
var util_1 = __webpack_require__(4);
/*
A cache for the left/right/top/bottom/width/height values for one or more elements.
Works with both offset (from topleft document) and position (from offsetParent).

options:
- els
- isHorizontal
- isVertical
*/
var CoordCache = /** @class */ (function () {
    function CoordCache(options) {
        this.isHorizontal = false; // whether to query for left/right/width
        this.isVertical = false; // whether to query for top/bottom/height
        this.els = $(options.els);
        this.isHorizontal = options.isHorizontal;
        this.isVertical = options.isVertical;
        this.forcedOffsetParentEl = options.offsetParent ? $(options.offsetParent) : null;
    }
    // Queries the els for coordinates and stores them.
    // Call this method before using and of the get* methods below.
    CoordCache.prototype.build = function () {
        var offsetParentEl = this.forcedOffsetParentEl;
        if (!offsetParentEl && this.els.length > 0) {
            offsetParentEl = this.els.eq(0).offsetParent();
        }
        this.origin = offsetParentEl ?
            offsetParentEl.offset() :
            null;
        this.boundingRect = this.queryBoundingRect();
        if (this.isHorizontal) {
            this.buildElHorizontals();
        }
        if (this.isVertical) {
            this.buildElVerticals();
        }
    };
    // Destroys all internal data about coordinates, freeing memory
    CoordCache.prototype.clear = function () {
        this.origin = null;
        this.boundingRect = null;
        this.lefts = null;
        this.rights = null;
        this.tops = null;
        this.bottoms = null;
    };
    // When called, if coord caches aren't built, builds them
    CoordCache.prototype.ensureBuilt = function () {
        if (!this.origin) {
            this.build();
        }
    };
    // Populates the left/right internal coordinate arrays
    CoordCache.prototype.buildElHorizontals = function () {
        var lefts = [];
        var rights = [];
        this.els.each(function (i, node) {
            var el = $(node);
            var left = el.offset().left;
            var width = el.outerWidth();
            lefts.push(left);
            rights.push(left + width);
        });
        this.lefts = lefts;
        this.rights = rights;
    };
    // Populates the top/bottom internal coordinate arrays
    CoordCache.prototype.buildElVerticals = function () {
        var tops = [];
        var bottoms = [];
        this.els.each(function (i, node) {
            var el = $(node);
            var top = el.offset().top;
            var height = el.outerHeight();
            tops.push(top);
            bottoms.push(top + height);
        });
        this.tops = tops;
        this.bottoms = bottoms;
    };
    // Given a left offset (from document left), returns the index of the el that it horizontally intersects.
    // If no intersection is made, returns undefined.
    CoordCache.prototype.getHorizontalIndex = function (leftOffset) {
        this.ensureBuilt();
        var lefts = this.lefts;
        var rights = this.rights;
        var len = lefts.length;
        var i;
        for (i = 0; i < len; i++) {
            if (leftOffset >= lefts[i] && leftOffset < rights[i]) {
                return i;
            }
        }
    };
    // Given a top offset (from document top), returns the index of the el that it vertically intersects.
    // If no intersection is made, returns undefined.
    CoordCache.prototype.getVerticalIndex = function (topOffset) {
        this.ensureBuilt();
        var tops = this.tops;
        var bottoms = this.bottoms;
        var len = tops.length;
        var i;
        for (i = 0; i < len; i++) {
            if (topOffset >= tops[i] && topOffset < bottoms[i]) {
                return i;
            }
        }
    };
    // Gets the left offset (from document left) of the element at the given index
    CoordCache.prototype.getLeftOffset = function (leftIndex) {
        this.ensureBuilt();
        return this.lefts[leftIndex];
    };
    // Gets the left position (from offsetParent left) of the element at the given index
    CoordCache.prototype.getLeftPosition = function (leftIndex) {
        this.ensureBuilt();
        return this.lefts[leftIndex] - this.origin.left;
    };
    // Gets the right offset (from document left) of the element at the given index.
    // This value is NOT relative to the document's right edge, like the CSS concept of "right" would be.
    CoordCache.prototype.getRightOffset = function (leftIndex) {
        this.ensureBuilt();
        return this.rights[leftIndex];
    };
    // Gets the right position (from offsetParent left) of the element at the given index.
    // This value is NOT relative to the offsetParent's right edge, like the CSS concept of "right" would be.
    CoordCache.prototype.getRightPosition = function (leftIndex) {
        this.ensureBuilt();
        return this.rights[leftIndex] - this.origin.left;
    };
    // Gets the width of the element at the given index
    CoordCache.prototype.getWidth = function (leftIndex) {
        this.ensureBuilt();
        return this.rights[leftIndex] - this.lefts[leftIndex];
    };
    // Gets the top offset (from document top) of the element at the given index
    CoordCache.prototype.getTopOffset = function (topIndex) {
        this.ensureBuilt();
        return this.tops[topIndex];
    };
    // Gets the top position (from offsetParent top) of the element at the given position
    CoordCache.prototype.getTopPosition = function (topIndex) {
        this.ensureBuilt();
        return this.tops[topIndex] - this.origin.top;
    };
    // Gets the bottom offset (from the document top) of the element at the given index.
    // This value is NOT relative to the offsetParent's bottom edge, like the CSS concept of "bottom" would be.
    CoordCache.prototype.getBottomOffset = function (topIndex) {
        this.ensureBuilt();
        return this.bottoms[topIndex];
    };
    // Gets the bottom position (from the offsetParent top) of the element at the given index.
    // This value is NOT relative to the offsetParent's bottom edge, like the CSS concept of "bottom" would be.
    CoordCache.prototype.getBottomPosition = function (topIndex) {
        this.ensureBuilt();
        return this.bottoms[topIndex] - this.origin.top;
    };
    // Gets the height of the element at the given index
    CoordCache.prototype.getHeight = function (topIndex) {
        this.ensureBuilt();
        return this.bottoms[topIndex] - this.tops[topIndex];
    };
    // Bounding Rect
    // TODO: decouple this from CoordCache
    // Compute and return what the elements' bounding rectangle is, from the user's perspective.
    // Right now, only returns a rectangle if constrained by an overflow:scroll element.
    // Returns null if there are no elements
    CoordCache.prototype.queryBoundingRect = function () {
        var scrollParentEl;
        if (this.els.length > 0) {
            scrollParentEl = util_1.getScrollParent(this.els.eq(0));
            if (!scrollParentEl.is(document)) {
                return util_1.getClientRect(scrollParentEl);
            }
        }
        return null;
    };
    CoordCache.prototype.isPointInBounds = function (leftOffset, topOffset) {
        return this.isLeftInBounds(leftOffset) && this.isTopInBounds(topOffset);
    };
    CoordCache.prototype.isLeftInBounds = function (leftOffset) {
        return !this.boundingRect || (leftOffset >= this.boundingRect.left && leftOffset < this.boundingRect.right);
    };
    CoordCache.prototype.isTopInBounds = function (topOffset) {
        return !this.boundingRect || (topOffset >= this.boundingRect.top && topOffset < this.boundingRect.bottom);
    };
    return CoordCache;
}());
exports.default = CoordCache;


/***/ }),
/* 54 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var $ = __webpack_require__(3);
var util_1 = __webpack_require__(4);
var ListenerMixin_1 = __webpack_require__(7);
var GlobalEmitter_1 = __webpack_require__(21);
/* Tracks a drag's mouse movement, firing various handlers
----------------------------------------------------------------------------------------------------------------------*/
// TODO: use Emitter
var DragListener = /** @class */ (function () {
    function DragListener(options) {
        this.isInteracting = false;
        this.isDistanceSurpassed = false;
        this.isDelayEnded = false;
        this.isDragging = false;
        this.isTouch = false;
        this.isGeneric = false; // initiated by 'dragstart' (jqui)
        this.shouldCancelTouchScroll = true;
        this.scrollAlwaysKills = false;
        this.isAutoScroll = false;
        // defaults
        this.scrollSensitivity = 30; // pixels from edge for scrolling to start
        this.scrollSpeed = 200; // pixels per second, at maximum speed
        this.scrollIntervalMs = 50; // millisecond wait between scroll increment
        this.options = options || {};
    }
    // Interaction (high-level)
    // -----------------------------------------------------------------------------------------------------------------
    DragListener.prototype.startInteraction = function (ev, extraOptions) {
        if (extraOptions === void 0) { extraOptions = {}; }
        if (ev.type === 'mousedown') {
            if (GlobalEmitter_1.default.get().shouldIgnoreMouse()) {
                return;
            }
            else if (!util_1.isPrimaryMouseButton(ev)) {
                return;
            }
            else {
                ev.preventDefault(); // prevents native selection in most browsers
            }
        }
        if (!this.isInteracting) {
            // process options
            this.delay = util_1.firstDefined(extraOptions.delay, this.options.delay, 0);
            this.minDistance = util_1.firstDefined(extraOptions.distance, this.options.distance, 0);
            this.subjectEl = this.options.subjectEl;
            util_1.preventSelection($('body'));
            this.isInteracting = true;
            this.isTouch = util_1.getEvIsTouch(ev);
            this.isGeneric = ev.type === 'dragstart';
            this.isDelayEnded = false;
            this.isDistanceSurpassed = false;
            this.originX = util_1.getEvX(ev);
            this.originY = util_1.getEvY(ev);
            this.scrollEl = util_1.getScrollParent($(ev.target));
            this.bindHandlers();
            this.initAutoScroll();
            this.handleInteractionStart(ev);
            this.startDelay(ev);
            if (!this.minDistance) {
                this.handleDistanceSurpassed(ev);
            }
        }
    };
    DragListener.prototype.handleInteractionStart = function (ev) {
        this.trigger('interactionStart', ev);
    };
    DragListener.prototype.endInteraction = function (ev, isCancelled) {
        if (this.isInteracting) {
            this.endDrag(ev);
            if (this.delayTimeoutId) {
                clearTimeout(this.delayTimeoutId);
                this.delayTimeoutId = null;
            }
            this.destroyAutoScroll();
            this.unbindHandlers();
            this.isInteracting = false;
            this.handleInteractionEnd(ev, isCancelled);
            util_1.allowSelection($('body'));
        }
    };
    DragListener.prototype.handleInteractionEnd = function (ev, isCancelled) {
        this.trigger('interactionEnd', ev, isCancelled || false);
    };
    // Binding To DOM
    // -----------------------------------------------------------------------------------------------------------------
    DragListener.prototype.bindHandlers = function () {
        // some browsers (Safari in iOS 10) don't allow preventDefault on touch events that are bound after touchstart,
        // so listen to the GlobalEmitter singleton, which is always bound, instead of the document directly.
        var globalEmitter = GlobalEmitter_1.default.get();
        if (this.isGeneric) {
            this.listenTo($(document), {
                drag: this.handleMove,
                dragstop: this.endInteraction
            });
        }
        else if (this.isTouch) {
            this.listenTo(globalEmitter, {
                touchmove: this.handleTouchMove,
                touchend: this.endInteraction,
                scroll: this.handleTouchScroll
            });
        }
        else {
            this.listenTo(globalEmitter, {
                mousemove: this.handleMouseMove,
                mouseup: this.endInteraction
            });
        }
        this.listenTo(globalEmitter, {
            selectstart: util_1.preventDefault,
            contextmenu: util_1.preventDefault // long taps would open menu on Chrome dev tools
        });
    };
    DragListener.prototype.unbindHandlers = function () {
        this.stopListeningTo(GlobalEmitter_1.default.get());
        this.stopListeningTo($(document)); // for isGeneric
    };
    // Drag (high-level)
    // -----------------------------------------------------------------------------------------------------------------
    // extraOptions ignored if drag already started
    DragListener.prototype.startDrag = function (ev, extraOptions) {
        this.startInteraction(ev, extraOptions); // ensure interaction began
        if (!this.isDragging) {
            this.isDragging = true;
            this.handleDragStart(ev);
        }
    };
    DragListener.prototype.handleDragStart = function (ev) {
        this.trigger('dragStart', ev);
    };
    DragListener.prototype.handleMove = function (ev) {
        var dx = util_1.getEvX(ev) - this.originX;
        var dy = util_1.getEvY(ev) - this.originY;
        var minDistance = this.minDistance;
        var distanceSq; // current distance from the origin, squared
        if (!this.isDistanceSurpassed) {
            distanceSq = dx * dx + dy * dy;
            if (distanceSq >= minDistance * minDistance) {
                this.handleDistanceSurpassed(ev);
            }
        }
        if (this.isDragging) {
            this.handleDrag(dx, dy, ev);
        }
    };
    // Called while the mouse is being moved and when we know a legitimate drag is taking place
    DragListener.prototype.handleDrag = function (dx, dy, ev) {
        this.trigger('drag', dx, dy, ev);
        this.updateAutoScroll(ev); // will possibly cause scrolling
    };
    DragListener.prototype.endDrag = function (ev) {
        if (this.isDragging) {
            this.isDragging = false;
            this.handleDragEnd(ev);
        }
    };
    DragListener.prototype.handleDragEnd = function (ev) {
        this.trigger('dragEnd', ev);
    };
    // Delay
    // -----------------------------------------------------------------------------------------------------------------
    DragListener.prototype.startDelay = function (initialEv) {
        var _this = this;
        if (this.delay) {
            this.delayTimeoutId = setTimeout(function () {
                _this.handleDelayEnd(initialEv);
            }, this.delay);
        }
        else {
            this.handleDelayEnd(initialEv);
        }
    };
    DragListener.prototype.handleDelayEnd = function (initialEv) {
        this.isDelayEnded = true;
        if (this.isDistanceSurpassed) {
            this.startDrag(initialEv);
        }
    };
    // Distance
    // -----------------------------------------------------------------------------------------------------------------
    DragListener.prototype.handleDistanceSurpassed = function (ev) {
        this.isDistanceSurpassed = true;
        if (this.isDelayEnded) {
            this.startDrag(ev);
        }
    };
    // Mouse / Touch
    // -----------------------------------------------------------------------------------------------------------------
    DragListener.prototype.handleTouchMove = function (ev) {
        // prevent inertia and touchmove-scrolling while dragging
        if (this.isDragging && this.shouldCancelTouchScroll) {
            ev.preventDefault();
        }
        this.handleMove(ev);
    };
    DragListener.prototype.handleMouseMove = function (ev) {
        this.handleMove(ev);
    };
    // Scrolling (unrelated to auto-scroll)
    // -----------------------------------------------------------------------------------------------------------------
    DragListener.prototype.handleTouchScroll = function (ev) {
        // if the drag is being initiated by touch, but a scroll happens before
        // the drag-initiating delay is over, cancel the drag
        if (!this.isDragging || this.scrollAlwaysKills) {
            this.endInteraction(ev, true); // isCancelled=true
        }
    };
    // Utils
    // -----------------------------------------------------------------------------------------------------------------
    // Triggers a callback. Calls a function in the option hash of the same name.
    // Arguments beyond the first `name` are forwarded on.
    DragListener.prototype.trigger = function (name) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        if (this.options[name]) {
            this.options[name].apply(this, args);
        }
        // makes _methods callable by event name. TODO: kill this
        if (this['_' + name]) {
            this['_' + name].apply(this, args);
        }
    };
    // Auto-scroll
    // -----------------------------------------------------------------------------------------------------------------
    DragListener.prototype.initAutoScroll = function () {
        var scrollEl = this.scrollEl;
        this.isAutoScroll =
            this.options.scroll &&
                scrollEl &&
                !scrollEl.is(window) &&
                !scrollEl.is(document);
        if (this.isAutoScroll) {
            // debounce makes sure rapid calls don't happen
            this.listenTo(scrollEl, 'scroll', util_1.debounce(this.handleDebouncedScroll, 100));
        }
    };
    DragListener.prototype.destroyAutoScroll = function () {
        this.endAutoScroll(); // kill any animation loop
        // remove the scroll handler if there is a scrollEl
        if (this.isAutoScroll) {
            this.stopListeningTo(this.scrollEl, 'scroll'); // will probably get removed by unbindHandlers too :(
        }
    };
    // Computes and stores the bounding rectangle of scrollEl
    DragListener.prototype.computeScrollBounds = function () {
        if (this.isAutoScroll) {
            this.scrollBounds = util_1.getOuterRect(this.scrollEl);
            // TODO: use getClientRect in future. but prevents auto scrolling when on top of scrollbars
        }
    };
    // Called when the dragging is in progress and scrolling should be updated
    DragListener.prototype.updateAutoScroll = function (ev) {
        var sensitivity = this.scrollSensitivity;
        var bounds = this.scrollBounds;
        var topCloseness;
        var bottomCloseness;
        var leftCloseness;
        var rightCloseness;
        var topVel = 0;
        var leftVel = 0;
        if (bounds) {
            // compute closeness to edges. valid range is from 0.0 - 1.0
            topCloseness = (sensitivity - (util_1.getEvY(ev) - bounds.top)) / sensitivity;
            bottomCloseness = (sensitivity - (bounds.bottom - util_1.getEvY(ev))) / sensitivity;
            leftCloseness = (sensitivity - (util_1.getEvX(ev) - bounds.left)) / sensitivity;
            rightCloseness = (sensitivity - (bounds.right - util_1.getEvX(ev))) / sensitivity;
            // translate vertical closeness into velocity.
            // mouse must be completely in bounds for velocity to happen.
            if (topCloseness >= 0 && topCloseness <= 1) {
                topVel = topCloseness * this.scrollSpeed * -1; // negative. for scrolling up
            }
            else if (bottomCloseness >= 0 && bottomCloseness <= 1) {
                topVel = bottomCloseness * this.scrollSpeed;
            }
            // translate horizontal closeness into velocity
            if (leftCloseness >= 0 && leftCloseness <= 1) {
                leftVel = leftCloseness * this.scrollSpeed * -1; // negative. for scrolling left
            }
            else if (rightCloseness >= 0 && rightCloseness <= 1) {
                leftVel = rightCloseness * this.scrollSpeed;
            }
        }
        this.setScrollVel(topVel, leftVel);
    };
    // Sets the speed-of-scrolling for the scrollEl
    DragListener.prototype.setScrollVel = function (topVel, leftVel) {
        this.scrollTopVel = topVel;
        this.scrollLeftVel = leftVel;
        this.constrainScrollVel(); // massages into realistic values
        // if there is non-zero velocity, and an animation loop hasn't already started, then START
        if ((this.scrollTopVel || this.scrollLeftVel) && !this.scrollIntervalId) {
            this.scrollIntervalId = setInterval(util_1.proxy(this, 'scrollIntervalFunc'), // scope to `this`
            this.scrollIntervalMs);
        }
    };
    // Forces scrollTopVel and scrollLeftVel to be zero if scrolling has already gone all the way
    DragListener.prototype.constrainScrollVel = function () {
        var el = this.scrollEl;
        if (this.scrollTopVel < 0) {
            if (el.scrollTop() <= 0) {
                this.scrollTopVel = 0;
            }
        }
        else if (this.scrollTopVel > 0) {
            if (el.scrollTop() + el[0].clientHeight >= el[0].scrollHeight) {
                this.scrollTopVel = 0;
            }
        }
        if (this.scrollLeftVel < 0) {
            if (el.scrollLeft() <= 0) {
                this.scrollLeftVel = 0;
            }
        }
        else if (this.scrollLeftVel > 0) {
            if (el.scrollLeft() + el[0].clientWidth >= el[0].scrollWidth) {
                this.scrollLeftVel = 0;
            }
        }
    };
    // This function gets called during every iteration of the scrolling animation loop
    DragListener.prototype.scrollIntervalFunc = function () {
        var el = this.scrollEl;
        var frac = this.scrollIntervalMs / 1000; // considering animation frequency, what the vel should be mult'd by
        // change the value of scrollEl's scroll
        if (this.scrollTopVel) {
            el.scrollTop(el.scrollTop() + this.scrollTopVel * frac);
        }
        if (this.scrollLeftVel) {
            el.scrollLeft(el.scrollLeft() + this.scrollLeftVel * frac);
        }
        this.constrainScrollVel(); // since the scroll values changed, recompute the velocities
        // if scrolled all the way, which causes the vels to be zero, stop the animation loop
        if (!this.scrollTopVel && !this.scrollLeftVel) {
            this.endAutoScroll();
        }
    };
    // Kills any existing scrolling animation loop
    DragListener.prototype.endAutoScroll = function () {
        if (this.scrollIntervalId) {
            clearInterval(this.scrollIntervalId);
            this.scrollIntervalId = null;
            this.handleScrollEnd();
        }
    };
    // Get called when the scrollEl is scrolled (NOTE: this is delayed via debounce)
    DragListener.prototype.handleDebouncedScroll = function () {
        // recompute all coordinates, but *only* if this is *not* part of our scrolling animation
        if (!this.scrollIntervalId) {
            this.handleScrollEnd();
        }
    };
    DragListener.prototype.handleScrollEnd = function () {
        // Called when scrolling has stopped, whether through auto scroll, or the user scrolling
    };
    return DragListener;
}());
exports.default = DragListener;
ListenerMixin_1.default.mixInto(DragListener);


/***/ }),
/* 55 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var util_1 = __webpack_require__(4);
var Mixin_1 = __webpack_require__(14);
/*
A set of rendering and date-related methods for a visual component comprised of one or more rows of day columns.
Prerequisite: the object being mixed into needs to be a *Grid*
*/
var DayTableMixin = /** @class */ (function (_super) {
    tslib_1.__extends(DayTableMixin, _super);
    function DayTableMixin() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    // Populates internal variables used for date calculation and rendering
    DayTableMixin.prototype.updateDayTable = function () {
        var t = this;
        var view = t.view;
        var calendar = view.calendar;
        var date = calendar.msToUtcMoment(t.dateProfile.renderUnzonedRange.startMs, true);
        var end = calendar.msToUtcMoment(t.dateProfile.renderUnzonedRange.endMs, true);
        var dayIndex = -1;
        var dayIndices = [];
        var dayDates = [];
        var daysPerRow;
        var firstDay;
        var rowCnt;
        while (date.isBefore(end)) {
            if (view.isHiddenDay(date)) {
                dayIndices.push(dayIndex + 0.5); // mark that it's between indices
            }
            else {
                dayIndex++;
                dayIndices.push(dayIndex);
                dayDates.push(date.clone());
            }
            date.add(1, 'days');
        }
        if (this.breakOnWeeks) {
            // count columns until the day-of-week repeats
            firstDay = dayDates[0].day();
            for (daysPerRow = 1; daysPerRow < dayDates.length; daysPerRow++) {
                if (dayDates[daysPerRow].day() === firstDay) {
                    break;
                }
            }
            rowCnt = Math.ceil(dayDates.length / daysPerRow);
        }
        else {
            rowCnt = 1;
            daysPerRow = dayDates.length;
        }
        this.dayDates = dayDates;
        this.dayIndices = dayIndices;
        this.daysPerRow = daysPerRow;
        this.rowCnt = rowCnt;
        this.updateDayTableCols();
    };
    // Computes and assigned the colCnt property and updates any options that may be computed from it
    DayTableMixin.prototype.updateDayTableCols = function () {
        this.colCnt = this.computeColCnt();
        this.colHeadFormat =
            this.opt('columnHeaderFormat') ||
                this.opt('columnFormat') || // deprecated
                this.computeColHeadFormat();
    };
    // Determines how many columns there should be in the table
    DayTableMixin.prototype.computeColCnt = function () {
        return this.daysPerRow;
    };
    // Computes the ambiguously-timed moment for the given cell
    DayTableMixin.prototype.getCellDate = function (row, col) {
        return this.dayDates[this.getCellDayIndex(row, col)].clone();
    };
    // Computes the ambiguously-timed date range for the given cell
    DayTableMixin.prototype.getCellRange = function (row, col) {
        var start = this.getCellDate(row, col);
        var end = start.clone().add(1, 'days');
        return { start: start, end: end };
    };
    // Returns the number of day cells, chronologically, from the first of the grid (0-based)
    DayTableMixin.prototype.getCellDayIndex = function (row, col) {
        return row * this.daysPerRow + this.getColDayIndex(col);
    };
    // Returns the numner of day cells, chronologically, from the first cell in *any given row*
    DayTableMixin.prototype.getColDayIndex = function (col) {
        if (this.isRTL) {
            return this.colCnt - 1 - col;
        }
        else {
            return col;
        }
    };
    // Given a date, returns its chronolocial cell-index from the first cell of the grid.
    // If the date lies between cells (because of hiddenDays), returns a floating-point value between offsets.
    // If before the first offset, returns a negative number.
    // If after the last offset, returns an offset past the last cell offset.
    // Only works for *start* dates of cells. Will not work for exclusive end dates for cells.
    DayTableMixin.prototype.getDateDayIndex = function (date) {
        var dayIndices = this.dayIndices;
        var dayOffset = date.diff(this.dayDates[0], 'days');
        if (dayOffset < 0) {
            return dayIndices[0] - 1;
        }
        else if (dayOffset >= dayIndices.length) {
            return dayIndices[dayIndices.length - 1] + 1;
        }
        else {
            return dayIndices[dayOffset];
        }
    };
    /* Options
    ------------------------------------------------------------------------------------------------------------------*/
    // Computes a default column header formatting string if `colFormat` is not explicitly defined
    DayTableMixin.prototype.computeColHeadFormat = function () {
        // if more than one week row, or if there are a lot of columns with not much space,
        // put just the day numbers will be in each cell
        if (this.rowCnt > 1 || this.colCnt > 10) {
            return 'ddd'; // "Sat"
        }
        else if (this.colCnt > 1) {
            return this.opt('dayOfMonthFormat'); // "Sat 12/10"
        }
        else {
            return 'dddd'; // "Saturday"
        }
    };
    /* Slicing
    ------------------------------------------------------------------------------------------------------------------*/
    // Slices up a date range into a segment for every week-row it intersects with
    DayTableMixin.prototype.sliceRangeByRow = function (unzonedRange) {
        var daysPerRow = this.daysPerRow;
        var normalRange = this.view.computeDayRange(unzonedRange); // make whole-day range, considering nextDayThreshold
        var rangeFirst = this.getDateDayIndex(normalRange.start); // inclusive first index
        var rangeLast = this.getDateDayIndex(normalRange.end.clone().subtract(1, 'days')); // inclusive last index
        var segs = [];
        var row;
        var rowFirst;
        var rowLast; // inclusive day-index range for current row
        var segFirst;
        var segLast; // inclusive day-index range for segment
        for (row = 0; row < this.rowCnt; row++) {
            rowFirst = row * daysPerRow;
            rowLast = rowFirst + daysPerRow - 1;
            // intersect segment's offset range with the row's
            segFirst = Math.max(rangeFirst, rowFirst);
            segLast = Math.min(rangeLast, rowLast);
            // deal with in-between indices
            segFirst = Math.ceil(segFirst); // in-between starts round to next cell
            segLast = Math.floor(segLast); // in-between ends round to prev cell
            if (segFirst <= segLast) {
                segs.push({
                    row: row,
                    // normalize to start of row
                    firstRowDayIndex: segFirst - rowFirst,
                    lastRowDayIndex: segLast - rowFirst,
                    // must be matching integers to be the segment's start/end
                    isStart: segFirst === rangeFirst,
                    isEnd: segLast === rangeLast
                });
            }
        }
        return segs;
    };
    // Slices up a date range into a segment for every day-cell it intersects with.
    // TODO: make more DRY with sliceRangeByRow somehow.
    DayTableMixin.prototype.sliceRangeByDay = function (unzonedRange) {
        var daysPerRow = this.daysPerRow;
        var normalRange = this.view.computeDayRange(unzonedRange); // make whole-day range, considering nextDayThreshold
        var rangeFirst = this.getDateDayIndex(normalRange.start); // inclusive first index
        var rangeLast = this.getDateDayIndex(normalRange.end.clone().subtract(1, 'days')); // inclusive last index
        var segs = [];
        var row;
        var rowFirst;
        var rowLast; // inclusive day-index range for current row
        var i;
        var segFirst;
        var segLast; // inclusive day-index range for segment
        for (row = 0; row < this.rowCnt; row++) {
            rowFirst = row * daysPerRow;
            rowLast = rowFirst + daysPerRow - 1;
            for (i = rowFirst; i <= rowLast; i++) {
                // intersect segment's offset range with the row's
                segFirst = Math.max(rangeFirst, i);
                segLast = Math.min(rangeLast, i);
                // deal with in-between indices
                segFirst = Math.ceil(segFirst); // in-between starts round to next cell
                segLast = Math.floor(segLast); // in-between ends round to prev cell
                if (segFirst <= segLast) {
                    segs.push({
                        row: row,
                        // normalize to start of row
                        firstRowDayIndex: segFirst - rowFirst,
                        lastRowDayIndex: segLast - rowFirst,
                        // must be matching integers to be the segment's start/end
                        isStart: segFirst === rangeFirst,
                        isEnd: segLast === rangeLast
                    });
                }
            }
        }
        return segs;
    };
    /* Header Rendering
    ------------------------------------------------------------------------------------------------------------------*/
    DayTableMixin.prototype.renderHeadHtml = function () {
        var theme = this.view.calendar.theme;
        return '' +
            '<div class="fc-row ' + theme.getClass('headerRow') + '">' +
            '<table class="' + theme.getClass('tableGrid') + '">' +
            '<thead>' +
            this.renderHeadTrHtml() +
            '</thead>' +
            '</table>' +
            '</div>';
    };
    DayTableMixin.prototype.renderHeadIntroHtml = function () {
        return this.renderIntroHtml(); // fall back to generic
    };
    DayTableMixin.prototype.renderHeadTrHtml = function () {
        return '' +
            '<tr>' +
            (this.isRTL ? '' : this.renderHeadIntroHtml()) +
            this.renderHeadDateCellsHtml() +
            (this.isRTL ? this.renderHeadIntroHtml() : '') +
            '</tr>';
    };
    DayTableMixin.prototype.renderHeadDateCellsHtml = function () {
        var htmls = [];
        var col;
        var date;
        for (col = 0; col < this.colCnt; col++) {
            date = this.getCellDate(0, col);
            htmls.push(this.renderHeadDateCellHtml(date));
        }
        return htmls.join('');
    };
    // TODO: when internalApiVersion, accept an object for HTML attributes
    // (colspan should be no different)
    DayTableMixin.prototype.renderHeadDateCellHtml = function (date, colspan, otherAttrs) {
        var t = this;
        var view = t.view;
        var isDateValid = t.dateProfile.activeUnzonedRange.containsDate(date); // TODO: called too frequently. cache somehow.
        var classNames = [
            'fc-day-header',
            view.calendar.theme.getClass('widgetHeader')
        ];
        var innerHtml;
        if (typeof t.opt('columnHeaderHtml') === 'function') {
            innerHtml = t.opt('columnHeaderHtml')(date);
        }
        else if (typeof t.opt('columnHeaderText') === 'function') {
            innerHtml = util_1.htmlEscape(t.opt('columnHeaderText')(date));
        }
        else {
            innerHtml = util_1.htmlEscape(date.format(t.colHeadFormat));
        }
        // if only one row of days, the classNames on the header can represent the specific days beneath
        if (t.rowCnt === 1) {
            classNames = classNames.concat(
            // includes the day-of-week class
            // noThemeHighlight=true (don't highlight the header)
            t.getDayClasses(date, true));
        }
        else {
            classNames.push('fc-' + util_1.dayIDs[date.day()]); // only add the day-of-week class
        }
        return '' +
            '<th class="' + classNames.join(' ') + '"' +
            ((isDateValid && t.rowCnt) === 1 ?
                ' data-date="' + date.format('YYYY-MM-DD') + '"' :
                '') +
            (colspan > 1 ?
                ' colspan="' + colspan + '"' :
                '') +
            (otherAttrs ?
                ' ' + otherAttrs :
                '') +
            '>' +
            (isDateValid ?
                // don't make a link if the heading could represent multiple days, or if there's only one day (forceOff)
                view.buildGotoAnchorHtml({ date: date, forceOff: t.rowCnt > 1 || t.colCnt === 1 }, innerHtml) :
                // if not valid, display text, but no link
                innerHtml) +
            '</th>';
    };
    /* Background Rendering
    ------------------------------------------------------------------------------------------------------------------*/
    DayTableMixin.prototype.renderBgTrHtml = function (row) {
        return '' +
            '<tr>' +
            (this.isRTL ? '' : this.renderBgIntroHtml(row)) +
            this.renderBgCellsHtml(row) +
            (this.isRTL ? this.renderBgIntroHtml(row) : '') +
            '</tr>';
    };
    DayTableMixin.prototype.renderBgIntroHtml = function (row) {
        return this.renderIntroHtml(); // fall back to generic
    };
    DayTableMixin.prototype.renderBgCellsHtml = function (row) {
        var htmls = [];
        var col;
        var date;
        for (col = 0; col < this.colCnt; col++) {
            date = this.getCellDate(row, col);
            htmls.push(this.renderBgCellHtml(date));
        }
        return htmls.join('');
    };
    DayTableMixin.prototype.renderBgCellHtml = function (date, otherAttrs) {
        var t = this;
        var view = t.view;
        var isDateValid = t.dateProfile.activeUnzonedRange.containsDate(date); // TODO: called too frequently. cache somehow.
        var classes = t.getDayClasses(date);
        classes.unshift('fc-day', view.calendar.theme.getClass('widgetContent'));
        return '<td class="' + classes.join(' ') + '"' +
            (isDateValid ?
                ' data-date="' + date.format('YYYY-MM-DD') + '"' : // if date has a time, won't format it
                '') +
            (otherAttrs ?
                ' ' + otherAttrs :
                '') +
            '></td>';
    };
    /* Generic
    ------------------------------------------------------------------------------------------------------------------*/
    DayTableMixin.prototype.renderIntroHtml = function () {
        // Generates the default HTML intro for any row. User classes should override
    };
    // TODO: a generic method for dealing with <tr>, RTL, intro
    // when increment internalApiVersion
    // wrapTr (scheduler)
    /* Utils
    ------------------------------------------------------------------------------------------------------------------*/
    // Applies the generic "intro" and "outro" HTML to the given cells.
    // Intro means the leftmost cell when the calendar is LTR and the rightmost cell when RTL. Vice-versa for outro.
    DayTableMixin.prototype.bookendCells = function (trEl) {
        var introHtml = this.renderIntroHtml();
        if (introHtml) {
            if (this.isRTL) {
                trEl.append(introHtml);
            }
            else {
                trEl.prepend(introHtml);
            }
        }
    };
    return DayTableMixin;
}(Mixin_1.default));
exports.default = DayTableMixin;


/***/ }),
/* 56 */
/***/ (function(module, exports) {

Object.defineProperty(exports, "__esModule", { value: true });
var BusinessHourRenderer = /** @class */ (function () {
    /*
    component implements:
      - eventRangesToEventFootprints
      - eventFootprintsToSegs
    */
    function BusinessHourRenderer(component, fillRenderer) {
        this.component = component;
        this.fillRenderer = fillRenderer;
    }
    BusinessHourRenderer.prototype.render = function (businessHourGenerator) {
        var component = this.component;
        var unzonedRange = component._getDateProfile().activeUnzonedRange;
        var eventInstanceGroup = businessHourGenerator.buildEventInstanceGroup(component.hasAllDayBusinessHours, unzonedRange);
        var eventFootprints = eventInstanceGroup ?
            component.eventRangesToEventFootprints(eventInstanceGroup.sliceRenderRanges(unzonedRange)) :
            [];
        this.renderEventFootprints(eventFootprints);
    };
    BusinessHourRenderer.prototype.renderEventFootprints = function (eventFootprints) {
        var segs = this.component.eventFootprintsToSegs(eventFootprints);
        this.renderSegs(segs);
        this.segs = segs;
    };
    BusinessHourRenderer.prototype.renderSegs = function (segs) {
        if (this.fillRenderer) {
            this.fillRenderer.renderSegs('businessHours', segs, {
                getClasses: function (seg) {
                    return ['fc-nonbusiness', 'fc-bgevent'];
                }
            });
        }
    };
    BusinessHourRenderer.prototype.unrender = function () {
        if (this.fillRenderer) {
            this.fillRenderer.unrender('businessHours');
        }
        this.segs = null;
    };
    BusinessHourRenderer.prototype.getSegs = function () {
        return this.segs || [];
    };
    return BusinessHourRenderer;
}());
exports.default = BusinessHourRenderer;


/***/ }),
/* 57 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var $ = __webpack_require__(3);
var util_1 = __webpack_require__(4);
var FillRenderer = /** @class */ (function () {
    function FillRenderer(component) {
        this.fillSegTag = 'div';
        this.component = component;
        this.elsByFill = {};
    }
    FillRenderer.prototype.renderFootprint = function (type, componentFootprint, props) {
        this.renderSegs(type, this.component.componentFootprintToSegs(componentFootprint), props);
    };
    FillRenderer.prototype.renderSegs = function (type, segs, props) {
        var els;
        segs = this.buildSegEls(type, segs, props); // assignes `.el` to each seg. returns successfully rendered segs
        els = this.attachSegEls(type, segs);
        if (els) {
            this.reportEls(type, els);
        }
        return segs;
    };
    // Unrenders a specific type of fill that is currently rendered on the grid
    FillRenderer.prototype.unrender = function (type) {
        var el = this.elsByFill[type];
        if (el) {
            el.remove();
            delete this.elsByFill[type];
        }
    };
    // Renders and assigns an `el` property for each fill segment. Generic enough to work with different types.
    // Only returns segments that successfully rendered.
    FillRenderer.prototype.buildSegEls = function (type, segs, props) {
        var _this = this;
        var html = '';
        var renderedSegs = [];
        var i;
        if (segs.length) {
            // build a large concatenation of segment HTML
            for (i = 0; i < segs.length; i++) {
                html += this.buildSegHtml(type, segs[i], props);
            }
            // Grab individual elements from the combined HTML string. Use each as the default rendering.
            // Then, compute the 'el' for each segment.
            $(html).each(function (i, node) {
                var seg = segs[i];
                var el = $(node);
                // allow custom filter methods per-type
                if (props.filterEl) {
                    el = props.filterEl(seg, el);
                }
                if (el) {
                    el = $(el); // allow custom filter to return raw DOM node
                    // correct element type? (would be bad if a non-TD were inserted into a table for example)
                    if (el.is(_this.fillSegTag)) {
                        seg.el = el;
                        renderedSegs.push(seg);
                    }
                }
            });
        }
        return renderedSegs;
    };
    // Builds the HTML needed for one fill segment. Generic enough to work with different types.
    FillRenderer.prototype.buildSegHtml = function (type, seg, props) {
        // custom hooks per-type
        var classes = props.getClasses ? props.getClasses(seg) : [];
        var css = util_1.cssToStr(props.getCss ? props.getCss(seg) : {});
        return '<' + this.fillSegTag +
            (classes.length ? ' class="' + classes.join(' ') + '"' : '') +
            (css ? ' style="' + css + '"' : '') +
            ' />';
    };
    // Should return wrapping DOM structure
    FillRenderer.prototype.attachSegEls = function (type, segs) {
        // subclasses must implement
    };
    FillRenderer.prototype.reportEls = function (type, nodes) {
        if (this.elsByFill[type]) {
            this.elsByFill[type] = this.elsByFill[type].add(nodes);
        }
        else {
            this.elsByFill[type] = $(nodes);
        }
    };
    return FillRenderer;
}());
exports.default = FillRenderer;


/***/ }),
/* 58 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var SingleEventDef_1 = __webpack_require__(13);
var EventFootprint_1 = __webpack_require__(36);
var EventSource_1 = __webpack_require__(6);
var HelperRenderer = /** @class */ (function () {
    function HelperRenderer(component, eventRenderer) {
        this.view = component._getView();
        this.component = component;
        this.eventRenderer = eventRenderer;
    }
    HelperRenderer.prototype.renderComponentFootprint = function (componentFootprint) {
        this.renderEventFootprints([
            this.fabricateEventFootprint(componentFootprint)
        ]);
    };
    HelperRenderer.prototype.renderEventDraggingFootprints = function (eventFootprints, sourceSeg, isTouch) {
        this.renderEventFootprints(eventFootprints, sourceSeg, 'fc-dragging', isTouch ? null : this.view.opt('dragOpacity'));
    };
    HelperRenderer.prototype.renderEventResizingFootprints = function (eventFootprints, sourceSeg, isTouch) {
        this.renderEventFootprints(eventFootprints, sourceSeg, 'fc-resizing');
    };
    HelperRenderer.prototype.renderEventFootprints = function (eventFootprints, sourceSeg, extraClassNames, opacity) {
        var segs = this.component.eventFootprintsToSegs(eventFootprints);
        var classNames = 'fc-helper ' + (extraClassNames || '');
        var i;
        // assigns each seg's el and returns a subset of segs that were rendered
        segs = this.eventRenderer.renderFgSegEls(segs);
        for (i = 0; i < segs.length; i++) {
            segs[i].el.addClass(classNames);
        }
        if (opacity != null) {
            for (i = 0; i < segs.length; i++) {
                segs[i].el.css('opacity', opacity);
            }
        }
        this.helperEls = this.renderSegs(segs, sourceSeg);
    };
    /*
    Must return all mock event elements
    */
    HelperRenderer.prototype.renderSegs = function (segs, sourceSeg) {
        // Subclasses must implement
    };
    HelperRenderer.prototype.unrender = function () {
        if (this.helperEls) {
            this.helperEls.remove();
            this.helperEls = null;
        }
    };
    HelperRenderer.prototype.fabricateEventFootprint = function (componentFootprint) {
        var calendar = this.view.calendar;
        var eventDateProfile = calendar.footprintToDateProfile(componentFootprint);
        var dummyEvent = new SingleEventDef_1.default(new EventSource_1.default(calendar));
        var dummyInstance;
        dummyEvent.dateProfile = eventDateProfile;
        dummyInstance = dummyEvent.buildInstance();
        return new EventFootprint_1.default(componentFootprint, dummyEvent, dummyInstance);
    };
    return HelperRenderer;
}());
exports.default = HelperRenderer;


/***/ }),
/* 59 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var GlobalEmitter_1 = __webpack_require__(21);
var Interaction_1 = __webpack_require__(15);
var EventPointing = /** @class */ (function (_super) {
    tslib_1.__extends(EventPointing, _super);
    function EventPointing() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /*
    component must implement:
      - publiclyTrigger
    */
    EventPointing.prototype.bindToEl = function (el) {
        var component = this.component;
        component.bindSegHandlerToEl(el, 'click', this.handleClick.bind(this));
        component.bindSegHandlerToEl(el, 'mouseenter', this.handleMouseover.bind(this));
        component.bindSegHandlerToEl(el, 'mouseleave', this.handleMouseout.bind(this));
    };
    EventPointing.prototype.handleClick = function (seg, ev) {
        var res = this.component.publiclyTrigger('eventClick', {
            context: seg.el[0],
            args: [seg.footprint.getEventLegacy(), ev, this.view]
        });
        if (res === false) {
            ev.preventDefault();
        }
    };
    // Updates internal state and triggers handlers for when an event element is moused over
    EventPointing.prototype.handleMouseover = function (seg, ev) {
        if (!GlobalEmitter_1.default.get().shouldIgnoreMouse() &&
            !this.mousedOverSeg) {
            this.mousedOverSeg = seg;
            // TODO: move to EventSelecting's responsibility
            if (this.view.isEventDefResizable(seg.footprint.eventDef)) {
                seg.el.addClass('fc-allow-mouse-resize');
            }
            this.component.publiclyTrigger('eventMouseover', {
                context: seg.el[0],
                args: [seg.footprint.getEventLegacy(), ev, this.view]
            });
        }
    };
    // Updates internal state and triggers handlers for when an event element is moused out.
    // Can be given no arguments, in which case it will mouseout the segment that was previously moused over.
    EventPointing.prototype.handleMouseout = function (seg, ev) {
        if (this.mousedOverSeg) {
            this.mousedOverSeg = null;
            // TODO: move to EventSelecting's responsibility
            if (this.view.isEventDefResizable(seg.footprint.eventDef)) {
                seg.el.removeClass('fc-allow-mouse-resize');
            }
            this.component.publiclyTrigger('eventMouseout', {
                context: seg.el[0],
                args: [
                    seg.footprint.getEventLegacy(),
                    ev || {},
                    this.view
                ]
            });
        }
    };
    EventPointing.prototype.end = function () {
        if (this.mousedOverSeg) {
            this.handleMouseout(this.mousedOverSeg);
        }
    };
    return EventPointing;
}(Interaction_1.default));
exports.default = EventPointing;


/***/ }),
/* 60 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var Mixin_1 = __webpack_require__(14);
var DateClicking_1 = __webpack_require__(245);
var DateSelecting_1 = __webpack_require__(225);
var EventPointing_1 = __webpack_require__(59);
var EventDragging_1 = __webpack_require__(224);
var EventResizing_1 = __webpack_require__(223);
var ExternalDropping_1 = __webpack_require__(222);
var StandardInteractionsMixin = /** @class */ (function (_super) {
    tslib_1.__extends(StandardInteractionsMixin, _super);
    function StandardInteractionsMixin() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return StandardInteractionsMixin;
}(Mixin_1.default));
exports.default = StandardInteractionsMixin;
StandardInteractionsMixin.prototype.dateClickingClass = DateClicking_1.default;
StandardInteractionsMixin.prototype.dateSelectingClass = DateSelecting_1.default;
StandardInteractionsMixin.prototype.eventPointingClass = EventPointing_1.default;
StandardInteractionsMixin.prototype.eventDraggingClass = EventDragging_1.default;
StandardInteractionsMixin.prototype.eventResizingClass = EventResizing_1.default;
StandardInteractionsMixin.prototype.externalDroppingClass = ExternalDropping_1.default;


/***/ }),
/* 61 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var $ = __webpack_require__(3);
var util_1 = __webpack_require__(4);
var CoordCache_1 = __webpack_require__(53);
var Popover_1 = __webpack_require__(249);
var UnzonedRange_1 = __webpack_require__(5);
var ComponentFootprint_1 = __webpack_require__(12);
var EventFootprint_1 = __webpack_require__(36);
var BusinessHourRenderer_1 = __webpack_require__(56);
var StandardInteractionsMixin_1 = __webpack_require__(60);
var InteractiveDateComponent_1 = __webpack_require__(40);
var DayTableMixin_1 = __webpack_require__(55);
var DayGridEventRenderer_1 = __webpack_require__(250);
var DayGridHelperRenderer_1 = __webpack_require__(251);
var DayGridFillRenderer_1 = __webpack_require__(252);
/* A component that renders a grid of whole-days that runs horizontally. There can be multiple rows, one per week.
----------------------------------------------------------------------------------------------------------------------*/
var DayGrid = /** @class */ (function (_super) {
    tslib_1.__extends(DayGrid, _super);
    function DayGrid(view) {
        var _this = _super.call(this, view) || this;
        _this.cellWeekNumbersVisible = false; // display week numbers in day cell?
        _this.bottomCoordPadding = 0; // hack for extending the hit area for the last row of the coordinate grid
        // isRigid determines whether the individual rows should ignore the contents and be a constant height.
        // Relies on the view's colCnt and rowCnt. In the future, this component should probably be self-sufficient.
        _this.isRigid = false;
        _this.hasAllDayBusinessHours = true;
        return _this;
    }
    // Slices up the given span (unzoned start/end with other misc data) into an array of segments
    DayGrid.prototype.componentFootprintToSegs = function (componentFootprint) {
        var segs = this.sliceRangeByRow(componentFootprint.unzonedRange);
        var i;
        var seg;
        for (i = 0; i < segs.length; i++) {
            seg = segs[i];
            if (this.isRTL) {
                seg.leftCol = this.daysPerRow - 1 - seg.lastRowDayIndex;
                seg.rightCol = this.daysPerRow - 1 - seg.firstRowDayIndex;
            }
            else {
                seg.leftCol = seg.firstRowDayIndex;
                seg.rightCol = seg.lastRowDayIndex;
            }
        }
        return segs;
    };
    /* Date Rendering
    ------------------------------------------------------------------------------------------------------------------*/
    DayGrid.prototype.renderDates = function (dateProfile) {
        this.dateProfile = dateProfile;
        this.updateDayTable();
        this.renderGrid();
    };
    DayGrid.prototype.unrenderDates = function () {
        this.removeSegPopover();
    };
    // Renders the rows and columns into the component's `this.el`, which should already be assigned.
    DayGrid.prototype.renderGrid = function () {
        var view = this.view;
        var rowCnt = this.rowCnt;
        var colCnt = this.colCnt;
        var html = '';
        var row;
        var col;
        if (this.headContainerEl) {
            this.headContainerEl.html(this.renderHeadHtml());
        }
        for (row = 0; row < rowCnt; row++) {
            html += this.renderDayRowHtml(row, this.isRigid);
        }
        this.el.html(html);
        this.rowEls = this.el.find('.fc-row');
        this.cellEls = this.el.find('.fc-day, .fc-disabled-day');
        this.rowCoordCache = new CoordCache_1.default({
            els: this.rowEls,
            isVertical: true
        });
        this.colCoordCache = new CoordCache_1.default({
            els: this.cellEls.slice(0, this.colCnt),
            isHorizontal: true
        });
        // trigger dayRender with each cell's element
        for (row = 0; row < rowCnt; row++) {
            for (col = 0; col < colCnt; col++) {
                this.publiclyTrigger('dayRender', {
                    context: view,
                    args: [
                        this.getCellDate(row, col),
                        this.getCellEl(row, col),
                        view
                    ]
                });
            }
        }
    };
    // Generates the HTML for a single row, which is a div that wraps a table.
    // `row` is the row number.
    DayGrid.prototype.renderDayRowHtml = function (row, isRigid) {
        var theme = this.view.calendar.theme;
        var classes = ['fc-row', 'fc-week', theme.getClass('dayRow')];
        if (isRigid) {
            classes.push('fc-rigid');
        }
        return '' +
            '<div class="' + classes.join(' ') + '">' +
            '<div class="fc-bg">' +
            '<table class="' + theme.getClass('tableGrid') + '">' +
            this.renderBgTrHtml(row) +
            '</table>' +
            '</div>' +
            '<div class="fc-content-skeleton">' +
            '<table>' +
            (this.getIsNumbersVisible() ?
                '<thead>' +
                    this.renderNumberTrHtml(row) +
                    '</thead>' :
                '') +
            '</table>' +
            '</div>' +
            '</div>';
    };
    DayGrid.prototype.getIsNumbersVisible = function () {
        return this.getIsDayNumbersVisible() || this.cellWeekNumbersVisible;
    };
    DayGrid.prototype.getIsDayNumbersVisible = function () {
        return this.rowCnt > 1;
    };
    /* Grid Number Rendering
    ------------------------------------------------------------------------------------------------------------------*/
    DayGrid.prototype.renderNumberTrHtml = function (row) {
        return '' +
            '<tr>' +
            (this.isRTL ? '' : this.renderNumberIntroHtml(row)) +
            this.renderNumberCellsHtml(row) +
            (this.isRTL ? this.renderNumberIntroHtml(row) : '') +
            '</tr>';
    };
    DayGrid.prototype.renderNumberIntroHtml = function (row) {
        return this.renderIntroHtml();
    };
    DayGrid.prototype.renderNumberCellsHtml = function (row) {
        var htmls = [];
        var col;
        var date;
        for (col = 0; col < this.colCnt; col++) {
            date = this.getCellDate(row, col);
            htmls.push(this.renderNumberCellHtml(date));
        }
        return htmls.join('');
    };
    // Generates the HTML for the <td>s of the "number" row in the DayGrid's content skeleton.
    // The number row will only exist if either day numbers or week numbers are turned on.
    DayGrid.prototype.renderNumberCellHtml = function (date) {
        var view = this.view;
        var html = '';
        var isDateValid = this.dateProfile.activeUnzonedRange.containsDate(date); // TODO: called too frequently. cache somehow.
        var isDayNumberVisible = this.getIsDayNumbersVisible() && isDateValid;
        var classes;
        var weekCalcFirstDoW;
        if (!isDayNumberVisible && !this.cellWeekNumbersVisible) {
            // no numbers in day cell (week number must be along the side)
            return '<td/>'; //  will create an empty space above events :(
        }
        classes = this.getDayClasses(date);
        classes.unshift('fc-day-top');
        if (this.cellWeekNumbersVisible) {
            // To determine the day of week number change under ISO, we cannot
            // rely on moment.js methods such as firstDayOfWeek() or weekday(),
            // because they rely on the locale's dow (possibly overridden by
            // our firstDay option), which may not be Monday. We cannot change
            // dow, because that would affect the calendar start day as well.
            if (date._locale._fullCalendar_weekCalc === 'ISO') {
                weekCalcFirstDoW = 1; // Monday by ISO 8601 definition
            }
            else {
                weekCalcFirstDoW = date._locale.firstDayOfWeek();
            }
        }
        html += '<td class="' + classes.join(' ') + '"' +
            (isDateValid ?
                ' data-date="' + date.format() + '"' :
                '') +
            '>';
        if (this.cellWeekNumbersVisible && (date.day() === weekCalcFirstDoW)) {
            html += view.buildGotoAnchorHtml({ date: date, type: 'week' }, { 'class': 'fc-week-number' }, date.format('w') // inner HTML
            );
        }
        if (isDayNumberVisible) {
            html += view.buildGotoAnchorHtml(date, { 'class': 'fc-day-number' }, date.format('D') // inner HTML
            );
        }
        html += '</td>';
        return html;
    };
    /* Hit System
    ------------------------------------------------------------------------------------------------------------------*/
    DayGrid.prototype.prepareHits = function () {
        this.colCoordCache.build();
        this.rowCoordCache.build();
        this.rowCoordCache.bottoms[this.rowCnt - 1] += this.bottomCoordPadding; // hack
    };
    DayGrid.prototype.releaseHits = function () {
        this.colCoordCache.clear();
        this.rowCoordCache.clear();
    };
    DayGrid.prototype.queryHit = function (leftOffset, topOffset) {
        if (this.colCoordCache.isLeftInBounds(leftOffset) && this.rowCoordCache.isTopInBounds(topOffset)) {
            var col = this.colCoordCache.getHorizontalIndex(leftOffset);
            var row = this.rowCoordCache.getVerticalIndex(topOffset);
            if (row != null && col != null) {
                return this.getCellHit(row, col);
            }
        }
    };
    DayGrid.prototype.getHitFootprint = function (hit) {
        var range = this.getCellRange(hit.row, hit.col);
        return new ComponentFootprint_1.default(new UnzonedRange_1.default(range.start, range.end), true // all-day?
        );
    };
    DayGrid.prototype.getHitEl = function (hit) {
        return this.getCellEl(hit.row, hit.col);
    };
    /* Cell System
    ------------------------------------------------------------------------------------------------------------------*/
    // FYI: the first column is the leftmost column, regardless of date
    DayGrid.prototype.getCellHit = function (row, col) {
        return {
            row: row,
            col: col,
            component: this,
            left: this.colCoordCache.getLeftOffset(col),
            right: this.colCoordCache.getRightOffset(col),
            top: this.rowCoordCache.getTopOffset(row),
            bottom: this.rowCoordCache.getBottomOffset(row)
        };
    };
    DayGrid.prototype.getCellEl = function (row, col) {
        return this.cellEls.eq(row * this.colCnt + col);
    };
    /* Event Rendering
    ------------------------------------------------------------------------------------------------------------------*/
    // Unrenders all events currently rendered on the grid
    DayGrid.prototype.executeEventUnrender = function () {
        this.removeSegPopover(); // removes the "more.." events popover
        _super.prototype.executeEventUnrender.call(this);
    };
    // Retrieves all rendered segment objects currently rendered on the grid
    DayGrid.prototype.getOwnEventSegs = function () {
        // append the segments from the "more..." popover
        return _super.prototype.getOwnEventSegs.call(this).concat(this.popoverSegs || []);
    };
    /* Event Drag Visualization
    ------------------------------------------------------------------------------------------------------------------*/
    // Renders a visual indication of an event or external element being dragged.
    // `eventLocation` has zoned start and end (optional)
    DayGrid.prototype.renderDrag = function (eventFootprints, seg, isTouch) {
        var i;
        for (i = 0; i < eventFootprints.length; i++) {
            this.renderHighlight(eventFootprints[i].componentFootprint);
        }
        // render drags from OTHER components as helpers
        if (eventFootprints.length && seg && seg.component !== this) {
            this.helperRenderer.renderEventDraggingFootprints(eventFootprints, seg, isTouch);
            return true; // signal helpers rendered
        }
    };
    // Unrenders any visual indication of a hovering event
    DayGrid.prototype.unrenderDrag = function () {
        this.unrenderHighlight();
        this.helperRenderer.unrender();
    };
    /* Event Resize Visualization
    ------------------------------------------------------------------------------------------------------------------*/
    // Renders a visual indication of an event being resized
    DayGrid.prototype.renderEventResize = function (eventFootprints, seg, isTouch) {
        var i;
        for (i = 0; i < eventFootprints.length; i++) {
            this.renderHighlight(eventFootprints[i].componentFootprint);
        }
        this.helperRenderer.renderEventResizingFootprints(eventFootprints, seg, isTouch);
    };
    // Unrenders a visual indication of an event being resized
    DayGrid.prototype.unrenderEventResize = function () {
        this.unrenderHighlight();
        this.helperRenderer.unrender();
    };
    /* More+ Link Popover
    ------------------------------------------------------------------------------------------------------------------*/
    DayGrid.prototype.removeSegPopover = function () {
        if (this.segPopover) {
            this.segPopover.hide(); // in handler, will call segPopover's removeElement
        }
    };
    // Limits the number of "levels" (vertically stacking layers of events) for each row of the grid.
    // `levelLimit` can be false (don't limit), a number, or true (should be computed).
    DayGrid.prototype.limitRows = function (levelLimit) {
        var rowStructs = this.eventRenderer.rowStructs || [];
        var row; // row #
        var rowLevelLimit;
        for (row = 0; row < rowStructs.length; row++) {
            this.unlimitRow(row);
            if (!levelLimit) {
                rowLevelLimit = false;
            }
            else if (typeof levelLimit === 'number') {
                rowLevelLimit = levelLimit;
            }
            else {
                rowLevelLimit = this.computeRowLevelLimit(row);
            }
            if (rowLevelLimit !== false) {
                this.limitRow(row, rowLevelLimit);
            }
        }
    };
    // Computes the number of levels a row will accomodate without going outside its bounds.
    // Assumes the row is "rigid" (maintains a constant height regardless of what is inside).
    // `row` is the row number.
    DayGrid.prototype.computeRowLevelLimit = function (row) {
        var rowEl = this.rowEls.eq(row); // the containing "fake" row div
        var rowHeight = rowEl.height(); // TODO: cache somehow?
        var trEls = this.eventRenderer.rowStructs[row].tbodyEl.children();
        var i;
        var trEl;
        var trHeight;
        function iterInnerHeights(i, childNode) {
            trHeight = Math.max(trHeight, $(childNode).outerHeight());
        }
        // Reveal one level <tr> at a time and stop when we find one out of bounds
        for (i = 0; i < trEls.length; i++) {
            trEl = trEls.eq(i).removeClass('fc-limited'); // reset to original state (reveal)
            // with rowspans>1 and IE8, trEl.outerHeight() would return the height of the largest cell,
            // so instead, find the tallest inner content element.
            trHeight = 0;
            trEl.find('> td > :first-child').each(iterInnerHeights);
            if (trEl.position().top + trHeight > rowHeight) {
                return i;
            }
        }
        return false; // should not limit at all
    };
    // Limits the given grid row to the maximum number of levels and injects "more" links if necessary.
    // `row` is the row number.
    // `levelLimit` is a number for the maximum (inclusive) number of levels allowed.
    DayGrid.prototype.limitRow = function (row, levelLimit) {
        var _this = this;
        var rowStruct = this.eventRenderer.rowStructs[row];
        var moreNodes = []; // array of "more" <a> links and <td> DOM nodes
        var col = 0; // col #, left-to-right (not chronologically)
        var levelSegs; // array of segment objects in the last allowable level, ordered left-to-right
        var cellMatrix; // a matrix (by level, then column) of all <td> jQuery elements in the row
        var limitedNodes; // array of temporarily hidden level <tr> and segment <td> DOM nodes
        var i;
        var seg;
        var segsBelow; // array of segment objects below `seg` in the current `col`
        var totalSegsBelow; // total number of segments below `seg` in any of the columns `seg` occupies
        var colSegsBelow; // array of segment arrays, below seg, one for each column (offset from segs's first column)
        var td;
        var rowspan;
        var segMoreNodes; // array of "more" <td> cells that will stand-in for the current seg's cell
        var j;
        var moreTd;
        var moreWrap;
        var moreLink;
        // Iterates through empty level cells and places "more" links inside if need be
        var emptyCellsUntil = function (endCol) {
            while (col < endCol) {
                segsBelow = _this.getCellSegs(row, col, levelLimit);
                if (segsBelow.length) {
                    td = cellMatrix[levelLimit - 1][col];
                    moreLink = _this.renderMoreLink(row, col, segsBelow);
                    moreWrap = $('<div/>').append(moreLink);
                    td.append(moreWrap);
                    moreNodes.push(moreWrap[0]);
                }
                col++;
            }
        };
        if (levelLimit && levelLimit < rowStruct.segLevels.length) {
            levelSegs = rowStruct.segLevels[levelLimit - 1];
            cellMatrix = rowStruct.cellMatrix;
            limitedNodes = rowStruct.tbodyEl.children().slice(levelLimit) // get level <tr> elements past the limit
                .addClass('fc-limited').get(); // hide elements and get a simple DOM-nodes array
            // iterate though segments in the last allowable level
            for (i = 0; i < levelSegs.length; i++) {
                seg = levelSegs[i];
                emptyCellsUntil(seg.leftCol); // process empty cells before the segment
                // determine *all* segments below `seg` that occupy the same columns
                colSegsBelow = [];
                totalSegsBelow = 0;
                while (col <= seg.rightCol) {
                    segsBelow = this.getCellSegs(row, col, levelLimit);
                    colSegsBelow.push(segsBelow);
                    totalSegsBelow += segsBelow.length;
                    col++;
                }
                if (totalSegsBelow) {
                    td = cellMatrix[levelLimit - 1][seg.leftCol]; // the segment's parent cell
                    rowspan = td.attr('rowspan') || 1;
                    segMoreNodes = [];
                    // make a replacement <td> for each column the segment occupies. will be one for each colspan
                    for (j = 0; j < colSegsBelow.length; j++) {
                        moreTd = $('<td class="fc-more-cell"/>').attr('rowspan', rowspan);
                        segsBelow = colSegsBelow[j];
                        moreLink = this.renderMoreLink(row, seg.leftCol + j, [seg].concat(segsBelow) // count seg as hidden too
                        );
                        moreWrap = $('<div/>').append(moreLink);
                        moreTd.append(moreWrap);
                        segMoreNodes.push(moreTd[0]);
                        moreNodes.push(moreTd[0]);
                    }
                    td.addClass('fc-limited').after($(segMoreNodes)); // hide original <td> and inject replacements
                    limitedNodes.push(td[0]);
                }
            }
            emptyCellsUntil(this.colCnt); // finish off the level
            rowStruct.moreEls = $(moreNodes); // for easy undoing later
            rowStruct.limitedEls = $(limitedNodes); // for easy undoing later
        }
    };
    // Reveals all levels and removes all "more"-related elements for a grid's row.
    // `row` is a row number.
    DayGrid.prototype.unlimitRow = function (row) {
        var rowStruct = this.eventRenderer.rowStructs[row];
        if (rowStruct.moreEls) {
            rowStruct.moreEls.remove();
            rowStruct.moreEls = null;
        }
        if (rowStruct.limitedEls) {
            rowStruct.limitedEls.removeClass('fc-limited');
            rowStruct.limitedEls = null;
        }
    };
    // Renders an <a> element that represents hidden event element for a cell.
    // Responsible for attaching click handler as well.
    DayGrid.prototype.renderMoreLink = function (row, col, hiddenSegs) {
        var _this = this;
        var view = this.view;
        return $('<a class="fc-more"/>')
            .text(this.getMoreLinkText(hiddenSegs.length))
            .on('click', function (ev) {
            var clickOption = _this.opt('eventLimitClick');
            var date = _this.getCellDate(row, col);
            var moreEl = $(ev.currentTarget);
            var dayEl = _this.getCellEl(row, col);
            var allSegs = _this.getCellSegs(row, col);
            // rescope the segments to be within the cell's date
            var reslicedAllSegs = _this.resliceDaySegs(allSegs, date);
            var reslicedHiddenSegs = _this.resliceDaySegs(hiddenSegs, date);
            if (typeof clickOption === 'function') {
                // the returned value can be an atomic option
                clickOption = _this.publiclyTrigger('eventLimitClick', {
                    context: view,
                    args: [
                        {
                            date: date.clone(),
                            dayEl: dayEl,
                            moreEl: moreEl,
                            segs: reslicedAllSegs,
                            hiddenSegs: reslicedHiddenSegs
                        },
                        ev,
                        view
                    ]
                });
            }
            if (clickOption === 'popover') {
                _this.showSegPopover(row, col, moreEl, reslicedAllSegs);
            }
            else if (typeof clickOption === 'string') {
                view.calendar.zoomTo(date, clickOption);
            }
        });
    };
    // Reveals the popover that displays all events within a cell
    DayGrid.prototype.showSegPopover = function (row, col, moreLink, segs) {
        var _this = this;
        var view = this.view;
        var moreWrap = moreLink.parent(); // the <div> wrapper around the <a>
        var topEl; // the element we want to match the top coordinate of
        var options;
        if (this.rowCnt === 1) {
            topEl = view.el; // will cause the popover to cover any sort of header
        }
        else {
            topEl = this.rowEls.eq(row); // will align with top of row
        }
        options = {
            className: 'fc-more-popover ' + view.calendar.theme.getClass('popover'),
            content: this.renderSegPopoverContent(row, col, segs),
            parentEl: view.el,
            top: topEl.offset().top,
            autoHide: true,
            viewportConstrain: this.opt('popoverViewportConstrain'),
            hide: function () {
                // kill everything when the popover is hidden
                // notify events to be removed
                if (_this.popoverSegs) {
                    _this.triggerBeforeEventSegsDestroyed(_this.popoverSegs);
                }
                _this.segPopover.removeElement();
                _this.segPopover = null;
                _this.popoverSegs = null;
            }
        };
        // Determine horizontal coordinate.
        // We use the moreWrap instead of the <td> to avoid border confusion.
        if (this.isRTL) {
            options.right = moreWrap.offset().left + moreWrap.outerWidth() + 1; // +1 to be over cell border
        }
        else {
            options.left = moreWrap.offset().left - 1; // -1 to be over cell border
        }
        this.segPopover = new Popover_1.default(options);
        this.segPopover.show();
        // the popover doesn't live within the grid's container element, and thus won't get the event
        // delegated-handlers for free. attach event-related handlers to the popover.
        this.bindAllSegHandlersToEl(this.segPopover.el);
        this.triggerAfterEventSegsRendered(segs);
    };
    // Builds the inner DOM contents of the segment popover
    DayGrid.prototype.renderSegPopoverContent = function (row, col, segs) {
        var view = this.view;
        var theme = view.calendar.theme;
        var title = this.getCellDate(row, col).format(this.opt('dayPopoverFormat'));
        var content = $('<div class="fc-header ' + theme.getClass('popoverHeader') + '">' +
            '<span class="fc-close ' + theme.getIconClass('close') + '"></span>' +
            '<span class="fc-title">' +
            util_1.htmlEscape(title) +
            '</span>' +
            '<div class="fc-clear"/>' +
            '</div>' +
            '<div class="fc-body ' + theme.getClass('popoverContent') + '">' +
            '<div class="fc-event-container"></div>' +
            '</div>');
        var segContainer = content.find('.fc-event-container');
        var i;
        // render each seg's `el` and only return the visible segs
        segs = this.eventRenderer.renderFgSegEls(segs, true); // disableResizing=true
        this.popoverSegs = segs;
        for (i = 0; i < segs.length; i++) {
            // because segments in the popover are not part of a grid coordinate system, provide a hint to any
            // grids that want to do drag-n-drop about which cell it came from
            this.hitsNeeded();
            segs[i].hit = this.getCellHit(row, col);
            this.hitsNotNeeded();
            segContainer.append(segs[i].el);
        }
        return content;
    };
    // Given the events within an array of segment objects, reslice them to be in a single day
    DayGrid.prototype.resliceDaySegs = function (segs, dayDate) {
        var dayStart = dayDate.clone();
        var dayEnd = dayStart.clone().add(1, 'days');
        var dayRange = new UnzonedRange_1.default(dayStart, dayEnd);
        var newSegs = [];
        var i;
        var seg;
        var slicedRange;
        for (i = 0; i < segs.length; i++) {
            seg = segs[i];
            slicedRange = seg.footprint.componentFootprint.unzonedRange.intersect(dayRange);
            if (slicedRange) {
                newSegs.push($.extend({}, seg, {
                    footprint: new EventFootprint_1.default(new ComponentFootprint_1.default(slicedRange, seg.footprint.componentFootprint.isAllDay), seg.footprint.eventDef, seg.footprint.eventInstance),
                    isStart: seg.isStart && slicedRange.isStart,
                    isEnd: seg.isEnd && slicedRange.isEnd
                }));
            }
        }
        // force an order because eventsToSegs doesn't guarantee one
        // TODO: research if still needed
        this.eventRenderer.sortEventSegs(newSegs);
        return newSegs;
    };
    // Generates the text that should be inside a "more" link, given the number of events it represents
    DayGrid.prototype.getMoreLinkText = function (num) {
        var opt = this.opt('eventLimitText');
        if (typeof opt === 'function') {
            return opt(num);
        }
        else {
            return '+' + num + ' ' + opt;
        }
    };
    // Returns segments within a given cell.
    // If `startLevel` is specified, returns only events including and below that level. Otherwise returns all segs.
    DayGrid.prototype.getCellSegs = function (row, col, startLevel) {
        var segMatrix = this.eventRenderer.rowStructs[row].segMatrix;
        var level = startLevel || 0;
        var segs = [];
        var seg;
        while (level < segMatrix.length) {
            seg = segMatrix[level][col];
            if (seg) {
                segs.push(seg);
            }
            level++;
        }
        return segs;
    };
    return DayGrid;
}(InteractiveDateComponent_1.default));
exports.default = DayGrid;
DayGrid.prototype.eventRendererClass = DayGridEventRenderer_1.default;
DayGrid.prototype.businessHourRendererClass = BusinessHourRenderer_1.default;
DayGrid.prototype.helperRendererClass = DayGridHelperRenderer_1.default;
DayGrid.prototype.fillRendererClass = DayGridFillRenderer_1.default;
StandardInteractionsMixin_1.default.mixInto(DayGrid);
DayTableMixin_1.default.mixInto(DayGrid);


/***/ }),
/* 62 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var $ = __webpack_require__(3);
var util_1 = __webpack_require__(4);
var Scroller_1 = __webpack_require__(39);
var View_1 = __webpack_require__(41);
var BasicViewDateProfileGenerator_1 = __webpack_require__(228);
var DayGrid_1 = __webpack_require__(61);
/* An abstract class for the "basic" views, as well as month view. Renders one or more rows of day cells.
----------------------------------------------------------------------------------------------------------------------*/
// It is a manager for a DayGrid subcomponent, which does most of the heavy lifting.
// It is responsible for managing width/height.
var BasicView = /** @class */ (function (_super) {
    tslib_1.__extends(BasicView, _super);
    function BasicView(calendar, viewSpec) {
        var _this = _super.call(this, calendar, viewSpec) || this;
        _this.dayGrid = _this.instantiateDayGrid();
        _this.dayGrid.isRigid = _this.hasRigidRows();
        if (_this.opt('weekNumbers')) {
            if (_this.opt('weekNumbersWithinDays')) {
                _this.dayGrid.cellWeekNumbersVisible = true;
                _this.dayGrid.colWeekNumbersVisible = false;
            }
            else {
                _this.dayGrid.cellWeekNumbersVisible = false;
                _this.dayGrid.colWeekNumbersVisible = true;
            }
        }
        _this.addChild(_this.dayGrid);
        _this.scroller = new Scroller_1.default({
            overflowX: 'hidden',
            overflowY: 'auto'
        });
        return _this;
    }
    // Generates the DayGrid object this view needs. Draws from this.dayGridClass
    BasicView.prototype.instantiateDayGrid = function () {
        // generate a subclass on the fly with BasicView-specific behavior
        // TODO: cache this subclass
        var subclass = makeDayGridSubclass(this.dayGridClass);
        return new subclass(this);
    };
    BasicView.prototype.executeDateRender = function (dateProfile) {
        this.dayGrid.breakOnWeeks = /year|month|week/.test(dateProfile.currentRangeUnit);
        _super.prototype.executeDateRender.call(this, dateProfile);
    };
    BasicView.prototype.renderSkeleton = function () {
        var dayGridContainerEl;
        var dayGridEl;
        this.el.addClass('fc-basic-view').html(this.renderSkeletonHtml());
        this.scroller.render();
        dayGridContainerEl = this.scroller.el.addClass('fc-day-grid-container');
        dayGridEl = $('<div class="fc-day-grid" />').appendTo(dayGridContainerEl);
        this.el.find('.fc-body > tr > td').append(dayGridContainerEl);
        this.dayGrid.headContainerEl = this.el.find('.fc-head-container');
        this.dayGrid.setElement(dayGridEl);
    };
    BasicView.prototype.unrenderSkeleton = function () {
        this.dayGrid.removeElement();
        this.scroller.destroy();
    };
    // Builds the HTML skeleton for the view.
    // The day-grid component will render inside of a container defined by this HTML.
    BasicView.prototype.renderSkeletonHtml = function () {
        var theme = this.calendar.theme;
        return '' +
            '<table class="' + theme.getClass('tableGrid') + '">' +
            (this.opt('columnHeader') ?
                '<thead class="fc-head">' +
                    '<tr>' +
                    '<td class="fc-head-container ' + theme.getClass('widgetHeader') + '">&nbsp;</td>' +
                    '</tr>' +
                    '</thead>' :
                '') +
            '<tbody class="fc-body">' +
            '<tr>' +
            '<td class="' + theme.getClass('widgetContent') + '"></td>' +
            '</tr>' +
            '</tbody>' +
            '</table>';
    };
    // Generates an HTML attribute string for setting the width of the week number column, if it is known
    BasicView.prototype.weekNumberStyleAttr = function () {
        if (this.weekNumberWidth != null) {
            return 'style="width:' + this.weekNumberWidth + 'px"';
        }
        return '';
    };
    // Determines whether each row should have a constant height
    BasicView.prototype.hasRigidRows = function () {
        var eventLimit = this.opt('eventLimit');
        return eventLimit && typeof eventLimit !== 'number';
    };
    /* Dimensions
    ------------------------------------------------------------------------------------------------------------------*/
    // Refreshes the horizontal dimensions of the view
    BasicView.prototype.updateSize = function (totalHeight, isAuto, isResize) {
        var eventLimit = this.opt('eventLimit');
        var headRowEl = this.dayGrid.headContainerEl.find('.fc-row');
        var scrollerHeight;
        var scrollbarWidths;
        // hack to give the view some height prior to dayGrid's columns being rendered
        // TODO: separate setting height from scroller VS dayGrid.
        if (!this.dayGrid.rowEls) {
            if (!isAuto) {
                scrollerHeight = this.computeScrollerHeight(totalHeight);
                this.scroller.setHeight(scrollerHeight);
            }
            return;
        }
        _super.prototype.updateSize.call(this, totalHeight, isAuto, isResize);
        if (this.dayGrid.colWeekNumbersVisible) {
            // Make sure all week number cells running down the side have the same width.
            // Record the width for cells created later.
            this.weekNumberWidth = util_1.matchCellWidths(this.el.find('.fc-week-number'));
        }
        // reset all heights to be natural
        this.scroller.clear();
        util_1.uncompensateScroll(headRowEl);
        this.dayGrid.removeSegPopover(); // kill the "more" popover if displayed
        // is the event limit a constant level number?
        if (eventLimit && typeof eventLimit === 'number') {
            this.dayGrid.limitRows(eventLimit); // limit the levels first so the height can redistribute after
        }
        // distribute the height to the rows
        // (totalHeight is a "recommended" value if isAuto)
        scrollerHeight = this.computeScrollerHeight(totalHeight);
        this.setGridHeight(scrollerHeight, isAuto);
        // is the event limit dynamically calculated?
        if (eventLimit && typeof eventLimit !== 'number') {
            this.dayGrid.limitRows(eventLimit); // limit the levels after the grid's row heights have been set
        }
        if (!isAuto) {
            this.scroller.setHeight(scrollerHeight);
            scrollbarWidths = this.scroller.getScrollbarWidths();
            if (scrollbarWidths.left || scrollbarWidths.right) {
                util_1.compensateScroll(headRowEl, scrollbarWidths);
                // doing the scrollbar compensation might have created text overflow which created more height. redo
                scrollerHeight = this.computeScrollerHeight(totalHeight);
                this.scroller.setHeight(scrollerHeight);
            }
            // guarantees the same scrollbar widths
            this.scroller.lockOverflow(scrollbarWidths);
        }
    };
    // given a desired total height of the view, returns what the height of the scroller should be
    BasicView.prototype.computeScrollerHeight = function (totalHeight) {
        return totalHeight -
            util_1.subtractInnerElHeight(this.el, this.scroller.el); // everything that's NOT the scroller
    };
    // Sets the height of just the DayGrid component in this view
    BasicView.prototype.setGridHeight = function (height, isAuto) {
        if (isAuto) {
            util_1.undistributeHeight(this.dayGrid.rowEls); // let the rows be their natural height with no expanding
        }
        else {
            util_1.distributeHeight(this.dayGrid.rowEls, height, true); // true = compensate for height-hogging rows
        }
    };
    /* Scroll
    ------------------------------------------------------------------------------------------------------------------*/
    BasicView.prototype.computeInitialDateScroll = function () {
        return { top: 0 };
    };
    BasicView.prototype.queryDateScroll = function () {
        return { top: this.scroller.getScrollTop() };
    };
    BasicView.prototype.applyDateScroll = function (scroll) {
        if (scroll.top !== undefined) {
            this.scroller.setScrollTop(scroll.top);
        }
    };
    return BasicView;
}(View_1.default));
exports.default = BasicView;
BasicView.prototype.dateProfileGeneratorClass = BasicViewDateProfileGenerator_1.default;
BasicView.prototype.dayGridClass = DayGrid_1.default;
// customize the rendering behavior of BasicView's dayGrid
function makeDayGridSubclass(SuperClass) {
    return /** @class */ (function (_super) {
        tslib_1.__extends(SubClass, _super);
        function SubClass() {
            var _this = _super !== null && _super.apply(this, arguments) || this;
            _this.colWeekNumbersVisible = false; // display week numbers along the side?
            return _this;
        }
        // Generates the HTML that will go before the day-of week header cells
        SubClass.prototype.renderHeadIntroHtml = function () {
            var view = this.view;
            if (this.colWeekNumbersVisible) {
                return '' +
                    '<th class="fc-week-number ' + view.calendar.theme.getClass('widgetHeader') + '" ' + view.weekNumberStyleAttr() + '>' +
                    '<span>' + // needed for matchCellWidths
                    util_1.htmlEscape(this.opt('weekNumberTitle')) +
                    '</span>' +
                    '</th>';
            }
            return '';
        };
        // Generates the HTML that will go before content-skeleton cells that display the day/week numbers
        SubClass.prototype.renderNumberIntroHtml = function (row) {
            var view = this.view;
            var weekStart = this.getCellDate(row, 0);
            if (this.colWeekNumbersVisible) {
                return '' +
                    '<td class="fc-week-number" ' + view.weekNumberStyleAttr() + '>' +
                    view.buildGotoAnchorHtml(// aside from link, important for matchCellWidths
                    { date: weekStart, type: 'week', forceOff: this.colCnt === 1 }, weekStart.format('w') // inner HTML
                    ) +
                    '</td>';
            }
            return '';
        };
        // Generates the HTML that goes before the day bg cells for each day-row
        SubClass.prototype.renderBgIntroHtml = function () {
            var view = this.view;
            if (this.colWeekNumbersVisible) {
                return '<td class="fc-week-number ' + view.calendar.theme.getClass('widgetContent') + '" ' +
                    view.weekNumberStyleAttr() + '></td>';
            }
            return '';
        };
        // Generates the HTML that goes before every other type of row generated by DayGrid.
        // Affects helper-skeleton and highlight-skeleton rows.
        SubClass.prototype.renderIntroHtml = function () {
            var view = this.view;
            if (this.colWeekNumbersVisible) {
                return '<td class="fc-week-number" ' + view.weekNumberStyleAttr() + '></td>';
            }
            return '';
        };
        SubClass.prototype.getIsNumbersVisible = function () {
            return DayGrid_1.default.prototype.getIsNumbersVisible.apply(this, arguments) || this.colWeekNumbersVisible;
        };
        return SubClass;
    }(SuperClass));
}


/***/ }),
/* 63 */,
/* 64 */,
/* 65 */,
/* 66 */,
/* 67 */,
/* 68 */,
/* 69 */,
/* 70 */,
/* 71 */,
/* 72 */,
/* 73 */,
/* 74 */,
/* 75 */,
/* 76 */,
/* 77 */,
/* 78 */,
/* 79 */,
/* 80 */,
/* 81 */,
/* 82 */,
/* 83 */,
/* 84 */,
/* 85 */,
/* 86 */,
/* 87 */,
/* 88 */,
/* 89 */,
/* 90 */,
/* 91 */,
/* 92 */,
/* 93 */,
/* 94 */,
/* 95 */,
/* 96 */,
/* 97 */,
/* 98 */,
/* 99 */,
/* 100 */,
/* 101 */,
/* 102 */,
/* 103 */,
/* 104 */,
/* 105 */,
/* 106 */,
/* 107 */,
/* 108 */,
/* 109 */,
/* 110 */,
/* 111 */,
/* 112 */,
/* 113 */,
/* 114 */,
/* 115 */,
/* 116 */,
/* 117 */,
/* 118 */,
/* 119 */,
/* 120 */,
/* 121 */,
/* 122 */,
/* 123 */,
/* 124 */,
/* 125 */,
/* 126 */,
/* 127 */,
/* 128 */,
/* 129 */,
/* 130 */,
/* 131 */,
/* 132 */,
/* 133 */,
/* 134 */,
/* 135 */,
/* 136 */,
/* 137 */,
/* 138 */,
/* 139 */,
/* 140 */,
/* 141 */,
/* 142 */,
/* 143 */,
/* 144 */,
/* 145 */,
/* 146 */,
/* 147 */,
/* 148 */,
/* 149 */,
/* 150 */,
/* 151 */,
/* 152 */,
/* 153 */,
/* 154 */,
/* 155 */,
/* 156 */,
/* 157 */,
/* 158 */,
/* 159 */,
/* 160 */,
/* 161 */,
/* 162 */,
/* 163 */,
/* 164 */,
/* 165 */,
/* 166 */,
/* 167 */,
/* 168 */,
/* 169 */,
/* 170 */,
/* 171 */,
/* 172 */,
/* 173 */,
/* 174 */,
/* 175 */,
/* 176 */,
/* 177 */,
/* 178 */,
/* 179 */,
/* 180 */,
/* 181 */,
/* 182 */,
/* 183 */,
/* 184 */,
/* 185 */,
/* 186 */,
/* 187 */,
/* 188 */,
/* 189 */,
/* 190 */,
/* 191 */,
/* 192 */,
/* 193 */,
/* 194 */,
/* 195 */,
/* 196 */,
/* 197 */,
/* 198 */,
/* 199 */,
/* 200 */,
/* 201 */,
/* 202 */,
/* 203 */,
/* 204 */,
/* 205 */,
/* 206 */,
/* 207 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var UnzonedRange_1 = __webpack_require__(5);
var ComponentFootprint_1 = __webpack_require__(12);
var EventDefParser_1 = __webpack_require__(49);
var EventSource_1 = __webpack_require__(6);
var util_1 = __webpack_require__(35);
var Constraints = /** @class */ (function () {
    function Constraints(eventManager, _calendar) {
        this.eventManager = eventManager;
        this._calendar = _calendar;
    }
    Constraints.prototype.opt = function (name) {
        return this._calendar.opt(name);
    };
    /*
    determines if eventInstanceGroup is allowed,
    in relation to other EVENTS and business hours.
    */
    Constraints.prototype.isEventInstanceGroupAllowed = function (eventInstanceGroup) {
        var eventDef = eventInstanceGroup.getEventDef();
        var eventFootprints = this.eventRangesToEventFootprints(eventInstanceGroup.getAllEventRanges());
        var i;
        var peerEventInstances = this.getPeerEventInstances(eventDef);
        var peerEventRanges = peerEventInstances.map(util_1.eventInstanceToEventRange);
        var peerEventFootprints = this.eventRangesToEventFootprints(peerEventRanges);
        var constraintVal = eventDef.getConstraint();
        var overlapVal = eventDef.getOverlap();
        var eventAllowFunc = this.opt('eventAllow');
        for (i = 0; i < eventFootprints.length; i++) {
            if (!this.isFootprintAllowed(eventFootprints[i].componentFootprint, peerEventFootprints, constraintVal, overlapVal, eventFootprints[i].eventInstance)) {
                return false;
            }
        }
        if (eventAllowFunc) {
            for (i = 0; i < eventFootprints.length; i++) {
                if (eventAllowFunc(eventFootprints[i].componentFootprint.toLegacy(this._calendar), eventFootprints[i].getEventLegacy()) === false) {
                    return false;
                }
            }
        }
        return true;
    };
    Constraints.prototype.getPeerEventInstances = function (eventDef) {
        return this.eventManager.getEventInstancesWithoutId(eventDef.id);
    };
    Constraints.prototype.isSelectionFootprintAllowed = function (componentFootprint) {
        var peerEventInstances = this.eventManager.getEventInstances();
        var peerEventRanges = peerEventInstances.map(util_1.eventInstanceToEventRange);
        var peerEventFootprints = this.eventRangesToEventFootprints(peerEventRanges);
        var selectAllowFunc;
        if (this.isFootprintAllowed(componentFootprint, peerEventFootprints, this.opt('selectConstraint'), this.opt('selectOverlap'))) {
            selectAllowFunc = this.opt('selectAllow');
            if (selectAllowFunc) {
                return selectAllowFunc(componentFootprint.toLegacy(this._calendar)) !== false;
            }
            else {
                return true;
            }
        }
        return false;
    };
    Constraints.prototype.isFootprintAllowed = function (componentFootprint, peerEventFootprints, constraintVal, overlapVal, subjectEventInstance // optional
    ) {
        var constraintFootprints; // ComponentFootprint[]
        var overlapEventFootprints; // EventFootprint[]
        if (constraintVal != null) {
            constraintFootprints = this.constraintValToFootprints(constraintVal, componentFootprint.isAllDay);
            if (!this.isFootprintWithinConstraints(componentFootprint, constraintFootprints)) {
                return false;
            }
        }
        overlapEventFootprints = this.collectOverlapEventFootprints(peerEventFootprints, componentFootprint);
        if (overlapVal === false) {
            if (overlapEventFootprints.length) {
                return false;
            }
        }
        else if (typeof overlapVal === 'function') {
            if (!isOverlapsAllowedByFunc(overlapEventFootprints, overlapVal, subjectEventInstance)) {
                return false;
            }
        }
        if (subjectEventInstance) {
            if (!isOverlapEventInstancesAllowed(overlapEventFootprints, subjectEventInstance)) {
                return false;
            }
        }
        return true;
    };
    // Constraint
    // ------------------------------------------------------------------------------------------------
    Constraints.prototype.isFootprintWithinConstraints = function (componentFootprint, constraintFootprints) {
        var i;
        for (i = 0; i < constraintFootprints.length; i++) {
            if (this.footprintContainsFootprint(constraintFootprints[i], componentFootprint)) {
                return true;
            }
        }
        return false;
    };
    Constraints.prototype.constraintValToFootprints = function (constraintVal, isAllDay) {
        var eventInstances;
        if (constraintVal === 'businessHours') {
            return this.buildCurrentBusinessFootprints(isAllDay);
        }
        else if (typeof constraintVal === 'object') {
            eventInstances = this.parseEventDefToInstances(constraintVal); // handles recurring events
            if (!eventInstances) {
                return this.parseFootprints(constraintVal);
            }
            else {
                return this.eventInstancesToFootprints(eventInstances);
            }
        }
        else if (constraintVal != null) {
            eventInstances = this.eventManager.getEventInstancesWithId(constraintVal);
            return this.eventInstancesToFootprints(eventInstances);
        }
    };
    // returns ComponentFootprint[]
    // uses current view's range
    Constraints.prototype.buildCurrentBusinessFootprints = function (isAllDay) {
        var view = this._calendar.view;
        var businessHourGenerator = view.get('businessHourGenerator');
        var unzonedRange = view.dateProfile.activeUnzonedRange;
        var eventInstanceGroup = businessHourGenerator.buildEventInstanceGroup(isAllDay, unzonedRange);
        if (eventInstanceGroup) {
            return this.eventInstancesToFootprints(eventInstanceGroup.eventInstances);
        }
        else {
            return [];
        }
    };
    // conversion util
    Constraints.prototype.eventInstancesToFootprints = function (eventInstances) {
        var eventRanges = eventInstances.map(util_1.eventInstanceToEventRange);
        var eventFootprints = this.eventRangesToEventFootprints(eventRanges);
        return eventFootprints.map(util_1.eventFootprintToComponentFootprint);
    };
    // Overlap
    // ------------------------------------------------------------------------------------------------
    Constraints.prototype.collectOverlapEventFootprints = function (peerEventFootprints, targetFootprint) {
        var overlapEventFootprints = [];
        var i;
        for (i = 0; i < peerEventFootprints.length; i++) {
            if (this.footprintsIntersect(targetFootprint, peerEventFootprints[i].componentFootprint)) {
                overlapEventFootprints.push(peerEventFootprints[i]);
            }
        }
        return overlapEventFootprints;
    };
    // Conversion: eventDefs -> eventInstances -> eventRanges -> eventFootprints -> componentFootprints
    // ------------------------------------------------------------------------------------------------
    // NOTE: this might seem like repetitive code with the Grid class, however, this code is related to
    // constraints whereas the Grid code is related to rendering. Each approach might want to convert
    // eventRanges -> eventFootprints in a different way. Regardless, there are opportunities to make
    // this more DRY.
    /*
    Returns false on invalid input.
    */
    Constraints.prototype.parseEventDefToInstances = function (eventInput) {
        var eventManager = this.eventManager;
        var eventDef = EventDefParser_1.default.parse(eventInput, new EventSource_1.default(this._calendar));
        if (!eventDef) {
            return false;
        }
        return eventDef.buildInstances(eventManager.currentPeriod.unzonedRange);
    };
    Constraints.prototype.eventRangesToEventFootprints = function (eventRanges) {
        var i;
        var eventFootprints = [];
        for (i = 0; i < eventRanges.length; i++) {
            eventFootprints.push.apply(// footprints
            eventFootprints, this.eventRangeToEventFootprints(eventRanges[i]));
        }
        return eventFootprints;
    };
    Constraints.prototype.eventRangeToEventFootprints = function (eventRange) {
        return [util_1.eventRangeToEventFootprint(eventRange)];
    };
    /*
    Parses footprints directly.
    Very similar to EventDateProfile::parse :(
    */
    Constraints.prototype.parseFootprints = function (rawInput) {
        var start;
        var end;
        if (rawInput.start) {
            start = this._calendar.moment(rawInput.start);
            if (!start.isValid()) {
                start = null;
            }
        }
        if (rawInput.end) {
            end = this._calendar.moment(rawInput.end);
            if (!end.isValid()) {
                end = null;
            }
        }
        return [
            new ComponentFootprint_1.default(new UnzonedRange_1.default(start, end), (start && !start.hasTime()) || (end && !end.hasTime()) // isAllDay
            )
        ];
    };
    // Footprint Utils
    // ----------------------------------------------------------------------------------------
    Constraints.prototype.footprintContainsFootprint = function (outerFootprint, innerFootprint) {
        return outerFootprint.unzonedRange.containsRange(innerFootprint.unzonedRange);
    };
    Constraints.prototype.footprintsIntersect = function (footprint0, footprint1) {
        return footprint0.unzonedRange.intersectsWith(footprint1.unzonedRange);
    };
    return Constraints;
}());
exports.default = Constraints;
// optional subjectEventInstance
function isOverlapsAllowedByFunc(overlapEventFootprints, overlapFunc, subjectEventInstance) {
    var i;
    for (i = 0; i < overlapEventFootprints.length; i++) {
        if (!overlapFunc(overlapEventFootprints[i].eventInstance.toLegacy(), subjectEventInstance ? subjectEventInstance.toLegacy() : null)) {
            return false;
        }
    }
    return true;
}
function isOverlapEventInstancesAllowed(overlapEventFootprints, subjectEventInstance) {
    var subjectLegacyInstance = subjectEventInstance.toLegacy();
    var i;
    var overlapEventInstance;
    var overlapEventDef;
    var overlapVal;
    for (i = 0; i < overlapEventFootprints.length; i++) {
        overlapEventInstance = overlapEventFootprints[i].eventInstance;
        overlapEventDef = overlapEventInstance.def;
        // don't need to pass in calendar, because don't want to consider global eventOverlap property,
        // because we already considered that earlier in the process.
        overlapVal = overlapEventDef.getOverlap();
        if (overlapVal === false) {
            return false;
        }
        else if (typeof overlapVal === 'function') {
            if (!overlapVal(overlapEventInstance.toLegacy(), subjectLegacyInstance)) {
                return false;
            }
        }
    }
    return true;
}


/***/ }),
/* 208 */
/***/ (function(module, exports, __webpack_require__) {

/*
USAGE:
  import { default as ParsableModelMixin, ParsableModelInterface } from './ParsableModelMixin'
in class:
  applyProps: ParsableModelInterface['applyProps']
  applyManualStandardProps: ParsableModelInterface['applyManualStandardProps']
  applyMiscProps: ParsableModelInterface['applyMiscProps']
  isStandardProp: ParsableModelInterface['isStandardProp']
  static defineStandardProps = ParsableModelMixin.defineStandardProps
  static copyVerbatimStandardProps = ParsableModelMixin.copyVerbatimStandardProps
after class:
  ParsableModelMixin.mixInto(TheClass)
*/
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var util_1 = __webpack_require__(4);
var Mixin_1 = __webpack_require__(14);
var ParsableModelMixin = /** @class */ (function (_super) {
    tslib_1.__extends(ParsableModelMixin, _super);
    function ParsableModelMixin() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ParsableModelMixin.defineStandardProps = function (propDefs) {
        var proto = this.prototype;
        if (!proto.hasOwnProperty('standardPropMap')) {
            proto.standardPropMap = Object.create(proto.standardPropMap);
        }
        util_1.copyOwnProps(propDefs, proto.standardPropMap);
    };
    ParsableModelMixin.copyVerbatimStandardProps = function (src, dest) {
        var map = this.prototype.standardPropMap;
        var propName;
        for (propName in map) {
            if (src[propName] != null && // in the src object?
                map[propName] === true // false means "copy verbatim"
            ) {
                dest[propName] = src[propName];
            }
        }
    };
    /*
    Returns true/false for success.
    Meant to be only called ONCE, at object creation.
    */
    ParsableModelMixin.prototype.applyProps = function (rawProps) {
        var standardPropMap = this.standardPropMap;
        var manualProps = {};
        var miscProps = {};
        var propName;
        for (propName in rawProps) {
            if (standardPropMap[propName] === true) {
                this[propName] = rawProps[propName];
            }
            else if (standardPropMap[propName] === false) {
                manualProps[propName] = rawProps[propName];
            }
            else {
                miscProps[propName] = rawProps[propName];
            }
        }
        this.applyMiscProps(miscProps);
        return this.applyManualStandardProps(manualProps);
    };
    /*
    If subclasses override, they must call this supermethod and return the boolean response.
    Meant to be only called ONCE, at object creation.
    */
    ParsableModelMixin.prototype.applyManualStandardProps = function (rawProps) {
        return true;
    };
    /*
    Can be called even after initial object creation.
    */
    ParsableModelMixin.prototype.applyMiscProps = function (rawProps) {
        // subclasses can implement
    };
    /*
    TODO: why is this a method when defineStandardProps is static
    */
    ParsableModelMixin.prototype.isStandardProp = function (propName) {
        return propName in this.standardPropMap;
    };
    return ParsableModelMixin;
}(Mixin_1.default));
exports.default = ParsableModelMixin;
ParsableModelMixin.prototype.standardPropMap = {}; // will be cloned by defineStandardProps


/***/ }),
/* 209 */
/***/ (function(module, exports) {

Object.defineProperty(exports, "__esModule", { value: true });
var EventInstance = /** @class */ (function () {
    function EventInstance(def, dateProfile) {
        this.def = def;
        this.dateProfile = dateProfile;
    }
    EventInstance.prototype.toLegacy = function () {
        var dateProfile = this.dateProfile;
        var obj = this.def.toLegacy();
        obj.start = dateProfile.start.clone();
        obj.end = dateProfile.end ? dateProfile.end.clone() : null;
        return obj;
    };
    return EventInstance;
}());
exports.default = EventInstance;


/***/ }),
/* 210 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var $ = __webpack_require__(3);
var moment = __webpack_require__(0);
var EventDef_1 = __webpack_require__(34);
var EventInstance_1 = __webpack_require__(209);
var EventDateProfile_1 = __webpack_require__(17);
var RecurringEventDef = /** @class */ (function (_super) {
    tslib_1.__extends(RecurringEventDef, _super);
    function RecurringEventDef() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RecurringEventDef.prototype.isAllDay = function () {
        return !this.startTime && !this.endTime;
    };
    RecurringEventDef.prototype.buildInstances = function (unzonedRange) {
        var calendar = this.source.calendar;
        var unzonedDate = unzonedRange.getStart();
        var unzonedEnd = unzonedRange.getEnd();
        var zonedDayStart;
        var instanceStart;
        var instanceEnd;
        var instances = [];
        while (unzonedDate.isBefore(unzonedEnd)) {
            // if everyday, or this particular day-of-week
            if (!this.dowHash || this.dowHash[unzonedDate.day()]) {
                zonedDayStart = calendar.applyTimezone(unzonedDate);
                instanceStart = zonedDayStart.clone();
                instanceEnd = null;
                if (this.startTime) {
                    instanceStart.time(this.startTime);
                }
                else {
                    instanceStart.stripTime();
                }
                if (this.endTime) {
                    instanceEnd = zonedDayStart.clone().time(this.endTime);
                }
                instances.push(new EventInstance_1.default(this, // definition
                new EventDateProfile_1.default(instanceStart, instanceEnd, calendar)));
            }
            unzonedDate.add(1, 'days');
        }
        return instances;
    };
    RecurringEventDef.prototype.setDow = function (dowNumbers) {
        if (!this.dowHash) {
            this.dowHash = {};
        }
        for (var i = 0; i < dowNumbers.length; i++) {
            this.dowHash[dowNumbers[i]] = true;
        }
    };
    RecurringEventDef.prototype.clone = function () {
        var def = _super.prototype.clone.call(this);
        if (def.startTime) {
            def.startTime = moment.duration(this.startTime);
        }
        if (def.endTime) {
            def.endTime = moment.duration(this.endTime);
        }
        if (this.dowHash) {
            def.dowHash = $.extend({}, this.dowHash);
        }
        return def;
    };
    return RecurringEventDef;
}(EventDef_1.default));
exports.default = RecurringEventDef;
/*
HACK to work with TypeScript mixins
NOTE: if super-method fails, should still attempt to apply
*/
RecurringEventDef.prototype.applyProps = function (rawProps) {
    var superSuccess = EventDef_1.default.prototype.applyProps.call(this, rawProps);
    if (rawProps.start) {
        this.startTime = moment.duration(rawProps.start);
    }
    if (rawProps.end) {
        this.endTime = moment.duration(rawProps.end);
    }
    if (rawProps.dow) {
        this.setDow(rawProps.dow);
    }
    return superSuccess;
};
// Parsing
// ---------------------------------------------------------------------------------------------------------------------
RecurringEventDef.defineStandardProps({
    start: false,
    end: false,
    dow: false
});


/***/ }),
/* 211 */
/***/ (function(module, exports) {

Object.defineProperty(exports, "__esModule", { value: true });
var EventRange = /** @class */ (function () {
    function EventRange(unzonedRange, eventDef, eventInstance) {
        this.unzonedRange = unzonedRange;
        this.eventDef = eventDef;
        if (eventInstance) {
            this.eventInstance = eventInstance;
        }
    }
    return EventRange;
}());
exports.default = EventRange;


/***/ }),
/* 212 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var $ = __webpack_require__(3);
var util_1 = __webpack_require__(35);
var EventInstanceGroup_1 = __webpack_require__(18);
var RecurringEventDef_1 = __webpack_require__(210);
var EventSource_1 = __webpack_require__(6);
var BUSINESS_HOUR_EVENT_DEFAULTS = {
    start: '09:00',
    end: '17:00',
    dow: [1, 2, 3, 4, 5],
    rendering: 'inverse-background'
    // classNames are defined in businessHoursSegClasses
};
var BusinessHourGenerator = /** @class */ (function () {
    function BusinessHourGenerator(rawComplexDef, calendar) {
        this.rawComplexDef = rawComplexDef;
        this.calendar = calendar;
    }
    BusinessHourGenerator.prototype.buildEventInstanceGroup = function (isAllDay, unzonedRange) {
        var eventDefs = this.buildEventDefs(isAllDay);
        var eventInstanceGroup;
        if (eventDefs.length) {
            eventInstanceGroup = new EventInstanceGroup_1.default(util_1.eventDefsToEventInstances(eventDefs, unzonedRange));
            // so that inverse-background rendering can happen even when no eventRanges in view
            eventInstanceGroup.explicitEventDef = eventDefs[0];
            return eventInstanceGroup;
        }
    };
    BusinessHourGenerator.prototype.buildEventDefs = function (isAllDay) {
        var rawComplexDef = this.rawComplexDef;
        var rawDefs = [];
        var requireDow = false;
        var i;
        var defs = [];
        if (rawComplexDef === true) {
            rawDefs = [{}]; // will get BUSINESS_HOUR_EVENT_DEFAULTS verbatim
        }
        else if ($.isPlainObject(rawComplexDef)) {
            rawDefs = [rawComplexDef];
        }
        else if ($.isArray(rawComplexDef)) {
            rawDefs = rawComplexDef;
            requireDow = true; // every sub-definition NEEDS a day-of-week
        }
        for (i = 0; i < rawDefs.length; i++) {
            if (!requireDow || rawDefs[i].dow) {
                defs.push(this.buildEventDef(isAllDay, rawDefs[i]));
            }
        }
        return defs;
    };
    BusinessHourGenerator.prototype.buildEventDef = function (isAllDay, rawDef) {
        var fullRawDef = $.extend({}, BUSINESS_HOUR_EVENT_DEFAULTS, rawDef);
        if (isAllDay) {
            fullRawDef.start = null;
            fullRawDef.end = null;
        }
        return RecurringEventDef_1.default.parse(fullRawDef, new EventSource_1.default(this.calendar) // dummy source
        );
    };
    return BusinessHourGenerator;
}());
exports.default = BusinessHourGenerator;


/***/ }),
/* 213 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var Theme_1 = __webpack_require__(19);
var StandardTheme = /** @class */ (function (_super) {
    tslib_1.__extends(StandardTheme, _super);
    function StandardTheme() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return StandardTheme;
}(Theme_1.default));
exports.default = StandardTheme;
StandardTheme.prototype.classes = {
    widget: 'fc-unthemed',
    widgetHeader: 'fc-widget-header',
    widgetContent: 'fc-widget-content',
    buttonGroup: 'fc-button-group',
    button: 'fc-button',
    cornerLeft: 'fc-corner-left',
    cornerRight: 'fc-corner-right',
    stateDefault: 'fc-state-default',
    stateActive: 'fc-state-active',
    stateDisabled: 'fc-state-disabled',
    stateHover: 'fc-state-hover',
    stateDown: 'fc-state-down',
    popoverHeader: 'fc-widget-header',
    popoverContent: 'fc-widget-content',
    // day grid
    headerRow: 'fc-widget-header',
    dayRow: 'fc-widget-content',
    // list view
    listView: 'fc-widget-content'
};
StandardTheme.prototype.baseIconClass = 'fc-icon';
StandardTheme.prototype.iconClasses = {
    close: 'fc-icon-x',
    prev: 'fc-icon-left-single-arrow',
    next: 'fc-icon-right-single-arrow',
    prevYear: 'fc-icon-left-double-arrow',
    nextYear: 'fc-icon-right-double-arrow'
};
StandardTheme.prototype.iconOverrideOption = 'buttonIcons';
StandardTheme.prototype.iconOverrideCustomButtonOption = 'icon';
StandardTheme.prototype.iconOverridePrefix = 'fc-icon-';


/***/ }),
/* 214 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var Theme_1 = __webpack_require__(19);
var JqueryUiTheme = /** @class */ (function (_super) {
    tslib_1.__extends(JqueryUiTheme, _super);
    function JqueryUiTheme() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return JqueryUiTheme;
}(Theme_1.default));
exports.default = JqueryUiTheme;
JqueryUiTheme.prototype.classes = {
    widget: 'ui-widget',
    widgetHeader: 'ui-widget-header',
    widgetContent: 'ui-widget-content',
    buttonGroup: 'fc-button-group',
    button: 'ui-button',
    cornerLeft: 'ui-corner-left',
    cornerRight: 'ui-corner-right',
    stateDefault: 'ui-state-default',
    stateActive: 'ui-state-active',
    stateDisabled: 'ui-state-disabled',
    stateHover: 'ui-state-hover',
    stateDown: 'ui-state-down',
    today: 'ui-state-highlight',
    popoverHeader: 'ui-widget-header',
    popoverContent: 'ui-widget-content',
    // day grid
    headerRow: 'ui-widget-header',
    dayRow: 'ui-widget-content',
    // list view
    listView: 'ui-widget-content'
};
JqueryUiTheme.prototype.baseIconClass = 'ui-icon';
JqueryUiTheme.prototype.iconClasses = {
    close: 'ui-icon-closethick',
    prev: 'ui-icon-circle-triangle-w',
    next: 'ui-icon-circle-triangle-e',
    prevYear: 'ui-icon-seek-prev',
    nextYear: 'ui-icon-seek-next'
};
JqueryUiTheme.prototype.iconOverrideOption = 'themeButtonIcons';
JqueryUiTheme.prototype.iconOverrideCustomButtonOption = 'themeIcon';
JqueryUiTheme.prototype.iconOverridePrefix = 'ui-icon-';


/***/ }),
/* 215 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var $ = __webpack_require__(3);
var Promise_1 = __webpack_require__(20);
var EventSource_1 = __webpack_require__(6);
var FuncEventSource = /** @class */ (function (_super) {
    tslib_1.__extends(FuncEventSource, _super);
    function FuncEventSource() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FuncEventSource.parse = function (rawInput, calendar) {
        var rawProps;
        // normalize raw input
        if ($.isFunction(rawInput.events)) {
            rawProps = rawInput;
        }
        else if ($.isFunction(rawInput)) {
            rawProps = { events: rawInput };
        }
        if (rawProps) {
            return EventSource_1.default.parse.call(this, rawProps, calendar);
        }
        return false;
    };
    FuncEventSource.prototype.fetch = function (start, end, timezone) {
        var _this = this;
        this.calendar.pushLoading();
        return Promise_1.default.construct(function (onResolve) {
            _this.func.call(_this.calendar, start.clone(), end.clone(), timezone, function (rawEventDefs) {
                _this.calendar.popLoading();
                onResolve(_this.parseEventDefs(rawEventDefs));
            });
        });
    };
    FuncEventSource.prototype.getPrimitive = function () {
        return this.func;
    };
    FuncEventSource.prototype.applyManualStandardProps = function (rawProps) {
        var superSuccess = _super.prototype.applyManualStandardProps.call(this, rawProps);
        this.func = rawProps.events;
        return superSuccess;
    };
    return FuncEventSource;
}(EventSource_1.default));
exports.default = FuncEventSource;
FuncEventSource.defineStandardProps({
    events: false // don't automatically transfer
});


/***/ }),
/* 216 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var $ = __webpack_require__(3);
var util_1 = __webpack_require__(4);
var Promise_1 = __webpack_require__(20);
var EventSource_1 = __webpack_require__(6);
var JsonFeedEventSource = /** @class */ (function (_super) {
    tslib_1.__extends(JsonFeedEventSource, _super);
    function JsonFeedEventSource() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    JsonFeedEventSource.parse = function (rawInput, calendar) {
        var rawProps;
        // normalize raw input
        if (typeof rawInput.url === 'string') {
            rawProps = rawInput;
        }
        else if (typeof rawInput === 'string') {
            rawProps = { url: rawInput };
        }
        if (rawProps) {
            return EventSource_1.default.parse.call(this, rawProps, calendar);
        }
        return false;
    };
    JsonFeedEventSource.prototype.fetch = function (start, end, timezone) {
        var _this = this;
        var ajaxSettings = this.ajaxSettings;
        var onSuccess = ajaxSettings.success;
        var onError = ajaxSettings.error;
        var requestParams = this.buildRequestParams(start, end, timezone);
        // todo: eventually handle the promise's then,
        // don't intercept success/error
        // tho will be a breaking API change
        this.calendar.pushLoading();
        return Promise_1.default.construct(function (onResolve, onReject) {
            $.ajax($.extend({}, // destination
            JsonFeedEventSource.AJAX_DEFAULTS, ajaxSettings, {
                url: _this.url,
                data: requestParams,
                success: function (rawEventDefs, status, xhr) {
                    var callbackRes;
                    _this.calendar.popLoading();
                    if (rawEventDefs) {
                        callbackRes = util_1.applyAll(onSuccess, _this, [rawEventDefs, status, xhr]); // redirect `this`
                        if ($.isArray(callbackRes)) {
                            rawEventDefs = callbackRes;
                        }
                        onResolve(_this.parseEventDefs(rawEventDefs));
                    }
                    else {
                        onReject();
                    }
                },
                error: function (xhr, statusText, errorThrown) {
                    _this.calendar.popLoading();
                    util_1.applyAll(onError, _this, [xhr, statusText, errorThrown]); // redirect `this`
                    onReject();
                }
            }));
        });
    };
    JsonFeedEventSource.prototype.buildRequestParams = function (start, end, timezone) {
        var calendar = this.calendar;
        var ajaxSettings = this.ajaxSettings;
        var startParam;
        var endParam;
        var timezoneParam;
        var customRequestParams;
        var params = {};
        startParam = this.startParam;
        if (startParam == null) {
            startParam = calendar.opt('startParam');
        }
        endParam = this.endParam;
        if (endParam == null) {
            endParam = calendar.opt('endParam');
        }
        timezoneParam = this.timezoneParam;
        if (timezoneParam == null) {
            timezoneParam = calendar.opt('timezoneParam');
        }
        // retrieve any outbound GET/POST $.ajax data from the options
        if ($.isFunction(ajaxSettings.data)) {
            // supplied as a function that returns a key/value object
            customRequestParams = ajaxSettings.data();
        }
        else {
            // probably supplied as a straight key/value object
            customRequestParams = ajaxSettings.data || {};
        }
        $.extend(params, customRequestParams);
        params[startParam] = start.format();
        params[endParam] = end.format();
        if (timezone && timezone !== 'local') {
            params[timezoneParam] = timezone;
        }
        return params;
    };
    JsonFeedEventSource.prototype.getPrimitive = function () {
        return this.url;
    };
    JsonFeedEventSource.prototype.applyMiscProps = function (rawProps) {
        this.ajaxSettings = rawProps;
    };
    JsonFeedEventSource.AJAX_DEFAULTS = {
        dataType: 'json',
        cache: false
    };
    return JsonFeedEventSource;
}(EventSource_1.default));
exports.default = JsonFeedEventSource;
JsonFeedEventSource.defineStandardProps({
    // automatically transfer (true)...
    url: true,
    startParam: true,
    endParam: true,
    timezoneParam: true
});


/***/ }),
/* 217 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var EmitterMixin_1 = __webpack_require__(11);
var TaskQueue = /** @class */ (function () {
    function TaskQueue() {
        this.q = [];
        this.isPaused = false;
        this.isRunning = false;
    }
    TaskQueue.prototype.queue = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        this.q.push.apply(this.q, args); // append
        this.tryStart();
    };
    TaskQueue.prototype.pause = function () {
        this.isPaused = true;
    };
    TaskQueue.prototype.resume = function () {
        this.isPaused = false;
        this.tryStart();
    };
    TaskQueue.prototype.getIsIdle = function () {
        return !this.isRunning && !this.isPaused;
    };
    TaskQueue.prototype.tryStart = function () {
        if (!this.isRunning && this.canRunNext()) {
            this.isRunning = true;
            this.trigger('start');
            this.runRemaining();
        }
    };
    TaskQueue.prototype.canRunNext = function () {
        return !this.isPaused && this.q.length;
    };
    TaskQueue.prototype.runRemaining = function () {
        var _this = this;
        var task;
        var res;
        do {
            task = this.q.shift(); // always freshly reference q. might have been reassigned.
            res = this.runTask(task);
            if (res && res.then) {
                res.then(function () {
                    if (_this.canRunNext()) {
                        _this.runRemaining();
                    }
                });
                return; // prevent marking as stopped
            }
        } while (this.canRunNext());
        this.trigger('stop'); // not really a 'stop' ... more of a 'drained'
        this.isRunning = false;
        // if 'stop' handler added more tasks.... TODO: write test for this
        this.tryStart();
    };
    TaskQueue.prototype.runTask = function (task) {
        return task(); // task *is* the function, but subclasses can change the format of a task
    };
    return TaskQueue;
}());
exports.default = TaskQueue;
EmitterMixin_1.default.mixInto(TaskQueue);


/***/ }),
/* 218 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var TaskQueue_1 = __webpack_require__(217);
var RenderQueue = /** @class */ (function (_super) {
    tslib_1.__extends(RenderQueue, _super);
    function RenderQueue(waitsByNamespace) {
        var _this = _super.call(this) || this;
        _this.waitsByNamespace = waitsByNamespace || {};
        return _this;
    }
    RenderQueue.prototype.queue = function (taskFunc, namespace, type) {
        var task = {
            func: taskFunc,
            namespace: namespace,
            type: type
        };
        var waitMs;
        if (namespace) {
            waitMs = this.waitsByNamespace[namespace];
        }
        if (this.waitNamespace) {
            if (namespace === this.waitNamespace && waitMs != null) {
                this.delayWait(waitMs);
            }
            else {
                this.clearWait();
                this.tryStart();
            }
        }
        if (this.compoundTask(task)) {
            if (!this.waitNamespace && waitMs != null) {
                this.startWait(namespace, waitMs);
            }
            else {
                this.tryStart();
            }
        }
    };
    RenderQueue.prototype.startWait = function (namespace, waitMs) {
        this.waitNamespace = namespace;
        this.spawnWait(waitMs);
    };
    RenderQueue.prototype.delayWait = function (waitMs) {
        clearTimeout(this.waitId);
        this.spawnWait(waitMs);
    };
    RenderQueue.prototype.spawnWait = function (waitMs) {
        var _this = this;
        this.waitId = setTimeout(function () {
            _this.waitNamespace = null;
            _this.tryStart();
        }, waitMs);
    };
    RenderQueue.prototype.clearWait = function () {
        if (this.waitNamespace) {
            clearTimeout(this.waitId);
            this.waitId = null;
            this.waitNamespace = null;
        }
    };
    RenderQueue.prototype.canRunNext = function () {
        if (!_super.prototype.canRunNext.call(this)) {
            return false;
        }
        // waiting for a certain namespace to stop receiving tasks?
        if (this.waitNamespace) {
            var q = this.q;
            // if there was a different namespace task in the meantime,
            // that forces all previously-waiting tasks to suddenly execute.
            // TODO: find a way to do this in constant time.
            for (var i = 0; i < q.length; i++) {
                if (q[i].namespace !== this.waitNamespace) {
                    return true; // allow execution
                }
            }
            return false;
        }
        return true;
    };
    RenderQueue.prototype.runTask = function (task) {
        task.func();
    };
    RenderQueue.prototype.compoundTask = function (newTask) {
        var q = this.q;
        var shouldAppend = true;
        var i;
        var task;
        if (newTask.namespace && newTask.type === 'destroy') {
            // remove all init/add/remove ops with same namespace, regardless of order
            for (i = q.length - 1; i >= 0; i--) {
                task = q[i];
                switch (task.type) {
                    case 'init':
                        shouldAppend = false;
                    // the latest destroy is cancelled out by not doing the init
                    /* falls through */
                    case 'add':
                    /* falls through */
                    case 'remove':
                        q.splice(i, 1); // remove task
                }
            }
        }
        if (shouldAppend) {
            q.push(newTask);
        }
        return shouldAppend;
    };
    return RenderQueue;
}(TaskQueue_1.default));
exports.default = RenderQueue;


/***/ }),
/* 219 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var $ = __webpack_require__(3);
var moment = __webpack_require__(0);
var util_1 = __webpack_require__(4);
var moment_ext_1 = __webpack_require__(10);
var date_formatting_1 = __webpack_require__(47);
var Component_1 = __webpack_require__(237);
var util_2 = __webpack_require__(35);
var DateComponent = /** @class */ (function (_super) {
    tslib_1.__extends(DateComponent, _super);
    function DateComponent(_view, _options) {
        var _this = _super.call(this) || this;
        _this.isRTL = false; // frequently accessed options
        _this.hitsNeededDepth = 0; // necessary because multiple callers might need the same hits
        _this.hasAllDayBusinessHours = false; // TODO: unify with largeUnit and isTimeScale?
        _this.isDatesRendered = false;
        // hack to set options prior to the this.opt calls
        if (_view) {
            _this['view'] = _view;
        }
        if (_options) {
            _this['options'] = _options;
        }
        _this.uid = String(DateComponent.guid++);
        _this.childrenByUid = {};
        _this.nextDayThreshold = moment.duration(_this.opt('nextDayThreshold'));
        _this.isRTL = _this.opt('isRTL');
        if (_this.fillRendererClass) {
            _this.fillRenderer = new _this.fillRendererClass(_this);
        }
        if (_this.eventRendererClass) {
            _this.eventRenderer = new _this.eventRendererClass(_this, _this.fillRenderer);
        }
        if (_this.helperRendererClass && _this.eventRenderer) {
            _this.helperRenderer = new _this.helperRendererClass(_this, _this.eventRenderer);
        }
        if (_this.businessHourRendererClass && _this.fillRenderer) {
            _this.businessHourRenderer = new _this.businessHourRendererClass(_this, _this.fillRenderer);
        }
        return _this;
    }
    DateComponent.prototype.addChild = function (child) {
        if (!this.childrenByUid[child.uid]) {
            this.childrenByUid[child.uid] = child;
            return true;
        }
        return false;
    };
    DateComponent.prototype.removeChild = function (child) {
        if (this.childrenByUid[child.uid]) {
            delete this.childrenByUid[child.uid];
            return true;
        }
        return false;
    };
    // TODO: only do if isInDom?
    // TODO: make part of Component, along with children/batch-render system?
    DateComponent.prototype.updateSize = function (totalHeight, isAuto, isResize) {
        this.callChildren('updateSize', arguments);
    };
    // Options
    // -----------------------------------------------------------------------------------------------------------------
    DateComponent.prototype.opt = function (name) {
        return this._getView().opt(name); // default implementation
    };
    DateComponent.prototype.publiclyTrigger = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        var calendar = this._getCalendar();
        return calendar.publiclyTrigger.apply(calendar, args);
    };
    DateComponent.prototype.hasPublicHandlers = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        var calendar = this._getCalendar();
        return calendar.hasPublicHandlers.apply(calendar, args);
    };
    // Date
    // -----------------------------------------------------------------------------------------------------------------
    DateComponent.prototype.executeDateRender = function (dateProfile) {
        this.dateProfile = dateProfile; // for rendering
        this.renderDates(dateProfile);
        this.isDatesRendered = true;
        this.callChildren('executeDateRender', arguments);
    };
    DateComponent.prototype.executeDateUnrender = function () {
        this.callChildren('executeDateUnrender', arguments);
        this.dateProfile = null;
        this.unrenderDates();
        this.isDatesRendered = false;
    };
    // date-cell content only
    DateComponent.prototype.renderDates = function (dateProfile) {
        // subclasses should implement
    };
    // date-cell content only
    DateComponent.prototype.unrenderDates = function () {
        // subclasses should override
    };
    // Now-Indicator
    // -----------------------------------------------------------------------------------------------------------------
    // Returns a string unit, like 'second' or 'minute' that defined how often the current time indicator
    // should be refreshed. If something falsy is returned, no time indicator is rendered at all.
    DateComponent.prototype.getNowIndicatorUnit = function () {
        // subclasses should implement
    };
    // Renders a current time indicator at the given datetime
    DateComponent.prototype.renderNowIndicator = function (date) {
        this.callChildren('renderNowIndicator', arguments);
    };
    // Undoes the rendering actions from renderNowIndicator
    DateComponent.prototype.unrenderNowIndicator = function () {
        this.callChildren('unrenderNowIndicator', arguments);
    };
    // Business Hours
    // ---------------------------------------------------------------------------------------------------------------
    DateComponent.prototype.renderBusinessHours = function (businessHourGenerator) {
        if (this.businessHourRenderer) {
            this.businessHourRenderer.render(businessHourGenerator);
        }
        this.callChildren('renderBusinessHours', arguments);
    };
    // Unrenders previously-rendered business-hours
    DateComponent.prototype.unrenderBusinessHours = function () {
        this.callChildren('unrenderBusinessHours', arguments);
        if (this.businessHourRenderer) {
            this.businessHourRenderer.unrender();
        }
    };
    // Event Displaying
    // -----------------------------------------------------------------------------------------------------------------
    DateComponent.prototype.executeEventRender = function (eventsPayload) {
        if (this.eventRenderer) {
            this.eventRenderer.rangeUpdated(); // poorly named now
            this.eventRenderer.render(eventsPayload);
        }
        else if (this['renderEvents']) {
            this['renderEvents'](convertEventsPayloadToLegacyArray(eventsPayload));
        }
        this.callChildren('executeEventRender', arguments);
    };
    DateComponent.prototype.executeEventUnrender = function () {
        this.callChildren('executeEventUnrender', arguments);
        if (this.eventRenderer) {
            this.eventRenderer.unrender();
        }
        else if (this['destroyEvents']) {
            this['destroyEvents']();
        }
    };
    DateComponent.prototype.getBusinessHourSegs = function () {
        var segs = this.getOwnBusinessHourSegs();
        this.iterChildren(function (child) {
            segs.push.apply(segs, child.getBusinessHourSegs());
        });
        return segs;
    };
    DateComponent.prototype.getOwnBusinessHourSegs = function () {
        if (this.businessHourRenderer) {
            return this.businessHourRenderer.getSegs();
        }
        return [];
    };
    DateComponent.prototype.getEventSegs = function () {
        var segs = this.getOwnEventSegs();
        this.iterChildren(function (child) {
            segs.push.apply(segs, child.getEventSegs());
        });
        return segs;
    };
    DateComponent.prototype.getOwnEventSegs = function () {
        if (this.eventRenderer) {
            return this.eventRenderer.getSegs();
        }
        return [];
    };
    // Event Rendering Triggering
    // -----------------------------------------------------------------------------------------------------------------
    DateComponent.prototype.triggerAfterEventsRendered = function () {
        this.triggerAfterEventSegsRendered(this.getEventSegs());
        this.publiclyTrigger('eventAfterAllRender', {
            context: this,
            args: [this]
        });
    };
    DateComponent.prototype.triggerAfterEventSegsRendered = function (segs) {
        var _this = this;
        // an optimization, because getEventLegacy is expensive
        if (this.hasPublicHandlers('eventAfterRender')) {
            segs.forEach(function (seg) {
                var legacy;
                if (seg.el) {
                    legacy = seg.footprint.getEventLegacy();
                    _this.publiclyTrigger('eventAfterRender', {
                        context: legacy,
                        args: [legacy, seg.el, _this]
                    });
                }
            });
        }
    };
    DateComponent.prototype.triggerBeforeEventsDestroyed = function () {
        this.triggerBeforeEventSegsDestroyed(this.getEventSegs());
    };
    DateComponent.prototype.triggerBeforeEventSegsDestroyed = function (segs) {
        var _this = this;
        if (this.hasPublicHandlers('eventDestroy')) {
            segs.forEach(function (seg) {
                var legacy;
                if (seg.el) {
                    legacy = seg.footprint.getEventLegacy();
                    _this.publiclyTrigger('eventDestroy', {
                        context: legacy,
                        args: [legacy, seg.el, _this]
                    });
                }
            });
        }
    };
    // Event Rendering Utils
    // -----------------------------------------------------------------------------------------------------------------
    // Hides all rendered event segments linked to the given event
    // RECURSIVE with subcomponents
    DateComponent.prototype.showEventsWithId = function (eventDefId) {
        this.getEventSegs().forEach(function (seg) {
            if (seg.footprint.eventDef.id === eventDefId &&
                seg.el // necessary?
            ) {
                seg.el.css('visibility', '');
            }
        });
        this.callChildren('showEventsWithId', arguments);
    };
    // Shows all rendered event segments linked to the given event
    // RECURSIVE with subcomponents
    DateComponent.prototype.hideEventsWithId = function (eventDefId) {
        this.getEventSegs().forEach(function (seg) {
            if (seg.footprint.eventDef.id === eventDefId &&
                seg.el // necessary?
            ) {
                seg.el.css('visibility', 'hidden');
            }
        });
        this.callChildren('hideEventsWithId', arguments);
    };
    // Drag-n-Drop Rendering (for both events and external elements)
    // ---------------------------------------------------------------------------------------------------------------
    // Renders a visual indication of a event or external-element drag over the given drop zone.
    // If an external-element, seg will be `null`.
    // Must return elements used for any mock events.
    DateComponent.prototype.renderDrag = function (eventFootprints, seg, isTouch) {
        var renderedHelper = false;
        this.iterChildren(function (child) {
            if (child.renderDrag(eventFootprints, seg, isTouch)) {
                renderedHelper = true;
            }
        });
        return renderedHelper;
    };
    // Unrenders a visual indication of an event or external-element being dragged.
    DateComponent.prototype.unrenderDrag = function () {
        this.callChildren('unrenderDrag', arguments);
    };
    // Event Resizing
    // ---------------------------------------------------------------------------------------------------------------
    // Renders a visual indication of an event being resized.
    DateComponent.prototype.renderEventResize = function (eventFootprints, seg, isTouch) {
        this.callChildren('renderEventResize', arguments);
    };
    // Unrenders a visual indication of an event being resized.
    DateComponent.prototype.unrenderEventResize = function () {
        this.callChildren('unrenderEventResize', arguments);
    };
    // Selection
    // ---------------------------------------------------------------------------------------------------------------
    // Renders a visual indication of the selection
    // TODO: rename to `renderSelection` after legacy is gone
    DateComponent.prototype.renderSelectionFootprint = function (componentFootprint) {
        this.renderHighlight(componentFootprint);
        this.callChildren('renderSelectionFootprint', arguments);
    };
    // Unrenders a visual indication of selection
    DateComponent.prototype.unrenderSelection = function () {
        this.unrenderHighlight();
        this.callChildren('unrenderSelection', arguments);
    };
    // Highlight
    // ---------------------------------------------------------------------------------------------------------------
    // Renders an emphasis on the given date range. Given a span (unzoned start/end and other misc data)
    DateComponent.prototype.renderHighlight = function (componentFootprint) {
        if (this.fillRenderer) {
            this.fillRenderer.renderFootprint('highlight', componentFootprint, {
                getClasses: function () {
                    return ['fc-highlight'];
                }
            });
        }
        this.callChildren('renderHighlight', arguments);
    };
    // Unrenders the emphasis on a date range
    DateComponent.prototype.unrenderHighlight = function () {
        if (this.fillRenderer) {
            this.fillRenderer.unrender('highlight');
        }
        this.callChildren('unrenderHighlight', arguments);
    };
    // Hit Areas
    // ---------------------------------------------------------------------------------------------------------------
    // just because all DateComponents support this interface
    // doesn't mean they need to have their own internal coord system. they can defer to sub-components.
    DateComponent.prototype.hitsNeeded = function () {
        if (!(this.hitsNeededDepth++)) {
            this.prepareHits();
        }
        this.callChildren('hitsNeeded', arguments);
    };
    DateComponent.prototype.hitsNotNeeded = function () {
        if (this.hitsNeededDepth && !(--this.hitsNeededDepth)) {
            this.releaseHits();
        }
        this.callChildren('hitsNotNeeded', arguments);
    };
    DateComponent.prototype.prepareHits = function () {
        // subclasses can implement
    };
    DateComponent.prototype.releaseHits = function () {
        // subclasses can implement
    };
    // Given coordinates from the topleft of the document, return data about the date-related area underneath.
    // Can return an object with arbitrary properties (although top/right/left/bottom are encouraged).
    // Must have a `grid` property, a reference to this current grid. TODO: avoid this
    // The returned object will be processed by getHitFootprint and getHitEl.
    DateComponent.prototype.queryHit = function (leftOffset, topOffset) {
        var childrenByUid = this.childrenByUid;
        var uid;
        var hit;
        for (uid in childrenByUid) {
            hit = childrenByUid[uid].queryHit(leftOffset, topOffset);
            if (hit) {
                break;
            }
        }
        return hit;
    };
    DateComponent.prototype.getSafeHitFootprint = function (hit) {
        var footprint = this.getHitFootprint(hit);
        if (!this.dateProfile.activeUnzonedRange.containsRange(footprint.unzonedRange)) {
            return null;
        }
        return footprint;
    };
    DateComponent.prototype.getHitFootprint = function (hit) {
        // what about being abstract!?
    };
    // Given position-level information about a date-related area within the grid,
    // should return a jQuery element that best represents it. passed to dayClick callback.
    DateComponent.prototype.getHitEl = function (hit) {
        // what about being abstract!?
    };
    /* Converting eventRange -> eventFootprint
    ------------------------------------------------------------------------------------------------------------------*/
    DateComponent.prototype.eventRangesToEventFootprints = function (eventRanges) {
        var eventFootprints = [];
        var i;
        for (i = 0; i < eventRanges.length; i++) {
            eventFootprints.push.apply(// append
            eventFootprints, this.eventRangeToEventFootprints(eventRanges[i]));
        }
        return eventFootprints;
    };
    DateComponent.prototype.eventRangeToEventFootprints = function (eventRange) {
        return [util_2.eventRangeToEventFootprint(eventRange)];
    };
    /* Converting componentFootprint/eventFootprint -> segs
    ------------------------------------------------------------------------------------------------------------------*/
    DateComponent.prototype.eventFootprintsToSegs = function (eventFootprints) {
        var segs = [];
        var i;
        for (i = 0; i < eventFootprints.length; i++) {
            segs.push.apply(segs, this.eventFootprintToSegs(eventFootprints[i]));
        }
        return segs;
    };
    // Given an event's span (unzoned start/end and other misc data), and the event itself,
    // slices into segments and attaches event-derived properties to them.
    // eventSpan - { start, end, isStart, isEnd, otherthings... }
    DateComponent.prototype.eventFootprintToSegs = function (eventFootprint) {
        var unzonedRange = eventFootprint.componentFootprint.unzonedRange;
        var segs;
        var i;
        var seg;
        segs = this.componentFootprintToSegs(eventFootprint.componentFootprint);
        for (i = 0; i < segs.length; i++) {
            seg = segs[i];
            if (!unzonedRange.isStart) {
                seg.isStart = false;
            }
            if (!unzonedRange.isEnd) {
                seg.isEnd = false;
            }
            seg.footprint = eventFootprint;
            // TODO: rename to seg.eventFootprint
        }
        return segs;
    };
    DateComponent.prototype.componentFootprintToSegs = function (componentFootprint) {
        return [];
    };
    // Utils
    // ---------------------------------------------------------------------------------------------------------------
    DateComponent.prototype.callChildren = function (methodName, args) {
        this.iterChildren(function (child) {
            child[methodName].apply(child, args);
        });
    };
    DateComponent.prototype.iterChildren = function (func) {
        var childrenByUid = this.childrenByUid;
        var uid;
        for (uid in childrenByUid) {
            func(childrenByUid[uid]);
        }
    };
    DateComponent.prototype._getCalendar = function () {
        var t = this;
        return t.calendar || t.view.calendar;
    };
    DateComponent.prototype._getView = function () {
        return this.view;
    };
    DateComponent.prototype._getDateProfile = function () {
        return this._getView().get('dateProfile');
    };
    // Generates HTML for an anchor to another view into the calendar.
    // Will either generate an <a> tag or a non-clickable <span> tag, depending on enabled settings.
    // `gotoOptions` can either be a moment input, or an object with the form:
    // { date, type, forceOff }
    // `type` is a view-type like "day" or "week". default value is "day".
    // `attrs` and `innerHtml` are use to generate the rest of the HTML tag.
    DateComponent.prototype.buildGotoAnchorHtml = function (gotoOptions, attrs, innerHtml) {
        var date;
        var type;
        var forceOff;
        var finalOptions;
        if ($.isPlainObject(gotoOptions)) {
            date = gotoOptions.date;
            type = gotoOptions.type;
            forceOff = gotoOptions.forceOff;
        }
        else {
            date = gotoOptions; // a single moment input
        }
        date = moment_ext_1.default(date); // if a string, parse it
        finalOptions = {
            date: date.format('YYYY-MM-DD'),
            type: type || 'day'
        };
        if (typeof attrs === 'string') {
            innerHtml = attrs;
            attrs = null;
        }
        attrs = attrs ? ' ' + util_1.attrsToStr(attrs) : ''; // will have a leading space
        innerHtml = innerHtml || '';
        if (!forceOff && this.opt('navLinks')) {
            return '<a' + attrs +
                ' data-goto="' + util_1.htmlEscape(JSON.stringify(finalOptions)) + '">' +
                innerHtml +
                '</a>';
        }
        else {
            return '<span' + attrs + '>' +
                innerHtml +
                '</span>';
        }
    };
    DateComponent.prototype.getAllDayHtml = function () {
        return this.opt('allDayHtml') || util_1.htmlEscape(this.opt('allDayText'));
    };
    // Computes HTML classNames for a single-day element
    DateComponent.prototype.getDayClasses = function (date, noThemeHighlight) {
        var view = this._getView();
        var classes = [];
        var today;
        if (!this.dateProfile.activeUnzonedRange.containsDate(date)) {
            classes.push('fc-disabled-day'); // TODO: jQuery UI theme?
        }
        else {
            classes.push('fc-' + util_1.dayIDs[date.day()]);
            if (view.isDateInOtherMonth(date, this.dateProfile)) {
                classes.push('fc-other-month');
            }
            today = view.calendar.getNow();
            if (date.isSame(today, 'day')) {
                classes.push('fc-today');
                if (noThemeHighlight !== true) {
                    classes.push(view.calendar.theme.getClass('today'));
                }
            }
            else if (date < today) {
                classes.push('fc-past');
            }
            else {
                classes.push('fc-future');
            }
        }
        return classes;
    };
    // Utility for formatting a range. Accepts a range object, formatting string, and optional separator.
    // Displays all-day ranges naturally, with an inclusive end. Takes the current isRTL into account.
    // The timezones of the dates within `range` will be respected.
    DateComponent.prototype.formatRange = function (range, isAllDay, formatStr, separator) {
        var end = range.end;
        if (isAllDay) {
            end = end.clone().subtract(1); // convert to inclusive. last ms of previous day
        }
        return date_formatting_1.formatRange(range.start, end, formatStr, separator, this.isRTL);
    };
    // Compute the number of the give units in the "current" range.
    // Will return a floating-point number. Won't round.
    DateComponent.prototype.currentRangeAs = function (unit) {
        return this._getDateProfile().currentUnzonedRange.as(unit);
    };
    // Returns the date range of the full days the given range visually appears to occupy.
    // Returns a plain object with start/end, NOT an UnzonedRange!
    DateComponent.prototype.computeDayRange = function (unzonedRange) {
        var calendar = this._getCalendar();
        var startDay = calendar.msToUtcMoment(unzonedRange.startMs, true); // the beginning of the day the range starts
        var end = calendar.msToUtcMoment(unzonedRange.endMs);
        var endTimeMS = +end.time(); // # of milliseconds into `endDay`
        var endDay = end.clone().stripTime(); // the beginning of the day the range exclusively ends
        // If the end time is actually inclusively part of the next day and is equal to or
        // beyond the next day threshold, adjust the end to be the exclusive end of `endDay`.
        // Otherwise, leaving it as inclusive will cause it to exclude `endDay`.
        if (endTimeMS && endTimeMS >= this.nextDayThreshold) {
            endDay.add(1, 'days');
        }
        // If end is within `startDay` but not past nextDayThreshold, assign the default duration of one day.
        if (endDay <= startDay) {
            endDay = startDay.clone().add(1, 'days');
        }
        return { start: startDay, end: endDay };
    };
    // Does the given range visually appear to occupy more than one day?
    DateComponent.prototype.isMultiDayRange = function (unzonedRange) {
        var dayRange = this.computeDayRange(unzonedRange);
        return dayRange.end.diff(dayRange.start, 'days') > 1;
    };
    DateComponent.guid = 0; // TODO: better system for this?
    return DateComponent;
}(Component_1.default));
exports.default = DateComponent;
// legacy
function convertEventsPayloadToLegacyArray(eventsPayload) {
    var eventDefId;
    var eventInstances;
    var legacyEvents = [];
    var i;
    for (eventDefId in eventsPayload) {
        eventInstances = eventsPayload[eventDefId].eventInstances;
        for (i = 0; i < eventInstances.length; i++) {
            legacyEvents.push(eventInstances[i].toLegacy());
        }
    }
    return legacyEvents;
}


/***/ }),
/* 220 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var $ = __webpack_require__(3);
var moment = __webpack_require__(0);
var util_1 = __webpack_require__(4);
var options_1 = __webpack_require__(32);
var Iterator_1 = __webpack_require__(238);
var GlobalEmitter_1 = __webpack_require__(21);
var EmitterMixin_1 = __webpack_require__(11);
var ListenerMixin_1 = __webpack_require__(7);
var Toolbar_1 = __webpack_require__(239);
var OptionsManager_1 = __webpack_require__(240);
var ViewSpecManager_1 = __webpack_require__(241);
var Constraints_1 = __webpack_require__(207);
var locale_1 = __webpack_require__(31);
var moment_ext_1 = __webpack_require__(10);
var UnzonedRange_1 = __webpack_require__(5);
var ComponentFootprint_1 = __webpack_require__(12);
var EventDateProfile_1 = __webpack_require__(17);
var EventManager_1 = __webpack_require__(242);
var BusinessHourGenerator_1 = __webpack_require__(212);
var EventSourceParser_1 = __webpack_require__(38);
var EventDefParser_1 = __webpack_require__(49);
var SingleEventDef_1 = __webpack_require__(13);
var EventDefMutation_1 = __webpack_require__(37);
var EventSource_1 = __webpack_require__(6);
var ThemeRegistry_1 = __webpack_require__(51);
var Calendar = /** @class */ (function () {
    function Calendar(el, overrides) {
        this.loadingLevel = 0; // number of simultaneous loading tasks
        this.ignoreUpdateViewSize = 0;
        this.freezeContentHeightDepth = 0;
        // declare the current calendar instance relies on GlobalEmitter. needed for garbage collection.
        // unneeded() is called in destroy.
        GlobalEmitter_1.default.needed();
        this.el = el;
        this.viewsByType = {};
        this.optionsManager = new OptionsManager_1.default(this, overrides);
        this.viewSpecManager = new ViewSpecManager_1.default(this.optionsManager, this);
        this.initMomentInternals(); // needs to happen after options hash initialized
        this.initCurrentDate();
        this.initEventManager();
        this.constraints = new Constraints_1.default(this.eventManager, this);
        this.constructed();
    }
    Calendar.prototype.constructed = function () {
        // useful for monkeypatching. used?
    };
    Calendar.prototype.getView = function () {
        return this.view;
    };
    Calendar.prototype.publiclyTrigger = function (name, triggerInfo) {
        var optHandler = this.opt(name);
        var context;
        var args;
        if ($.isPlainObject(triggerInfo)) {
            context = triggerInfo.context;
            args = triggerInfo.args;
        }
        else if ($.isArray(triggerInfo)) {
            args = triggerInfo;
        }
        if (context == null) {
            context = this.el[0]; // fallback context
        }
        if (!args) {
            args = [];
        }
        this.triggerWith(name, context, args); // Emitter's method
        if (optHandler) {
            return optHandler.apply(context, args);
        }
    };
    Calendar.prototype.hasPublicHandlers = function (name) {
        return this.hasHandlers(name) ||
            this.opt(name); // handler specified in options
    };
    // Options Public API
    // -----------------------------------------------------------------------------------------------------------------
    // public getter/setter
    Calendar.prototype.option = function (name, value) {
        var newOptionHash;
        if (typeof name === 'string') {
            if (value === undefined) {
                return this.optionsManager.get(name);
            }
            else {
                newOptionHash = {};
                newOptionHash[name] = value;
                this.optionsManager.add(newOptionHash);
            }
        }
        else if (typeof name === 'object') {
            this.optionsManager.add(name);
        }
    };
    // private getter
    Calendar.prototype.opt = function (name) {
        return this.optionsManager.get(name);
    };
    // View
    // -----------------------------------------------------------------------------------------------------------------
    // Given a view name for a custom view or a standard view, creates a ready-to-go View object
    Calendar.prototype.instantiateView = function (viewType) {
        var spec = this.viewSpecManager.getViewSpec(viewType);
        if (!spec) {
            throw new Error("View type \"" + viewType + "\" is not valid");
        }
        return new spec['class'](this, spec);
    };
    // Returns a boolean about whether the view is okay to instantiate at some point
    Calendar.prototype.isValidViewType = function (viewType) {
        return Boolean(this.viewSpecManager.getViewSpec(viewType));
    };
    Calendar.prototype.changeView = function (viewName, dateOrRange) {
        if (dateOrRange) {
            if (dateOrRange.start && dateOrRange.end) {
                this.optionsManager.recordOverrides({
                    visibleRange: dateOrRange
                });
            }
            else {
                this.currentDate = this.moment(dateOrRange).stripZone(); // just like gotoDate
            }
        }
        this.renderView(viewName);
    };
    // Forces navigation to a view for the given date.
    // `viewType` can be a specific view name or a generic one like "week" or "day".
    Calendar.prototype.zoomTo = function (newDate, viewType) {
        var spec;
        viewType = viewType || 'day'; // day is default zoom
        spec = this.viewSpecManager.getViewSpec(viewType) ||
            this.viewSpecManager.getUnitViewSpec(viewType);
        this.currentDate = newDate.clone();
        this.renderView(spec ? spec.type : null);
    };
    // Current Date
    // -----------------------------------------------------------------------------------------------------------------
    Calendar.prototype.initCurrentDate = function () {
        var defaultDateInput = this.opt('defaultDate');
        // compute the initial ambig-timezone date
        if (defaultDateInput != null) {
            this.currentDate = this.moment(defaultDateInput).stripZone();
        }
        else {
            this.currentDate = this.getNow(); // getNow already returns unzoned
        }
    };
    Calendar.prototype.prev = function () {
        var view = this.view;
        var prevInfo = view.dateProfileGenerator.buildPrev(view.get('dateProfile'));
        if (prevInfo.isValid) {
            this.currentDate = prevInfo.date;
            this.renderView();
        }
    };
    Calendar.prototype.next = function () {
        var view = this.view;
        var nextInfo = view.dateProfileGenerator.buildNext(view.get('dateProfile'));
        if (nextInfo.isValid) {
            this.currentDate = nextInfo.date;
            this.renderView();
        }
    };
    Calendar.prototype.prevYear = function () {
        this.currentDate.add(-1, 'years');
        this.renderView();
    };
    Calendar.prototype.nextYear = function () {
        this.currentDate.add(1, 'years');
        this.renderView();
    };
    Calendar.prototype.today = function () {
        this.currentDate = this.getNow(); // should deny like prev/next?
        this.renderView();
    };
    Calendar.prototype.gotoDate = function (zonedDateInput) {
        this.currentDate = this.moment(zonedDateInput).stripZone();
        this.renderView();
    };
    Calendar.prototype.incrementDate = function (delta) {
        this.currentDate.add(moment.duration(delta));
        this.renderView();
    };
    // for external API
    Calendar.prototype.getDate = function () {
        return this.applyTimezone(this.currentDate); // infuse the calendar's timezone
    };
    // Loading Triggering
    // -----------------------------------------------------------------------------------------------------------------
    // Should be called when any type of async data fetching begins
    Calendar.prototype.pushLoading = function () {
        if (!(this.loadingLevel++)) {
            this.publiclyTrigger('loading', [true, this.view]);
        }
    };
    // Should be called when any type of async data fetching completes
    Calendar.prototype.popLoading = function () {
        if (!(--this.loadingLevel)) {
            this.publiclyTrigger('loading', [false, this.view]);
        }
    };
    // High-level Rendering
    // -----------------------------------------------------------------------------------
    Calendar.prototype.render = function () {
        if (!this.contentEl) {
            this.initialRender();
        }
        else if (this.elementVisible()) {
            // mainly for the public API
            this.calcSize();
            this.updateViewSize();
        }
    };
    Calendar.prototype.initialRender = function () {
        var _this = this;
        var el = this.el;
        el.addClass('fc');
        // event delegation for nav links
        el.on('click.fc', 'a[data-goto]', function (ev) {
            var anchorEl = $(ev.currentTarget);
            var gotoOptions = anchorEl.data('goto'); // will automatically parse JSON
            var date = _this.moment(gotoOptions.date);
            var viewType = gotoOptions.type;
            // property like "navLinkDayClick". might be a string or a function
            var customAction = _this.view.opt('navLink' + util_1.capitaliseFirstLetter(viewType) + 'Click');
            if (typeof customAction === 'function') {
                customAction(date, ev);
            }
            else {
                if (typeof customAction === 'string') {
                    viewType = customAction;
                }
                _this.zoomTo(date, viewType);
            }
        });
        // called immediately, and upon option change
        this.optionsManager.watch('settingTheme', ['?theme', '?themeSystem'], function (opts) {
            var themeClass = ThemeRegistry_1.getThemeSystemClass(opts.themeSystem || opts.theme);
            var theme = new themeClass(_this.optionsManager);
            var widgetClass = theme.getClass('widget');
            _this.theme = theme;
            if (widgetClass) {
                el.addClass(widgetClass);
            }
        }, function () {
            var widgetClass = _this.theme.getClass('widget');
            _this.theme = null;
            if (widgetClass) {
                el.removeClass(widgetClass);
            }
        });
        this.optionsManager.watch('settingBusinessHourGenerator', ['?businessHours'], function (deps) {
            _this.businessHourGenerator = new BusinessHourGenerator_1.default(deps.businessHours, _this);
            if (_this.view) {
                _this.view.set('businessHourGenerator', _this.businessHourGenerator);
            }
        }, function () {
            _this.businessHourGenerator = null;
        });
        // called immediately, and upon option change.
        // HACK: locale often affects isRTL, so we explicitly listen to that too.
        this.optionsManager.watch('applyingDirClasses', ['?isRTL', '?locale'], function (opts) {
            el.toggleClass('fc-ltr', !opts.isRTL);
            el.toggleClass('fc-rtl', opts.isRTL);
        });
        this.contentEl = $("<div class='fc-view-container'/>").prependTo(el);
        this.initToolbars();
        this.renderHeader();
        this.renderFooter();
        this.renderView(this.opt('defaultView'));
        if (this.opt('handleWindowResize')) {
            $(window).resize(this.windowResizeProxy = util_1.debounce(// prevents rapid calls
            this.windowResize.bind(this), this.opt('windowResizeDelay')));
        }
    };
    Calendar.prototype.destroy = function () {
        if (this.view) {
            this.clearView();
        }
        this.toolbarsManager.proxyCall('removeElement');
        this.contentEl.remove();
        this.el.removeClass('fc fc-ltr fc-rtl');
        // removes theme-related root className
        this.optionsManager.unwatch('settingTheme');
        this.optionsManager.unwatch('settingBusinessHourGenerator');
        this.el.off('.fc'); // unbind nav link handlers
        if (this.windowResizeProxy) {
            $(window).unbind('resize', this.windowResizeProxy);
            this.windowResizeProxy = null;
        }
        GlobalEmitter_1.default.unneeded();
    };
    Calendar.prototype.elementVisible = function () {
        return this.el.is(':visible');
    };
    // Render Queue
    // -----------------------------------------------------------------------------------------------------------------
    Calendar.prototype.bindViewHandlers = function (view) {
        var _this = this;
        view.watch('titleForCalendar', ['title'], function (deps) {
            if (view === _this.view) {
                _this.setToolbarsTitle(deps.title);
            }
        });
        view.watch('dateProfileForCalendar', ['dateProfile'], function (deps) {
            if (view === _this.view) {
                _this.currentDate = deps.dateProfile.date; // might have been constrained by view dates
                _this.updateToolbarButtons(deps.dateProfile);
            }
        });
    };
    Calendar.prototype.unbindViewHandlers = function (view) {
        view.unwatch('titleForCalendar');
        view.unwatch('dateProfileForCalendar');
    };
    // View Rendering
    // -----------------------------------------------------------------------------------
    // Renders a view because of a date change, view-type change, or for the first time.
    // If not given a viewType, keep the current view but render different dates.
    // Accepts an optional scroll state to restore to.
    Calendar.prototype.renderView = function (viewType) {
        var oldView = this.view;
        var newView;
        this.freezeContentHeight();
        if (oldView && viewType && oldView.type !== viewType) {
            this.clearView();
        }
        // if viewType changed, or the view was never created, create a fresh view
        if (!this.view && viewType) {
            newView = this.view =
                this.viewsByType[viewType] ||
                    (this.viewsByType[viewType] = this.instantiateView(viewType));
            this.bindViewHandlers(newView);
            newView.startBatchRender(); // so that setElement+setDate rendering are joined
            newView.setElement($("<div class='fc-view fc-" + viewType + "-view' />").appendTo(this.contentEl));
            this.toolbarsManager.proxyCall('activateButton', viewType);
        }
        if (this.view) {
            // prevent unnecessary change firing
            if (this.view.get('businessHourGenerator') !== this.businessHourGenerator) {
                this.view.set('businessHourGenerator', this.businessHourGenerator);
            }
            this.view.setDate(this.currentDate);
            if (newView) {
                newView.stopBatchRender();
            }
        }
        this.thawContentHeight();
    };
    // Unrenders the current view and reflects this change in the Header.
    // Unregsiters the `view`, but does not remove from viewByType hash.
    Calendar.prototype.clearView = function () {
        var currentView = this.view;
        this.toolbarsManager.proxyCall('deactivateButton', currentView.type);
        this.unbindViewHandlers(currentView);
        currentView.removeElement();
        currentView.unsetDate(); // so bindViewHandlers doesn't fire with old values next time
        this.view = null;
    };
    // Destroys the view, including the view object. Then, re-instantiates it and renders it.
    // Maintains the same scroll state.
    // TODO: maintain any other user-manipulated state.
    Calendar.prototype.reinitView = function () {
        var oldView = this.view;
        var scroll = oldView.queryScroll(); // wouldn't be so complicated if Calendar owned the scroll
        this.freezeContentHeight();
        this.clearView();
        this.calcSize();
        this.renderView(oldView.type); // needs the type to freshly render
        this.view.applyScroll(scroll);
        this.thawContentHeight();
    };
    // Resizing
    // -----------------------------------------------------------------------------------
    Calendar.prototype.getSuggestedViewHeight = function () {
        if (this.suggestedViewHeight == null) {
            this.calcSize();
        }
        return this.suggestedViewHeight;
    };
    Calendar.prototype.isHeightAuto = function () {
        return this.opt('contentHeight') === 'auto' || this.opt('height') === 'auto';
    };
    Calendar.prototype.updateViewSize = function (isResize) {
        if (isResize === void 0) { isResize = false; }
        var view = this.view;
        var scroll;
        if (!this.ignoreUpdateViewSize && view) {
            if (isResize) {
                this.calcSize();
                scroll = view.queryScroll();
            }
            this.ignoreUpdateViewSize++;
            view.updateSize(this.getSuggestedViewHeight(), this.isHeightAuto(), isResize);
            this.ignoreUpdateViewSize--;
            if (isResize) {
                view.applyScroll(scroll);
            }
            return true; // signal success
        }
    };
    Calendar.prototype.calcSize = function () {
        if (this.elementVisible()) {
            this._calcSize();
        }
    };
    Calendar.prototype._calcSize = function () {
        var contentHeightInput = this.opt('contentHeight');
        var heightInput = this.opt('height');
        if (typeof contentHeightInput === 'number') {
            this.suggestedViewHeight = contentHeightInput;
        }
        else if (typeof contentHeightInput === 'function') {
            this.suggestedViewHeight = contentHeightInput();
        }
        else if (typeof heightInput === 'number') {
            this.suggestedViewHeight = heightInput - this.queryToolbarsHeight();
        }
        else if (typeof heightInput === 'function') {
            this.suggestedViewHeight = heightInput() - this.queryToolbarsHeight();
        }
        else if (heightInput === 'parent') {
            this.suggestedViewHeight = this.el.parent().height() - this.queryToolbarsHeight();
        }
        else {
            this.suggestedViewHeight = Math.round(this.contentEl.width() /
                Math.max(this.opt('aspectRatio'), .5));
        }
    };
    Calendar.prototype.windowResize = function (ev) {
        if (
        // the purpose: so we don't process jqui "resize" events that have bubbled up
        // cast to any because .target, which is Element, can't be compared to window for some reason.
        ev.target === window &&
            this.view &&
            this.view.isDatesRendered) {
            if (this.updateViewSize(true)) {
                this.publiclyTrigger('windowResize', [this.view]);
            }
        }
    };
    /* Height "Freezing"
    -----------------------------------------------------------------------------*/
    Calendar.prototype.freezeContentHeight = function () {
        if (!(this.freezeContentHeightDepth++)) {
            this.forceFreezeContentHeight();
        }
    };
    Calendar.prototype.forceFreezeContentHeight = function () {
        this.contentEl.css({
            width: '100%',
            height: this.contentEl.height(),
            overflow: 'hidden'
        });
    };
    Calendar.prototype.thawContentHeight = function () {
        this.freezeContentHeightDepth--;
        // always bring back to natural height
        this.contentEl.css({
            width: '',
            height: '',
            overflow: ''
        });
        // but if there are future thaws, re-freeze
        if (this.freezeContentHeightDepth) {
            this.forceFreezeContentHeight();
        }
    };
    // Toolbar
    // -----------------------------------------------------------------------------------------------------------------
    Calendar.prototype.initToolbars = function () {
        this.header = new Toolbar_1.default(this, this.computeHeaderOptions());
        this.footer = new Toolbar_1.default(this, this.computeFooterOptions());
        this.toolbarsManager = new Iterator_1.default([this.header, this.footer]);
    };
    Calendar.prototype.computeHeaderOptions = function () {
        return {
            extraClasses: 'fc-header-toolbar',
            layout: this.opt('header')
        };
    };
    Calendar.prototype.computeFooterOptions = function () {
        return {
            extraClasses: 'fc-footer-toolbar',
            layout: this.opt('footer')
        };
    };
    // can be called repeatedly and Header will rerender
    Calendar.prototype.renderHeader = function () {
        var header = this.header;
        header.setToolbarOptions(this.computeHeaderOptions());
        header.render();
        if (header.el) {
            this.el.prepend(header.el);
        }
    };
    // can be called repeatedly and Footer will rerender
    Calendar.prototype.renderFooter = function () {
        var footer = this.footer;
        footer.setToolbarOptions(this.computeFooterOptions());
        footer.render();
        if (footer.el) {
            this.el.append(footer.el);
        }
    };
    Calendar.prototype.setToolbarsTitle = function (title) {
        this.toolbarsManager.proxyCall('updateTitle', title);
    };
    Calendar.prototype.updateToolbarButtons = function (dateProfile) {
        var now = this.getNow();
        var view = this.view;
        var todayInfo = view.dateProfileGenerator.build(now);
        var prevInfo = view.dateProfileGenerator.buildPrev(view.get('dateProfile'));
        var nextInfo = view.dateProfileGenerator.buildNext(view.get('dateProfile'));
        this.toolbarsManager.proxyCall((todayInfo.isValid && !dateProfile.currentUnzonedRange.containsDate(now)) ?
            'enableButton' :
            'disableButton', 'today');
        this.toolbarsManager.proxyCall(prevInfo.isValid ?
            'enableButton' :
            'disableButton', 'prev');
        this.toolbarsManager.proxyCall(nextInfo.isValid ?
            'enableButton' :
            'disableButton', 'next');
    };
    Calendar.prototype.queryToolbarsHeight = function () {
        return this.toolbarsManager.items.reduce(function (accumulator, toolbar) {
            var toolbarHeight = toolbar.el ? toolbar.el.outerHeight(true) : 0; // includes margin
            return accumulator + toolbarHeight;
        }, 0);
    };
    // Selection
    // -----------------------------------------------------------------------------------------------------------------
    // this public method receives start/end dates in any format, with any timezone
    Calendar.prototype.select = function (zonedStartInput, zonedEndInput) {
        this.view.select(this.buildSelectFootprint.apply(this, arguments));
    };
    Calendar.prototype.unselect = function () {
        if (this.view) {
            this.view.unselect();
        }
    };
    // Given arguments to the select method in the API, returns a span (unzoned start/end and other info)
    Calendar.prototype.buildSelectFootprint = function (zonedStartInput, zonedEndInput) {
        var start = this.moment(zonedStartInput).stripZone();
        var end;
        if (zonedEndInput) {
            end = this.moment(zonedEndInput).stripZone();
        }
        else if (start.hasTime()) {
            end = start.clone().add(this.defaultTimedEventDuration);
        }
        else {
            end = start.clone().add(this.defaultAllDayEventDuration);
        }
        return new ComponentFootprint_1.default(new UnzonedRange_1.default(start, end), !start.hasTime());
    };
    // Date Utils
    // -----------------------------------------------------------------------------------------------------------------
    Calendar.prototype.initMomentInternals = function () {
        var _this = this;
        this.defaultAllDayEventDuration = moment.duration(this.opt('defaultAllDayEventDuration'));
        this.defaultTimedEventDuration = moment.duration(this.opt('defaultTimedEventDuration'));
        // Called immediately, and when any of the options change.
        // Happens before any internal objects rebuild or rerender, because this is very core.
        this.optionsManager.watch('buildingMomentLocale', [
            '?locale', '?monthNames', '?monthNamesShort', '?dayNames', '?dayNamesShort',
            '?firstDay', '?weekNumberCalculation'
        ], function (opts) {
            var weekNumberCalculation = opts.weekNumberCalculation;
            var firstDay = opts.firstDay;
            var _week;
            // normalize
            if (weekNumberCalculation === 'iso') {
                weekNumberCalculation = 'ISO'; // normalize
            }
            var localeData = Object.create(// make a cheap copy
            locale_1.getMomentLocaleData(opts.locale) // will fall back to en
            );
            if (opts.monthNames) {
                localeData._months = opts.monthNames;
            }
            if (opts.monthNamesShort) {
                localeData._monthsShort = opts.monthNamesShort;
            }
            if (opts.dayNames) {
                localeData._weekdays = opts.dayNames;
            }
            if (opts.dayNamesShort) {
                localeData._weekdaysShort = opts.dayNamesShort;
            }
            if (firstDay == null && weekNumberCalculation === 'ISO') {
                firstDay = 1;
            }
            if (firstDay != null) {
                _week = Object.create(localeData._week); // _week: { dow: # }
                _week.dow = firstDay;
                localeData._week = _week;
            }
            if (weekNumberCalculation === 'ISO' ||
                weekNumberCalculation === 'local' ||
                typeof weekNumberCalculation === 'function') {
                localeData._fullCalendar_weekCalc = weekNumberCalculation; // moment-ext will know what to do with it
            }
            _this.localeData = localeData;
            // If the internal current date object already exists, move to new locale.
            // We do NOT need to do this technique for event dates, because this happens when converting to "segments".
            if (_this.currentDate) {
                _this.localizeMoment(_this.currentDate); // sets to localeData
            }
        });
    };
    // Builds a moment using the settings of the current calendar: timezone and locale.
    // Accepts anything the vanilla moment() constructor accepts.
    Calendar.prototype.moment = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        var mom;
        if (this.opt('timezone') === 'local') {
            mom = moment_ext_1.default.apply(null, args);
            // Force the moment to be local, because momentExt doesn't guarantee it.
            if (mom.hasTime()) {
                mom.local();
            }
        }
        else if (this.opt('timezone') === 'UTC') {
            mom = moment_ext_1.default.utc.apply(null, args); // process as UTC
        }
        else {
            mom = moment_ext_1.default.parseZone.apply(null, args); // let the input decide the zone
        }
        this.localizeMoment(mom); // TODO
        return mom;
    };
    Calendar.prototype.msToMoment = function (ms, forceAllDay) {
        var mom = moment_ext_1.default.utc(ms); // TODO: optimize by using Date.UTC
        if (forceAllDay) {
            mom.stripTime();
        }
        else {
            mom = this.applyTimezone(mom); // may or may not apply locale
        }
        this.localizeMoment(mom);
        return mom;
    };
    Calendar.prototype.msToUtcMoment = function (ms, forceAllDay) {
        var mom = moment_ext_1.default.utc(ms); // TODO: optimize by using Date.UTC
        if (forceAllDay) {
            mom.stripTime();
        }
        this.localizeMoment(mom);
        return mom;
    };
    // Updates the given moment's locale settings to the current calendar locale settings.
    Calendar.prototype.localizeMoment = function (mom) {
        mom._locale = this.localeData;
    };
    // Returns a boolean about whether or not the calendar knows how to calculate
    // the timezone offset of arbitrary dates in the current timezone.
    Calendar.prototype.getIsAmbigTimezone = function () {
        return this.opt('timezone') !== 'local' && this.opt('timezone') !== 'UTC';
    };
    // Returns a copy of the given date in the current timezone. Has no effect on dates without times.
    Calendar.prototype.applyTimezone = function (date) {
        if (!date.hasTime()) {
            return date.clone();
        }
        var zonedDate = this.moment(date.toArray());
        var timeAdjust = date.time().asMilliseconds() - zonedDate.time().asMilliseconds();
        var adjustedZonedDate;
        // Safari sometimes has problems with this coersion when near DST. Adjust if necessary. (bug #2396)
        if (timeAdjust) {
            adjustedZonedDate = zonedDate.clone().add(timeAdjust); // add milliseconds
            if (date.time().asMilliseconds() - adjustedZonedDate.time().asMilliseconds() === 0) {
                zonedDate = adjustedZonedDate;
            }
        }
        return zonedDate;
    };
    /*
    Assumes the footprint is non-open-ended.
    */
    Calendar.prototype.footprintToDateProfile = function (componentFootprint, ignoreEnd) {
        if (ignoreEnd === void 0) { ignoreEnd = false; }
        var start = moment_ext_1.default.utc(componentFootprint.unzonedRange.startMs);
        var end;
        if (!ignoreEnd) {
            end = moment_ext_1.default.utc(componentFootprint.unzonedRange.endMs);
        }
        if (componentFootprint.isAllDay) {
            start.stripTime();
            if (end) {
                end.stripTime();
            }
        }
        else {
            start = this.applyTimezone(start);
            if (end) {
                end = this.applyTimezone(end);
            }
        }
        return new EventDateProfile_1.default(start, end, this);
    };
    // Returns a moment for the current date, as defined by the client's computer or from the `now` option.
    // Will return an moment with an ambiguous timezone.
    Calendar.prototype.getNow = function () {
        var now = this.opt('now');
        if (typeof now === 'function') {
            now = now();
        }
        return this.moment(now).stripZone();
    };
    // Produces a human-readable string for the given duration.
    // Side-effect: changes the locale of the given duration.
    Calendar.prototype.humanizeDuration = function (duration) {
        return duration.locale(this.opt('locale')).humanize();
    };
    // will return `null` if invalid range
    Calendar.prototype.parseUnzonedRange = function (rangeInput) {
        var start = null;
        var end = null;
        if (rangeInput.start) {
            start = this.moment(rangeInput.start).stripZone();
        }
        if (rangeInput.end) {
            end = this.moment(rangeInput.end).stripZone();
        }
        if (!start && !end) {
            return null;
        }
        if (start && end && end.isBefore(start)) {
            return null;
        }
        return new UnzonedRange_1.default(start, end);
    };
    // Event-Date Utilities
    // -----------------------------------------------------------------------------------------------------------------
    Calendar.prototype.initEventManager = function () {
        var _this = this;
        var eventManager = new EventManager_1.default(this);
        var rawSources = this.opt('eventSources') || [];
        var singleRawSource = this.opt('events');
        this.eventManager = eventManager;
        if (singleRawSource) {
            rawSources.unshift(singleRawSource);
        }
        eventManager.on('release', function (eventsPayload) {
            _this.trigger('eventsReset', eventsPayload);
        });
        eventManager.freeze();
        rawSources.forEach(function (rawSource) {
            var source = EventSourceParser_1.default.parse(rawSource, _this);
            if (source) {
                eventManager.addSource(source);
            }
        });
        eventManager.thaw();
    };
    Calendar.prototype.requestEvents = function (start, end) {
        return this.eventManager.requestEvents(start, end, this.opt('timezone'), !this.opt('lazyFetching'));
    };
    // Get an event's normalized end date. If not present, calculate it from the defaults.
    Calendar.prototype.getEventEnd = function (event) {
        if (event.end) {
            return event.end.clone();
        }
        else {
            return this.getDefaultEventEnd(event.allDay, event.start);
        }
    };
    // Given an event's allDay status and start date, return what its fallback end date should be.
    // TODO: rename to computeDefaultEventEnd
    Calendar.prototype.getDefaultEventEnd = function (allDay, zonedStart) {
        var end = zonedStart.clone();
        if (allDay) {
            end.stripTime().add(this.defaultAllDayEventDuration);
        }
        else {
            end.add(this.defaultTimedEventDuration);
        }
        if (this.getIsAmbigTimezone()) {
            end.stripZone(); // we don't know what the tzo should be
        }
        return end;
    };
    // Public Events API
    // -----------------------------------------------------------------------------------------------------------------
    Calendar.prototype.rerenderEvents = function () {
        this.view.flash('displayingEvents');
    };
    Calendar.prototype.refetchEvents = function () {
        this.eventManager.refetchAllSources();
    };
    Calendar.prototype.renderEvents = function (eventInputs, isSticky) {
        this.eventManager.freeze();
        for (var i = 0; i < eventInputs.length; i++) {
            this.renderEvent(eventInputs[i], isSticky);
        }
        this.eventManager.thaw();
    };
    Calendar.prototype.renderEvent = function (eventInput, isSticky) {
        if (isSticky === void 0) { isSticky = false; }
        var eventManager = this.eventManager;
        var eventDef = EventDefParser_1.default.parse(eventInput, eventInput.source || eventManager.stickySource);
        if (eventDef) {
            eventManager.addEventDef(eventDef, isSticky);
        }
    };
    // legacyQuery operates on legacy event instance objects
    Calendar.prototype.removeEvents = function (legacyQuery) {
        var eventManager = this.eventManager;
        var legacyInstances = [];
        var idMap = {};
        var eventDef;
        var i;
        if (legacyQuery == null) {
            eventManager.removeAllEventDefs(); // persist=true
        }
        else {
            eventManager.getEventInstances().forEach(function (eventInstance) {
                legacyInstances.push(eventInstance.toLegacy());
            });
            legacyInstances = filterLegacyEventInstances(legacyInstances, legacyQuery);
            // compute unique IDs
            for (i = 0; i < legacyInstances.length; i++) {
                eventDef = this.eventManager.getEventDefByUid(legacyInstances[i]._id);
                idMap[eventDef.id] = true;
            }
            eventManager.freeze();
            for (i in idMap) {
                eventManager.removeEventDefsById(i); // persist=true
            }
            eventManager.thaw();
        }
    };
    // legacyQuery operates on legacy event instance objects
    Calendar.prototype.clientEvents = function (legacyQuery) {
        var legacyEventInstances = [];
        this.eventManager.getEventInstances().forEach(function (eventInstance) {
            legacyEventInstances.push(eventInstance.toLegacy());
        });
        return filterLegacyEventInstances(legacyEventInstances, legacyQuery);
    };
    Calendar.prototype.updateEvents = function (eventPropsArray) {
        this.eventManager.freeze();
        for (var i = 0; i < eventPropsArray.length; i++) {
            this.updateEvent(eventPropsArray[i]);
        }
        this.eventManager.thaw();
    };
    Calendar.prototype.updateEvent = function (eventProps) {
        var eventDef = this.eventManager.getEventDefByUid(eventProps._id);
        var eventInstance;
        var eventDefMutation;
        if (eventDef instanceof SingleEventDef_1.default) {
            eventInstance = eventDef.buildInstance();
            eventDefMutation = EventDefMutation_1.default.createFromRawProps(eventInstance, eventProps, // raw props
            null // largeUnit -- who uses it?
            );
            this.eventManager.mutateEventsWithId(eventDef.id, eventDefMutation); // will release
        }
    };
    // Public Event Sources API
    // ------------------------------------------------------------------------------------
    Calendar.prototype.getEventSources = function () {
        return this.eventManager.otherSources.slice(); // clone
    };
    Calendar.prototype.getEventSourceById = function (id) {
        return this.eventManager.getSourceById(EventSource_1.default.normalizeId(id));
    };
    Calendar.prototype.addEventSource = function (sourceInput) {
        var source = EventSourceParser_1.default.parse(sourceInput, this);
        if (source) {
            this.eventManager.addSource(source);
        }
    };
    Calendar.prototype.removeEventSources = function (sourceMultiQuery) {
        var eventManager = this.eventManager;
        var sources;
        var i;
        if (sourceMultiQuery == null) {
            this.eventManager.removeAllSources();
        }
        else {
            sources = eventManager.multiQuerySources(sourceMultiQuery);
            eventManager.freeze();
            for (i = 0; i < sources.length; i++) {
                eventManager.removeSource(sources[i]);
            }
            eventManager.thaw();
        }
    };
    Calendar.prototype.removeEventSource = function (sourceQuery) {
        var eventManager = this.eventManager;
        var sources = eventManager.querySources(sourceQuery);
        var i;
        eventManager.freeze();
        for (i = 0; i < sources.length; i++) {
            eventManager.removeSource(sources[i]);
        }
        eventManager.thaw();
    };
    Calendar.prototype.refetchEventSources = function (sourceMultiQuery) {
        var eventManager = this.eventManager;
        var sources = eventManager.multiQuerySources(sourceMultiQuery);
        var i;
        eventManager.freeze();
        for (i = 0; i < sources.length; i++) {
            eventManager.refetchSource(sources[i]);
        }
        eventManager.thaw();
    };
    // not for internal use. use options module directly instead.
    Calendar.defaults = options_1.globalDefaults;
    Calendar.englishDefaults = options_1.englishDefaults;
    Calendar.rtlDefaults = options_1.rtlDefaults;
    return Calendar;
}());
exports.default = Calendar;
EmitterMixin_1.default.mixInto(Calendar);
ListenerMixin_1.default.mixInto(Calendar);
function filterLegacyEventInstances(legacyEventInstances, legacyQuery) {
    if (legacyQuery == null) {
        return legacyEventInstances;
    }
    else if ($.isFunction(legacyQuery)) {
        return legacyEventInstances.filter(legacyQuery);
    }
    else {
        legacyQuery += ''; // normalize to string
        return legacyEventInstances.filter(function (legacyEventInstance) {
            // soft comparison because id not be normalized to string
            // tslint:disable-next-line
            return legacyEventInstance.id == legacyQuery ||
                legacyEventInstance._id === legacyQuery; // can specify internal id, but must exactly match
        });
    }
}


/***/ }),
/* 221 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var moment = __webpack_require__(0);
var util_1 = __webpack_require__(4);
var UnzonedRange_1 = __webpack_require__(5);
var DateProfileGenerator = /** @class */ (function () {
    function DateProfileGenerator(_view) {
        this._view = _view;
    }
    DateProfileGenerator.prototype.opt = function (name) {
        return this._view.opt(name);
    };
    DateProfileGenerator.prototype.trimHiddenDays = function (unzonedRange) {
        return this._view.trimHiddenDays(unzonedRange);
    };
    DateProfileGenerator.prototype.msToUtcMoment = function (ms, forceAllDay) {
        return this._view.calendar.msToUtcMoment(ms, forceAllDay);
    };
    /* Date Range Computation
    ------------------------------------------------------------------------------------------------------------------*/
    // Builds a structure with info about what the dates/ranges will be for the "prev" view.
    DateProfileGenerator.prototype.buildPrev = function (currentDateProfile) {
        var prevDate = currentDateProfile.date.clone()
            .startOf(currentDateProfile.currentRangeUnit)
            .subtract(currentDateProfile.dateIncrement);
        return this.build(prevDate, -1);
    };
    // Builds a structure with info about what the dates/ranges will be for the "next" view.
    DateProfileGenerator.prototype.buildNext = function (currentDateProfile) {
        var nextDate = currentDateProfile.date.clone()
            .startOf(currentDateProfile.currentRangeUnit)
            .add(currentDateProfile.dateIncrement);
        return this.build(nextDate, 1);
    };
    // Builds a structure holding dates/ranges for rendering around the given date.
    // Optional direction param indicates whether the date is being incremented/decremented
    // from its previous value. decremented = -1, incremented = 1 (default).
    DateProfileGenerator.prototype.build = function (date, direction, forceToValid) {
        if (forceToValid === void 0) { forceToValid = false; }
        var isDateAllDay = !date.hasTime();
        var validUnzonedRange;
        var minTime = null;
        var maxTime = null;
        var currentInfo;
        var isRangeAllDay;
        var renderUnzonedRange;
        var activeUnzonedRange;
        var isValid;
        validUnzonedRange = this.buildValidRange();
        validUnzonedRange = this.trimHiddenDays(validUnzonedRange);
        if (forceToValid) {
            date = this.msToUtcMoment(validUnzonedRange.constrainDate(date), // returns MS
            isDateAllDay);
        }
        currentInfo = this.buildCurrentRangeInfo(date, direction);
        isRangeAllDay = /^(year|month|week|day)$/.test(currentInfo.unit);
        renderUnzonedRange = this.buildRenderRange(this.trimHiddenDays(currentInfo.unzonedRange), currentInfo.unit, isRangeAllDay);
        renderUnzonedRange = this.trimHiddenDays(renderUnzonedRange);
        activeUnzonedRange = renderUnzonedRange.clone();
        if (!this.opt('showNonCurrentDates')) {
            activeUnzonedRange = activeUnzonedRange.intersect(currentInfo.unzonedRange);
        }
        minTime = moment.duration(this.opt('minTime'));
        maxTime = moment.duration(this.opt('maxTime'));
        activeUnzonedRange = this.adjustActiveRange(activeUnzonedRange, minTime, maxTime);
        activeUnzonedRange = activeUnzonedRange.intersect(validUnzonedRange); // might return null
        if (activeUnzonedRange) {
            date = this.msToUtcMoment(activeUnzonedRange.constrainDate(date), // returns MS
            isDateAllDay);
        }
        // it's invalid if the originally requested date is not contained,
        // or if the range is completely outside of the valid range.
        isValid = currentInfo.unzonedRange.intersectsWith(validUnzonedRange);
        return {
            // constraint for where prev/next operations can go and where events can be dragged/resized to.
            // an object with optional start and end properties.
            validUnzonedRange: validUnzonedRange,
            // range the view is formally responsible for.
            // for example, a month view might have 1st-31st, excluding padded dates
            currentUnzonedRange: currentInfo.unzonedRange,
            // name of largest unit being displayed, like "month" or "week"
            currentRangeUnit: currentInfo.unit,
            isRangeAllDay: isRangeAllDay,
            // dates that display events and accept drag-n-drop
            // will be `null` if no dates accept events
            activeUnzonedRange: activeUnzonedRange,
            // date range with a rendered skeleton
            // includes not-active days that need some sort of DOM
            renderUnzonedRange: renderUnzonedRange,
            // Duration object that denotes the first visible time of any given day
            minTime: minTime,
            // Duration object that denotes the exclusive visible end time of any given day
            maxTime: maxTime,
            isValid: isValid,
            date: date,
            // how far the current date will move for a prev/next operation
            dateIncrement: this.buildDateIncrement(currentInfo.duration)
            // pass a fallback (might be null) ^
        };
    };
    // Builds an object with optional start/end properties.
    // Indicates the minimum/maximum dates to display.
    // not responsible for trimming hidden days.
    DateProfileGenerator.prototype.buildValidRange = function () {
        return this._view.getUnzonedRangeOption('validRange', this._view.calendar.getNow()) ||
            new UnzonedRange_1.default(); // completely open-ended
    };
    // Builds a structure with info about the "current" range, the range that is
    // highlighted as being the current month for example.
    // See build() for a description of `direction`.
    // Guaranteed to have `range` and `unit` properties. `duration` is optional.
    // TODO: accept a MS-time instead of a moment `date`?
    DateProfileGenerator.prototype.buildCurrentRangeInfo = function (date, direction) {
        var viewSpec = this._view.viewSpec;
        var duration = null;
        var unit = null;
        var unzonedRange = null;
        var dayCount;
        if (viewSpec.duration) {
            duration = viewSpec.duration;
            unit = viewSpec.durationUnit;
            unzonedRange = this.buildRangeFromDuration(date, direction, duration, unit);
        }
        else if ((dayCount = this.opt('dayCount'))) {
            unit = 'day';
            unzonedRange = this.buildRangeFromDayCount(date, direction, dayCount);
        }
        else if ((unzonedRange = this.buildCustomVisibleRange(date))) {
            unit = util_1.computeGreatestUnit(unzonedRange.getStart(), unzonedRange.getEnd());
        }
        else {
            duration = this.getFallbackDuration();
            unit = util_1.computeGreatestUnit(duration);
            unzonedRange = this.buildRangeFromDuration(date, direction, duration, unit);
        }
        return { duration: duration, unit: unit, unzonedRange: unzonedRange };
    };
    DateProfileGenerator.prototype.getFallbackDuration = function () {
        return moment.duration({ days: 1 });
    };
    // Returns a new activeUnzonedRange to have time values (un-ambiguate)
    // minTime or maxTime causes the range to expand.
    DateProfileGenerator.prototype.adjustActiveRange = function (unzonedRange, minTime, maxTime) {
        var start = unzonedRange.getStart();
        var end = unzonedRange.getEnd();
        if (this._view.usesMinMaxTime) {
            if (minTime < 0) {
                start.time(0).add(minTime);
            }
            if (maxTime > 24 * 60 * 60 * 1000) {
                end.time(maxTime - (24 * 60 * 60 * 1000));
            }
        }
        return new UnzonedRange_1.default(start, end);
    };
    // Builds the "current" range when it is specified as an explicit duration.
    // `unit` is the already-computed computeGreatestUnit value of duration.
    // TODO: accept a MS-time instead of a moment `date`?
    DateProfileGenerator.prototype.buildRangeFromDuration = function (date, direction, duration, unit) {
        var alignment = this.opt('dateAlignment');
        var dateIncrementInput;
        var dateIncrementDuration;
        var start;
        var end;
        var res;
        // compute what the alignment should be
        if (!alignment) {
            dateIncrementInput = this.opt('dateIncrement');
            if (dateIncrementInput) {
                dateIncrementDuration = moment.duration(dateIncrementInput);
                // use the smaller of the two units
                if (dateIncrementDuration < duration) {
                    alignment = util_1.computeDurationGreatestUnit(dateIncrementDuration, dateIncrementInput);
                }
                else {
                    alignment = unit;
                }
            }
            else {
                alignment = unit;
            }
        }
        // if the view displays a single day or smaller
        if (duration.as('days') <= 1) {
            if (this._view.isHiddenDay(start)) {
                start = this._view.skipHiddenDays(start, direction);
                start.startOf('day');
            }
        }
        function computeRes() {
            start = date.clone().startOf(alignment);
            end = start.clone().add(duration);
            res = new UnzonedRange_1.default(start, end);
        }
        computeRes();
        // if range is completely enveloped by hidden days, go past the hidden days
        if (!this.trimHiddenDays(res)) {
            date = this._view.skipHiddenDays(date, direction);
            computeRes();
        }
        return res;
    };
    // Builds the "current" range when a dayCount is specified.
    // TODO: accept a MS-time instead of a moment `date`?
    DateProfileGenerator.prototype.buildRangeFromDayCount = function (date, direction, dayCount) {
        var customAlignment = this.opt('dateAlignment');
        var runningCount = 0;
        var start = date.clone();
        var end;
        if (customAlignment) {
            start.startOf(customAlignment);
        }
        start.startOf('day');
        start = this._view.skipHiddenDays(start, direction);
        end = start.clone();
        do {
            end.add(1, 'day');
            if (!this._view.isHiddenDay(end)) {
                runningCount++;
            }
        } while (runningCount < dayCount);
        return new UnzonedRange_1.default(start, end);
    };
    // Builds a normalized range object for the "visible" range,
    // which is a way to define the currentUnzonedRange and activeUnzonedRange at the same time.
    // TODO: accept a MS-time instead of a moment `date`?
    DateProfileGenerator.prototype.buildCustomVisibleRange = function (date) {
        var visibleUnzonedRange = this._view.getUnzonedRangeOption('visibleRange', this._view.calendar.applyTimezone(date) // correct zone. also generates new obj that avoids mutations
        );
        if (visibleUnzonedRange && (visibleUnzonedRange.startMs == null || visibleUnzonedRange.endMs == null)) {
            return null;
        }
        return visibleUnzonedRange;
    };
    // Computes the range that will represent the element/cells for *rendering*,
    // but which may have voided days/times.
    // not responsible for trimming hidden days.
    DateProfileGenerator.prototype.buildRenderRange = function (currentUnzonedRange, currentRangeUnit, isRangeAllDay) {
        return currentUnzonedRange.clone();
    };
    // Compute the duration value that should be added/substracted to the current date
    // when a prev/next operation happens.
    DateProfileGenerator.prototype.buildDateIncrement = function (fallback) {
        var dateIncrementInput = this.opt('dateIncrement');
        var customAlignment;
        if (dateIncrementInput) {
            return moment.duration(dateIncrementInput);
        }
        else if ((customAlignment = this.opt('dateAlignment'))) {
            return moment.duration(1, customAlignment);
        }
        else if (fallback) {
            return fallback;
        }
        else {
            return moment.duration({ days: 1 });
        }
    };
    return DateProfileGenerator;
}());
exports.default = DateProfileGenerator;


/***/ }),
/* 222 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var $ = __webpack_require__(3);
var moment = __webpack_require__(0);
var exportHooks = __webpack_require__(16);
var util_1 = __webpack_require__(4);
var moment_ext_1 = __webpack_require__(10);
var ListenerMixin_1 = __webpack_require__(7);
var HitDragListener_1 = __webpack_require__(23);
var SingleEventDef_1 = __webpack_require__(13);
var EventInstanceGroup_1 = __webpack_require__(18);
var EventSource_1 = __webpack_require__(6);
var Interaction_1 = __webpack_require__(15);
var ExternalDropping = /** @class */ (function (_super) {
    tslib_1.__extends(ExternalDropping, _super);
    function ExternalDropping() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.isDragging = false; // jqui-dragging an external element? boolean
        return _this;
    }
    /*
    component impements:
      - eventRangesToEventFootprints
      - isEventInstanceGroupAllowed
      - isExternalInstanceGroupAllowed
      - renderDrag
      - unrenderDrag
    */
    ExternalDropping.prototype.end = function () {
        if (this.dragListener) {
            this.dragListener.endInteraction();
        }
    };
    ExternalDropping.prototype.bindToDocument = function () {
        this.listenTo($(document), {
            dragstart: this.handleDragStart,
            sortstart: this.handleDragStart // jqui
        });
    };
    ExternalDropping.prototype.unbindFromDocument = function () {
        this.stopListeningTo($(document));
    };
    // Called when a jQuery UI drag is initiated anywhere in the DOM
    ExternalDropping.prototype.handleDragStart = function (ev, ui) {
        var el;
        var accept;
        if (this.opt('droppable')) {
            el = $((ui ? ui.item : null) || ev.target);
            // Test that the dragged element passes the dropAccept selector or filter function.
            // FYI, the default is "*" (matches all)
            accept = this.opt('dropAccept');
            if ($.isFunction(accept) ? accept.call(el[0], el) : el.is(accept)) {
                if (!this.isDragging) {
                    this.listenToExternalDrag(el, ev, ui);
                }
            }
        }
    };
    // Called when a jQuery UI drag starts and it needs to be monitored for dropping
    ExternalDropping.prototype.listenToExternalDrag = function (el, ev, ui) {
        var _this = this;
        var component = this.component;
        var view = this.view;
        var meta = getDraggedElMeta(el); // extra data about event drop, including possible event to create
        var singleEventDef; // a null value signals an unsuccessful drag
        // listener that tracks mouse movement over date-associated pixel regions
        var dragListener = this.dragListener = new HitDragListener_1.default(component, {
            interactionStart: function () {
                _this.isDragging = true;
            },
            hitOver: function (hit) {
                var isAllowed = true;
                var hitFootprint = hit.component.getSafeHitFootprint(hit); // hit might not belong to this grid
                var mutatedEventInstanceGroup;
                if (hitFootprint) {
                    singleEventDef = _this.computeExternalDrop(hitFootprint, meta);
                    if (singleEventDef) {
                        mutatedEventInstanceGroup = new EventInstanceGroup_1.default(singleEventDef.buildInstances());
                        isAllowed = meta.eventProps ? // isEvent?
                            component.isEventInstanceGroupAllowed(mutatedEventInstanceGroup) :
                            component.isExternalInstanceGroupAllowed(mutatedEventInstanceGroup);
                    }
                    else {
                        isAllowed = false;
                    }
                }
                else {
                    isAllowed = false;
                }
                if (!isAllowed) {
                    singleEventDef = null;
                    util_1.disableCursor();
                }
                if (singleEventDef) {
                    component.renderDrag(// called without a seg parameter
                    component.eventRangesToEventFootprints(mutatedEventInstanceGroup.sliceRenderRanges(component.dateProfile.renderUnzonedRange, view.calendar)));
                }
            },
            hitOut: function () {
                singleEventDef = null; // signal unsuccessful
            },
            hitDone: function () {
                util_1.enableCursor();
                component.unrenderDrag();
            },
            interactionEnd: function (ev) {
                if (singleEventDef) {
                    view.reportExternalDrop(singleEventDef, Boolean(meta.eventProps), // isEvent
                    Boolean(meta.stick), // isSticky
                    el, ev, ui);
                }
                _this.isDragging = false;
                _this.dragListener = null;
            }
        });
        dragListener.startDrag(ev); // start listening immediately
    };
    // Given a hit to be dropped upon, and misc data associated with the jqui drag (guaranteed to be a plain object),
    // returns the zoned start/end dates for the event that would result from the hypothetical drop. end might be null.
    // Returning a null value signals an invalid drop hit.
    // DOES NOT consider overlap/constraint.
    // Assumes both footprints are non-open-ended.
    ExternalDropping.prototype.computeExternalDrop = function (componentFootprint, meta) {
        var calendar = this.view.calendar;
        var start = moment_ext_1.default.utc(componentFootprint.unzonedRange.startMs).stripZone();
        var end;
        var eventDef;
        if (componentFootprint.isAllDay) {
            // if dropped on an all-day span, and element's metadata specified a time, set it
            if (meta.startTime) {
                start.time(meta.startTime);
            }
            else {
                start.stripTime();
            }
        }
        if (meta.duration) {
            end = start.clone().add(meta.duration);
        }
        start = calendar.applyTimezone(start);
        if (end) {
            end = calendar.applyTimezone(end);
        }
        eventDef = SingleEventDef_1.default.parse($.extend({}, meta.eventProps, {
            start: start,
            end: end
        }), new EventSource_1.default(calendar));
        return eventDef;
    };
    return ExternalDropping;
}(Interaction_1.default));
exports.default = ExternalDropping;
ListenerMixin_1.default.mixInto(ExternalDropping);
/* External-Dragging-Element Data
----------------------------------------------------------------------------------------------------------------------*/
// Require all HTML5 data-* attributes used by FullCalendar to have this prefix.
// A value of '' will query attributes like data-event. A value of 'fc' will query attributes like data-fc-event.
exportHooks.dataAttrPrefix = '';
// Given a jQuery element that might represent a dragged FullCalendar event, returns an intermediate data structure
// to be used for Event Object creation.
// A defined `.eventProps`, even when empty, indicates that an event should be created.
function getDraggedElMeta(el) {
    var prefix = exportHooks.dataAttrPrefix;
    var eventProps; // properties for creating the event, not related to date/time
    var startTime; // a Duration
    var duration;
    var stick;
    if (prefix) {
        prefix += '-';
    }
    eventProps = el.data(prefix + 'event') || null;
    if (eventProps) {
        if (typeof eventProps === 'object') {
            eventProps = $.extend({}, eventProps); // make a copy
        }
        else {
            eventProps = {};
        }
        // pluck special-cased date/time properties
        startTime = eventProps.start;
        if (startTime == null) {
            startTime = eventProps.time;
        } // accept 'time' as well
        duration = eventProps.duration;
        stick = eventProps.stick;
        delete eventProps.start;
        delete eventProps.time;
        delete eventProps.duration;
        delete eventProps.stick;
    }
    // fallback to standalone attribute values for each of the date/time properties
    if (startTime == null) {
        startTime = el.data(prefix + 'start');
    }
    if (startTime == null) {
        startTime = el.data(prefix + 'time');
    } // accept 'time' as well
    if (duration == null) {
        duration = el.data(prefix + 'duration');
    }
    if (stick == null) {
        stick = el.data(prefix + 'stick');
    }
    // massage into correct data types
    startTime = startTime != null ? moment.duration(startTime) : null;
    duration = duration != null ? moment.duration(duration) : null;
    stick = Boolean(stick);
    return { eventProps: eventProps, startTime: startTime, duration: duration, stick: stick };
}


/***/ }),
/* 223 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var $ = __webpack_require__(3);
var util_1 = __webpack_require__(4);
var EventDefMutation_1 = __webpack_require__(37);
var EventDefDateMutation_1 = __webpack_require__(50);
var HitDragListener_1 = __webpack_require__(23);
var Interaction_1 = __webpack_require__(15);
var EventResizing = /** @class */ (function (_super) {
    tslib_1.__extends(EventResizing, _super);
    /*
    component impements:
      - bindSegHandlerToEl
      - publiclyTrigger
      - diffDates
      - eventRangesToEventFootprints
      - isEventInstanceGroupAllowed
      - getSafeHitFootprint
    */
    function EventResizing(component, eventPointing) {
        var _this = _super.call(this, component) || this;
        _this.isResizing = false;
        _this.eventPointing = eventPointing;
        return _this;
    }
    EventResizing.prototype.end = function () {
        if (this.dragListener) {
            this.dragListener.endInteraction();
        }
    };
    EventResizing.prototype.bindToEl = function (el) {
        var component = this.component;
        component.bindSegHandlerToEl(el, 'mousedown', this.handleMouseDown.bind(this));
        component.bindSegHandlerToEl(el, 'touchstart', this.handleTouchStart.bind(this));
    };
    EventResizing.prototype.handleMouseDown = function (seg, ev) {
        if (this.component.canStartResize(seg, ev)) {
            this.buildDragListener(seg, $(ev.target).is('.fc-start-resizer'))
                .startInteraction(ev, { distance: 5 });
        }
    };
    EventResizing.prototype.handleTouchStart = function (seg, ev) {
        if (this.component.canStartResize(seg, ev)) {
            this.buildDragListener(seg, $(ev.target).is('.fc-start-resizer'))
                .startInteraction(ev);
        }
    };
    // Creates a listener that tracks the user as they resize an event segment.
    // Generic enough to work with any type of Grid.
    EventResizing.prototype.buildDragListener = function (seg, isStart) {
        var _this = this;
        var component = this.component;
        var view = this.view;
        var calendar = view.calendar;
        var eventManager = calendar.eventManager;
        var el = seg.el;
        var eventDef = seg.footprint.eventDef;
        var eventInstance = seg.footprint.eventInstance;
        var isDragging;
        var resizeMutation; // zoned event date properties. falsy if invalid resize
        // Tracks mouse movement over the *grid's* coordinate map
        var dragListener = this.dragListener = new HitDragListener_1.default(component, {
            scroll: this.opt('dragScroll'),
            subjectEl: el,
            interactionStart: function () {
                isDragging = false;
            },
            dragStart: function (ev) {
                isDragging = true;
                // ensure a mouseout on the manipulated event has been reported
                _this.eventPointing.handleMouseout(seg, ev);
                _this.segResizeStart(seg, ev);
            },
            hitOver: function (hit, isOrig, origHit) {
                var isAllowed = true;
                var origHitFootprint = component.getSafeHitFootprint(origHit);
                var hitFootprint = component.getSafeHitFootprint(hit);
                var mutatedEventInstanceGroup;
                if (origHitFootprint && hitFootprint) {
                    resizeMutation = isStart ?
                        _this.computeEventStartResizeMutation(origHitFootprint, hitFootprint, seg.footprint) :
                        _this.computeEventEndResizeMutation(origHitFootprint, hitFootprint, seg.footprint);
                    if (resizeMutation) {
                        mutatedEventInstanceGroup = eventManager.buildMutatedEventInstanceGroup(eventDef.id, resizeMutation);
                        isAllowed = component.isEventInstanceGroupAllowed(mutatedEventInstanceGroup);
                    }
                    else {
                        isAllowed = false;
                    }
                }
                else {
                    isAllowed = false;
                }
                if (!isAllowed) {
                    resizeMutation = null;
                    util_1.disableCursor();
                }
                else if (resizeMutation.isEmpty()) {
                    // no change. (FYI, event dates might have zones)
                    resizeMutation = null;
                }
                if (resizeMutation) {
                    view.hideEventsWithId(seg.footprint.eventDef.id);
                    view.renderEventResize(component.eventRangesToEventFootprints(mutatedEventInstanceGroup.sliceRenderRanges(component.dateProfile.renderUnzonedRange, calendar)), seg);
                }
            },
            hitOut: function () {
                resizeMutation = null;
            },
            hitDone: function () {
                view.unrenderEventResize(seg);
                view.showEventsWithId(seg.footprint.eventDef.id);
                util_1.enableCursor();
            },
            interactionEnd: function (ev) {
                if (isDragging) {
                    _this.segResizeStop(seg, ev);
                }
                if (resizeMutation) {
                    // no need to re-show original, will rerender all anyways. esp important if eventRenderWait
                    view.reportEventResize(eventInstance, resizeMutation, el, ev);
                }
                _this.dragListener = null;
            }
        });
        return dragListener;
    };
    // Called before event segment resizing starts
    EventResizing.prototype.segResizeStart = function (seg, ev) {
        this.isResizing = true;
        this.component.publiclyTrigger('eventResizeStart', {
            context: seg.el[0],
            args: [
                seg.footprint.getEventLegacy(),
                ev,
                {},
                this.view
            ]
        });
    };
    // Called after event segment resizing stops
    EventResizing.prototype.segResizeStop = function (seg, ev) {
        this.isResizing = false;
        this.component.publiclyTrigger('eventResizeStop', {
            context: seg.el[0],
            args: [
                seg.footprint.getEventLegacy(),
                ev,
                {},
                this.view
            ]
        });
    };
    // Returns new date-information for an event segment being resized from its start
    EventResizing.prototype.computeEventStartResizeMutation = function (startFootprint, endFootprint, origEventFootprint) {
        var origRange = origEventFootprint.componentFootprint.unzonedRange;
        var startDelta = this.component.diffDates(endFootprint.unzonedRange.getStart(), startFootprint.unzonedRange.getStart());
        var dateMutation;
        var eventDefMutation;
        if (origRange.getStart().add(startDelta) < origRange.getEnd()) {
            dateMutation = new EventDefDateMutation_1.default();
            dateMutation.setStartDelta(startDelta);
            eventDefMutation = new EventDefMutation_1.default();
            eventDefMutation.setDateMutation(dateMutation);
            return eventDefMutation;
        }
        return false;
    };
    // Returns new date-information for an event segment being resized from its end
    EventResizing.prototype.computeEventEndResizeMutation = function (startFootprint, endFootprint, origEventFootprint) {
        var origRange = origEventFootprint.componentFootprint.unzonedRange;
        var endDelta = this.component.diffDates(endFootprint.unzonedRange.getEnd(), startFootprint.unzonedRange.getEnd());
        var dateMutation;
        var eventDefMutation;
        if (origRange.getEnd().add(endDelta) > origRange.getStart()) {
            dateMutation = new EventDefDateMutation_1.default();
            dateMutation.setEndDelta(endDelta);
            eventDefMutation = new EventDefMutation_1.default();
            eventDefMutation.setDateMutation(dateMutation);
            return eventDefMutation;
        }
        return false;
    };
    return EventResizing;
}(Interaction_1.default));
exports.default = EventResizing;


/***/ }),
/* 224 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var util_1 = __webpack_require__(4);
var EventDefMutation_1 = __webpack_require__(37);
var EventDefDateMutation_1 = __webpack_require__(50);
var DragListener_1 = __webpack_require__(54);
var HitDragListener_1 = __webpack_require__(23);
var MouseFollower_1 = __webpack_require__(244);
var Interaction_1 = __webpack_require__(15);
var EventDragging = /** @class */ (function (_super) {
    tslib_1.__extends(EventDragging, _super);
    /*
    component implements:
      - bindSegHandlerToEl
      - publiclyTrigger
      - diffDates
      - eventRangesToEventFootprints
      - isEventInstanceGroupAllowed
    */
    function EventDragging(component, eventPointing) {
        var _this = _super.call(this, component) || this;
        _this.isDragging = false;
        _this.eventPointing = eventPointing;
        return _this;
    }
    EventDragging.prototype.end = function () {
        if (this.dragListener) {
            this.dragListener.endInteraction();
        }
    };
    EventDragging.prototype.getSelectionDelay = function () {
        var delay = this.opt('eventLongPressDelay');
        if (delay == null) {
            delay = this.opt('longPressDelay'); // fallback
        }
        return delay;
    };
    EventDragging.prototype.bindToEl = function (el) {
        var component = this.component;
        component.bindSegHandlerToEl(el, 'mousedown', this.handleMousedown.bind(this));
        component.bindSegHandlerToEl(el, 'touchstart', this.handleTouchStart.bind(this));
    };
    EventDragging.prototype.handleMousedown = function (seg, ev) {
        if (!this.component.shouldIgnoreMouse() &&
            this.component.canStartDrag(seg, ev)) {
            this.buildDragListener(seg).startInteraction(ev, { distance: 5 });
        }
    };
    EventDragging.prototype.handleTouchStart = function (seg, ev) {
        var component = this.component;
        var settings = {
            delay: this.view.isEventDefSelected(seg.footprint.eventDef) ? // already selected?
                0 : this.getSelectionDelay()
        };
        if (component.canStartDrag(seg, ev)) {
            this.buildDragListener(seg).startInteraction(ev, settings);
        }
        else if (component.canStartSelection(seg, ev)) {
            this.buildSelectListener(seg).startInteraction(ev, settings);
        }
    };
    // seg isn't draggable, but let's use a generic DragListener
    // simply for the delay, so it can be selected.
    // Has side effect of setting/unsetting `dragListener`
    EventDragging.prototype.buildSelectListener = function (seg) {
        var _this = this;
        var view = this.view;
        var eventDef = seg.footprint.eventDef;
        var eventInstance = seg.footprint.eventInstance; // null for inverse-background events
        if (this.dragListener) {
            return this.dragListener;
        }
        var dragListener = this.dragListener = new DragListener_1.default({
            dragStart: function (ev) {
                if (dragListener.isTouch &&
                    !view.isEventDefSelected(eventDef) &&
                    eventInstance) {
                    // if not previously selected, will fire after a delay. then, select the event
                    view.selectEventInstance(eventInstance);
                }
            },
            interactionEnd: function (ev) {
                _this.dragListener = null;
            }
        });
        return dragListener;
    };
    // Builds a listener that will track user-dragging on an event segment.
    // Generic enough to work with any type of Grid.
    // Has side effect of setting/unsetting `dragListener`
    EventDragging.prototype.buildDragListener = function (seg) {
        var _this = this;
        var component = this.component;
        var view = this.view;
        var calendar = view.calendar;
        var eventManager = calendar.eventManager;
        var el = seg.el;
        var eventDef = seg.footprint.eventDef;
        var eventInstance = seg.footprint.eventInstance; // null for inverse-background events
        var isDragging;
        var mouseFollower; // A clone of the original element that will move with the mouse
        var eventDefMutation;
        if (this.dragListener) {
            return this.dragListener;
        }
        // Tracks mouse movement over the *view's* coordinate map. Allows dragging and dropping between subcomponents
        // of the view.
        var dragListener = this.dragListener = new HitDragListener_1.default(view, {
            scroll: this.opt('dragScroll'),
            subjectEl: el,
            subjectCenter: true,
            interactionStart: function (ev) {
                seg.component = component; // for renderDrag
                isDragging = false;
                mouseFollower = new MouseFollower_1.default(seg.el, {
                    additionalClass: 'fc-dragging',
                    parentEl: view.el,
                    opacity: dragListener.isTouch ? null : _this.opt('dragOpacity'),
                    revertDuration: _this.opt('dragRevertDuration'),
                    zIndex: 2 // one above the .fc-view
                });
                mouseFollower.hide(); // don't show until we know this is a real drag
                mouseFollower.start(ev);
            },
            dragStart: function (ev) {
                if (dragListener.isTouch &&
                    !view.isEventDefSelected(eventDef) &&
                    eventInstance) {
                    // if not previously selected, will fire after a delay. then, select the event
                    view.selectEventInstance(eventInstance);
                }
                isDragging = true;
                // ensure a mouseout on the manipulated event has been reported
                _this.eventPointing.handleMouseout(seg, ev);
                _this.segDragStart(seg, ev);
                view.hideEventsWithId(seg.footprint.eventDef.id);
            },
            hitOver: function (hit, isOrig, origHit) {
                var isAllowed = true;
                var origFootprint;
                var footprint;
                var mutatedEventInstanceGroup;
                // starting hit could be forced (DayGrid.limit)
                if (seg.hit) {
                    origHit = seg.hit;
                }
                // hit might not belong to this grid, so query origin grid
                origFootprint = origHit.component.getSafeHitFootprint(origHit);
                footprint = hit.component.getSafeHitFootprint(hit);
                if (origFootprint && footprint) {
                    eventDefMutation = _this.computeEventDropMutation(origFootprint, footprint, eventDef);
                    if (eventDefMutation) {
                        mutatedEventInstanceGroup = eventManager.buildMutatedEventInstanceGroup(eventDef.id, eventDefMutation);
                        isAllowed = component.isEventInstanceGroupAllowed(mutatedEventInstanceGroup);
                    }
                    else {
                        isAllowed = false;
                    }
                }
                else {
                    isAllowed = false;
                }
                if (!isAllowed) {
                    eventDefMutation = null;
                    util_1.disableCursor();
                }
                // if a valid drop location, have the subclass render a visual indication
                if (eventDefMutation &&
                    view.renderDrag(// truthy if rendered something
                    component.eventRangesToEventFootprints(mutatedEventInstanceGroup.sliceRenderRanges(component.dateProfile.renderUnzonedRange, calendar)), seg, dragListener.isTouch)) {
                    mouseFollower.hide(); // if the subclass is already using a mock event "helper", hide our own
                }
                else {
                    mouseFollower.show(); // otherwise, have the helper follow the mouse (no snapping)
                }
                if (isOrig) {
                    // needs to have moved hits to be a valid drop
                    eventDefMutation = null;
                }
            },
            hitOut: function () {
                view.unrenderDrag(seg); // unrender whatever was done in renderDrag
                mouseFollower.show(); // show in case we are moving out of all hits
                eventDefMutation = null;
            },
            hitDone: function () {
                util_1.enableCursor();
            },
            interactionEnd: function (ev) {
                delete seg.component; // prevent side effects
                // do revert animation if hasn't changed. calls a callback when finished (whether animation or not)
                mouseFollower.stop(!eventDefMutation, function () {
                    if (isDragging) {
                        view.unrenderDrag(seg);
                        _this.segDragStop(seg, ev);
                    }
                    view.showEventsWithId(seg.footprint.eventDef.id);
                    if (eventDefMutation) {
                        // no need to re-show original, will rerender all anyways. esp important if eventRenderWait
                        view.reportEventDrop(eventInstance, eventDefMutation, el, ev);
                    }
                });
                _this.dragListener = null;
            }
        });
        return dragListener;
    };
    // Called before event segment dragging starts
    EventDragging.prototype.segDragStart = function (seg, ev) {
        this.isDragging = true;
        this.component.publiclyTrigger('eventDragStart', {
            context: seg.el[0],
            args: [
                seg.footprint.getEventLegacy(),
                ev,
                {},
                this.view
            ]
        });
    };
    // Called after event segment dragging stops
    EventDragging.prototype.segDragStop = function (seg, ev) {
        this.isDragging = false;
        this.component.publiclyTrigger('eventDragStop', {
            context: seg.el[0],
            args: [
                seg.footprint.getEventLegacy(),
                ev,
                {},
                this.view
            ]
        });
    };
    // DOES NOT consider overlap/constraint
    EventDragging.prototype.computeEventDropMutation = function (startFootprint, endFootprint, eventDef) {
        var eventDefMutation = new EventDefMutation_1.default();
        eventDefMutation.setDateMutation(this.computeEventDateMutation(startFootprint, endFootprint));
        return eventDefMutation;
    };
    EventDragging.prototype.computeEventDateMutation = function (startFootprint, endFootprint) {
        var date0 = startFootprint.unzonedRange.getStart();
        var date1 = endFootprint.unzonedRange.getStart();
        var clearEnd = false;
        var forceTimed = false;
        var forceAllDay = false;
        var dateDelta;
        var dateMutation;
        if (startFootprint.isAllDay !== endFootprint.isAllDay) {
            clearEnd = true;
            if (endFootprint.isAllDay) {
                forceAllDay = true;
                date0.stripTime();
            }
            else {
                forceTimed = true;
            }
        }
        dateDelta = this.component.diffDates(date1, date0);
        dateMutation = new EventDefDateMutation_1.default();
        dateMutation.clearEnd = clearEnd;
        dateMutation.forceTimed = forceTimed;
        dateMutation.forceAllDay = forceAllDay;
        dateMutation.setDateDelta(dateDelta);
        return dateMutation;
    };
    return EventDragging;
}(Interaction_1.default));
exports.default = EventDragging;


/***/ }),
/* 225 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var util_1 = __webpack_require__(4);
var HitDragListener_1 = __webpack_require__(23);
var ComponentFootprint_1 = __webpack_require__(12);
var UnzonedRange_1 = __webpack_require__(5);
var Interaction_1 = __webpack_require__(15);
var DateSelecting = /** @class */ (function (_super) {
    tslib_1.__extends(DateSelecting, _super);
    /*
    component must implement:
      - bindDateHandlerToEl
      - getSafeHitFootprint
      - renderHighlight
      - unrenderHighlight
    */
    function DateSelecting(component) {
        var _this = _super.call(this, component) || this;
        _this.dragListener = _this.buildDragListener();
        return _this;
    }
    DateSelecting.prototype.end = function () {
        this.dragListener.endInteraction();
    };
    DateSelecting.prototype.getDelay = function () {
        var delay = this.opt('selectLongPressDelay');
        if (delay == null) {
            delay = this.opt('longPressDelay'); // fallback
        }
        return delay;
    };
    DateSelecting.prototype.bindToEl = function (el) {
        var _this = this;
        var component = this.component;
        var dragListener = this.dragListener;
        component.bindDateHandlerToEl(el, 'mousedown', function (ev) {
            if (_this.opt('selectable') && !component.shouldIgnoreMouse()) {
                dragListener.startInteraction(ev, {
                    distance: _this.opt('selectMinDistance')
                });
            }
        });
        component.bindDateHandlerToEl(el, 'touchstart', function (ev) {
            if (_this.opt('selectable') && !component.shouldIgnoreTouch()) {
                dragListener.startInteraction(ev, {
                    delay: _this.getDelay()
                });
            }
        });
        util_1.preventSelection(el);
    };
    // Creates a listener that tracks the user's drag across day elements, for day selecting.
    DateSelecting.prototype.buildDragListener = function () {
        var _this = this;
        var component = this.component;
        var selectionFootprint; // null if invalid selection
        var dragListener = new HitDragListener_1.default(component, {
            scroll: this.opt('dragScroll'),
            interactionStart: function () {
                selectionFootprint = null;
            },
            dragStart: function (ev) {
                _this.view.unselect(ev); // since we could be rendering a new selection, we want to clear any old one
            },
            hitOver: function (hit, isOrig, origHit) {
                var origHitFootprint;
                var hitFootprint;
                if (origHit) {
                    origHitFootprint = component.getSafeHitFootprint(origHit);
                    hitFootprint = component.getSafeHitFootprint(hit);
                    if (origHitFootprint && hitFootprint) {
                        selectionFootprint = _this.computeSelection(origHitFootprint, hitFootprint);
                    }
                    else {
                        selectionFootprint = null;
                    }
                    if (selectionFootprint) {
                        component.renderSelectionFootprint(selectionFootprint);
                    }
                    else if (selectionFootprint === false) {
                        util_1.disableCursor();
                    }
                }
            },
            hitOut: function () {
                selectionFootprint = null;
                component.unrenderSelection();
            },
            hitDone: function () {
                util_1.enableCursor();
            },
            interactionEnd: function (ev, isCancelled) {
                if (!isCancelled && selectionFootprint) {
                    // the selection will already have been rendered. just report it
                    _this.view.reportSelection(selectionFootprint, ev);
                }
            }
        });
        return dragListener;
    };
    // Given the first and last date-spans of a selection, returns another date-span object.
    // Subclasses can override and provide additional data in the span object. Will be passed to renderSelectionFootprint().
    // Will return false if the selection is invalid and this should be indicated to the user.
    // Will return null/undefined if a selection invalid but no error should be reported.
    DateSelecting.prototype.computeSelection = function (footprint0, footprint1) {
        var wholeFootprint = this.computeSelectionFootprint(footprint0, footprint1);
        if (wholeFootprint && !this.isSelectionFootprintAllowed(wholeFootprint)) {
            return false;
        }
        return wholeFootprint;
    };
    // Given two spans, must return the combination of the two.
    // TODO: do this separation of concerns (combining VS validation) for event dnd/resize too.
    // Assumes both footprints are non-open-ended.
    DateSelecting.prototype.computeSelectionFootprint = function (footprint0, footprint1) {
        var ms = [
            footprint0.unzonedRange.startMs,
            footprint0.unzonedRange.endMs,
            footprint1.unzonedRange.startMs,
            footprint1.unzonedRange.endMs
        ];
        ms.sort(util_1.compareNumbers);
        return new ComponentFootprint_1.default(new UnzonedRange_1.default(ms[0], ms[3]), footprint0.isAllDay);
    };
    DateSelecting.prototype.isSelectionFootprintAllowed = function (componentFootprint) {
        return this.component.dateProfile.validUnzonedRange.containsRange(componentFootprint.unzonedRange) &&
            this.view.calendar.constraints.isSelectionFootprintAllowed(componentFootprint);
    };
    return DateSelecting;
}(Interaction_1.default));
exports.default = DateSelecting;


/***/ }),
/* 226 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var moment = __webpack_require__(0);
var $ = __webpack_require__(3);
var util_1 = __webpack_require__(4);
var Scroller_1 = __webpack_require__(39);
var View_1 = __webpack_require__(41);
var TimeGrid_1 = __webpack_require__(227);
var DayGrid_1 = __webpack_require__(61);
var AGENDA_ALL_DAY_EVENT_LIMIT = 5;
var agendaTimeGridMethods;
var agendaDayGridMethods;
/* An abstract class for all agenda-related views. Displays one more columns with time slots running vertically.
----------------------------------------------------------------------------------------------------------------------*/
// Is a manager for the TimeGrid subcomponent and possibly the DayGrid subcomponent (if allDaySlot is on).
// Responsible for managing width/height.
var AgendaView = /** @class */ (function (_super) {
    tslib_1.__extends(AgendaView, _super);
    function AgendaView(calendar, viewSpec) {
        var _this = _super.call(this, calendar, viewSpec) || this;
        _this.usesMinMaxTime = true; // indicates that minTime/maxTime affects rendering
        _this.timeGrid = _this.instantiateTimeGrid();
        _this.addChild(_this.timeGrid);
        if (_this.opt('allDaySlot')) {
            _this.dayGrid = _this.instantiateDayGrid(); // the all-day subcomponent of this view
            _this.addChild(_this.dayGrid);
        }
        _this.scroller = new Scroller_1.default({
            overflowX: 'hidden',
            overflowY: 'auto'
        });
        return _this;
    }
    // Instantiates the TimeGrid object this view needs. Draws from this.timeGridClass
    AgendaView.prototype.instantiateTimeGrid = function () {
        var timeGrid = new this.timeGridClass(this);
        util_1.copyOwnProps(agendaTimeGridMethods, timeGrid);
        return timeGrid;
    };
    // Instantiates the DayGrid object this view might need. Draws from this.dayGridClass
    AgendaView.prototype.instantiateDayGrid = function () {
        var dayGrid = new this.dayGridClass(this);
        util_1.copyOwnProps(agendaDayGridMethods, dayGrid);
        return dayGrid;
    };
    /* Rendering
    ------------------------------------------------------------------------------------------------------------------*/
    AgendaView.prototype.renderSkeleton = function () {
        var timeGridWrapEl;
        var timeGridEl;
        this.el.addClass('fc-agenda-view').html(this.renderSkeletonHtml());
        this.scroller.render();
        timeGridWrapEl = this.scroller.el.addClass('fc-time-grid-container');
        timeGridEl = $('<div class="fc-time-grid" />').appendTo(timeGridWrapEl);
        this.el.find('.fc-body > tr > td').append(timeGridWrapEl);
        this.timeGrid.headContainerEl = this.el.find('.fc-head-container');
        this.timeGrid.setElement(timeGridEl);
        if (this.dayGrid) {
            this.dayGrid.setElement(this.el.find('.fc-day-grid'));
            // have the day-grid extend it's coordinate area over the <hr> dividing the two grids
            this.dayGrid.bottomCoordPadding = this.dayGrid.el.next('hr').outerHeight();
        }
    };
    AgendaView.prototype.unrenderSkeleton = function () {
        this.timeGrid.removeElement();
        if (this.dayGrid) {
            this.dayGrid.removeElement();
        }
        this.scroller.destroy();
    };
    // Builds the HTML skeleton for the view.
    // The day-grid and time-grid components will render inside containers defined by this HTML.
    AgendaView.prototype.renderSkeletonHtml = function () {
        var theme = this.calendar.theme;
        return '' +
            '<table class="' + theme.getClass('tableGrid') + '">' +
            (this.opt('columnHeader') ?
                '<thead class="fc-head">' +
                    '<tr>' +
                    '<td class="fc-head-container ' + theme.getClass('widgetHeader') + '">&nbsp;</td>' +
                    '</tr>' +
                    '</thead>' :
                '') +
            '<tbody class="fc-body">' +
            '<tr>' +
            '<td class="' + theme.getClass('widgetContent') + '">' +
            (this.dayGrid ?
                '<div class="fc-day-grid"/>' +
                    '<hr class="fc-divider ' + theme.getClass('widgetHeader') + '"/>' :
                '') +
            '</td>' +
            '</tr>' +
            '</tbody>' +
            '</table>';
    };
    // Generates an HTML attribute string for setting the width of the axis, if it is known
    AgendaView.prototype.axisStyleAttr = function () {
        if (this.axisWidth != null) {
            return 'style="width:' + this.axisWidth + 'px"';
        }
        return '';
    };
    /* Now Indicator
    ------------------------------------------------------------------------------------------------------------------*/
    AgendaView.prototype.getNowIndicatorUnit = function () {
        return this.timeGrid.getNowIndicatorUnit();
    };
    /* Dimensions
    ------------------------------------------------------------------------------------------------------------------*/
    // Adjusts the vertical dimensions of the view to the specified values
    AgendaView.prototype.updateSize = function (totalHeight, isAuto, isResize) {
        var eventLimit;
        var scrollerHeight;
        var scrollbarWidths;
        _super.prototype.updateSize.call(this, totalHeight, isAuto, isResize);
        // make all axis cells line up, and record the width so newly created axis cells will have it
        this.axisWidth = util_1.matchCellWidths(this.el.find('.fc-axis'));
        // hack to give the view some height prior to timeGrid's columns being rendered
        // TODO: separate setting height from scroller VS timeGrid.
        if (!this.timeGrid.colEls) {
            if (!isAuto) {
                scrollerHeight = this.computeScrollerHeight(totalHeight);
                this.scroller.setHeight(scrollerHeight);
            }
            return;
        }
        // set of fake row elements that must compensate when scroller has scrollbars
        var noScrollRowEls = this.el.find('.fc-row:not(.fc-scroller *)');
        // reset all dimensions back to the original state
        this.timeGrid.bottomRuleEl.hide(); // .show() will be called later if this <hr> is necessary
        this.scroller.clear(); // sets height to 'auto' and clears overflow
        util_1.uncompensateScroll(noScrollRowEls);
        // limit number of events in the all-day area
        if (this.dayGrid) {
            this.dayGrid.removeSegPopover(); // kill the "more" popover if displayed
            eventLimit = this.opt('eventLimit');
            if (eventLimit && typeof eventLimit !== 'number') {
                eventLimit = AGENDA_ALL_DAY_EVENT_LIMIT; // make sure "auto" goes to a real number
            }
            if (eventLimit) {
                this.dayGrid.limitRows(eventLimit);
            }
        }
        if (!isAuto) {
            scrollerHeight = this.computeScrollerHeight(totalHeight);
            this.scroller.setHeight(scrollerHeight);
            scrollbarWidths = this.scroller.getScrollbarWidths();
            if (scrollbarWidths.left || scrollbarWidths.right) {
                // make the all-day and header rows lines up
                util_1.compensateScroll(noScrollRowEls, scrollbarWidths);
                // the scrollbar compensation might have changed text flow, which might affect height, so recalculate
                // and reapply the desired height to the scroller.
                scrollerHeight = this.computeScrollerHeight(totalHeight);
                this.scroller.setHeight(scrollerHeight);
            }
            // guarantees the same scrollbar widths
            this.scroller.lockOverflow(scrollbarWidths);
            // if there's any space below the slats, show the horizontal rule.
            // this won't cause any new overflow, because lockOverflow already called.
            if (this.timeGrid.getTotalSlatHeight() < scrollerHeight) {
                this.timeGrid.bottomRuleEl.show();
            }
        }
    };
    // given a desired total height of the view, returns what the height of the scroller should be
    AgendaView.prototype.computeScrollerHeight = function (totalHeight) {
        return totalHeight -
            util_1.subtractInnerElHeight(this.el, this.scroller.el); // everything that's NOT the scroller
    };
    /* Scroll
    ------------------------------------------------------------------------------------------------------------------*/
    // Computes the initial pre-configured scroll state prior to allowing the user to change it
    AgendaView.prototype.computeInitialDateScroll = function () {
        var scrollTime = moment.duration(this.opt('scrollTime'));
        var top = this.timeGrid.computeTimeTop(scrollTime);
        // zoom can give weird floating-point values. rather scroll a little bit further
        top = Math.ceil(top);
        if (top) {
            top++; // to overcome top border that slots beyond the first have. looks better
        }
        return { top: top };
    };
    AgendaView.prototype.queryDateScroll = function () {
        return { top: this.scroller.getScrollTop() };
    };
    AgendaView.prototype.applyDateScroll = function (scroll) {
        if (scroll.top !== undefined) {
            this.scroller.setScrollTop(scroll.top);
        }
    };
    /* Hit Areas
    ------------------------------------------------------------------------------------------------------------------*/
    // forward all hit-related method calls to the grids (dayGrid might not be defined)
    AgendaView.prototype.getHitFootprint = function (hit) {
        // TODO: hit.component is set as a hack to identify where the hit came from
        return hit.component.getHitFootprint(hit);
    };
    AgendaView.prototype.getHitEl = function (hit) {
        // TODO: hit.component is set as a hack to identify where the hit came from
        return hit.component.getHitEl(hit);
    };
    /* Event Rendering
    ------------------------------------------------------------------------------------------------------------------*/
    AgendaView.prototype.executeEventRender = function (eventsPayload) {
        var dayEventsPayload = {};
        var timedEventsPayload = {};
        var id;
        var eventInstanceGroup;
        // separate the events into all-day and timed
        for (id in eventsPayload) {
            eventInstanceGroup = eventsPayload[id];
            if (eventInstanceGroup.getEventDef().isAllDay()) {
                dayEventsPayload[id] = eventInstanceGroup;
            }
            else {
                timedEventsPayload[id] = eventInstanceGroup;
            }
        }
        this.timeGrid.executeEventRender(timedEventsPayload);
        if (this.dayGrid) {
            this.dayGrid.executeEventRender(dayEventsPayload);
        }
    };
    /* Dragging/Resizing Routing
    ------------------------------------------------------------------------------------------------------------------*/
    // A returned value of `true` signals that a mock "helper" event has been rendered.
    AgendaView.prototype.renderDrag = function (eventFootprints, seg, isTouch) {
        var groups = groupEventFootprintsByAllDay(eventFootprints);
        var renderedHelper = false;
        renderedHelper = this.timeGrid.renderDrag(groups.timed, seg, isTouch);
        if (this.dayGrid) {
            renderedHelper = this.dayGrid.renderDrag(groups.allDay, seg, isTouch) || renderedHelper;
        }
        return renderedHelper;
    };
    AgendaView.prototype.renderEventResize = function (eventFootprints, seg, isTouch) {
        var groups = groupEventFootprintsByAllDay(eventFootprints);
        this.timeGrid.renderEventResize(groups.timed, seg, isTouch);
        if (this.dayGrid) {
            this.dayGrid.renderEventResize(groups.allDay, seg, isTouch);
        }
    };
    /* Selection
    ------------------------------------------------------------------------------------------------------------------*/
    // Renders a visual indication of a selection
    AgendaView.prototype.renderSelectionFootprint = function (componentFootprint) {
        if (!componentFootprint.isAllDay) {
            this.timeGrid.renderSelectionFootprint(componentFootprint);
        }
        else if (this.dayGrid) {
            this.dayGrid.renderSelectionFootprint(componentFootprint);
        }
    };
    return AgendaView;
}(View_1.default));
exports.default = AgendaView;
AgendaView.prototype.timeGridClass = TimeGrid_1.default;
AgendaView.prototype.dayGridClass = DayGrid_1.default;
// Will customize the rendering behavior of the AgendaView's timeGrid
agendaTimeGridMethods = {
    // Generates the HTML that will go before the day-of week header cells
    renderHeadIntroHtml: function () {
        var view = this.view;
        var calendar = view.calendar;
        var weekStart = calendar.msToUtcMoment(this.dateProfile.renderUnzonedRange.startMs, true);
        var weekText;
        if (this.opt('weekNumbers')) {
            weekText = weekStart.format(this.opt('smallWeekFormat'));
            return '' +
                '<th class="fc-axis fc-week-number ' + calendar.theme.getClass('widgetHeader') + '" ' + view.axisStyleAttr() + '>' +
                view.buildGotoAnchorHtml(// aside from link, important for matchCellWidths
                { date: weekStart, type: 'week', forceOff: this.colCnt > 1 }, util_1.htmlEscape(weekText) // inner HTML
                ) +
                '</th>';
        }
        else {
            return '<th class="fc-axis ' + calendar.theme.getClass('widgetHeader') + '" ' + view.axisStyleAttr() + '></th>';
        }
    },
    // Generates the HTML that goes before the bg of the TimeGrid slot area. Long vertical column.
    renderBgIntroHtml: function () {
        var view = this.view;
        return '<td class="fc-axis ' + view.calendar.theme.getClass('widgetContent') + '" ' + view.axisStyleAttr() + '></td>';
    },
    // Generates the HTML that goes before all other types of cells.
    // Affects content-skeleton, helper-skeleton, highlight-skeleton for both the time-grid and day-grid.
    renderIntroHtml: function () {
        var view = this.view;
        return '<td class="fc-axis" ' + view.axisStyleAttr() + '></td>';
    }
};
// Will customize the rendering behavior of the AgendaView's dayGrid
agendaDayGridMethods = {
    // Generates the HTML that goes before the all-day cells
    renderBgIntroHtml: function () {
        var view = this.view;
        return '' +
            '<td class="fc-axis ' + view.calendar.theme.getClass('widgetContent') + '" ' + view.axisStyleAttr() + '>' +
            '<span>' + // needed for matchCellWidths
            view.getAllDayHtml() +
            '</span>' +
            '</td>';
    },
    // Generates the HTML that goes before all other types of cells.
    // Affects content-skeleton, helper-skeleton, highlight-skeleton for both the time-grid and day-grid.
    renderIntroHtml: function () {
        var view = this.view;
        return '<td class="fc-axis" ' + view.axisStyleAttr() + '></td>';
    }
};
function groupEventFootprintsByAllDay(eventFootprints) {
    var allDay = [];
    var timed = [];
    var i;
    for (i = 0; i < eventFootprints.length; i++) {
        if (eventFootprints[i].componentFootprint.isAllDay) {
            allDay.push(eventFootprints[i]);
        }
        else {
            timed.push(eventFootprints[i]);
        }
    }
    return { allDay: allDay, timed: timed };
}


/***/ }),
/* 227 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var $ = __webpack_require__(3);
var moment = __webpack_require__(0);
var util_1 = __webpack_require__(4);
var InteractiveDateComponent_1 = __webpack_require__(40);
var BusinessHourRenderer_1 = __webpack_require__(56);
var StandardInteractionsMixin_1 = __webpack_require__(60);
var DayTableMixin_1 = __webpack_require__(55);
var CoordCache_1 = __webpack_require__(53);
var UnzonedRange_1 = __webpack_require__(5);
var ComponentFootprint_1 = __webpack_require__(12);
var TimeGridEventRenderer_1 = __webpack_require__(246);
var TimeGridHelperRenderer_1 = __webpack_require__(247);
var TimeGridFillRenderer_1 = __webpack_require__(248);
/* A component that renders one or more columns of vertical time slots
----------------------------------------------------------------------------------------------------------------------*/
// We mixin DayTable, even though there is only a single row of days
// potential nice values for the slot-duration and interval-duration
// from largest to smallest
var AGENDA_STOCK_SUB_DURATIONS = [
    { hours: 1 },
    { minutes: 30 },
    { minutes: 15 },
    { seconds: 30 },
    { seconds: 15 }
];
var TimeGrid = /** @class */ (function (_super) {
    tslib_1.__extends(TimeGrid, _super);
    function TimeGrid(view) {
        var _this = _super.call(this, view) || this;
        _this.processOptions();
        return _this;
    }
    // Slices up the given span (unzoned start/end with other misc data) into an array of segments
    TimeGrid.prototype.componentFootprintToSegs = function (componentFootprint) {
        var segs = this.sliceRangeByTimes(componentFootprint.unzonedRange);
        var i;
        for (i = 0; i < segs.length; i++) {
            if (this.isRTL) {
                segs[i].col = this.daysPerRow - 1 - segs[i].dayIndex;
            }
            else {
                segs[i].col = segs[i].dayIndex;
            }
        }
        return segs;
    };
    /* Date Handling
    ------------------------------------------------------------------------------------------------------------------*/
    TimeGrid.prototype.sliceRangeByTimes = function (unzonedRange) {
        var segs = [];
        var segRange;
        var dayIndex;
        for (dayIndex = 0; dayIndex < this.daysPerRow; dayIndex++) {
            segRange = unzonedRange.intersect(this.dayRanges[dayIndex]);
            if (segRange) {
                segs.push({
                    startMs: segRange.startMs,
                    endMs: segRange.endMs,
                    isStart: segRange.isStart,
                    isEnd: segRange.isEnd,
                    dayIndex: dayIndex
                });
            }
        }
        return segs;
    };
    /* Options
    ------------------------------------------------------------------------------------------------------------------*/
    // Parses various options into properties of this object
    TimeGrid.prototype.processOptions = function () {
        var slotDuration = this.opt('slotDuration');
        var snapDuration = this.opt('snapDuration');
        var input;
        slotDuration = moment.duration(slotDuration);
        snapDuration = snapDuration ? moment.duration(snapDuration) : slotDuration;
        this.slotDuration = slotDuration;
        this.snapDuration = snapDuration;
        this.snapsPerSlot = slotDuration / snapDuration; // TODO: ensure an integer multiple?
        // might be an array value (for TimelineView).
        // if so, getting the most granular entry (the last one probably).
        input = this.opt('slotLabelFormat');
        if ($.isArray(input)) {
            input = input[input.length - 1];
        }
        this.labelFormat = input ||
            this.opt('smallTimeFormat'); // the computed default
        input = this.opt('slotLabelInterval');
        this.labelInterval = input ?
            moment.duration(input) :
            this.computeLabelInterval(slotDuration);
    };
    // Computes an automatic value for slotLabelInterval
    TimeGrid.prototype.computeLabelInterval = function (slotDuration) {
        var i;
        var labelInterval;
        var slotsPerLabel;
        // find the smallest stock label interval that results in more than one slots-per-label
        for (i = AGENDA_STOCK_SUB_DURATIONS.length - 1; i >= 0; i--) {
            labelInterval = moment.duration(AGENDA_STOCK_SUB_DURATIONS[i]);
            slotsPerLabel = util_1.divideDurationByDuration(labelInterval, slotDuration);
            if (util_1.isInt(slotsPerLabel) && slotsPerLabel > 1) {
                return labelInterval;
            }
        }
        return moment.duration(slotDuration); // fall back. clone
    };
    /* Date Rendering
    ------------------------------------------------------------------------------------------------------------------*/
    TimeGrid.prototype.renderDates = function (dateProfile) {
        this.dateProfile = dateProfile;
        this.updateDayTable();
        this.renderSlats();
        this.renderColumns();
    };
    TimeGrid.prototype.unrenderDates = function () {
        // this.unrenderSlats(); // don't need this because repeated .html() calls clear
        this.unrenderColumns();
    };
    TimeGrid.prototype.renderSkeleton = function () {
        var theme = this.view.calendar.theme;
        this.el.html('<div class="fc-bg"></div>' +
            '<div class="fc-slats"></div>' +
            '<hr class="fc-divider ' + theme.getClass('widgetHeader') + '" style="display:none" />');
        this.bottomRuleEl = this.el.find('hr');
    };
    TimeGrid.prototype.renderSlats = function () {
        var theme = this.view.calendar.theme;
        this.slatContainerEl = this.el.find('> .fc-slats')
            .html(// avoids needing ::unrenderSlats()
        '<table class="' + theme.getClass('tableGrid') + '">' +
            this.renderSlatRowHtml() +
            '</table>');
        this.slatEls = this.slatContainerEl.find('tr');
        this.slatCoordCache = new CoordCache_1.default({
            els: this.slatEls,
            isVertical: true
        });
    };
    // Generates the HTML for the horizontal "slats" that run width-wise. Has a time axis on a side. Depends on RTL.
    TimeGrid.prototype.renderSlatRowHtml = function () {
        var view = this.view;
        var calendar = view.calendar;
        var theme = calendar.theme;
        var isRTL = this.isRTL;
        var dateProfile = this.dateProfile;
        var html = '';
        var slotTime = moment.duration(+dateProfile.minTime); // wish there was .clone() for durations
        var slotIterator = moment.duration(0);
        var slotDate; // will be on the view's first day, but we only care about its time
        var isLabeled;
        var axisHtml;
        // Calculate the time for each slot
        while (slotTime < dateProfile.maxTime) {
            slotDate = calendar.msToUtcMoment(dateProfile.renderUnzonedRange.startMs).time(slotTime);
            isLabeled = util_1.isInt(util_1.divideDurationByDuration(slotIterator, this.labelInterval));
            axisHtml =
                '<td class="fc-axis fc-time ' + theme.getClass('widgetContent') + '" ' + view.axisStyleAttr() + '>' +
                    (isLabeled ?
                        '<span>' + // for matchCellWidths
                            util_1.htmlEscape(slotDate.format(this.labelFormat)) +
                            '</span>' :
                        '') +
                    '</td>';
            html +=
                '<tr data-time="' + slotDate.format('HH:mm:ss') + '"' +
                    (isLabeled ? '' : ' class="fc-minor"') +
                    '>' +
                    (!isRTL ? axisHtml : '') +
                    '<td class="' + theme.getClass('widgetContent') + '"/>' +
                    (isRTL ? axisHtml : '') +
                    '</tr>';
            slotTime.add(this.slotDuration);
            slotIterator.add(this.slotDuration);
        }
        return html;
    };
    TimeGrid.prototype.renderColumns = function () {
        var dateProfile = this.dateProfile;
        var theme = this.view.calendar.theme;
        this.dayRanges = this.dayDates.map(function (dayDate) {
            return new UnzonedRange_1.default(dayDate.clone().add(dateProfile.minTime), dayDate.clone().add(dateProfile.maxTime));
        });
        if (this.headContainerEl) {
            this.headContainerEl.html(this.renderHeadHtml());
        }
        this.el.find('> .fc-bg').html('<table class="' + theme.getClass('tableGrid') + '">' +
            this.renderBgTrHtml(0) + // row=0
            '</table>');
        this.colEls = this.el.find('.fc-day, .fc-disabled-day');
        this.colCoordCache = new CoordCache_1.default({
            els: this.colEls,
            isHorizontal: true
        });
        this.renderContentSkeleton();
    };
    TimeGrid.prototype.unrenderColumns = function () {
        this.unrenderContentSkeleton();
    };
    /* Content Skeleton
    ------------------------------------------------------------------------------------------------------------------*/
    // Renders the DOM that the view's content will live in
    TimeGrid.prototype.renderContentSkeleton = function () {
        var cellHtml = '';
        var i;
        var skeletonEl;
        for (i = 0; i < this.colCnt; i++) {
            cellHtml +=
                '<td>' +
                    '<div class="fc-content-col">' +
                    '<div class="fc-event-container fc-helper-container"></div>' +
                    '<div class="fc-event-container"></div>' +
                    '<div class="fc-highlight-container"></div>' +
                    '<div class="fc-bgevent-container"></div>' +
                    '<div class="fc-business-container"></div>' +
                    '</div>' +
                    '</td>';
        }
        skeletonEl = this.contentSkeletonEl = $('<div class="fc-content-skeleton">' +
            '<table>' +
            '<tr>' + cellHtml + '</tr>' +
            '</table>' +
            '</div>');
        this.colContainerEls = skeletonEl.find('.fc-content-col');
        this.helperContainerEls = skeletonEl.find('.fc-helper-container');
        this.fgContainerEls = skeletonEl.find('.fc-event-container:not(.fc-helper-container)');
        this.bgContainerEls = skeletonEl.find('.fc-bgevent-container');
        this.highlightContainerEls = skeletonEl.find('.fc-highlight-container');
        this.businessContainerEls = skeletonEl.find('.fc-business-container');
        this.bookendCells(skeletonEl.find('tr')); // TODO: do this on string level
        this.el.append(skeletonEl);
    };
    TimeGrid.prototype.unrenderContentSkeleton = function () {
        if (this.contentSkeletonEl) {
            this.contentSkeletonEl.remove();
            this.contentSkeletonEl = null;
            this.colContainerEls = null;
            this.helperContainerEls = null;
            this.fgContainerEls = null;
            this.bgContainerEls = null;
            this.highlightContainerEls = null;
            this.businessContainerEls = null;
        }
    };
    // Given a flat array of segments, return an array of sub-arrays, grouped by each segment's col
    TimeGrid.prototype.groupSegsByCol = function (segs) {
        var segsByCol = [];
        var i;
        for (i = 0; i < this.colCnt; i++) {
            segsByCol.push([]);
        }
        for (i = 0; i < segs.length; i++) {
            segsByCol[segs[i].col].push(segs[i]);
        }
        return segsByCol;
    };
    // Given segments grouped by column, insert the segments' elements into a parallel array of container
    // elements, each living within a column.
    TimeGrid.prototype.attachSegsByCol = function (segsByCol, containerEls) {
        var col;
        var segs;
        var i;
        for (col = 0; col < this.colCnt; col++) {
            segs = segsByCol[col];
            for (i = 0; i < segs.length; i++) {
                containerEls.eq(col).append(segs[i].el);
            }
        }
    };
    /* Now Indicator
    ------------------------------------------------------------------------------------------------------------------*/
    TimeGrid.prototype.getNowIndicatorUnit = function () {
        return 'minute'; // will refresh on the minute
    };
    TimeGrid.prototype.renderNowIndicator = function (date) {
        // HACK: if date columns not ready for some reason (scheduler)
        if (!this.colContainerEls) {
            return;
        }
        // seg system might be overkill, but it handles scenario where line needs to be rendered
        //  more than once because of columns with the same date (resources columns for example)
        var segs = this.componentFootprintToSegs(new ComponentFootprint_1.default(new UnzonedRange_1.default(date, date.valueOf() + 1), // protect against null range
        false // all-day
        ));
        var top = this.computeDateTop(date, date);
        var nodes = [];
        var i;
        // render lines within the columns
        for (i = 0; i < segs.length; i++) {
            nodes.push($('<div class="fc-now-indicator fc-now-indicator-line"></div>')
                .css('top', top)
                .appendTo(this.colContainerEls.eq(segs[i].col))[0]);
        }
        // render an arrow over the axis
        if (segs.length > 0) {
            nodes.push($('<div class="fc-now-indicator fc-now-indicator-arrow"></div>')
                .css('top', top)
                .appendTo(this.el.find('.fc-content-skeleton'))[0]);
        }
        this.nowIndicatorEls = $(nodes);
    };
    TimeGrid.prototype.unrenderNowIndicator = function () {
        if (this.nowIndicatorEls) {
            this.nowIndicatorEls.remove();
            this.nowIndicatorEls = null;
        }
    };
    /* Coordinates
    ------------------------------------------------------------------------------------------------------------------*/
    TimeGrid.prototype.updateSize = function (totalHeight, isAuto, isResize) {
        _super.prototype.updateSize.call(this, totalHeight, isAuto, isResize);
        this.slatCoordCache.build();
        if (isResize) {
            this.updateSegVerticals([].concat(this.eventRenderer.getSegs(), this.businessSegs || []));
        }
    };
    TimeGrid.prototype.getTotalSlatHeight = function () {
        return this.slatContainerEl.outerHeight();
    };
    // Computes the top coordinate, relative to the bounds of the grid, of the given date.
    // `ms` can be a millisecond UTC time OR a UTC moment.
    // A `startOfDayDate` must be given for avoiding ambiguity over how to treat midnight.
    TimeGrid.prototype.computeDateTop = function (ms, startOfDayDate) {
        return this.computeTimeTop(moment.duration(ms - startOfDayDate.clone().stripTime()));
    };
    // Computes the top coordinate, relative to the bounds of the grid, of the given time (a Duration).
    TimeGrid.prototype.computeTimeTop = function (time) {
        var len = this.slatEls.length;
        var dateProfile = this.dateProfile;
        var slatCoverage = (time - dateProfile.minTime) / this.slotDuration; // floating-point value of # of slots covered
        var slatIndex;
        var slatRemainder;
        // compute a floating-point number for how many slats should be progressed through.
        // from 0 to number of slats (inclusive)
        // constrained because minTime/maxTime might be customized.
        slatCoverage = Math.max(0, slatCoverage);
        slatCoverage = Math.min(len, slatCoverage);
        // an integer index of the furthest whole slat
        // from 0 to number slats (*exclusive*, so len-1)
        slatIndex = Math.floor(slatCoverage);
        slatIndex = Math.min(slatIndex, len - 1);
        // how much further through the slatIndex slat (from 0.0-1.0) must be covered in addition.
        // could be 1.0 if slatCoverage is covering *all* the slots
        slatRemainder = slatCoverage - slatIndex;
        return this.slatCoordCache.getTopPosition(slatIndex) +
            this.slatCoordCache.getHeight(slatIndex) * slatRemainder;
    };
    // Refreshes the CSS top/bottom coordinates for each segment element.
    // Works when called after initial render, after a window resize/zoom for example.
    TimeGrid.prototype.updateSegVerticals = function (segs) {
        this.computeSegVerticals(segs);
        this.assignSegVerticals(segs);
    };
    // For each segment in an array, computes and assigns its top and bottom properties
    TimeGrid.prototype.computeSegVerticals = function (segs) {
        var eventMinHeight = this.opt('agendaEventMinHeight');
        var i;
        var seg;
        var dayDate;
        for (i = 0; i < segs.length; i++) {
            seg = segs[i];
            dayDate = this.dayDates[seg.dayIndex];
            seg.top = this.computeDateTop(seg.startMs, dayDate);
            seg.bottom = Math.max(seg.top + eventMinHeight, this.computeDateTop(seg.endMs, dayDate));
        }
    };
    // Given segments that already have their top/bottom properties computed, applies those values to
    // the segments' elements.
    TimeGrid.prototype.assignSegVerticals = function (segs) {
        var i;
        var seg;
        for (i = 0; i < segs.length; i++) {
            seg = segs[i];
            seg.el.css(this.generateSegVerticalCss(seg));
        }
    };
    // Generates an object with CSS properties for the top/bottom coordinates of a segment element
    TimeGrid.prototype.generateSegVerticalCss = function (seg) {
        return {
            top: seg.top,
            bottom: -seg.bottom // flipped because needs to be space beyond bottom edge of event container
        };
    };
    /* Hit System
    ------------------------------------------------------------------------------------------------------------------*/
    TimeGrid.prototype.prepareHits = function () {
        this.colCoordCache.build();
        this.slatCoordCache.build();
    };
    TimeGrid.prototype.releaseHits = function () {
        this.colCoordCache.clear();
        // NOTE: don't clear slatCoordCache because we rely on it for computeTimeTop
    };
    TimeGrid.prototype.queryHit = function (leftOffset, topOffset) {
        var snapsPerSlot = this.snapsPerSlot;
        var colCoordCache = this.colCoordCache;
        var slatCoordCache = this.slatCoordCache;
        if (colCoordCache.isLeftInBounds(leftOffset) && slatCoordCache.isTopInBounds(topOffset)) {
            var colIndex = colCoordCache.getHorizontalIndex(leftOffset);
            var slatIndex = slatCoordCache.getVerticalIndex(topOffset);
            if (colIndex != null && slatIndex != null) {
                var slatTop = slatCoordCache.getTopOffset(slatIndex);
                var slatHeight = slatCoordCache.getHeight(slatIndex);
                var partial = (topOffset - slatTop) / slatHeight; // floating point number between 0 and 1
                var localSnapIndex = Math.floor(partial * snapsPerSlot); // the snap # relative to start of slat
                var snapIndex = slatIndex * snapsPerSlot + localSnapIndex;
                var snapTop = slatTop + (localSnapIndex / snapsPerSlot) * slatHeight;
                var snapBottom = slatTop + ((localSnapIndex + 1) / snapsPerSlot) * slatHeight;
                return {
                    col: colIndex,
                    snap: snapIndex,
                    component: this,
                    left: colCoordCache.getLeftOffset(colIndex),
                    right: colCoordCache.getRightOffset(colIndex),
                    top: snapTop,
                    bottom: snapBottom
                };
            }
        }
    };
    TimeGrid.prototype.getHitFootprint = function (hit) {
        var start = this.getCellDate(0, hit.col); // row=0
        var time = this.computeSnapTime(hit.snap); // pass in the snap-index
        var end;
        start.time(time);
        end = start.clone().add(this.snapDuration);
        return new ComponentFootprint_1.default(new UnzonedRange_1.default(start, end), false // all-day?
        );
    };
    // Given a row number of the grid, representing a "snap", returns a time (Duration) from its start-of-day
    TimeGrid.prototype.computeSnapTime = function (snapIndex) {
        return moment.duration(this.dateProfile.minTime + this.snapDuration * snapIndex);
    };
    TimeGrid.prototype.getHitEl = function (hit) {
        return this.colEls.eq(hit.col);
    };
    /* Event Drag Visualization
    ------------------------------------------------------------------------------------------------------------------*/
    // Renders a visual indication of an event being dragged over the specified date(s).
    // A returned value of `true` signals that a mock "helper" event has been rendered.
    TimeGrid.prototype.renderDrag = function (eventFootprints, seg, isTouch) {
        var i;
        if (seg) {
            if (eventFootprints.length) {
                this.helperRenderer.renderEventDraggingFootprints(eventFootprints, seg, isTouch);
                // signal that a helper has been rendered
                return true;
            }
        }
        else {
            for (i = 0; i < eventFootprints.length; i++) {
                this.renderHighlight(eventFootprints[i].componentFootprint);
            }
        }
    };
    // Unrenders any visual indication of an event being dragged
    TimeGrid.prototype.unrenderDrag = function () {
        this.unrenderHighlight();
        this.helperRenderer.unrender();
    };
    /* Event Resize Visualization
    ------------------------------------------------------------------------------------------------------------------*/
    // Renders a visual indication of an event being resized
    TimeGrid.prototype.renderEventResize = function (eventFootprints, seg, isTouch) {
        this.helperRenderer.renderEventResizingFootprints(eventFootprints, seg, isTouch);
    };
    // Unrenders any visual indication of an event being resized
    TimeGrid.prototype.unrenderEventResize = function () {
        this.helperRenderer.unrender();
    };
    /* Selection
    ------------------------------------------------------------------------------------------------------------------*/
    // Renders a visual indication of a selection. Overrides the default, which was to simply render a highlight.
    TimeGrid.prototype.renderSelectionFootprint = function (componentFootprint) {
        if (this.opt('selectHelper')) {
            this.helperRenderer.renderComponentFootprint(componentFootprint);
        }
        else {
            this.renderHighlight(componentFootprint);
        }
    };
    // Unrenders any visual indication of a selection
    TimeGrid.prototype.unrenderSelection = function () {
        this.helperRenderer.unrender();
        this.unrenderHighlight();
    };
    return TimeGrid;
}(InteractiveDateComponent_1.default));
exports.default = TimeGrid;
TimeGrid.prototype.eventRendererClass = TimeGridEventRenderer_1.default;
TimeGrid.prototype.businessHourRendererClass = BusinessHourRenderer_1.default;
TimeGrid.prototype.helperRendererClass = TimeGridHelperRenderer_1.default;
TimeGrid.prototype.fillRendererClass = TimeGridFillRenderer_1.default;
StandardInteractionsMixin_1.default.mixInto(TimeGrid);
DayTableMixin_1.default.mixInto(TimeGrid);


/***/ }),
/* 228 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var UnzonedRange_1 = __webpack_require__(5);
var DateProfileGenerator_1 = __webpack_require__(221);
var BasicViewDateProfileGenerator = /** @class */ (function (_super) {
    tslib_1.__extends(BasicViewDateProfileGenerator, _super);
    function BasicViewDateProfileGenerator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    // Computes the date range that will be rendered.
    BasicViewDateProfileGenerator.prototype.buildRenderRange = function (currentUnzonedRange, currentRangeUnit, isRangeAllDay) {
        var renderUnzonedRange = _super.prototype.buildRenderRange.call(this, currentUnzonedRange, currentRangeUnit, isRangeAllDay); // an UnzonedRange
        var start = this.msToUtcMoment(renderUnzonedRange.startMs, isRangeAllDay);
        var end = this.msToUtcMoment(renderUnzonedRange.endMs, isRangeAllDay);
        // year and month views should be aligned with weeks. this is already done for week
        if (/^(year|month)$/.test(currentRangeUnit)) {
            start.startOf('week');
            // make end-of-week if not already
            if (end.weekday()) {
                end.add(1, 'week').startOf('week'); // exclusively move backwards
            }
        }
        return new UnzonedRange_1.default(start, end);
    };
    return BasicViewDateProfileGenerator;
}(DateProfileGenerator_1.default));
exports.default = BasicViewDateProfileGenerator;


/***/ }),
/* 229 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var moment = __webpack_require__(0);
var util_1 = __webpack_require__(4);
var BasicView_1 = __webpack_require__(62);
var MonthViewDateProfileGenerator_1 = __webpack_require__(253);
/* A month view with day cells running in rows (one-per-week) and columns
----------------------------------------------------------------------------------------------------------------------*/
var MonthView = /** @class */ (function (_super) {
    tslib_1.__extends(MonthView, _super);
    function MonthView() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    // Overrides the default BasicView behavior to have special multi-week auto-height logic
    MonthView.prototype.setGridHeight = function (height, isAuto) {
        // if auto, make the height of each row the height that it would be if there were 6 weeks
        if (isAuto) {
            height *= this.dayGrid.rowCnt / 6;
        }
        util_1.distributeHeight(this.dayGrid.rowEls, height, !isAuto); // if auto, don't compensate for height-hogging rows
    };
    MonthView.prototype.isDateInOtherMonth = function (date, dateProfile) {
        return date.month() !== moment.utc(dateProfile.currentUnzonedRange.startMs).month(); // TODO: optimize
    };
    return MonthView;
}(BasicView_1.default));
exports.default = MonthView;
MonthView.prototype.dateProfileGeneratorClass = MonthViewDateProfileGenerator_1.default;


/***/ }),
/* 230 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var $ = __webpack_require__(3);
var util_1 = __webpack_require__(4);
var UnzonedRange_1 = __webpack_require__(5);
var View_1 = __webpack_require__(41);
var Scroller_1 = __webpack_require__(39);
var ListEventRenderer_1 = __webpack_require__(254);
var ListEventPointing_1 = __webpack_require__(255);
/*
Responsible for the scroller, and forwarding event-related actions into the "grid".
*/
var ListView = /** @class */ (function (_super) {
    tslib_1.__extends(ListView, _super);
    function ListView(calendar, viewSpec) {
        var _this = _super.call(this, calendar, viewSpec) || this;
        _this.segSelector = '.fc-list-item'; // which elements accept event actions
        _this.scroller = new Scroller_1.default({
            overflowX: 'hidden',
            overflowY: 'auto'
        });
        return _this;
    }
    ListView.prototype.renderSkeleton = function () {
        this.el.addClass('fc-list-view ' +
            this.calendar.theme.getClass('listView'));
        this.scroller.render();
        this.scroller.el.appendTo(this.el);
        this.contentEl = this.scroller.scrollEl; // shortcut
    };
    ListView.prototype.unrenderSkeleton = function () {
        this.scroller.destroy(); // will remove the Grid too
    };
    ListView.prototype.updateSize = function (totalHeight, isAuto, isResize) {
        _super.prototype.updateSize.call(this, totalHeight, isAuto, isResize);
        this.scroller.clear(); // sets height to 'auto' and clears overflow
        if (!isAuto) {
            this.scroller.setHeight(this.computeScrollerHeight(totalHeight));
        }
    };
    ListView.prototype.computeScrollerHeight = function (totalHeight) {
        return totalHeight -
            util_1.subtractInnerElHeight(this.el, this.scroller.el); // everything that's NOT the scroller
    };
    ListView.prototype.renderDates = function (dateProfile) {
        var calendar = this.calendar;
        var dayStart = calendar.msToUtcMoment(dateProfile.renderUnzonedRange.startMs, true);
        var viewEnd = calendar.msToUtcMoment(dateProfile.renderUnzonedRange.endMs, true);
        var dayDates = [];
        var dayRanges = [];
        while (dayStart < viewEnd) {
            dayDates.push(dayStart.clone());
            dayRanges.push(new UnzonedRange_1.default(dayStart, dayStart.clone().add(1, 'day')));
            dayStart.add(1, 'day');
        }
        this.dayDates = dayDates;
        this.dayRanges = dayRanges;
        // all real rendering happens in EventRenderer
    };
    // slices by day
    ListView.prototype.componentFootprintToSegs = function (footprint) {
        var dayRanges = this.dayRanges;
        var dayIndex;
        var segRange;
        var seg;
        var segs = [];
        for (dayIndex = 0; dayIndex < dayRanges.length; dayIndex++) {
            segRange = footprint.unzonedRange.intersect(dayRanges[dayIndex]);
            if (segRange) {
                seg = {
                    startMs: segRange.startMs,
                    endMs: segRange.endMs,
                    isStart: segRange.isStart,
                    isEnd: segRange.isEnd,
                    dayIndex: dayIndex
                };
                segs.push(seg);
                // detect when footprint won't go fully into the next day,
                // and mutate the latest seg to the be the end.
                if (!seg.isEnd && !footprint.isAllDay &&
                    dayIndex + 1 < dayRanges.length &&
                    footprint.unzonedRange.endMs < dayRanges[dayIndex + 1].startMs + this.nextDayThreshold) {
                    seg.endMs = footprint.unzonedRange.endMs;
                    seg.isEnd = true;
                    break;
                }
            }
        }
        return segs;
    };
    ListView.prototype.renderEmptyMessage = function () {
        this.contentEl.html('<div class="fc-list-empty-wrap2">' + // TODO: try less wraps
            '<div class="fc-list-empty-wrap1">' +
            '<div class="fc-list-empty">' +
            util_1.htmlEscape(this.opt('noEventsMessage')) +
            '</div>' +
            '</div>' +
            '</div>');
    };
    // render the event segments in the view
    ListView.prototype.renderSegList = function (allSegs) {
        var segsByDay = this.groupSegsByDay(allSegs); // sparse array
        var dayIndex;
        var daySegs;
        var i;
        var tableEl = $('<table class="fc-list-table ' + this.calendar.theme.getClass('tableList') + '"><tbody/></table>');
        var tbodyEl = tableEl.find('tbody');
        for (dayIndex = 0; dayIndex < segsByDay.length; dayIndex++) {
            daySegs = segsByDay[dayIndex];
            if (daySegs) {
                // append a day header
                tbodyEl.append(this.dayHeaderHtml(this.dayDates[dayIndex]));
                this.eventRenderer.sortEventSegs(daySegs);
                for (i = 0; i < daySegs.length; i++) {
                    tbodyEl.append(daySegs[i].el); // append event row
                }
            }
        }
        this.contentEl.empty().append(tableEl);
    };
    // Returns a sparse array of arrays, segs grouped by their dayIndex
    ListView.prototype.groupSegsByDay = function (segs) {
        var segsByDay = []; // sparse array
        var i;
        var seg;
        for (i = 0; i < segs.length; i++) {
            seg = segs[i];
            (segsByDay[seg.dayIndex] || (segsByDay[seg.dayIndex] = []))
                .push(seg);
        }
        return segsByDay;
    };
    // generates the HTML for the day headers that live amongst the event rows
    ListView.prototype.dayHeaderHtml = function (dayDate) {
        var mainFormat = this.opt('listDayFormat');
        var altFormat = this.opt('listDayAltFormat');
        return '<tr class="fc-list-heading" data-date="' + dayDate.format('YYYY-MM-DD') + '">' +
            '<td class="' + (this.calendar.theme.getClass('tableListHeading') ||
            this.calendar.theme.getClass('widgetHeader')) + '" colspan="3">' +
            (mainFormat ?
                this.buildGotoAnchorHtml(dayDate, { 'class': 'fc-list-heading-main' }, util_1.htmlEscape(dayDate.format(mainFormat)) // inner HTML
                ) :
                '') +
            (altFormat ?
                this.buildGotoAnchorHtml(dayDate, { 'class': 'fc-list-heading-alt' }, util_1.htmlEscape(dayDate.format(altFormat)) // inner HTML
                ) :
                '') +
            '</td>' +
            '</tr>';
    };
    return ListView;
}(View_1.default));
exports.default = ListView;
ListView.prototype.eventRendererClass = ListEventRenderer_1.default;
ListView.prototype.eventPointingClass = ListEventPointing_1.default;


/***/ }),
/* 231 */,
/* 232 */,
/* 233 */,
/* 234 */,
/* 235 */,
/* 236 */
/***/ (function(module, exports, __webpack_require__) {

var $ = __webpack_require__(3);
var exportHooks = __webpack_require__(16);
var util_1 = __webpack_require__(4);
var Calendar_1 = __webpack_require__(220);
// for intentional side-effects
__webpack_require__(10);
__webpack_require__(47);
__webpack_require__(256);
__webpack_require__(257);
__webpack_require__(260);
__webpack_require__(261);
__webpack_require__(262);
__webpack_require__(263);
$.fullCalendar = exportHooks;
$.fn.fullCalendar = function (options) {
    var args = Array.prototype.slice.call(arguments, 1); // for a possible method call
    var res = this; // what this function will return (this jQuery object by default)
    this.each(function (i, _element) {
        var element = $(_element);
        var calendar = element.data('fullCalendar'); // get the existing calendar object (if any)
        var singleRes; // the returned value of this single method call
        // a method call
        if (typeof options === 'string') {
            if (options === 'getCalendar') {
                if (!i) {
                    res = calendar;
                }
            }
            else if (options === 'destroy') {
                if (calendar) {
                    calendar.destroy();
                    element.removeData('fullCalendar');
                }
            }
            else if (!calendar) {
                util_1.warn('Attempting to call a FullCalendar method on an element with no calendar.');
            }
            else if ($.isFunction(calendar[options])) {
                singleRes = calendar[options].apply(calendar, args);
                if (!i) {
                    res = singleRes; // record the first method call result
                }
                if (options === 'destroy') {
                    element.removeData('fullCalendar');
                }
            }
            else {
                util_1.warn("'" + options + "' is an unknown FullCalendar method.");
            }
        }
        else if (!calendar) {
            calendar = new Calendar_1.default(element, options);
            element.data('fullCalendar', calendar);
            calendar.render();
        }
    });
    return res;
};
module.exports = exportHooks;


/***/ }),
/* 237 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var Model_1 = __webpack_require__(48);
var Component = /** @class */ (function (_super) {
    tslib_1.__extends(Component, _super);
    function Component() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Component.prototype.setElement = function (el) {
        this.el = el;
        this.bindGlobalHandlers();
        this.renderSkeleton();
        this.set('isInDom', true);
    };
    Component.prototype.removeElement = function () {
        this.unset('isInDom');
        this.unrenderSkeleton();
        this.unbindGlobalHandlers();
        this.el.remove();
        // NOTE: don't null-out this.el in case the View was destroyed within an API callback.
        // We don't null-out the View's other jQuery element references upon destroy,
        //  so we shouldn't kill this.el either.
    };
    Component.prototype.bindGlobalHandlers = function () {
        // subclasses can override
    };
    Component.prototype.unbindGlobalHandlers = function () {
        // subclasses can override
    };
    /*
    NOTE: Can't have a `render` method. Read the deprecation notice in View::executeDateRender
    */
    // Renders the basic structure of the view before any content is rendered
    Component.prototype.renderSkeleton = function () {
        // subclasses should implement
    };
    // Unrenders the basic structure of the view
    Component.prototype.unrenderSkeleton = function () {
        // subclasses should implement
    };
    return Component;
}(Model_1.default));
exports.default = Component;


/***/ }),
/* 238 */
/***/ (function(module, exports) {

Object.defineProperty(exports, "__esModule", { value: true });
var Iterator = /** @class */ (function () {
    function Iterator(items) {
        this.items = items || [];
    }
    /* Calls a method on every item passing the arguments through */
    Iterator.prototype.proxyCall = function (methodName) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        var results = [];
        this.items.forEach(function (item) {
            results.push(item[methodName].apply(item, args));
        });
        return results;
    };
    return Iterator;
}());
exports.default = Iterator;


/***/ }),
/* 239 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var $ = __webpack_require__(3);
var util_1 = __webpack_require__(4);
/* Toolbar with buttons and title
----------------------------------------------------------------------------------------------------------------------*/
var Toolbar = /** @class */ (function () {
    function Toolbar(calendar, toolbarOptions) {
        this.el = null; // mirrors local `el`
        this.viewsWithButtons = [];
        this.calendar = calendar;
        this.toolbarOptions = toolbarOptions;
    }
    // method to update toolbar-specific options, not calendar-wide options
    Toolbar.prototype.setToolbarOptions = function (newToolbarOptions) {
        this.toolbarOptions = newToolbarOptions;
    };
    // can be called repeatedly and will rerender
    Toolbar.prototype.render = function () {
        var sections = this.toolbarOptions.layout;
        var el = this.el;
        if (sections) {
            if (!el) {
                el = this.el = $("<div class='fc-toolbar " + this.toolbarOptions.extraClasses + "'/>");
            }
            else {
                el.empty();
            }
            el.append(this.renderSection('left'))
                .append(this.renderSection('right'))
                .append(this.renderSection('center'))
                .append('<div class="fc-clear"/>');
        }
        else {
            this.removeElement();
        }
    };
    Toolbar.prototype.removeElement = function () {
        if (this.el) {
            this.el.remove();
            this.el = null;
        }
    };
    Toolbar.prototype.renderSection = function (position) {
        var _this = this;
        var calendar = this.calendar;
        var theme = calendar.theme;
        var optionsManager = calendar.optionsManager;
        var viewSpecManager = calendar.viewSpecManager;
        var sectionEl = $('<div class="fc-' + position + '"/>');
        var buttonStr = this.toolbarOptions.layout[position];
        var calendarCustomButtons = optionsManager.get('customButtons') || {};
        var calendarButtonTextOverrides = optionsManager.overrides.buttonText || {};
        var calendarButtonText = optionsManager.get('buttonText') || {};
        if (buttonStr) {
            $.each(buttonStr.split(' '), function (i, buttonGroupStr) {
                var groupChildren = $();
                var isOnlyButtons = true;
                var groupEl;
                $.each(buttonGroupStr.split(','), function (j, buttonName) {
                    var customButtonProps;
                    var viewSpec;
                    var buttonClick;
                    var buttonIcon; // only one of these will be set
                    var buttonText; // "
                    var buttonInnerHtml;
                    var buttonClasses;
                    var buttonEl;
                    var buttonAriaAttr;
                    if (buttonName === 'title') {
                        groupChildren = groupChildren.add($('<h2>&nbsp;</h2>')); // we always want it to take up height
                        isOnlyButtons = false;
                    }
                    else {
                        if ((customButtonProps = calendarCustomButtons[buttonName])) {
                            buttonClick = function (ev) {
                                if (customButtonProps.click) {
                                    customButtonProps.click.call(buttonEl[0], ev);
                                }
                            };
                            (buttonIcon = theme.getCustomButtonIconClass(customButtonProps)) ||
                                (buttonIcon = theme.getIconClass(buttonName)) ||
                                (buttonText = customButtonProps.text);
                        }
                        else if ((viewSpec = viewSpecManager.getViewSpec(buttonName))) {
                            _this.viewsWithButtons.push(buttonName);
                            buttonClick = function () {
                                calendar.changeView(buttonName);
                            };
                            (buttonText = viewSpec.buttonTextOverride) ||
                                (buttonIcon = theme.getIconClass(buttonName)) ||
                                (buttonText = viewSpec.buttonTextDefault);
                        }
                        else if (calendar[buttonName]) {
                            buttonClick = function () {
                                calendar[buttonName]();
                            };
                            (buttonText = calendarButtonTextOverrides[buttonName]) ||
                                (buttonIcon = theme.getIconClass(buttonName)) ||
                                (buttonText = calendarButtonText[buttonName]);
                            //            ^ everything else is considered default
                        }
                        if (buttonClick) {
                            buttonClasses = [
                                'fc-' + buttonName + '-button',
                                theme.getClass('button'),
                                theme.getClass('stateDefault')
                            ];
                            if (buttonText) {
                                buttonInnerHtml = util_1.htmlEscape(buttonText);
                                buttonAriaAttr = '';
                            }
                            else if (buttonIcon) {
                                buttonInnerHtml = "<span class='" + buttonIcon + "'></span>";
                                buttonAriaAttr = ' aria-label="' + buttonName + '"';
                            }
                            buttonEl = $(// type="button" so that it doesn't submit a form
                            '<button type="button" class="' + buttonClasses.join(' ') + '"' +
                                buttonAriaAttr +
                                '>' + buttonInnerHtml + '</button>')
                                .click(function (ev) {
                                // don't process clicks for disabled buttons
                                if (!buttonEl.hasClass(theme.getClass('stateDisabled'))) {
                                    buttonClick(ev);
                                    // after the click action, if the button becomes the "active" tab, or disabled,
                                    // it should never have a hover class, so remove it now.
                                    if (buttonEl.hasClass(theme.getClass('stateActive')) ||
                                        buttonEl.hasClass(theme.getClass('stateDisabled'))) {
                                        buttonEl.removeClass(theme.getClass('stateHover'));
                                    }
                                }
                            })
                                .mousedown(function () {
                                // the *down* effect (mouse pressed in).
                                // only on buttons that are not the "active" tab, or disabled
                                buttonEl
                                    .not('.' + theme.getClass('stateActive'))
                                    .not('.' + theme.getClass('stateDisabled'))
                                    .addClass(theme.getClass('stateDown'));
                            })
                                .mouseup(function () {
                                // undo the *down* effect
                                buttonEl.removeClass(theme.getClass('stateDown'));
                            })
                                .hover(function () {
                                // the *hover* effect.
                                // only on buttons that are not the "active" tab, or disabled
                                buttonEl
                                    .not('.' + theme.getClass('stateActive'))
                                    .not('.' + theme.getClass('stateDisabled'))
                                    .addClass(theme.getClass('stateHover'));
                            }, function () {
                                // undo the *hover* effect
                                buttonEl
                                    .removeClass(theme.getClass('stateHover'))
                                    .removeClass(theme.getClass('stateDown')); // if mouseleave happens before mouseup
                            });
                            groupChildren = groupChildren.add(buttonEl);
                        }
                    }
                });
                if (isOnlyButtons) {
                    groupChildren
                        .first().addClass(theme.getClass('cornerLeft')).end()
                        .last().addClass(theme.getClass('cornerRight')).end();
                }
                if (groupChildren.length > 1) {
                    groupEl = $('<div/>');
                    if (isOnlyButtons) {
                        groupEl.addClass(theme.getClass('buttonGroup'));
                    }
                    groupEl.append(groupChildren);
                    sectionEl.append(groupEl);
                }
                else {
                    sectionEl.append(groupChildren); // 1 or 0 children
                }
            });
        }
        return sectionEl;
    };
    Toolbar.prototype.updateTitle = function (text) {
        if (this.el) {
            this.el.find('h2').text(text);
        }
    };
    Toolbar.prototype.activateButton = function (buttonName) {
        if (this.el) {
            this.el.find('.fc-' + buttonName + '-button')
                .addClass(this.calendar.theme.getClass('stateActive'));
        }
    };
    Toolbar.prototype.deactivateButton = function (buttonName) {
        if (this.el) {
            this.el.find('.fc-' + buttonName + '-button')
                .removeClass(this.calendar.theme.getClass('stateActive'));
        }
    };
    Toolbar.prototype.disableButton = function (buttonName) {
        if (this.el) {
            this.el.find('.fc-' + buttonName + '-button')
                .prop('disabled', true)
                .addClass(this.calendar.theme.getClass('stateDisabled'));
        }
    };
    Toolbar.prototype.enableButton = function (buttonName) {
        if (this.el) {
            this.el.find('.fc-' + buttonName + '-button')
                .prop('disabled', false)
                .removeClass(this.calendar.theme.getClass('stateDisabled'));
        }
    };
    Toolbar.prototype.getViewsWithButtons = function () {
        return this.viewsWithButtons;
    };
    return Toolbar;
}());
exports.default = Toolbar;


/***/ }),
/* 240 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var $ = __webpack_require__(3);
var util_1 = __webpack_require__(4);
var options_1 = __webpack_require__(32);
var locale_1 = __webpack_require__(31);
var Model_1 = __webpack_require__(48);
var OptionsManager = /** @class */ (function (_super) {
    tslib_1.__extends(OptionsManager, _super);
    function OptionsManager(_calendar, overrides) {
        var _this = _super.call(this) || this;
        _this._calendar = _calendar;
        _this.overrides = $.extend({}, overrides); // make a copy
        _this.dynamicOverrides = {};
        _this.compute();
        return _this;
    }
    OptionsManager.prototype.add = function (newOptionHash) {
        var optionCnt = 0;
        var optionName;
        this.recordOverrides(newOptionHash); // will trigger this model's watchers
        for (optionName in newOptionHash) {
            optionCnt++;
        }
        // special-case handling of single option change.
        // if only one option change, `optionName` will be its name.
        if (optionCnt === 1) {
            if (optionName === 'height' || optionName === 'contentHeight' || optionName === 'aspectRatio') {
                this._calendar.updateViewSize(true); // isResize=true
                return;
            }
            else if (optionName === 'defaultDate') {
                return; // can't change date this way. use gotoDate instead
            }
            else if (optionName === 'businessHours') {
                return; // this model already reacts to this
            }
            else if (/^(event|select)(Overlap|Constraint|Allow)$/.test(optionName)) {
                return; // doesn't affect rendering. only interactions.
            }
            else if (optionName === 'timezone') {
                this._calendar.view.flash('initialEvents');
                return;
            }
        }
        // catch-all. rerender the header and footer and rebuild/rerender the current view
        this._calendar.renderHeader();
        this._calendar.renderFooter();
        // even non-current views will be affected by this option change. do before rerender
        // TODO: detangle
        this._calendar.viewsByType = {};
        this._calendar.reinitView();
    };
    // Computes the flattened options hash for the calendar and assigns to `this.options`.
    // Assumes this.overrides and this.dynamicOverrides have already been initialized.
    OptionsManager.prototype.compute = function () {
        var locale;
        var localeDefaults;
        var isRTL;
        var dirDefaults;
        var rawOptions;
        locale = util_1.firstDefined(// explicit locale option given?
        this.dynamicOverrides.locale, this.overrides.locale);
        localeDefaults = locale_1.localeOptionHash[locale];
        if (!localeDefaults) {
            locale = options_1.globalDefaults.locale;
            localeDefaults = locale_1.localeOptionHash[locale] || {};
        }
        isRTL = util_1.firstDefined(// based on options computed so far, is direction RTL?
        this.dynamicOverrides.isRTL, this.overrides.isRTL, localeDefaults.isRTL, options_1.globalDefaults.isRTL);
        dirDefaults = isRTL ? options_1.rtlDefaults : {};
        this.dirDefaults = dirDefaults;
        this.localeDefaults = localeDefaults;
        rawOptions = options_1.mergeOptions([
            options_1.globalDefaults,
            dirDefaults,
            localeDefaults,
            this.overrides,
            this.dynamicOverrides
        ]);
        locale_1.populateInstanceComputableOptions(rawOptions); // fill in gaps with computed options
        this.reset(rawOptions);
    };
    // stores the new options internally, but does not rerender anything.
    OptionsManager.prototype.recordOverrides = function (newOptionHash) {
        var optionName;
        for (optionName in newOptionHash) {
            this.dynamicOverrides[optionName] = newOptionHash[optionName];
        }
        this._calendar.viewSpecManager.clearCache(); // the dynamic override invalidates the options in this cache, so just clear it
        this.compute(); // this.options needs to be recomputed after the dynamic override
    };
    return OptionsManager;
}(Model_1.default));
exports.default = OptionsManager;


/***/ }),
/* 241 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var moment = __webpack_require__(0);
var $ = __webpack_require__(3);
var ViewRegistry_1 = __webpack_require__(22);
var util_1 = __webpack_require__(4);
var options_1 = __webpack_require__(32);
var locale_1 = __webpack_require__(31);
var ViewSpecManager = /** @class */ (function () {
    function ViewSpecManager(optionsManager, _calendar) {
        this.optionsManager = optionsManager;
        this._calendar = _calendar;
        this.clearCache();
    }
    ViewSpecManager.prototype.clearCache = function () {
        this.viewSpecCache = {};
    };
    // Gets information about how to create a view. Will use a cache.
    ViewSpecManager.prototype.getViewSpec = function (viewType) {
        var cache = this.viewSpecCache;
        return cache[viewType] || (cache[viewType] = this.buildViewSpec(viewType));
    };
    // Given a duration singular unit, like "week" or "day", finds a matching view spec.
    // Preference is given to views that have corresponding buttons.
    ViewSpecManager.prototype.getUnitViewSpec = function (unit) {
        var viewTypes;
        var i;
        var spec;
        if ($.inArray(unit, util_1.unitsDesc) !== -1) {
            // put views that have buttons first. there will be duplicates, but oh well
            viewTypes = this._calendar.header.getViewsWithButtons(); // TODO: include footer as well?
            $.each(ViewRegistry_1.viewHash, function (viewType) {
                viewTypes.push(viewType);
            });
            for (i = 0; i < viewTypes.length; i++) {
                spec = this.getViewSpec(viewTypes[i]);
                if (spec) {
                    if (spec.singleUnit === unit) {
                        return spec;
                    }
                }
            }
        }
    };
    // Builds an object with information on how to create a given view
    ViewSpecManager.prototype.buildViewSpec = function (requestedViewType) {
        var viewOverrides = this.optionsManager.overrides.views || {};
        var specChain = []; // for the view. lowest to highest priority
        var defaultsChain = []; // for the view. lowest to highest priority
        var overridesChain = []; // for the view. lowest to highest priority
        var viewType = requestedViewType;
        var spec; // for the view
        var overrides; // for the view
        var durationInput;
        var duration;
        var unit;
        // iterate from the specific view definition to a more general one until we hit an actual View class
        while (viewType) {
            spec = ViewRegistry_1.viewHash[viewType];
            overrides = viewOverrides[viewType];
            viewType = null; // clear. might repopulate for another iteration
            if (typeof spec === 'function') {
                spec = { 'class': spec };
            }
            if (spec) {
                specChain.unshift(spec);
                defaultsChain.unshift(spec.defaults || {});
                durationInput = durationInput || spec.duration;
                viewType = viewType || spec.type;
            }
            if (overrides) {
                overridesChain.unshift(overrides); // view-specific option hashes have options at zero-level
                durationInput = durationInput || overrides.duration;
                viewType = viewType || overrides.type;
            }
        }
        spec = util_1.mergeProps(specChain);
        spec.type = requestedViewType;
        if (!spec['class']) {
            return false;
        }
        // fall back to top-level `duration` option
        durationInput = durationInput ||
            this.optionsManager.dynamicOverrides.duration ||
            this.optionsManager.overrides.duration;
        if (durationInput) {
            duration = moment.duration(durationInput);
            if (duration.valueOf()) {
                unit = util_1.computeDurationGreatestUnit(duration, durationInput);
                spec.duration = duration;
                spec.durationUnit = unit;
                // view is a single-unit duration, like "week" or "day"
                // incorporate options for this. lowest priority
                if (duration.as(unit) === 1) {
                    spec.singleUnit = unit;
                    overridesChain.unshift(viewOverrides[unit] || {});
                }
            }
        }
        spec.defaults = options_1.mergeOptions(defaultsChain);
        spec.overrides = options_1.mergeOptions(overridesChain);
        this.buildViewSpecOptions(spec);
        this.buildViewSpecButtonText(spec, requestedViewType);
        return spec;
    };
    // Builds and assigns a view spec's options object from its already-assigned defaults and overrides
    ViewSpecManager.prototype.buildViewSpecOptions = function (spec) {
        var optionsManager = this.optionsManager;
        spec.options = options_1.mergeOptions([
            options_1.globalDefaults,
            spec.defaults,
            optionsManager.dirDefaults,
            optionsManager.localeDefaults,
            optionsManager.overrides,
            spec.overrides,
            optionsManager.dynamicOverrides // dynamically set via setter. highest precedence
        ]);
        locale_1.populateInstanceComputableOptions(spec.options);
    };
    // Computes and assigns a view spec's buttonText-related options
    ViewSpecManager.prototype.buildViewSpecButtonText = function (spec, requestedViewType) {
        var optionsManager = this.optionsManager;
        // given an options object with a possible `buttonText` hash, lookup the buttonText for the
        // requested view, falling back to a generic unit entry like "week" or "day"
        function queryButtonText(options) {
            var buttonText = options.buttonText || {};
            return buttonText[requestedViewType] ||
                // view can decide to look up a certain key
                (spec.buttonTextKey ? buttonText[spec.buttonTextKey] : null) ||
                // a key like "month"
                (spec.singleUnit ? buttonText[spec.singleUnit] : null);
        }
        // highest to lowest priority
        spec.buttonTextOverride =
            queryButtonText(optionsManager.dynamicOverrides) ||
                queryButtonText(optionsManager.overrides) || // constructor-specified buttonText lookup hash takes precedence
                spec.overrides.buttonText; // `buttonText` for view-specific options is a string
        // highest to lowest priority. mirrors buildViewSpecOptions
        spec.buttonTextDefault =
            queryButtonText(optionsManager.localeDefaults) ||
                queryButtonText(optionsManager.dirDefaults) ||
                spec.defaults.buttonText || // a single string. from ViewSubclass.defaults
                queryButtonText(options_1.globalDefaults) ||
                (spec.duration ? this._calendar.humanizeDuration(spec.duration) : null) || // like "3 days"
                requestedViewType; // fall back to given view name
    };
    return ViewSpecManager;
}());
exports.default = ViewSpecManager;


/***/ }),
/* 242 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var $ = __webpack_require__(3);
var util_1 = __webpack_require__(4);
var EventPeriod_1 = __webpack_require__(243);
var ArrayEventSource_1 = __webpack_require__(52);
var EventSource_1 = __webpack_require__(6);
var EventSourceParser_1 = __webpack_require__(38);
var SingleEventDef_1 = __webpack_require__(13);
var EventInstanceGroup_1 = __webpack_require__(18);
var EmitterMixin_1 = __webpack_require__(11);
var ListenerMixin_1 = __webpack_require__(7);
var EventManager = /** @class */ (function () {
    function EventManager(calendar) {
        this.calendar = calendar;
        this.stickySource = new ArrayEventSource_1.default(calendar);
        this.otherSources = [];
    }
    EventManager.prototype.requestEvents = function (start, end, timezone, force) {
        if (force ||
            !this.currentPeriod ||
            !this.currentPeriod.isWithinRange(start, end) ||
            timezone !== this.currentPeriod.timezone) {
            this.setPeriod(// will change this.currentPeriod
            new EventPeriod_1.default(start, end, timezone));
        }
        return this.currentPeriod.whenReleased();
    };
    // Source Adding/Removing
    // -----------------------------------------------------------------------------------------------------------------
    EventManager.prototype.addSource = function (eventSource) {
        this.otherSources.push(eventSource);
        if (this.currentPeriod) {
            this.currentPeriod.requestSource(eventSource); // might release
        }
    };
    EventManager.prototype.removeSource = function (doomedSource) {
        util_1.removeExact(this.otherSources, doomedSource);
        if (this.currentPeriod) {
            this.currentPeriod.purgeSource(doomedSource); // might release
        }
    };
    EventManager.prototype.removeAllSources = function () {
        this.otherSources = [];
        if (this.currentPeriod) {
            this.currentPeriod.purgeAllSources(); // might release
        }
    };
    // Source Refetching
    // -----------------------------------------------------------------------------------------------------------------
    EventManager.prototype.refetchSource = function (eventSource) {
        var currentPeriod = this.currentPeriod;
        if (currentPeriod) {
            currentPeriod.freeze();
            currentPeriod.purgeSource(eventSource);
            currentPeriod.requestSource(eventSource);
            currentPeriod.thaw();
        }
    };
    EventManager.prototype.refetchAllSources = function () {
        var currentPeriod = this.currentPeriod;
        if (currentPeriod) {
            currentPeriod.freeze();
            currentPeriod.purgeAllSources();
            currentPeriod.requestSources(this.getSources());
            currentPeriod.thaw();
        }
    };
    // Source Querying
    // -----------------------------------------------------------------------------------------------------------------
    EventManager.prototype.getSources = function () {
        return [this.stickySource].concat(this.otherSources);
    };
    // like querySources, but accepts multple match criteria (like multiple IDs)
    EventManager.prototype.multiQuerySources = function (matchInputs) {
        // coerce into an array
        if (!matchInputs) {
            matchInputs = [];
        }
        else if (!$.isArray(matchInputs)) {
            matchInputs = [matchInputs];
        }
        var matchingSources = [];
        var i;
        // resolve raw inputs to real event source objects
        for (i = 0; i < matchInputs.length; i++) {
            matchingSources.push.apply(// append
            matchingSources, this.querySources(matchInputs[i]));
        }
        return matchingSources;
    };
    // matchInput can either by a real event source object, an ID, or the function/URL for the source.
    // returns an array of matching source objects.
    EventManager.prototype.querySources = function (matchInput) {
        var sources = this.otherSources;
        var i;
        var source;
        // given a proper event source object
        for (i = 0; i < sources.length; i++) {
            source = sources[i];
            if (source === matchInput) {
                return [source];
            }
        }
        // an ID match
        source = this.getSourceById(EventSource_1.default.normalizeId(matchInput));
        if (source) {
            return [source];
        }
        // parse as an event source
        matchInput = EventSourceParser_1.default.parse(matchInput, this.calendar);
        if (matchInput) {
            return $.grep(sources, function (source) {
                return isSourcesEquivalent(matchInput, source);
            });
        }
    };
    /*
    ID assumed to already be normalized
    */
    EventManager.prototype.getSourceById = function (id) {
        return $.grep(this.otherSources, function (source) {
            return source.id && source.id === id;
        })[0];
    };
    // Event-Period
    // -----------------------------------------------------------------------------------------------------------------
    EventManager.prototype.setPeriod = function (eventPeriod) {
        if (this.currentPeriod) {
            this.unbindPeriod(this.currentPeriod);
            this.currentPeriod = null;
        }
        this.currentPeriod = eventPeriod;
        this.bindPeriod(eventPeriod);
        eventPeriod.requestSources(this.getSources());
    };
    EventManager.prototype.bindPeriod = function (eventPeriod) {
        this.listenTo(eventPeriod, 'release', function (eventsPayload) {
            this.trigger('release', eventsPayload);
        });
    };
    EventManager.prototype.unbindPeriod = function (eventPeriod) {
        this.stopListeningTo(eventPeriod);
    };
    // Event Getting/Adding/Removing
    // -----------------------------------------------------------------------------------------------------------------
    EventManager.prototype.getEventDefByUid = function (uid) {
        if (this.currentPeriod) {
            return this.currentPeriod.getEventDefByUid(uid);
        }
    };
    EventManager.prototype.addEventDef = function (eventDef, isSticky) {
        if (isSticky) {
            this.stickySource.addEventDef(eventDef);
        }
        if (this.currentPeriod) {
            this.currentPeriod.addEventDef(eventDef); // might release
        }
    };
    EventManager.prototype.removeEventDefsById = function (eventId) {
        this.getSources().forEach(function (eventSource) {
            eventSource.removeEventDefsById(eventId);
        });
        if (this.currentPeriod) {
            this.currentPeriod.removeEventDefsById(eventId); // might release
        }
    };
    EventManager.prototype.removeAllEventDefs = function () {
        this.getSources().forEach(function (eventSource) {
            eventSource.removeAllEventDefs();
        });
        if (this.currentPeriod) {
            this.currentPeriod.removeAllEventDefs();
        }
    };
    // Event Mutating
    // -----------------------------------------------------------------------------------------------------------------
    /*
    Returns an undo function.
    */
    EventManager.prototype.mutateEventsWithId = function (eventDefId, eventDefMutation) {
        var currentPeriod = this.currentPeriod;
        var eventDefs;
        var undoFuncs = [];
        if (currentPeriod) {
            currentPeriod.freeze();
            eventDefs = currentPeriod.getEventDefsById(eventDefId);
            eventDefs.forEach(function (eventDef) {
                // add/remove esp because id might change
                currentPeriod.removeEventDef(eventDef);
                undoFuncs.push(eventDefMutation.mutateSingle(eventDef));
                currentPeriod.addEventDef(eventDef);
            });
            currentPeriod.thaw();
            return function () {
                currentPeriod.freeze();
                for (var i = 0; i < eventDefs.length; i++) {
                    currentPeriod.removeEventDef(eventDefs[i]);
                    undoFuncs[i]();
                    currentPeriod.addEventDef(eventDefs[i]);
                }
                currentPeriod.thaw();
            };
        }
        return function () { };
    };
    /*
    copies and then mutates
    */
    EventManager.prototype.buildMutatedEventInstanceGroup = function (eventDefId, eventDefMutation) {
        var eventDefs = this.getEventDefsById(eventDefId);
        var i;
        var defCopy;
        var allInstances = [];
        for (i = 0; i < eventDefs.length; i++) {
            defCopy = eventDefs[i].clone();
            if (defCopy instanceof SingleEventDef_1.default) {
                eventDefMutation.mutateSingle(defCopy);
                allInstances.push.apply(allInstances, // append
                defCopy.buildInstances());
            }
        }
        return new EventInstanceGroup_1.default(allInstances);
    };
    // Freezing
    // -----------------------------------------------------------------------------------------------------------------
    EventManager.prototype.freeze = function () {
        if (this.currentPeriod) {
            this.currentPeriod.freeze();
        }
    };
    EventManager.prototype.thaw = function () {
        if (this.currentPeriod) {
            this.currentPeriod.thaw();
        }
    };
    // methods that simply forward to EventPeriod
    EventManager.prototype.getEventDefsById = function (eventDefId) {
        return this.currentPeriod.getEventDefsById(eventDefId);
    };
    EventManager.prototype.getEventInstances = function () {
        return this.currentPeriod.getEventInstances();
    };
    EventManager.prototype.getEventInstancesWithId = function (eventDefId) {
        return this.currentPeriod.getEventInstancesWithId(eventDefId);
    };
    EventManager.prototype.getEventInstancesWithoutId = function (eventDefId) {
        return this.currentPeriod.getEventInstancesWithoutId(eventDefId);
    };
    return EventManager;
}());
exports.default = EventManager;
EmitterMixin_1.default.mixInto(EventManager);
ListenerMixin_1.default.mixInto(EventManager);
function isSourcesEquivalent(source0, source1) {
    return source0.getPrimitive() === source1.getPrimitive();
}


/***/ }),
/* 243 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var $ = __webpack_require__(3);
var util_1 = __webpack_require__(4);
var Promise_1 = __webpack_require__(20);
var EmitterMixin_1 = __webpack_require__(11);
var UnzonedRange_1 = __webpack_require__(5);
var EventInstanceGroup_1 = __webpack_require__(18);
var EventPeriod = /** @class */ (function () {
    function EventPeriod(start, end, timezone) {
        this.pendingCnt = 0;
        this.freezeDepth = 0;
        this.stuntedReleaseCnt = 0;
        this.releaseCnt = 0;
        this.start = start;
        this.end = end;
        this.timezone = timezone;
        this.unzonedRange = new UnzonedRange_1.default(start.clone().stripZone(), end.clone().stripZone());
        this.requestsByUid = {};
        this.eventDefsByUid = {};
        this.eventDefsById = {};
        this.eventInstanceGroupsById = {};
    }
    EventPeriod.prototype.isWithinRange = function (start, end) {
        // TODO: use a range util function?
        return !start.isBefore(this.start) && !end.isAfter(this.end);
    };
    // Requesting and Purging
    // -----------------------------------------------------------------------------------------------------------------
    EventPeriod.prototype.requestSources = function (sources) {
        this.freeze();
        for (var i = 0; i < sources.length; i++) {
            this.requestSource(sources[i]);
        }
        this.thaw();
    };
    EventPeriod.prototype.requestSource = function (source) {
        var _this = this;
        var request = { source: source, status: 'pending', eventDefs: null };
        this.requestsByUid[source.uid] = request;
        this.pendingCnt += 1;
        source.fetch(this.start, this.end, this.timezone).then(function (eventDefs) {
            if (request.status !== 'cancelled') {
                request.status = 'completed';
                request.eventDefs = eventDefs;
                _this.addEventDefs(eventDefs);
                _this.pendingCnt--;
                _this.tryRelease();
            }
        }, function () {
            if (request.status !== 'cancelled') {
                request.status = 'failed';
                _this.pendingCnt--;
                _this.tryRelease();
            }
        });
    };
    EventPeriod.prototype.purgeSource = function (source) {
        var request = this.requestsByUid[source.uid];
        if (request) {
            delete this.requestsByUid[source.uid];
            if (request.status === 'pending') {
                request.status = 'cancelled';
                this.pendingCnt--;
                this.tryRelease();
            }
            else if (request.status === 'completed') {
                request.eventDefs.forEach(this.removeEventDef.bind(this));
            }
        }
    };
    EventPeriod.prototype.purgeAllSources = function () {
        var requestsByUid = this.requestsByUid;
        var uid;
        var request;
        var completedCnt = 0;
        for (uid in requestsByUid) {
            request = requestsByUid[uid];
            if (request.status === 'pending') {
                request.status = 'cancelled';
            }
            else if (request.status === 'completed') {
                completedCnt++;
            }
        }
        this.requestsByUid = {};
        this.pendingCnt = 0;
        if (completedCnt) {
            this.removeAllEventDefs(); // might release
        }
    };
    // Event Definitions
    // -----------------------------------------------------------------------------------------------------------------
    EventPeriod.prototype.getEventDefByUid = function (eventDefUid) {
        return this.eventDefsByUid[eventDefUid];
    };
    EventPeriod.prototype.getEventDefsById = function (eventDefId) {
        var a = this.eventDefsById[eventDefId];
        if (a) {
            return a.slice(); // clone
        }
        return [];
    };
    EventPeriod.prototype.addEventDefs = function (eventDefs) {
        for (var i = 0; i < eventDefs.length; i++) {
            this.addEventDef(eventDefs[i]);
        }
    };
    EventPeriod.prototype.addEventDef = function (eventDef) {
        var eventDefsById = this.eventDefsById;
        var eventDefId = eventDef.id;
        var eventDefs = eventDefsById[eventDefId] || (eventDefsById[eventDefId] = []);
        var eventInstances = eventDef.buildInstances(this.unzonedRange);
        var i;
        eventDefs.push(eventDef);
        this.eventDefsByUid[eventDef.uid] = eventDef;
        for (i = 0; i < eventInstances.length; i++) {
            this.addEventInstance(eventInstances[i], eventDefId);
        }
    };
    EventPeriod.prototype.removeEventDefsById = function (eventDefId) {
        var _this = this;
        this.getEventDefsById(eventDefId).forEach(function (eventDef) {
            _this.removeEventDef(eventDef);
        });
    };
    EventPeriod.prototype.removeAllEventDefs = function () {
        var isEmpty = $.isEmptyObject(this.eventDefsByUid);
        this.eventDefsByUid = {};
        this.eventDefsById = {};
        this.eventInstanceGroupsById = {};
        if (!isEmpty) {
            this.tryRelease();
        }
    };
    EventPeriod.prototype.removeEventDef = function (eventDef) {
        var eventDefsById = this.eventDefsById;
        var eventDefs = eventDefsById[eventDef.id];
        delete this.eventDefsByUid[eventDef.uid];
        if (eventDefs) {
            util_1.removeExact(eventDefs, eventDef);
            if (!eventDefs.length) {
                delete eventDefsById[eventDef.id];
            }
            this.removeEventInstancesForDef(eventDef);
        }
    };
    // Event Instances
    // -----------------------------------------------------------------------------------------------------------------
    EventPeriod.prototype.getEventInstances = function () {
        var eventInstanceGroupsById = this.eventInstanceGroupsById;
        var eventInstances = [];
        var id;
        for (id in eventInstanceGroupsById) {
            eventInstances.push.apply(eventInstances, // append
            eventInstanceGroupsById[id].eventInstances);
        }
        return eventInstances;
    };
    EventPeriod.prototype.getEventInstancesWithId = function (eventDefId) {
        var eventInstanceGroup = this.eventInstanceGroupsById[eventDefId];
        if (eventInstanceGroup) {
            return eventInstanceGroup.eventInstances.slice(); // clone
        }
        return [];
    };
    EventPeriod.prototype.getEventInstancesWithoutId = function (eventDefId) {
        var eventInstanceGroupsById = this.eventInstanceGroupsById;
        var matchingInstances = [];
        var id;
        for (id in eventInstanceGroupsById) {
            if (id !== eventDefId) {
                matchingInstances.push.apply(matchingInstances, // append
                eventInstanceGroupsById[id].eventInstances);
            }
        }
        return matchingInstances;
    };
    EventPeriod.prototype.addEventInstance = function (eventInstance, eventDefId) {
        var eventInstanceGroupsById = this.eventInstanceGroupsById;
        var eventInstanceGroup = eventInstanceGroupsById[eventDefId] ||
            (eventInstanceGroupsById[eventDefId] = new EventInstanceGroup_1.default());
        eventInstanceGroup.eventInstances.push(eventInstance);
        this.tryRelease();
    };
    EventPeriod.prototype.removeEventInstancesForDef = function (eventDef) {
        var eventInstanceGroupsById = this.eventInstanceGroupsById;
        var eventInstanceGroup = eventInstanceGroupsById[eventDef.id];
        var removeCnt;
        if (eventInstanceGroup) {
            removeCnt = util_1.removeMatching(eventInstanceGroup.eventInstances, function (currentEventInstance) {
                return currentEventInstance.def === eventDef;
            });
            if (!eventInstanceGroup.eventInstances.length) {
                delete eventInstanceGroupsById[eventDef.id];
            }
            if (removeCnt) {
                this.tryRelease();
            }
        }
    };
    // Releasing and Freezing
    // -----------------------------------------------------------------------------------------------------------------
    EventPeriod.prototype.tryRelease = function () {
        if (!this.pendingCnt) {
            if (!this.freezeDepth) {
                this.release();
            }
            else {
                this.stuntedReleaseCnt++;
            }
        }
    };
    EventPeriod.prototype.release = function () {
        this.releaseCnt++;
        this.trigger('release', this.eventInstanceGroupsById);
    };
    EventPeriod.prototype.whenReleased = function () {
        var _this = this;
        if (this.releaseCnt) {
            return Promise_1.default.resolve(this.eventInstanceGroupsById);
        }
        else {
            return Promise_1.default.construct(function (onResolve) {
                _this.one('release', onResolve);
            });
        }
    };
    EventPeriod.prototype.freeze = function () {
        if (!(this.freezeDepth++)) {
            this.stuntedReleaseCnt = 0;
        }
    };
    EventPeriod.prototype.thaw = function () {
        if (!(--this.freezeDepth) && this.stuntedReleaseCnt && !this.pendingCnt) {
            this.release();
        }
    };
    return EventPeriod;
}());
exports.default = EventPeriod;
EmitterMixin_1.default.mixInto(EventPeriod);


/***/ }),
/* 244 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var $ = __webpack_require__(3);
var util_1 = __webpack_require__(4);
var ListenerMixin_1 = __webpack_require__(7);
/* Creates a clone of an element and lets it track the mouse as it moves
----------------------------------------------------------------------------------------------------------------------*/
var MouseFollower = /** @class */ (function () {
    function MouseFollower(sourceEl, options) {
        this.isFollowing = false;
        this.isHidden = false;
        this.isAnimating = false; // doing the revert animation?
        this.options = options = options || {};
        this.sourceEl = sourceEl;
        this.parentEl = options.parentEl ? $(options.parentEl) : sourceEl.parent(); // default to sourceEl's parent
    }
    // Causes the element to start following the mouse
    MouseFollower.prototype.start = function (ev) {
        if (!this.isFollowing) {
            this.isFollowing = true;
            this.y0 = util_1.getEvY(ev);
            this.x0 = util_1.getEvX(ev);
            this.topDelta = 0;
            this.leftDelta = 0;
            if (!this.isHidden) {
                this.updatePosition();
            }
            if (util_1.getEvIsTouch(ev)) {
                this.listenTo($(document), 'touchmove', this.handleMove);
            }
            else {
                this.listenTo($(document), 'mousemove', this.handleMove);
            }
        }
    };
    // Causes the element to stop following the mouse. If shouldRevert is true, will animate back to original position.
    // `callback` gets invoked when the animation is complete. If no animation, it is invoked immediately.
    MouseFollower.prototype.stop = function (shouldRevert, callback) {
        var _this = this;
        var revertDuration = this.options.revertDuration;
        var complete = function () {
            _this.isAnimating = false;
            _this.removeElement();
            _this.top0 = _this.left0 = null; // reset state for future updatePosition calls
            if (callback) {
                callback();
            }
        };
        if (this.isFollowing && !this.isAnimating) {
            this.isFollowing = false;
            this.stopListeningTo($(document));
            if (shouldRevert && revertDuration && !this.isHidden) {
                this.isAnimating = true;
                this.el.animate({
                    top: this.top0,
                    left: this.left0
                }, {
                    duration: revertDuration,
                    complete: complete
                });
            }
            else {
                complete();
            }
        }
    };
    // Gets the tracking element. Create it if necessary
    MouseFollower.prototype.getEl = function () {
        var el = this.el;
        if (!el) {
            el = this.el = this.sourceEl.clone()
                .addClass(this.options.additionalClass || '')
                .css({
                position: 'absolute',
                visibility: '',
                display: this.isHidden ? 'none' : '',
                margin: 0,
                right: 'auto',
                bottom: 'auto',
                width: this.sourceEl.width(),
                height: this.sourceEl.height(),
                opacity: this.options.opacity || '',
                zIndex: this.options.zIndex
            });
            // we don't want long taps or any mouse interaction causing selection/menus.
            // would use preventSelection(), but that prevents selectstart, causing problems.
            el.addClass('fc-unselectable');
            el.appendTo(this.parentEl);
        }
        return el;
    };
    // Removes the tracking element if it has already been created
    MouseFollower.prototype.removeElement = function () {
        if (this.el) {
            this.el.remove();
            this.el = null;
        }
    };
    // Update the CSS position of the tracking element
    MouseFollower.prototype.updatePosition = function () {
        var sourceOffset;
        var origin;
        this.getEl(); // ensure this.el
        // make sure origin info was computed
        if (this.top0 == null) {
            sourceOffset = this.sourceEl.offset();
            origin = this.el.offsetParent().offset();
            this.top0 = sourceOffset.top - origin.top;
            this.left0 = sourceOffset.left - origin.left;
        }
        this.el.css({
            top: this.top0 + this.topDelta,
            left: this.left0 + this.leftDelta
        });
    };
    // Gets called when the user moves the mouse
    MouseFollower.prototype.handleMove = function (ev) {
        this.topDelta = util_1.getEvY(ev) - this.y0;
        this.leftDelta = util_1.getEvX(ev) - this.x0;
        if (!this.isHidden) {
            this.updatePosition();
        }
    };
    // Temporarily makes the tracking element invisible. Can be called before following starts
    MouseFollower.prototype.hide = function () {
        if (!this.isHidden) {
            this.isHidden = true;
            if (this.el) {
                this.el.hide();
            }
        }
    };
    // Show the tracking element after it has been temporarily hidden
    MouseFollower.prototype.show = function () {
        if (this.isHidden) {
            this.isHidden = false;
            this.updatePosition();
            this.getEl().show();
        }
    };
    return MouseFollower;
}());
exports.default = MouseFollower;
ListenerMixin_1.default.mixInto(MouseFollower);


/***/ }),
/* 245 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var HitDragListener_1 = __webpack_require__(23);
var Interaction_1 = __webpack_require__(15);
var DateClicking = /** @class */ (function (_super) {
    tslib_1.__extends(DateClicking, _super);
    /*
    component must implement:
      - bindDateHandlerToEl
      - getSafeHitFootprint
      - getHitEl
    */
    function DateClicking(component) {
        var _this = _super.call(this, component) || this;
        _this.dragListener = _this.buildDragListener();
        return _this;
    }
    DateClicking.prototype.end = function () {
        this.dragListener.endInteraction();
    };
    DateClicking.prototype.bindToEl = function (el) {
        var component = this.component;
        var dragListener = this.dragListener;
        component.bindDateHandlerToEl(el, 'mousedown', function (ev) {
            if (!component.shouldIgnoreMouse()) {
                dragListener.startInteraction(ev);
            }
        });
        component.bindDateHandlerToEl(el, 'touchstart', function (ev) {
            if (!component.shouldIgnoreTouch()) {
                dragListener.startInteraction(ev);
            }
        });
    };
    // Creates a listener that tracks the user's drag across day elements, for day clicking.
    DateClicking.prototype.buildDragListener = function () {
        var _this = this;
        var component = this.component;
        var dayClickHit; // null if invalid dayClick
        var dragListener = new HitDragListener_1.default(component, {
            scroll: this.opt('dragScroll'),
            interactionStart: function () {
                dayClickHit = dragListener.origHit;
            },
            hitOver: function (hit, isOrig, origHit) {
                // if user dragged to another cell at any point, it can no longer be a dayClick
                if (!isOrig) {
                    dayClickHit = null;
                }
            },
            hitOut: function () {
                dayClickHit = null;
            },
            interactionEnd: function (ev, isCancelled) {
                var componentFootprint;
                if (!isCancelled && dayClickHit) {
                    componentFootprint = component.getSafeHitFootprint(dayClickHit);
                    if (componentFootprint) {
                        _this.view.triggerDayClick(componentFootprint, component.getHitEl(dayClickHit), ev);
                    }
                }
            }
        });
        // because dragListener won't be called with any time delay, "dragging" will begin immediately,
        // which will kill any touchmoving/scrolling. Prevent this.
        dragListener.shouldCancelTouchScroll = false;
        dragListener.scrollAlwaysKills = true;
        return dragListener;
    };
    return DateClicking;
}(Interaction_1.default));
exports.default = DateClicking;


/***/ }),
/* 246 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var util_1 = __webpack_require__(4);
var EventRenderer_1 = __webpack_require__(42);
/*
Only handles foreground segs.
Does not own rendering. Use for low-level util methods by TimeGrid.
*/
var TimeGridEventRenderer = /** @class */ (function (_super) {
    tslib_1.__extends(TimeGridEventRenderer, _super);
    function TimeGridEventRenderer(timeGrid, fillRenderer) {
        var _this = _super.call(this, timeGrid, fillRenderer) || this;
        _this.timeGrid = timeGrid;
        return _this;
    }
    TimeGridEventRenderer.prototype.renderFgSegs = function (segs) {
        this.renderFgSegsIntoContainers(segs, this.timeGrid.fgContainerEls);
    };
    // Given an array of foreground segments, render a DOM element for each, computes position,
    // and attaches to the column inner-container elements.
    TimeGridEventRenderer.prototype.renderFgSegsIntoContainers = function (segs, containerEls) {
        var segsByCol;
        var col;
        segsByCol = this.timeGrid.groupSegsByCol(segs);
        for (col = 0; col < this.timeGrid.colCnt; col++) {
            this.updateFgSegCoords(segsByCol[col]);
        }
        this.timeGrid.attachSegsByCol(segsByCol, containerEls);
    };
    TimeGridEventRenderer.prototype.unrenderFgSegs = function () {
        if (this.fgSegs) {
            this.fgSegs.forEach(function (seg) {
                seg.el.remove();
            });
        }
    };
    // Computes a default event time formatting string if `timeFormat` is not explicitly defined
    TimeGridEventRenderer.prototype.computeEventTimeFormat = function () {
        return this.opt('noMeridiemTimeFormat'); // like "6:30" (no AM/PM)
    };
    // Computes a default `displayEventEnd` value if one is not expliclty defined
    TimeGridEventRenderer.prototype.computeDisplayEventEnd = function () {
        return true;
    };
    // Renders the HTML for a single event segment's default rendering
    TimeGridEventRenderer.prototype.fgSegHtml = function (seg, disableResizing) {
        var view = this.view;
        var calendar = view.calendar;
        var componentFootprint = seg.footprint.componentFootprint;
        var isAllDay = componentFootprint.isAllDay;
        var eventDef = seg.footprint.eventDef;
        var isDraggable = view.isEventDefDraggable(eventDef);
        var isResizableFromStart = !disableResizing && seg.isStart && view.isEventDefResizableFromStart(eventDef);
        var isResizableFromEnd = !disableResizing && seg.isEnd && view.isEventDefResizableFromEnd(eventDef);
        var classes = this.getSegClasses(seg, isDraggable, isResizableFromStart || isResizableFromEnd);
        var skinCss = util_1.cssToStr(this.getSkinCss(eventDef));
        var timeText;
        var fullTimeText; // more verbose time text. for the print stylesheet
        var startTimeText; // just the start time text
        classes.unshift('fc-time-grid-event', 'fc-v-event');
        // if the event appears to span more than one day...
        if (view.isMultiDayRange(componentFootprint.unzonedRange)) {
            // Don't display time text on segments that run entirely through a day.
            // That would appear as midnight-midnight and would look dumb.
            // Otherwise, display the time text for the *segment's* times (like 6pm-midnight or midnight-10am)
            if (seg.isStart || seg.isEnd) {
                var zonedStart = calendar.msToMoment(seg.startMs);
                var zonedEnd = calendar.msToMoment(seg.endMs);
                timeText = this._getTimeText(zonedStart, zonedEnd, isAllDay);
                fullTimeText = this._getTimeText(zonedStart, zonedEnd, isAllDay, 'LT');
                startTimeText = this._getTimeText(zonedStart, zonedEnd, isAllDay, null, false); // displayEnd=false
            }
        }
        else {
            // Display the normal time text for the *event's* times
            timeText = this.getTimeText(seg.footprint);
            fullTimeText = this.getTimeText(seg.footprint, 'LT');
            startTimeText = this.getTimeText(seg.footprint, null, false); // displayEnd=false
        }
        return '<a class="' + classes.join(' ') + '"' +
            (eventDef.url ?
                ' href="' + util_1.htmlEscape(eventDef.url) + '"' :
                '') +
            (skinCss ?
                ' style="' + skinCss + '"' :
                '') +
            '>' +
            '<div class="fc-content">' +
            (timeText ?
                '<div class="fc-time"' +
                    ' data-start="' + util_1.htmlEscape(startTimeText) + '"' +
                    ' data-full="' + util_1.htmlEscape(fullTimeText) + '"' +
                    '>' +
                    '<span>' + util_1.htmlEscape(timeText) + '</span>' +
                    '</div>' :
                '') +
            (eventDef.title ?
                '<div class="fc-title">' +
                    util_1.htmlEscape(eventDef.title) +
                    '</div>' :
                '') +
            '</div>' +
            '<div class="fc-bg"/>' +
            /* TODO: write CSS for this
            (isResizableFromStart ?
              '<div class="fc-resizer fc-start-resizer" />' :
              ''
              ) +
            */
            (isResizableFromEnd ?
                '<div class="fc-resizer fc-end-resizer" />' :
                '') +
            '</a>';
    };
    // Given segments that are assumed to all live in the *same column*,
    // compute their verical/horizontal coordinates and assign to their elements.
    TimeGridEventRenderer.prototype.updateFgSegCoords = function (segs) {
        this.timeGrid.computeSegVerticals(segs); // horizontals relies on this
        this.computeFgSegHorizontals(segs); // compute horizontal coordinates, z-index's, and reorder the array
        this.timeGrid.assignSegVerticals(segs);
        this.assignFgSegHorizontals(segs);
    };
    // Given an array of segments that are all in the same column, sets the backwardCoord and forwardCoord on each.
    // NOTE: Also reorders the given array by date!
    TimeGridEventRenderer.prototype.computeFgSegHorizontals = function (segs) {
        var levels;
        var level0;
        var i;
        this.sortEventSegs(segs); // order by certain criteria
        levels = buildSlotSegLevels(segs);
        computeForwardSlotSegs(levels);
        if ((level0 = levels[0])) {
            for (i = 0; i < level0.length; i++) {
                computeSlotSegPressures(level0[i]);
            }
            for (i = 0; i < level0.length; i++) {
                this.computeFgSegForwardBack(level0[i], 0, 0);
            }
        }
    };
    // Calculate seg.forwardCoord and seg.backwardCoord for the segment, where both values range
    // from 0 to 1. If the calendar is left-to-right, the seg.backwardCoord maps to "left" and
    // seg.forwardCoord maps to "right" (via percentage). Vice-versa if the calendar is right-to-left.
    //
    // The segment might be part of a "series", which means consecutive segments with the same pressure
    // who's width is unknown until an edge has been hit. `seriesBackwardPressure` is the number of
    // segments behind this one in the current series, and `seriesBackwardCoord` is the starting
    // coordinate of the first segment in the series.
    TimeGridEventRenderer.prototype.computeFgSegForwardBack = function (seg, seriesBackwardPressure, seriesBackwardCoord) {
        var forwardSegs = seg.forwardSegs;
        var i;
        if (seg.forwardCoord === undefined) {
            if (!forwardSegs.length) {
                // if there are no forward segments, this segment should butt up against the edge
                seg.forwardCoord = 1;
            }
            else {
                // sort highest pressure first
                this.sortForwardSegs(forwardSegs);
                // this segment's forwardCoord will be calculated from the backwardCoord of the
                // highest-pressure forward segment.
                this.computeFgSegForwardBack(forwardSegs[0], seriesBackwardPressure + 1, seriesBackwardCoord);
                seg.forwardCoord = forwardSegs[0].backwardCoord;
            }
            // calculate the backwardCoord from the forwardCoord. consider the series
            seg.backwardCoord = seg.forwardCoord -
                (seg.forwardCoord - seriesBackwardCoord) / // available width for series
                    (seriesBackwardPressure + 1); // # of segments in the series
            // use this segment's coordinates to computed the coordinates of the less-pressurized
            // forward segments
            for (i = 0; i < forwardSegs.length; i++) {
                this.computeFgSegForwardBack(forwardSegs[i], 0, seg.forwardCoord);
            }
        }
    };
    TimeGridEventRenderer.prototype.sortForwardSegs = function (forwardSegs) {
        forwardSegs.sort(util_1.proxy(this, 'compareForwardSegs'));
    };
    // A cmp function for determining which forward segment to rely on more when computing coordinates.
    TimeGridEventRenderer.prototype.compareForwardSegs = function (seg1, seg2) {
        // put higher-pressure first
        return seg2.forwardPressure - seg1.forwardPressure ||
            // put segments that are closer to initial edge first (and favor ones with no coords yet)
            (seg1.backwardCoord || 0) - (seg2.backwardCoord || 0) ||
            // do normal sorting...
            this.compareEventSegs(seg1, seg2);
    };
    // Given foreground event segments that have already had their position coordinates computed,
    // assigns position-related CSS values to their elements.
    TimeGridEventRenderer.prototype.assignFgSegHorizontals = function (segs) {
        var i;
        var seg;
        for (i = 0; i < segs.length; i++) {
            seg = segs[i];
            seg.el.css(this.generateFgSegHorizontalCss(seg));
            // if the height is short, add a className for alternate styling
            if (seg.bottom - seg.top < 30) {
                seg.el.addClass('fc-short');
            }
        }
    };
    // Generates an object with CSS properties/values that should be applied to an event segment element.
    // Contains important positioning-related properties that should be applied to any event element, customized or not.
    TimeGridEventRenderer.prototype.generateFgSegHorizontalCss = function (seg) {
        var shouldOverlap = this.opt('slotEventOverlap');
        var backwardCoord = seg.backwardCoord; // the left side if LTR. the right side if RTL. floating-point
        var forwardCoord = seg.forwardCoord; // the right side if LTR. the left side if RTL. floating-point
        var props = this.timeGrid.generateSegVerticalCss(seg); // get top/bottom first
        var isRTL = this.timeGrid.isRTL;
        var left; // amount of space from left edge, a fraction of the total width
        var right; // amount of space from right edge, a fraction of the total width
        if (shouldOverlap) {
            // double the width, but don't go beyond the maximum forward coordinate (1.0)
            forwardCoord = Math.min(1, backwardCoord + (forwardCoord - backwardCoord) * 2);
        }
        if (isRTL) {
            left = 1 - forwardCoord;
            right = backwardCoord;
        }
        else {
            left = backwardCoord;
            right = 1 - forwardCoord;
        }
        props.zIndex = seg.level + 1; // convert from 0-base to 1-based
        props.left = left * 100 + '%';
        props.right = right * 100 + '%';
        if (shouldOverlap && seg.forwardPressure) {
            // add padding to the edge so that forward stacked events don't cover the resizer's icon
            props[isRTL ? 'marginLeft' : 'marginRight'] = 10 * 2; // 10 is a guesstimate of the icon's width
        }
        return props;
    };
    return TimeGridEventRenderer;
}(EventRenderer_1.default));
exports.default = TimeGridEventRenderer;
// Builds an array of segments "levels". The first level will be the leftmost tier of segments if the calendar is
// left-to-right, or the rightmost if the calendar is right-to-left. Assumes the segments are already ordered by date.
function buildSlotSegLevels(segs) {
    var levels = [];
    var i;
    var seg;
    var j;
    for (i = 0; i < segs.length; i++) {
        seg = segs[i];
        // go through all the levels and stop on the first level where there are no collisions
        for (j = 0; j < levels.length; j++) {
            if (!computeSlotSegCollisions(seg, levels[j]).length) {
                break;
            }
        }
        seg.level = j;
        (levels[j] || (levels[j] = [])).push(seg);
    }
    return levels;
}
// For every segment, figure out the other segments that are in subsequent
// levels that also occupy the same vertical space. Accumulate in seg.forwardSegs
function computeForwardSlotSegs(levels) {
    var i;
    var level;
    var j;
    var seg;
    var k;
    for (i = 0; i < levels.length; i++) {
        level = levels[i];
        for (j = 0; j < level.length; j++) {
            seg = level[j];
            seg.forwardSegs = [];
            for (k = i + 1; k < levels.length; k++) {
                computeSlotSegCollisions(seg, levels[k], seg.forwardSegs);
            }
        }
    }
}
// Figure out which path forward (via seg.forwardSegs) results in the longest path until
// the furthest edge is reached. The number of segments in this path will be seg.forwardPressure
function computeSlotSegPressures(seg) {
    var forwardSegs = seg.forwardSegs;
    var forwardPressure = 0;
    var i;
    var forwardSeg;
    if (seg.forwardPressure === undefined) {
        for (i = 0; i < forwardSegs.length; i++) {
            forwardSeg = forwardSegs[i];
            // figure out the child's maximum forward path
            computeSlotSegPressures(forwardSeg);
            // either use the existing maximum, or use the child's forward pressure
            // plus one (for the forwardSeg itself)
            forwardPressure = Math.max(forwardPressure, 1 + forwardSeg.forwardPressure);
        }
        seg.forwardPressure = forwardPressure;
    }
}
// Find all the segments in `otherSegs` that vertically collide with `seg`.
// Append into an optionally-supplied `results` array and return.
function computeSlotSegCollisions(seg, otherSegs, results) {
    if (results === void 0) { results = []; }
    for (var i = 0; i < otherSegs.length; i++) {
        if (isSlotSegCollision(seg, otherSegs[i])) {
            results.push(otherSegs[i]);
        }
    }
    return results;
}
// Do these segments occupy the same vertical space?
function isSlotSegCollision(seg1, seg2) {
    return seg1.bottom > seg2.top && seg1.top < seg2.bottom;
}


/***/ }),
/* 247 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var $ = __webpack_require__(3);
var HelperRenderer_1 = __webpack_require__(58);
var TimeGridHelperRenderer = /** @class */ (function (_super) {
    tslib_1.__extends(TimeGridHelperRenderer, _super);
    function TimeGridHelperRenderer() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TimeGridHelperRenderer.prototype.renderSegs = function (segs, sourceSeg) {
        var helperNodes = [];
        var i;
        var seg;
        var sourceEl;
        // TODO: not good to call eventRenderer this way
        this.eventRenderer.renderFgSegsIntoContainers(segs, this.component.helperContainerEls);
        // Try to make the segment that is in the same row as sourceSeg look the same
        for (i = 0; i < segs.length; i++) {
            seg = segs[i];
            if (sourceSeg && sourceSeg.col === seg.col) {
                sourceEl = sourceSeg.el;
                seg.el.css({
                    left: sourceEl.css('left'),
                    right: sourceEl.css('right'),
                    'margin-left': sourceEl.css('margin-left'),
                    'margin-right': sourceEl.css('margin-right')
                });
            }
            helperNodes.push(seg.el[0]);
        }
        return $(helperNodes); // must return the elements rendered
    };
    return TimeGridHelperRenderer;
}(HelperRenderer_1.default));
exports.default = TimeGridHelperRenderer;


/***/ }),
/* 248 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var FillRenderer_1 = __webpack_require__(57);
var TimeGridFillRenderer = /** @class */ (function (_super) {
    tslib_1.__extends(TimeGridFillRenderer, _super);
    function TimeGridFillRenderer() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TimeGridFillRenderer.prototype.attachSegEls = function (type, segs) {
        var timeGrid = this.component;
        var containerEls;
        // TODO: more efficient lookup
        if (type === 'bgEvent') {
            containerEls = timeGrid.bgContainerEls;
        }
        else if (type === 'businessHours') {
            containerEls = timeGrid.businessContainerEls;
        }
        else if (type === 'highlight') {
            containerEls = timeGrid.highlightContainerEls;
        }
        timeGrid.updateSegVerticals(segs);
        timeGrid.attachSegsByCol(timeGrid.groupSegsByCol(segs), containerEls);
        return segs.map(function (seg) {
            return seg.el[0];
        });
    };
    return TimeGridFillRenderer;
}(FillRenderer_1.default));
exports.default = TimeGridFillRenderer;


/***/ }),
/* 249 */
/***/ (function(module, exports, __webpack_require__) {

/* A rectangular panel that is absolutely positioned over other content
------------------------------------------------------------------------------------------------------------------------
Options:
  - className (string)
  - content (HTML string or jQuery element set)
  - parentEl
  - top
  - left
  - right (the x coord of where the right edge should be. not a "CSS" right)
  - autoHide (boolean)
  - show (callback)
  - hide (callback)
*/
Object.defineProperty(exports, "__esModule", { value: true });
var $ = __webpack_require__(3);
var util_1 = __webpack_require__(4);
var ListenerMixin_1 = __webpack_require__(7);
var Popover = /** @class */ (function () {
    function Popover(options) {
        this.isHidden = true;
        this.margin = 10; // the space required between the popover and the edges of the scroll container
        this.options = options || {};
    }
    // Shows the popover on the specified position. Renders it if not already
    Popover.prototype.show = function () {
        if (this.isHidden) {
            if (!this.el) {
                this.render();
            }
            this.el.show();
            this.position();
            this.isHidden = false;
            this.trigger('show');
        }
    };
    // Hides the popover, through CSS, but does not remove it from the DOM
    Popover.prototype.hide = function () {
        if (!this.isHidden) {
            this.el.hide();
            this.isHidden = true;
            this.trigger('hide');
        }
    };
    // Creates `this.el` and renders content inside of it
    Popover.prototype.render = function () {
        var _this = this;
        var options = this.options;
        this.el = $('<div class="fc-popover"/>')
            .addClass(options.className || '')
            .css({
            // position initially to the top left to avoid creating scrollbars
            top: 0,
            left: 0
        })
            .append(options.content)
            .appendTo(options.parentEl);
        // when a click happens on anything inside with a 'fc-close' className, hide the popover
        this.el.on('click', '.fc-close', function () {
            _this.hide();
        });
        if (options.autoHide) {
            this.listenTo($(document), 'mousedown', this.documentMousedown);
        }
    };
    // Triggered when the user clicks *anywhere* in the document, for the autoHide feature
    Popover.prototype.documentMousedown = function (ev) {
        // only hide the popover if the click happened outside the popover
        if (this.el && !$(ev.target).closest(this.el).length) {
            this.hide();
        }
    };
    // Hides and unregisters any handlers
    Popover.prototype.removeElement = function () {
        this.hide();
        if (this.el) {
            this.el.remove();
            this.el = null;
        }
        this.stopListeningTo($(document), 'mousedown');
    };
    // Positions the popover optimally, using the top/left/right options
    Popover.prototype.position = function () {
        var options = this.options;
        var origin = this.el.offsetParent().offset();
        var width = this.el.outerWidth();
        var height = this.el.outerHeight();
        var windowEl = $(window);
        var viewportEl = util_1.getScrollParent(this.el);
        var viewportTop;
        var viewportLeft;
        var viewportOffset;
        var top; // the "position" (not "offset") values for the popover
        var left; //
        // compute top and left
        top = options.top || 0;
        if (options.left !== undefined) {
            left = options.left;
        }
        else if (options.right !== undefined) {
            left = options.right - width; // derive the left value from the right value
        }
        else {
            left = 0;
        }
        if (viewportEl.is(window) || viewportEl.is(document)) {
            viewportEl = windowEl;
            viewportTop = 0; // the window is always at the top left
            viewportLeft = 0; // (and .offset() won't work if called here)
        }
        else {
            viewportOffset = viewportEl.offset();
            viewportTop = viewportOffset.top;
            viewportLeft = viewportOffset.left;
        }
        // if the window is scrolled, it causes the visible area to be further down
        viewportTop += windowEl.scrollTop();
        viewportLeft += windowEl.scrollLeft();
        // constrain to the view port. if constrained by two edges, give precedence to top/left
        if (options.viewportConstrain !== false) {
            top = Math.min(top, viewportTop + viewportEl.outerHeight() - height - this.margin);
            top = Math.max(top, viewportTop + this.margin);
            left = Math.min(left, viewportLeft + viewportEl.outerWidth() - width - this.margin);
            left = Math.max(left, viewportLeft + this.margin);
        }
        this.el.css({
            top: top - origin.top,
            left: left - origin.left
        });
    };
    // Triggers a callback. Calls a function in the option hash of the same name.
    // Arguments beyond the first `name` are forwarded on.
    // TODO: better code reuse for this. Repeat code
    Popover.prototype.trigger = function (name) {
        if (this.options[name]) {
            this.options[name].apply(this, Array.prototype.slice.call(arguments, 1));
        }
    };
    return Popover;
}());
exports.default = Popover;
ListenerMixin_1.default.mixInto(Popover);


/***/ }),
/* 250 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var $ = __webpack_require__(3);
var util_1 = __webpack_require__(4);
var EventRenderer_1 = __webpack_require__(42);
/* Event-rendering methods for the DayGrid class
----------------------------------------------------------------------------------------------------------------------*/
var DayGridEventRenderer = /** @class */ (function (_super) {
    tslib_1.__extends(DayGridEventRenderer, _super);
    function DayGridEventRenderer(dayGrid, fillRenderer) {
        var _this = _super.call(this, dayGrid, fillRenderer) || this;
        _this.dayGrid = dayGrid;
        return _this;
    }
    DayGridEventRenderer.prototype.renderBgRanges = function (eventRanges) {
        // don't render timed background events
        eventRanges = $.grep(eventRanges, function (eventRange) {
            return eventRange.eventDef.isAllDay();
        });
        _super.prototype.renderBgRanges.call(this, eventRanges);
    };
    // Renders the given foreground event segments onto the grid
    DayGridEventRenderer.prototype.renderFgSegs = function (segs) {
        var rowStructs = this.rowStructs = this.renderSegRows(segs);
        // append to each row's content skeleton
        this.dayGrid.rowEls.each(function (i, rowNode) {
            $(rowNode).find('.fc-content-skeleton > table').append(rowStructs[i].tbodyEl);
        });
    };
    // Unrenders all currently rendered foreground event segments
    DayGridEventRenderer.prototype.unrenderFgSegs = function () {
        var rowStructs = this.rowStructs || [];
        var rowStruct;
        while ((rowStruct = rowStructs.pop())) {
            rowStruct.tbodyEl.remove();
        }
        this.rowStructs = null;
    };
    // Uses the given events array to generate <tbody> elements that should be appended to each row's content skeleton.
    // Returns an array of rowStruct objects (see the bottom of `renderSegRow`).
    // PRECONDITION: each segment shoud already have a rendered and assigned `.el`
    DayGridEventRenderer.prototype.renderSegRows = function (segs) {
        var rowStructs = [];
        var segRows;
        var row;
        segRows = this.groupSegRows(segs); // group into nested arrays
        // iterate each row of segment groupings
        for (row = 0; row < segRows.length; row++) {
            rowStructs.push(this.renderSegRow(row, segRows[row]));
        }
        return rowStructs;
    };
    // Given a row # and an array of segments all in the same row, render a <tbody> element, a skeleton that contains
    // the segments. Returns object with a bunch of internal data about how the render was calculated.
    // NOTE: modifies rowSegs
    DayGridEventRenderer.prototype.renderSegRow = function (row, rowSegs) {
        var colCnt = this.dayGrid.colCnt;
        var segLevels = this.buildSegLevels(rowSegs); // group into sub-arrays of levels
        var levelCnt = Math.max(1, segLevels.length); // ensure at least one level
        var tbody = $('<tbody/>');
        var segMatrix = []; // lookup for which segments are rendered into which level+col cells
        var cellMatrix = []; // lookup for all <td> elements of the level+col matrix
        var loneCellMatrix = []; // lookup for <td> elements that only take up a single column
        var i;
        var levelSegs;
        var col;
        var tr;
        var j;
        var seg;
        var td;
        // populates empty cells from the current column (`col`) to `endCol`
        function emptyCellsUntil(endCol) {
            while (col < endCol) {
                // try to grab a cell from the level above and extend its rowspan. otherwise, create a fresh cell
                td = (loneCellMatrix[i - 1] || [])[col];
                if (td) {
                    td.attr('rowspan', parseInt(td.attr('rowspan') || 1, 10) + 1);
                }
                else {
                    td = $('<td/>');
                    tr.append(td);
                }
                cellMatrix[i][col] = td;
                loneCellMatrix[i][col] = td;
                col++;
            }
        }
        for (i = 0; i < levelCnt; i++) {
            levelSegs = segLevels[i];
            col = 0;
            tr = $('<tr/>');
            segMatrix.push([]);
            cellMatrix.push([]);
            loneCellMatrix.push([]);
            // levelCnt might be 1 even though there are no actual levels. protect against this.
            // this single empty row is useful for styling.
            if (levelSegs) {
                for (j = 0; j < levelSegs.length; j++) {
                    seg = levelSegs[j];
                    emptyCellsUntil(seg.leftCol);
                    // create a container that occupies or more columns. append the event element.
                    td = $('<td class="fc-event-container"/>').append(seg.el);
                    if (seg.leftCol !== seg.rightCol) {
                        td.attr('colspan', seg.rightCol - seg.leftCol + 1);
                    }
                    else {
                        loneCellMatrix[i][col] = td;
                    }
                    while (col <= seg.rightCol) {
                        cellMatrix[i][col] = td;
                        segMatrix[i][col] = seg;
                        col++;
                    }
                    tr.append(td);
                }
            }
            emptyCellsUntil(colCnt); // finish off the row
            this.dayGrid.bookendCells(tr);
            tbody.append(tr);
        }
        return {
            row: row,
            tbodyEl: tbody,
            cellMatrix: cellMatrix,
            segMatrix: segMatrix,
            segLevels: segLevels,
            segs: rowSegs
        };
    };
    // Stacks a flat array of segments, which are all assumed to be in the same row, into subarrays of vertical levels.
    // NOTE: modifies segs
    DayGridEventRenderer.prototype.buildSegLevels = function (segs) {
        var levels = [];
        var i;
        var seg;
        var j;
        // Give preference to elements with certain criteria, so they have
        // a chance to be closer to the top.
        this.sortEventSegs(segs);
        for (i = 0; i < segs.length; i++) {
            seg = segs[i];
            // loop through levels, starting with the topmost, until the segment doesn't collide with other segments
            for (j = 0; j < levels.length; j++) {
                if (!isDaySegCollision(seg, levels[j])) {
                    break;
                }
            }
            // `j` now holds the desired subrow index
            seg.level = j;
            // create new level array if needed and append segment
            (levels[j] || (levels[j] = [])).push(seg);
        }
        // order segments left-to-right. very important if calendar is RTL
        for (j = 0; j < levels.length; j++) {
            levels[j].sort(compareDaySegCols);
        }
        return levels;
    };
    // Given a flat array of segments, return an array of sub-arrays, grouped by each segment's row
    DayGridEventRenderer.prototype.groupSegRows = function (segs) {
        var segRows = [];
        var i;
        for (i = 0; i < this.dayGrid.rowCnt; i++) {
            segRows.push([]);
        }
        for (i = 0; i < segs.length; i++) {
            segRows[segs[i].row].push(segs[i]);
        }
        return segRows;
    };
    // Computes a default event time formatting string if `timeFormat` is not explicitly defined
    DayGridEventRenderer.prototype.computeEventTimeFormat = function () {
        return this.opt('extraSmallTimeFormat'); // like "6p" or "6:30p"
    };
    // Computes a default `displayEventEnd` value if one is not expliclty defined
    DayGridEventRenderer.prototype.computeDisplayEventEnd = function () {
        return this.dayGrid.colCnt === 1; // we'll likely have space if there's only one day
    };
    // Builds the HTML to be used for the default element for an individual segment
    DayGridEventRenderer.prototype.fgSegHtml = function (seg, disableResizing) {
        var view = this.view;
        var eventDef = seg.footprint.eventDef;
        var isAllDay = seg.footprint.componentFootprint.isAllDay;
        var isDraggable = view.isEventDefDraggable(eventDef);
        var isResizableFromStart = !disableResizing && isAllDay &&
            seg.isStart && view.isEventDefResizableFromStart(eventDef);
        var isResizableFromEnd = !disableResizing && isAllDay &&
            seg.isEnd && view.isEventDefResizableFromEnd(eventDef);
        var classes = this.getSegClasses(seg, isDraggable, isResizableFromStart || isResizableFromEnd);
        var skinCss = util_1.cssToStr(this.getSkinCss(eventDef));
        var timeHtml = '';
        var timeText;
        var titleHtml;
        classes.unshift('fc-day-grid-event', 'fc-h-event');
        // Only display a timed events time if it is the starting segment
        if (seg.isStart) {
            timeText = this.getTimeText(seg.footprint);
            if (timeText) {
                timeHtml = '<span class="fc-time">' + util_1.htmlEscape(timeText) + '</span>';
            }
        }
        titleHtml =
            '<span class="fc-title">' +
                (util_1.htmlEscape(eventDef.title || '') || '&nbsp;') + // we always want one line of height
                '</span>';
        return '<a class="' + classes.join(' ') + '"' +
            (eventDef.url ?
                ' href="' + util_1.htmlEscape(eventDef.url) + '"' :
                '') +
            (skinCss ?
                ' style="' + skinCss + '"' :
                '') +
            '>' +
            '<div class="fc-content">' +
            (this.dayGrid.isRTL ?
                titleHtml + ' ' + timeHtml : // put a natural space in between
                timeHtml + ' ' + titleHtml //
            ) +
            '</div>' +
            (isResizableFromStart ?
                '<div class="fc-resizer fc-start-resizer" />' :
                '') +
            (isResizableFromEnd ?
                '<div class="fc-resizer fc-end-resizer" />' :
                '') +
            '</a>';
    };
    return DayGridEventRenderer;
}(EventRenderer_1.default));
exports.default = DayGridEventRenderer;
// Computes whether two segments' columns collide. They are assumed to be in the same row.
function isDaySegCollision(seg, otherSegs) {
    var i;
    var otherSeg;
    for (i = 0; i < otherSegs.length; i++) {
        otherSeg = otherSegs[i];
        if (otherSeg.leftCol <= seg.rightCol &&
            otherSeg.rightCol >= seg.leftCol) {
            return true;
        }
    }
    return false;
}
// A cmp function for determining the leftmost event
function compareDaySegCols(a, b) {
    return a.leftCol - b.leftCol;
}


/***/ }),
/* 251 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var $ = __webpack_require__(3);
var HelperRenderer_1 = __webpack_require__(58);
var DayGridHelperRenderer = /** @class */ (function (_super) {
    tslib_1.__extends(DayGridHelperRenderer, _super);
    function DayGridHelperRenderer() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    // Renders a mock "helper" event. `sourceSeg` is the associated internal segment object. It can be null.
    DayGridHelperRenderer.prototype.renderSegs = function (segs, sourceSeg) {
        var helperNodes = [];
        var rowStructs;
        // TODO: not good to call eventRenderer this way
        rowStructs = this.eventRenderer.renderSegRows(segs);
        // inject each new event skeleton into each associated row
        this.component.rowEls.each(function (row, rowNode) {
            var rowEl = $(rowNode); // the .fc-row
            var skeletonEl = $('<div class="fc-helper-skeleton"><table/></div>'); // will be absolutely positioned
            var skeletonTopEl;
            var skeletonTop;
            // If there is an original segment, match the top position. Otherwise, put it at the row's top level
            if (sourceSeg && sourceSeg.row === row) {
                skeletonTop = sourceSeg.el.position().top;
            }
            else {
                skeletonTopEl = rowEl.find('.fc-content-skeleton tbody');
                if (!skeletonTopEl.length) {
                    skeletonTopEl = rowEl.find('.fc-content-skeleton table');
                }
                skeletonTop = skeletonTopEl.position().top;
            }
            skeletonEl.css('top', skeletonTop)
                .find('table')
                .append(rowStructs[row].tbodyEl);
            rowEl.append(skeletonEl);
            helperNodes.push(skeletonEl[0]);
        });
        return $(helperNodes); // must return the elements rendered
    };
    return DayGridHelperRenderer;
}(HelperRenderer_1.default));
exports.default = DayGridHelperRenderer;


/***/ }),
/* 252 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var $ = __webpack_require__(3);
var FillRenderer_1 = __webpack_require__(57);
var DayGridFillRenderer = /** @class */ (function (_super) {
    tslib_1.__extends(DayGridFillRenderer, _super);
    function DayGridFillRenderer() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.fillSegTag = 'td'; // override the default tag name
        return _this;
    }
    DayGridFillRenderer.prototype.attachSegEls = function (type, segs) {
        var nodes = [];
        var i;
        var seg;
        var skeletonEl;
        for (i = 0; i < segs.length; i++) {
            seg = segs[i];
            skeletonEl = this.renderFillRow(type, seg);
            this.component.rowEls.eq(seg.row).append(skeletonEl);
            nodes.push(skeletonEl[0]);
        }
        return nodes;
    };
    // Generates the HTML needed for one row of a fill. Requires the seg's el to be rendered.
    DayGridFillRenderer.prototype.renderFillRow = function (type, seg) {
        var colCnt = this.component.colCnt;
        var startCol = seg.leftCol;
        var endCol = seg.rightCol + 1;
        var className;
        var skeletonEl;
        var trEl;
        if (type === 'businessHours') {
            className = 'bgevent';
        }
        else {
            className = type.toLowerCase();
        }
        skeletonEl = $('<div class="fc-' + className + '-skeleton">' +
            '<table><tr/></table>' +
            '</div>');
        trEl = skeletonEl.find('tr');
        if (startCol > 0) {
            trEl.append('<td colspan="' + startCol + '"/>');
        }
        trEl.append(seg.el.attr('colspan', endCol - startCol));
        if (endCol < colCnt) {
            trEl.append('<td colspan="' + (colCnt - endCol) + '"/>');
        }
        this.component.bookendCells(trEl);
        return skeletonEl;
    };
    return DayGridFillRenderer;
}(FillRenderer_1.default));
exports.default = DayGridFillRenderer;


/***/ }),
/* 253 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var BasicViewDateProfileGenerator_1 = __webpack_require__(228);
var UnzonedRange_1 = __webpack_require__(5);
var MonthViewDateProfileGenerator = /** @class */ (function (_super) {
    tslib_1.__extends(MonthViewDateProfileGenerator, _super);
    function MonthViewDateProfileGenerator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    // Computes the date range that will be rendered.
    MonthViewDateProfileGenerator.prototype.buildRenderRange = function (currentUnzonedRange, currentRangeUnit, isRangeAllDay) {
        var renderUnzonedRange = _super.prototype.buildRenderRange.call(this, currentUnzonedRange, currentRangeUnit, isRangeAllDay);
        var start = this.msToUtcMoment(renderUnzonedRange.startMs, isRangeAllDay);
        var end = this.msToUtcMoment(renderUnzonedRange.endMs, isRangeAllDay);
        var rowCnt;
        // ensure 6 weeks
        if (this.opt('fixedWeekCount')) {
            rowCnt = Math.ceil(// could be partial weeks due to hiddenDays
            end.diff(start, 'weeks', true) // dontRound=true
            );
            end.add(6 - rowCnt, 'weeks');
        }
        return new UnzonedRange_1.default(start, end);
    };
    return MonthViewDateProfileGenerator;
}(BasicViewDateProfileGenerator_1.default));
exports.default = MonthViewDateProfileGenerator;


/***/ }),
/* 254 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var util_1 = __webpack_require__(4);
var EventRenderer_1 = __webpack_require__(42);
var ListEventRenderer = /** @class */ (function (_super) {
    tslib_1.__extends(ListEventRenderer, _super);
    function ListEventRenderer() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ListEventRenderer.prototype.renderFgSegs = function (segs) {
        if (!segs.length) {
            this.component.renderEmptyMessage();
        }
        else {
            this.component.renderSegList(segs);
        }
    };
    // generates the HTML for a single event row
    ListEventRenderer.prototype.fgSegHtml = function (seg) {
        var view = this.view;
        var calendar = view.calendar;
        var theme = calendar.theme;
        var eventFootprint = seg.footprint;
        var eventDef = eventFootprint.eventDef;
        var componentFootprint = eventFootprint.componentFootprint;
        var url = eventDef.url;
        var classes = ['fc-list-item'].concat(this.getClasses(eventDef));
        var bgColor = this.getBgColor(eventDef);
        var timeHtml;
        if (componentFootprint.isAllDay) {
            timeHtml = view.getAllDayHtml();
        }
        else if (view.isMultiDayRange(componentFootprint.unzonedRange)) {
            if (seg.isStart || seg.isEnd) {
                timeHtml = util_1.htmlEscape(this._getTimeText(calendar.msToMoment(seg.startMs), calendar.msToMoment(seg.endMs), componentFootprint.isAllDay));
            }
            else {
                timeHtml = view.getAllDayHtml();
            }
        }
        else {
            // Display the normal time text for the *event's* times
            timeHtml = util_1.htmlEscape(this.getTimeText(eventFootprint));
        }
        if (url) {
            classes.push('fc-has-url');
        }
        return '<tr class="' + classes.join(' ') + '">' +
            (this.displayEventTime ?
                '<td class="fc-list-item-time ' + theme.getClass('widgetContent') + '">' +
                    (timeHtml || '') +
                    '</td>' :
                '') +
            '<td class="fc-list-item-marker ' + theme.getClass('widgetContent') + '">' +
            '<span class="fc-event-dot"' +
            (bgColor ?
                ' style="background-color:' + bgColor + '"' :
                '') +
            '></span>' +
            '</td>' +
            '<td class="fc-list-item-title ' + theme.getClass('widgetContent') + '">' +
            '<a' + (url ? ' href="' + util_1.htmlEscape(url) + '"' : '') + '>' +
            util_1.htmlEscape(eventDef.title || '') +
            '</a>' +
            '</td>' +
            '</tr>';
    };
    // like "4:00am"
    ListEventRenderer.prototype.computeEventTimeFormat = function () {
        return this.opt('mediumTimeFormat');
    };
    return ListEventRenderer;
}(EventRenderer_1.default));
exports.default = ListEventRenderer;


/***/ }),
/* 255 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var $ = __webpack_require__(3);
var EventPointing_1 = __webpack_require__(59);
var ListEventPointing = /** @class */ (function (_super) {
    tslib_1.__extends(ListEventPointing, _super);
    function ListEventPointing() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    // for events with a url, the whole <tr> should be clickable,
    // but it's impossible to wrap with an <a> tag. simulate this.
    ListEventPointing.prototype.handleClick = function (seg, ev) {
        var url;
        _super.prototype.handleClick.call(this, seg, ev); // might prevent the default action
        // not clicking on or within an <a> with an href
        if (!$(ev.target).closest('a[href]').length) {
            url = seg.footprint.eventDef.url;
            if (url && !ev.isDefaultPrevented()) {
                window.location.href = url; // simulate link click
            }
        }
    };
    return ListEventPointing;
}(EventPointing_1.default));
exports.default = ListEventPointing;


/***/ }),
/* 256 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var EventSourceParser_1 = __webpack_require__(38);
var ArrayEventSource_1 = __webpack_require__(52);
var FuncEventSource_1 = __webpack_require__(215);
var JsonFeedEventSource_1 = __webpack_require__(216);
EventSourceParser_1.default.registerClass(ArrayEventSource_1.default);
EventSourceParser_1.default.registerClass(FuncEventSource_1.default);
EventSourceParser_1.default.registerClass(JsonFeedEventSource_1.default);


/***/ }),
/* 257 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var ThemeRegistry_1 = __webpack_require__(51);
var StandardTheme_1 = __webpack_require__(213);
var JqueryUiTheme_1 = __webpack_require__(214);
var Bootstrap3Theme_1 = __webpack_require__(258);
var Bootstrap4Theme_1 = __webpack_require__(259);
ThemeRegistry_1.defineThemeSystem('standard', StandardTheme_1.default);
ThemeRegistry_1.defineThemeSystem('jquery-ui', JqueryUiTheme_1.default);
ThemeRegistry_1.defineThemeSystem('bootstrap3', Bootstrap3Theme_1.default);
ThemeRegistry_1.defineThemeSystem('bootstrap4', Bootstrap4Theme_1.default);


/***/ }),
/* 258 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var Theme_1 = __webpack_require__(19);
var Bootstrap3Theme = /** @class */ (function (_super) {
    tslib_1.__extends(Bootstrap3Theme, _super);
    function Bootstrap3Theme() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return Bootstrap3Theme;
}(Theme_1.default));
exports.default = Bootstrap3Theme;
Bootstrap3Theme.prototype.classes = {
    widget: 'fc-bootstrap3',
    tableGrid: 'table-bordered',
    tableList: 'table',
    tableListHeading: 'active',
    buttonGroup: 'btn-group',
    button: 'btn btn-default',
    stateActive: 'active',
    stateDisabled: 'disabled',
    today: 'alert alert-info',
    popover: 'panel panel-default',
    popoverHeader: 'panel-heading',
    popoverContent: 'panel-body',
    // day grid
    // for left/right border color when border is inset from edges (all-day in agenda view)
    // avoid `panel` class b/c don't want margins/radius. only border color.
    headerRow: 'panel-default',
    dayRow: 'panel-default',
    // list view
    listView: 'panel panel-default'
};
Bootstrap3Theme.prototype.baseIconClass = 'glyphicon';
Bootstrap3Theme.prototype.iconClasses = {
    close: 'glyphicon-remove',
    prev: 'glyphicon-chevron-left',
    next: 'glyphicon-chevron-right',
    prevYear: 'glyphicon-backward',
    nextYear: 'glyphicon-forward'
};
Bootstrap3Theme.prototype.iconOverrideOption = 'bootstrapGlyphicons';
Bootstrap3Theme.prototype.iconOverrideCustomButtonOption = 'bootstrapGlyphicon';
Bootstrap3Theme.prototype.iconOverridePrefix = 'glyphicon-';


/***/ }),
/* 259 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = __webpack_require__(2);
var Theme_1 = __webpack_require__(19);
var Bootstrap4Theme = /** @class */ (function (_super) {
    tslib_1.__extends(Bootstrap4Theme, _super);
    function Bootstrap4Theme() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return Bootstrap4Theme;
}(Theme_1.default));
exports.default = Bootstrap4Theme;
Bootstrap4Theme.prototype.classes = {
    widget: 'fc-bootstrap4',
    tableGrid: 'table-bordered',
    tableList: 'table',
    tableListHeading: 'table-active',
    buttonGroup: 'btn-group',
    button: 'btn btn-primary',
    stateActive: 'active',
    stateDisabled: 'disabled',
    today: 'alert alert-info',
    popover: 'card card-primary',
    popoverHeader: 'card-header',
    popoverContent: 'card-body',
    // day grid
    // for left/right border color when border is inset from edges (all-day in agenda view)
    // avoid `table` class b/c don't want margins/padding/structure. only border color.
    headerRow: 'table-bordered',
    dayRow: 'table-bordered',
    // list view
    listView: 'card card-primary'
};
Bootstrap4Theme.prototype.baseIconClass = 'fa';
Bootstrap4Theme.prototype.iconClasses = {
    close: 'fa-times',
    prev: 'fa-chevron-left',
    next: 'fa-chevron-right',
    prevYear: 'fa-angle-double-left',
    nextYear: 'fa-angle-double-right'
};
Bootstrap4Theme.prototype.iconOverrideOption = 'bootstrapFontAwesome';
Bootstrap4Theme.prototype.iconOverrideCustomButtonOption = 'bootstrapFontAwesome';
Bootstrap4Theme.prototype.iconOverridePrefix = 'fa-';


/***/ }),
/* 260 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var ViewRegistry_1 = __webpack_require__(22);
var BasicView_1 = __webpack_require__(62);
var MonthView_1 = __webpack_require__(229);
ViewRegistry_1.defineView('basic', {
    'class': BasicView_1.default
});
ViewRegistry_1.defineView('basicDay', {
    type: 'basic',
    duration: { days: 1 }
});
ViewRegistry_1.defineView('basicWeek', {
    type: 'basic',
    duration: { weeks: 1 }
});
ViewRegistry_1.defineView('month', {
    'class': MonthView_1.default,
    duration: { months: 1 },
    defaults: {
        fixedWeekCount: true
    }
});


/***/ }),
/* 261 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var ViewRegistry_1 = __webpack_require__(22);
var AgendaView_1 = __webpack_require__(226);
ViewRegistry_1.defineView('agenda', {
    'class': AgendaView_1.default,
    defaults: {
        allDaySlot: true,
        slotDuration: '00:30:00',
        slotEventOverlap: true // a bad name. confused with overlap/constraint system
    }
});
ViewRegistry_1.defineView('agendaDay', {
    type: 'agenda',
    duration: { days: 1 }
});
ViewRegistry_1.defineView('agendaWeek', {
    type: 'agenda',
    duration: { weeks: 1 }
});


/***/ }),
/* 262 */
/***/ (function(module, exports, __webpack_require__) {

Object.defineProperty(exports, "__esModule", { value: true });
var ViewRegistry_1 = __webpack_require__(22);
var ListView_1 = __webpack_require__(230);
ViewRegistry_1.defineView('list', {
    'class': ListView_1.default,
    buttonTextKey: 'list',
    defaults: {
        buttonText: 'list',
        listDayFormat: 'LL',
        noEventsMessage: 'No events to display'
    }
});
ViewRegistry_1.defineView('listDay', {
    type: 'list',
    duration: { days: 1 },
    defaults: {
        listDayFormat: 'dddd' // day-of-week is all we need. full date is probably in header
    }
});
ViewRegistry_1.defineView('listWeek', {
    type: 'list',
    duration: { weeks: 1 },
    defaults: {
        listDayFormat: 'dddd',
        listDayAltFormat: 'LL'
    }
});
ViewRegistry_1.defineView('listMonth', {
    type: 'list',
    duration: { month: 1 },
    defaults: {
        listDayAltFormat: 'dddd' // day-of-week is nice-to-have
    }
});
ViewRegistry_1.defineView('listYear', {
    type: 'list',
    duration: { year: 1 },
    defaults: {
        listDayAltFormat: 'dddd' // day-of-week is nice-to-have
    }
});


/***/ }),
/* 263 */
/***/ (function(module, exports) {

Object.defineProperty(exports, "__esModule", { value: true });


/***/ })
/******/ ]);
});
 /*
 * The Calendar widget.
 */
 define('w/calendar',["jquery", "lodash", "moment", "oauth", "fullcalendar"], function($, _, moment, OAuth) { 
 	return {
		id: 10,
		sort: 110,
		size: 1,
		order: 7,
		interval: 300000,
		nicename: "calendar",
		sizes: ["variable"],
		settings: [
			{
				type: "text",
				nicename: "title",
				label: "i18n.settings.title",
				placeholder: "i18n.settings.title_placeholder"
			},
			{
				type: "select",
				multiple: true,
				label: "i18n.settings.calendar",
				nicename: "calendars",
				options: "getCalendars"
			},
			{
				type: "radio",
				label: "i18n.settings.show",
				nicename: "show",
				options: {
					all: "i18n.settings.show_options.all",
					today: "i18n.settings.show_options.today"
				}
			},
			{
				type: "radio",
				label: "i18n.settings.view",
				nicename: "view",
				options: {
					agenda1d: "i18n.settings.view_options.agenda1d",
					list2w: "i18n.settings.view_options.list2w",
					short1d: "i18n.settings.view_options.short1d",
				},
			},
			{
				type: "time",
				label: "i18n.settings.range.start",
				nicename: "startTime"
			},
			{
				type: "time",
				label: "i18n.settings.range.end",
				nicename: "endTime"
			},
			{
				type: "radio",
				label: "i18n.settings.timezone.title",
				nicename: "timezone",
				options: {
					calendar: "i18n.settings.timezone.calendar",
					local: "i18n.settings.timezone.local",
				},
			},
			{
				type: "text",
				nicename: "textcolor",
				label: "i18n.settings.text.color",
				placeholder: "i18n.settings.text.placeholder"
			}
		],
		config: {
			title: "i18n.title",
			size: "variable",
			show: "all",
			view: "agenda1d",
			startTime: "08:00",
			endTime: "22:00",
			calendars: [],
			timezone: "local"
		},
		data: {
			events: [
				{
					"url": "https://www.google.com/calendar",
					"title": "Multi-day Event",
					"start": "2018-07-19",
					"end": "2018-07-22",
					"calendar": "Personal",
					"calendarId": "Personal",
					"location": "Mountain View, CA, USA",
					"color": "#4986e7"
				},
				{
					"url": "https://www.google.com/calendar",
					"title": "Single day event",
					"start": "2018-07-19",
					"calendar": "Secondary Calendar",
					"calendarId": "Secondary Calendar",
					"color": "#ffad46"
				},
				{
					"url": "https://www.google.com/calendar",
					"title": "Lunch",
					"start": "2018-07-19 12:00:00",
					"end": "2018-07-19 13:00:00",
					"calendar": "Secondary Calendar",
					"calendarId": "Secondary Calendar",
					"color": "#ffad46"
				},
				{
					"url": "https://www.google.com/calendar",
					"title": "Meeting",
					"start": "2018-07-19 15:00:00",
					"end": "2018-07-19 16:00:00",
					"calendar": "Secondary Calendar",
					"calendarId": "Secondary Calendar",
					"color": "#ffad46"
				},
				{
					"url": "https://www.google.com/calendar",
					"title": "Dinner",
					"start": "2018-07-19 16:30:00",
					"end": "2018-07-19 19:30:00",
					"calendar": "emailaddress@gmail.com",
					"calendarId": "emailaddress@gmail.com",
					"color": "#4986e7"
				}
			]
		},
		oAuth: false,
		setOAuth: function() {
			this.oAuth = new OAuth({
				name: "calendar",
				id: "559765430405-2710gl95r9js4c6m4q9nveijgjji50b8.apps.googleusercontent.com",
				secret: "QLlFpcECWen5pm-7XWj-fMS3",
				scope: "https://www.googleapis.com/auth/calendar.readonly https://www.googleapis.com/auth/calendar"
			});
		},
		getCalendars: function(cb) {
			if (!this.oAuth) {
				this.setOAuth();
			}

			this.oAuth.ajax({
				type: "GET",
				dataType: "json",
				url: "https://www.googleapis.com/calendar/v3/users/me/calendarList/",
				success: function(d) {
					if (!d || !d.items) {
						return cb("error");
					}

					var calendars = {};

					d.items.forEach(function(e) {
						calendars[e.id] = e.summary;
					});

					cb(calendars);
				}
			});
		},
		refresh: function() {
			if (!this.oAuth) {
				this.setOAuth();
			}

			this.config.calendars = this.config.calendars || [];

			if (!this.config.calendars.length) {
				if (this.config.calendar) {
					this.config.calendars = [this.config.calendar];

					delete this.config.calendar;
				}
				else {
					return false;
				}
			}


			this.oAuth.getToken(function(token) {
				var events = [],
					multiple = this.config.calendars.length > 1,
					params = {
						singleEvents: true,
						orderBy: "startTime",
						timeMin: moment().startOf("day").format("YYYY-MM-DDTHH:mm:ss.SSSZ"),
						timeMax: moment().startOf("day").add(14, 'days').format("YYYY-MM-DDTHH:mm:ss.SSSZ"),
						fields: "summary,items(description,htmlLink,id,location,start,end,summary)"
					};

					if (this.config.timezone && this.config.timezone === "local") {
						try { params.timeZone = Intl.DateTimeFormat().resolvedOptions().timeZone; } catch(e) {}
					}
					

				if (this.config.show === "today") {
					params.timeMax = moment().endOf("day").format("YYYY-MM-DDTHH:mm:ss.SSSZ");
				}

				var requests = [],
					calendarColors = {};

				if (multiple) {
					requests.push($.ajax({
						type: "GET",
						dataType: "json",
						url: "https://www.googleapis.com/calendar/v3/users/me/calendarList?fields=items(backgroundColor%2Cid)",
						beforeSend: function(xhr) {
							xhr.setRequestHeader("Authorization", "Bearer " + token);
						},
						success: function(d) {
							if (!d || !d.items) {
								return;
							}

							d.items.forEach(function(e) {
								if (e.backgroundColor) {
									calendarColors[e.id] = e.backgroundColor;
								}
							});
						}.bind(this)
					}));
				}

				requests = requests.concat(_.map(this.config.calendars, function(calendar) {
					return $.ajax({
						type: "GET",
						dataType: "json",
						data: params,
						cache: false,
						url: "https://www.googleapis.com/calendar/v3/calendars/" + encodeURIComponent(calendar) + "/events",
						beforeSend: function(xhr) {
							xhr.setRequestHeader("Authorization", "Bearer " + token);
						},
						success: function(d) {
							if (d && d.items) {
								events = events.concat(_.map(d.items, function(e) {
									var event = {
										id: e.id,
										title: e.summary,
										start: e.start.dateTime || e.start.date,
										end: e.end.dateTime || e.end.date,
										url: e.htmlLink,
									};

									if (multiple && d.summary) {
										event.calendar = d.summary;
									}

									if (multiple) {
										event.calendarId = calendar;
									}

									if (e.location) {
										event.location = e.location;
									}

									if (e.description) {
										event.description = e.description;
									}

									return event;
								}, this));
							}
						}.bind(this)
					});
				}, this));

				$.when.apply($, requests).then(function() {
					if (multiple && Object.keys(calendarColors).length) {
						events = events.map(function(e) {
							if (e.calendarId && calendarColors[e.calendarId]) {
								e.color = calendarColors[e.calendarId];
							}

							return e;
						});
					}

					if (events.length > 0) {
						var startDate = this.getRange(events).start;
						var maxEvents = 40;
						if (events.length > maxEvents) {
							//Remove extra days from array until it is < 40
							var days = 13;
							while (days > 1 && events.length > maxEvents) {
								var endDate = moment(startDate).add(days, 'days');
								events = _.filter(events, function(e) {
									return moment(e.start, moment.ISO_8601).startOf('day').diff(endDate) < 0;
								});
	
								days--;
							}
						}
					}

					this.data = {
						events: events
					};

					var gcalendar = this.elm.children('.gcalendar');
					gcalendar.fullCalendar('removeEventSources');
					gcalendar.fullCalendar('option', 'validRange', this.getRange(events));
					gcalendar.fullCalendar('addEventSource', this.data.events);

					this.utils.saveData(this.data);
				}.bind(this));
			}.bind(this));
		},

		render: function(demo) {
			var data = _.clone(this.data, true);

			data.title = this.config.title;

			if (!demo && (!this.config.calendars || !this.config.calendars.length)) {
				data.noCalendars = true;
				this.utils.render(data);
				return;
			}

			this.utils.render(data);

			if (_.indexOf(["agenda1d", "list2w", "short1d"], this.config.view) < 0) {
				this.config.view = "agenda1d";
			}

			var gcalendar = this.elm.children('.gcalendar');
			var settings = {
				header: {
					left: 'prev,next today',
					center: 'title',
					//right: ''
					right: 'agenda1d,list2w,short1d'
				},
				height: "auto",
				displayEventTime: true, 
				showNonCurrentDates : false,
				eventLimit: true, 
				defaultView: this.config.view,
				eventRender: function(event, element) {
					var location = _.isString(event.location) ? "Location: " + event.location : null;
					var calendar = _.isString(event.calendar) ? "Calendar: " + event.calendar : null;
					element.attr('data-tooltip', [event.description, location, calendar].filter(Boolean).join('<br>'));
				},
				lazyFetching: false,
				viewRender: function(view) {
					if (this.config.view !== view.name) {
						this.config.view = view.name;
						this.utils.saveConfig();

						var gcal = this.elm.children('.gcalendar');
						if (view.name === "short1d") {
							this.lastDate = gcal.fullCalendar('getDate');
							gcal.fullCalendar('today');
						}else{
							if (this.lastDate) {
								gcal.fullCalendar('gotoDate', this.lastDate);
							}

							this.lastDate = null;
						}
					}
				}.bind(this),
				views: {
					short1d:  {
						type: 'list',
						duration: { weeks: 3 },
						buttonText: 'list'
					},
					list2w:  {
						type: 'basic',
						duration: {days: 1 },
						buttonText: 'short',
						eventLimit: false, 
					},
					agenda1d:  {
						type: 'agenda',
						duration: {days: 1 },
						buttonText: 'agenda'
					}
				}    
			};

			if (_.isString(this.config.textcolor) && this.config.textcolor !== '') {
				settings.eventTextColor = this.config.textcolor;
			}

			if (this.config.startTime !== this.config.endTime) {
				settings.minTime = this.config.startTime;
				settings.maxTime = this.config.endTime;
			}

			if (!demo) {
				settings.validRange = this.getRange(data.events);
			}

			gcalendar.fullCalendar(settings);
			gcalendar.fullCalendar('removeEventSources');
			gcalendar.fullCalendar('addEventSource', data.events);
			if (demo) {
				setTimeout(function() {
					gcalendar.fullCalendar('refetchEvents');
					gcalendar.fullCalendar('gotoDate', moment("2018-07-19"));
				});
			}

			this.elm.addClass("tabbed");
		},

		getRange: function(events) {
			if (events.length <= 0)	{
				return {
					start: moment().startOf("day"),
					end: moment().add(2, 'weeks').startOf("day")
				};
			}

			var starts = events.map(function(e) { return moment(e.start).startOf("day"); });
			var ends = events.map(function(e) { return moment(e.end).add(1, 'days').subtract(1, 'seconds').startOf("day"); });
			
			return {
				start: starts.reduce(function(a, b) { return a.valueOf() <= b.valueOf() ? a : b; }).format('YYYY-MM-DD'),
				end: ends.reduce(function(a, b) { return a.valueOf() >= b.valueOf() ? a : b; }).format('YYYY-MM-DD')
			};
		}



	};
});
/*
 * The Chrome Bookmarks widget.
 */
define('w/chrome_bookmarks',["jquery", "lodash", "moment", "browser/api"], function($, _, moment, Browser) {
	return {
		id: 33,
		sort: 90,
		size: 2,
		order: 12,
		permissions: ["bookmarks"],
		nicename: "chrome_bookmarks",
		sizes: ["tiny", "variable"],
		settings: [
			{
				type: "text",
				nicename: "title",
				label: "i18n.settings.title",
				placeholder: "i18n.settings.title_placeholder"
			},
			{
				type: "size"
			},
			{
				type: "select",
				nicename: "from",
				options: "getFolders",
				label: "i18n.settings.from"
			},
			{
				type: "radio",
				nicename: "sync",
				label: "i18n.settings.sync",
				options: {
					0: "i18n.settings.sync_options.id",
					1: "i18n.settings.sync_options.path"
				}
			},
			{
				type: "radio",
				nicename: "target",
				label: "i18n.settings.open",
				options: {
					_self: "i18n.settings.open_options.current",
					_blank: "i18n.settings.open_options.blank"
				}
			}
		],
		config: {
			title: "i18n.name",
			size: "variable",
			from: "1", // Folder #1 is the bookmarks bar
			frompath: "",
			target: "_self",
			sync: "0"
		},


		data: {
			bookmarks: [
				{
					title: "Google",
					url: "https://www.google.com/",
					favicon: "chrome://favicon/size/16@4x/origin/http://www.google.com/"
				},
				{
					title: "Facebook",
					url: "https://www.facebook.com/",
					favicon: "chrome://favicon/size/16@4x/origin/http://www.facebook.com/"
				},
				{
					name: "Sample Folder",
					items: [
						{
							title: "Youtube",
							url: "https://www.youtube.com/",
							favicon: "chrome://favicon/size/16@4x/origin/http://www.youtube.com/"
						},
						{
							title: "Amazon",
							url: "https://www.amazon.com/",
							favicon: "chrome://favicon/size/16@4x/origin/http://www.amazon.com/"
						}
					]
				},
				{
					title: "Wikipedia",
					url: "https://www.wikipedia.org/",
					favicon: "chrome://favicon/size/16@4x/origin/http://www.wikipedia.org/"
				}
			]
		},

		flatFolders: function() {
			if (this.folders === null) {
				return [];
			}

			function isNormalInteger(str) {
				var n = Math.floor(Number(str));
				return n !== Infinity && String(n) === str && n >= 0;
			}			

			var foldersByKey = function(current, path) {
				var result = [];

				for (var propertyName in current) {
					if (current.hasOwnProperty(propertyName)) {
						if (isNormalInteger(propertyName)) {
							result.push({ key: propertyName, value: path.concat([current[propertyName]]).join("/|`") });
						}else if (propertyName.endsWith("_folders")) {
							result = result.concat(foldersByKey(current[propertyName], path.concat([current[propertyName.substring(0, propertyName.length - 8)]])));
						}

					}
				}				

				return result;
			};

			return foldersByKey(this.folders, []);
		},


		adjustConfig: function(config) {
			if (!config || !config.from || !this.folders) {
				return;
			}

			config.fromPath = "";
			if (config.from !== "1") {
				var found = this.flatFolders().filter(function(i) { return i.key === config.from; } );
				if (found && found.length === 1) {
					config.fromPath = found[0].value;
				}
			}
		},

		folders: {},

		/**
		 * Returns a listing of bookmark folders
		 *
		 * @param   {Function}  cb  The callback
		 */
		getFolders: function(cb) {
			if (!Browser.bookmarks) {
				return;
			}

			Browser.bookmarks.getTree(function(d) {
				var folders = _.reduce(d[0].children, function getFolders(res, e) {
					if (e.children) {
						res[e.id] = e.title;

						var subFolders = _.reduce(_.sortBy(e.children, "index"), getFolders, {
							label: e.title
						});

						if (Object.keys(subFolders).length > 1) {
							res[e.id + "_folders"] = subFolders;
						}
					}

					return res;
				}, {});

				this.folders = folders;

				cb(folders);
			}.bind(this));
		},


		refresh: function() {
			if (!Browser.bookmarks) {
				return;
			}

			var refreshTree = function(from)
			{
				// Even though this is a Chrome API call it takes as long as a web request
				// and therefore should be part of a refresh pattern for faster loading
				Browser.bookmarks.getSubTree(from, function(d) {
					var getItems = function(e) {
						if (e.children) {
							return {
								name: e.title,
								items: _.map(_.sortBy(e.children, "index"), getItems)
							};
						}
						else {
							return {
								url: e.url,
								favicon: Browser.getFavicon(e.url),
								title: (e.title || "").trim() || (e.url || "").replace(/^[A-z]+\:\/+(?:www\.)?/, "")
							};
						}
					};


					// Bookmarks in the root folder are not sorted properly
					var bookmarks = _.map(_.sortBy(d[0].children, "index"), getItems);

					this.data = {
						bookmarks: bookmarks
					};

					this.render();

					this.utils.saveData(this.data);
				}.bind(this));
			}.bind(this);

			var from = this.config.from;
			
			if (this.config.sync === "1" && from !== "1" && this.config.fromPath) {
				this.getFolders(function() {
					if (this.folders) {
						var ff = this.flatFolders();
						var found = ff.filter(function(i) { return i.value === this.config.fromPath; }.bind(this) );
						if (found && found.length > 0 && !found.find(function(i) { return i.key === from; })) {
							if (found.length === 1) {
								from = found[0].key;
							}
						}
					}

					refreshTree(from);
				}.bind(this));
			}

			refreshTree(from);
		},


		render: function(demo) {
			// These listeners handle updating the widget when changes occur
			if (!this.listening && !demo) {
				this.listening = true;

				var render = this.render.bind(this, false);

				if (Browser.bookmarks) {
					Browser.bookmarks.onCreated.addListener(render);
					Browser.bookmarks.onRemoved.addListener(render);
					Browser.bookmarks.onChanged.addListener(render);
					Browser.bookmarks.onMoved.addListener(render);
					Browser.bookmarks.onChildrenReordered.addListener(render);
				}
			}


			var data = {
				bookmarks: this.data.bookmarks
			};


			if (this.config.title && this.config.title !== "") {
				data.title = this.config.title;
			}

			if (this.config.target && this.config.target === "_blank") {
				data.newTab = true;
			}


			$(this.elm).off("click.folder").on("click.folder", ".list .folder", function() {
				this.classList.toggle("active");
			}).off("click.chromelink").on("click.chromelink", ".list a.link[href^='chrome']", function(e) {
				e.preventDefault();

				var href = this.getAttribute("href");

				Browser.tabs.getCurrent(function(d) {
					if (e.which === 2 || e.currentTarget.target === "_blank") {
						Browser.tabs.create({
							url: href,
							index: d.index + 1
						});
					}
					else {
						Browser.tabs.update(d.id, {
							url: href
						});
					}
				});
			});


			this.utils.render(data, {
				listing: this.utils.getTemplate("listing")
			});
		}
	};
});
/*
 * The Clock widget.
 */
define('w/clock',["jquery", "lodash", "moment", "backbone", "browser/api"], function($, _, moment, Backbone, Browser) {
	var View = Backbone.View.extend({
		events: {
			"click header.tabs .item": function(e) {
				var tab = e.currentTarget.getAttribute("data-id");

				$(e.currentTarget).add(this.$(".section." + tab)).addClass("tab-active").siblings().removeClass("tab-active");

				this.data.tab = tab;

				this.utils.saveData();
			},

			"click .alert .dismiss": function(e) {
				$(e.currentTarget).parents(".alert").first().removeClass("visible");

				if (this.audio) {
					this.audio.pause();
				}
			},

			"change .audio input[type=checkbox]": function(e) {
				this.config.audio = e.currentTarget.checked;

				this.utils.saveConfig();
			},

			"click .stopwatch .start-stop": function(e) {
				if (this.data.stopwatch && this.data.stopwatch.start) {
					this.data.stopwatch.running = !this.data.stopwatch.running;

					if (!this.data.stopwatch.running) {
						this.data.stopwatch.paused = new Date().getTime();
					}
					else if (this.data.stopwatch.paused) {
						this.data.stopwatch.start += new Date().getTime() - this.data.stopwatch.paused;

						delete this.data.stopwatch.paused;
					}
				}
				else {
					this.data.stopwatch = {
						running: true,
						start: new Date().getTime()
					};
				}

				e.currentTarget.classList.toggle("started", this.data.stopwatch.running);

				this.utils.saveData();
			},

			"click .stopwatch .reset": function() {
				delete this.data.stopwatch;

				this.stopwatchElm.innerHTML = "0:00";

				this.$(".stopwatch .start-stop").removeClass("started");

				this.utils.saveData();
			},

			"click .timer .start-stop": "startTimer",

			"keydown .timer input.time": function(e) {
				if (e.which === 13) {
					this.startTimer(e);
				}
			},

			"click .timer .reset": function() {
				delete this.data.timer;

				this.timerElm.innerHTML = "0:00";

				this.$(".section.timer").removeClass("running");
				this.$(".timer .start-stop").removeClass("started");

				this.utils.saveData();
			},

			"keydown .alarm input.time": function(e) {
				if (e.which === 13) {
					this.startAlarm(e);
				}
			},

			"click .alarm .set": "startAlarm"
		},

		intervalUpdateClock: null,
		intervalUpdate: null,
		intervalUpdateStopwatch: null,

		formatTime: function(rTime, ms) {
			var time = Math.floor(rTime / 1000);

			var days = parseInt(time / 86400),
				hours = parseInt((time % 86400) / 3600),
				minutes = parseInt((time % 3600) / 60);

			if (days) {
				return days + ":" + _.padLeft(hours, 2, "0") + ":" + _.padLeft(minutes, 2, "0") + ":" + _.padLeft(time % 60, 2, "0");
			}
			else if (hours) {
				return hours + ":" + _.padLeft(minutes, 2, "0") + ":" + _.padLeft(time % 60, 2, "0");
			}
			else {
				return minutes + ":" + _.padLeft(time % 60, 2, "0") + (ms ? "." + _.padLeft(rTime % 1000, 3, "0") : "");
			}
		},

		isAuto: function() {
			return this.config.timezone === "auto";
		},

		timeZoneOffset: function() {
			var timezone = this.config.timezone;
			if (timezone === "auto") {
				return null;
			}

			if (!isNaN(timezone)) {
				return parseInt(timezone);
			}

			var now = new Date();
			var nowYYYYMMDD = now.getUTCFullYear() * 10000 + now.getUTCMonth() * 100 + now.getUTCDate();
			var keyTimeoffset = "timeoffset" + nowYYYYMMDD;
			var keyTimezone = "timezone" + nowYYYYMMDD;

			var cachedOffset;

			var cachedTimezone = this[keyTimezone];
			if (cachedTimezone && cachedTimezone === timezone) {
				cachedOffset = this[keyTimeoffset];
				if (!isNaN(cachedOffset)) {
					return cachedOffset;
				}
			}

			var storedOffsetData = Browser.storage.clocktimezone;
			if (storedOffsetData) {
				var items = storedOffsetData.split(";");
				if (items.length === 3 && items[0] === timezone && items[2] === nowYYYYMMDD + "") {
					cachedOffset = parseInt(items[1]);
					this[keyTimeoffset] = cachedOffset;
					this[keyTimezone] = timezone;
					return cachedOffset;
				}
			}

			if (this.loadingTimeout && this.loadingTimeout > new Date().getTime()) {
				return null;
			}

			this.loadingTimeout = new Date().getTime() + 10000;

			$.ajax({
				type: "GET",
				url: "https://worldtimeapi.org/api/timezone/" + timezone,
				success: function(d) {
					if (typeof d.utc_offset !== "undefined") {
						var hhmm = d.utc_offset.split(':');
						cachedOffset = parseInt(hhmm[0]) * 60 + parseInt(hhmm[1]);
						Browser.storage.clocktimezone = timezone + ";" + cachedOffset + ";" + nowYYYYMMDD;

						this[keyTimeoffset] = cachedOffset;
						this[keyTimezone] = timezone;

						this.render();
					}
				}.bind(this),
				complete: function() {
					if (this.loadingTimeout) {
						delete this.loadingTimeout;
					}
				}.bind(this)
			});

			return null;
		},

		updateClock: function(returnHTML) {
			var html = '<div class="time',
				dt = new Date();

			if (!this.isAuto()) {
				var timeZoneOffset = this.timeZoneOffset();
				if (timeZoneOffset === null) {
					if (returnHTML) {
						return "";
					}
					else {
						this.clockElm.innerHTML = "<div>Updating...</div>";
						return;
					}
				}

				dt = new Date(dt.getTime() + dt.getTimezoneOffset() * 60000 + timeZoneOffset * 60000);
			}

			var hours = dt.getHours(),
				minutes = dt.getMinutes(),
				seconds = dt.getSeconds(),
				am = hours < 12;

			if (this.config.format.indexOf("ampm") === 0) {
				hours = (hours > 12 ? hours - 12 : hours);

				if (hours === 0) {
					hours = 12;
				}

				html += (am ? " am" : " pm") + (this.config.format === "ampms" ? " no-seconds" : "");
			}
			else {
				html += " full" + (this.config.format === "fulls" ? " no-seconds" : "");
			}

			html += '">' + hours + ":" + _.padLeft(minutes, 2, "0");

			if (this.config.size === "tiny" && this.config.format.indexOf("ampm") === 0) {
				html += "<span>" + (this.config.format === "ampm" ? _.padLeft(seconds, 2, "0") : "") + "</span></div>";
			}
			else if (this.config.size !== "tiny") {
				// moment(dt) is slower so avoid it when possible
				var date = (!this.isAuto() ? moment(dt).format("dddd, MMMM Do YYYY") : moment().format("dddd, MMMM Do YYYY"));

				if (this.config.format === "ampm" || this.config.format === "full") {
					html += ":" + _.padLeft(seconds, 2, "0");
				}

				html += '</div><div class="date">' + date + "</div>";
			}
			else {
				html += "</div>";
			}

			if (returnHTML) {
				return html;
			}
			else {
				this.clockElm.innerHTML = html;
			}
		},

		updateStopwatch: function(ret, force) {
			if (this.data.stopwatch && (this.data.stopwatch.running || force)) {
				var time = new Date().getTime() - this.data.stopwatch.start;

				var formatted = this.formatTime(time, time < 6E5);

				if (ret) {
					return formatted;
				}

				this.stopwatchElm.innerHTML = formatted;
			}
		},

		startTimer: function() {
			if (this.data.timer && this.data.timer.start) {
				this.data.timer.running = !this.data.timer.running;

				if (!this.data.timer.running) {
					this.data.timer.paused = new Date().getTime();
				}
				else if (this.data.timer.paused) {
					this.data.timer.start += new Date().getTime() - this.data.timer.paused;

					delete this.data.timer.paused;
				}
			}
			else {
				var input = this.$(".timer input.time")[0];

				input.value = input.value.replace(/[^0-9:\.]/g, "");


				var multiples = [1E3, 6E4, 36E5, 864E5];

				// This splits 0:00:00:00.00 into ["0", "00", "00", "00.00"].
				//
				// Then it reverses it, so it's [seconds, minutes, hours, days] and limits
				// it to 4 values.
				//
				// Each value is then multiplied in order by its ms multiplier. They're combined
				// leaving a single total ms value for the time input
				var duration = _(input.value.split(":")).compact().reverse().take(4).reduce(function(total, e, i) {
					total += Math.floor(e * multiples[i]);

					return total;
				}, 0);

				if (duration) {
					input.value = "";

					this.data.timer = {
						running: true,
						duration: duration,
						start: new Date().getTime()
					};
				}
			}

			var running = !!(this.data.timer && this.data.timer.running);

			this.$(".timer .start-stop").toggleClass("started", running);
			this.$(".section.timer").toggleClass("running", !!this.data.timer);

			if (running) {
				this.updateTimer();
			}

			this.utils.saveData();
		},

		updateTimer: function(ret) {
			var formatted,
				time = (this.data.timer.start + this.data.timer.duration) - new Date().getTime();

			if (time <= 0) {
				formatted = "0:00";

				this.trigger("timer:ended");

				delete this.data.timer;

				this.$(".section.timer").removeClass("running");
				this.$(".timer .start-stop").removeClass("started");

				this.utils.saveData();
			}
			else {
				formatted = this.formatTime(time);
			}

			if (ret) {
				return formatted;
			}

			this.timerElm.innerHTML = formatted;
		},

		startAlarm: function() {
			if (this.data.alarm && this.data.alarm.set) {
				this.data.alarm.set = !this.data.alarm.set;
			}
			else {
				var time = new Date().setHours(0, 0, 0, 0) + this.$(".alarm input.time")[0].valueAsNumber;

				if (time <= new Date().getTime()) {
					time += 86400000;
				}

				this.data.alarm = {
					set: true,
					time: time
				};
			}

			this.$(".alarm .set").text(this.data.alarm && this.data.alarm.set ? this.utils.translate("unset") : this.utils.translate("set"));
			this.$(".section.alarm").toggleClass("running", this.data.alarm && this.data.alarm.set);

			if (this.data.alarm && this.data.alarm.set) {
				this.updateAlarm();
			}

			this.utils.saveData();
		},

		updateAlarm: function(ret) {
			var formatted,
				time = this.data.alarm.time - new Date().getTime();

			if (this.data.alarm.time <= new Date().getTime()) {
				formatted = "0:00";

				this.trigger("alarm:ended");

				// Don't delete the entire element, preserve the last used time
				this.data.alarm.set = false;

				this.$(".alarm .set").text(this.utils.translate("set"));
				this.$(".section.alarm").removeClass("running");

				this.utils.saveData();
			}
			else {
				formatted = this.formatTime(time);
			}

			if (ret) {
				return formatted;
			}

			this.alarmElm.innerHTML = formatted;
		},

		setCache: function() {
			this.timerElm = this.$(".timer div.time")[0];
			this.alarmElm = this.$(".alarm div.time")[0];
			this.stopwatchElm = this.$(".stopwatch .time")[0];
		},

		update: function() {
			this.updateClock();

			if (this.data.alarm && this.data.alarm.set) {
				this.updateAlarm();
			}

			if (this.data.timer && this.data.timer.running) {
				this.updateTimer();
			}
		},

		playAudio: function() {
			if (this.config.audio) {
				this.audio = new Audio();

				this.audio.loop = true;
				this.audio.volume = 0.3;
				this.audio.autoplay = true;
				this.audio.src = "https://ichro.me/widgets/clock/audio/" + this.config.sound + ".ogg";
			}
		},

		initialize: function() {
			this.on("alarm:ended", function() {
				this.$(".alert.alarm .time").text(moment(this.data.alarm.time).format("h:mm A"));

				this.$(".alert.alarm").addClass("visible");

				this.playAudio();
			}).on("timer:ended", function() {
				this.$(".alert.timer .time").text(this.formatTime(this.data.timer.duration));

				this.$(".alert.timer").addClass("visible");

				this.playAudio();
			});
		},

		render: function() {
			if (this.intervalUpdateClock) {
				clearInterval(this.intervalUpdateClock);
			}

			if (this.intervalUpdate) {
				clearInterval(this.intervalUpdate);
			}

			if (this.intervalUpdateStopwatch) {
				clearInterval(this.intervalUpdateStopwatch);
			}


			this.isAnalog = (this.config.format === "analog");

			this.$el.toggleClass("analog", this.isAnalog);


			var data;

			if (this.isAnalog) {
				var dt = new Date();

				if (!this.isAuto()) {
					var timeZoneOffset = this.timeZoneOffset();
					if (timeZoneOffset === null) {
						return this.utils.render({ isLoading: true });
					}
	
					dt = new Date(dt.getTime() + dt.getTimezoneOffset() * 60000 + this.timeZoneOffset() * 60000);
				}

				data = {
					analog: true,
					mPos: dt.getMinutes() * 6 + (dt.getSeconds() / 60 * 6),
					hPos: dt.getHours() * 30 + (dt.getMinutes() / 60 * 30),
					sPos: dt.getSeconds() * 6
				};

				return this.utils.render(data);
			}

			data = JSON.parse(JSON.stringify(this.data));

			data.html = this.updateClock(true);

			data.audio = this.config.audio;

			if (this.config.size === "tiny") {
				if (this.config.title) {
					data.title = this.config.title;
				}
			}
			else {
				if (data.stopwatch) {
					if (data.stopwatch.paused) {
						data.stopwatch.start += new Date().getTime() - data.stopwatch.paused;
					}

					data.stopwatch.html = this.updateStopwatch.call({ data: data, formatTime: this.formatTime }, true, true);
				}

				if (data.timer) {
					if (data.timer.paused) {
						data.timer.start += new Date().getTime() - data.timer.paused;
					}

					data.timer.html = this.updateTimer.call({ data: data, formatTime: this.formatTime }, true);
				}

				if (data.alarm) {
					if (data.alarm.set) {
						data.alarm.html = this.updateTimer.call({ data: data, formatTime: this.formatTime }, true);
					}
				}

				data.alarm = data.alarm || {};

				data.alarm.timeStr = data.alarm.time ? _.padLeft(new Date(data.alarm.time).getHours(), 2, "0") + ":" + _.padLeft(new Date(data.alarm.time).getMinutes(), 2, "0") : "07:00";
			}

			this.utils.render(data);

			if (this.data.tab) {
				this.$(".tabs .item[data-id=" + this.data.tab + "], .section." + this.data.tab).addClass("tab-active").siblings().removeClass("tab-active");
			}


			this.clockElm = this.$(".clock")[0];

			if (this.config.size === "tiny") {
				this.intervalUpdateClock = setInterval(this.updateClock.bind(this), 1000);
			}
			else {
				this.setCache();

				this.intervalUpdate = setInterval(this.update.bind(this), 1000);

				// The stopwatch displays milliseconds so it needs to update every ~50 ms
				// instead of every 1000 to display a smooth progression
				//
				// This uses 53 instead of 50 so the numbers displayed aren't continuously
				// repeated
				this.intervalUpdateStopwatch = setInterval(this.updateStopwatch.bind(this), 53);
			}
		}
	});

	return {
		id: 2,
		sort: 60,
		size: 2,
		nicename: "clock",
		sizes: ["tiny", "small"],
		settings: [
			{
				type: "text",
				nicename: "title",
				label: "i18n.settings.title",
				placeholder: "i18n.settings.title_placeholder"
			},
			{
				type: "size"
			},
			{
				type: "select",
				nicename: "timezone",
				label: "i18n.settings.timezone",
				options: "getSources"
			},
			{
				type: "select",
				nicename: "format",
				label: "i18n.settings.format",
				options: {
					ampm: "i18n.settings.format_options.ampm",
					full: "i18n.settings.format_options.24hour",
					analog: "i18n.settings.format_options.analog",
					ampms: "i18n.settings.format_options.ampmseconds",
					fulls: "i18n.settings.format_options.24hourseconds",
				}
			},
			{
				type: "select",
				nicename: "sound",
				label: "i18n.settings.sound",
				options: {
					urban_beat: "Urban Beat",
					argon: "Argon",
					ariel: "Ariel",
					carbon: "Carbon",
					carme: "Carme",
					ceres: "Ceres",
					dione: "Dione",
					elara: "Elara",
					europa: "Europa",
					ganymede: "Ganymede",
					helium: "Helium",
					iapetus: "Iapetus",
					io: "Io",
					krypton: "Krypton",
					luna: "Luna",
					neon: "Neon",
					oberon: "Oberon",
					osmium: "Osmium",
					oxygen: "Oxygen",
					phobos: "Phobos",
					platinum: "Platinum",
					rhea: "Rhea",
					salacia: "Salacia",
					sedna: "Sedna",
					tethys: "Tethys",
					titan: "Titan",
					triton: "Triton",
					umbriel: "Umbriel"
				}
			}
		],
		config: {
			title: "i18n.title",
			size: "small",
			timezone: "auto",
			format: "ampm",
			audio: true,
			sound: "urban_beat"
		},
		data: {},
		getSources: function(cb) {
			var listAuto = {
				auto: "i18n.settings.timezone_local",
			};

			var listUtc = {
				label: "i18n.settings.group_UTC",
				"-720": "UTC -12:00",
				"-660": "UTC -11:00",
				"-600": "UTC -10:00",
				"-570": "UTC -09:30",
				"-540": "UTC -09:00",
				"-480": "UTC -08:00",
				"-420": "UTC -07:00",
				"-360": "UTC -06:00",
				"-300": "UTC -05:00",
				"-270": "UTC -04:30",
				"-240": "UTC -04:00",
				"-210": "UTC -03:30",
				"-180": "UTC -03:00",
				"-120": "UTC -02:00",
				"-60": "UTC -01:00",
				"0": "UTC +00:00",
				"60": "UTC +01:00",
				"120": "UTC +02:00",
				"180": "UTC +03:00",
				"210": "UTC +03:30",
				"240": "UTC +04:00",
				"270": "UTC +04:30",
				"300": "UTC +05:00",
				"330": "UTC +05:30",
				"345": "UTC +05:45",
				"360": "UTC +06:00",
				"390": "UTC +06:30",
				"420": "UTC +07:00",
				"480": "UTC +08:00",
				"525": "UTC +08:45",
				"540": "UTC +09:00",
				"570": "UTC +09:30",
				"600": "UTC +10:00",
				"630": "UTC +10:30",
				"660": "UTC +11:00",
				"690": "UTC +11:30",
				"720": "UTC +12:00",
				"765": "UTC +12:45",
				"780": "UTC +13:00",
				"840": "UTC +14:00"							
			};

			$.ajax({
				type: "GET",
				url: "https://worldtimeapi.org/api/timezone",
				success: function(d) {
					var sources = {
						list0: listAuto,
						list1: {
							label: "i18n.settings.group_byregion"
						}, 
						list2: listUtc
					};

					if (d && d.length) {
						d.forEach(function(e) {
							if (e) {
								sources.list1[e] = e;
							}
						});
					}

					cb(sources);
				}.bind(this),
				error: function() {
					var sources = {
						list0: listAuto,
						list2: listUtc
					};

					cb(sources);
				}
			});
		},
		render: function() {
			if (!this.view) {
				this.view = new (View.extend({
					utils: this.utils,
					config: this.config,
					data: this.data || {}
				}))({
					el: this.elm
				});
			}

			this.view.config = this.config;
			this.view.data = this.data || {};

			this.view.render();

			//this.elm.addClass("tabbed");
		}
	};
});

/*
 * Directions
 */
define('w/directions',["jquery", "lodash", "moment", "backbone"], function($, _, moment, Backbone) {
	var View = Backbone.View.extend({
		events: {
			"focusout input.from, input.to": function() {
				if (!this.$(".results .route").length) {
					this.getDirections();
				}
				else {
					var from = this.$("input.from").val().trim(),
						to = this.$("input.to").val().trim();

					if (from && to && (from !== this.data.from || to !== this.data.to)) {
						this.getDirections(from, to);
					}
				}
			},

			"keydown input.from, input.to": function(e) {
				if (e.which === 13) {
					this.getDirections();
				}
			},

			"click .results .route": function(e) {
				e.currentTarget.classList.toggle("active");
			},

			"click .methods button": function(e) {
				$(e.currentTarget).addClass("active").siblings().removeClass("active");

				this.getDirections();
			}
		},


		/**
		 * Retrieves and renders directions
		 *
		 * @api     private
		 * @param   {String}  [from]    The start location
		 * @param   {String}  [to]      The destination location
		 * @param   {String}  [method]  The transit method
		 */
		getDirections: function(from, to, method) {
			if (typeof from !== "string") {
				from = null;
			}

			from = from || this.$("input.from").val().trim();
			to = to || this.$("input.to").val().trim();
			method = method || this.$(".methods .active").attr("data-method") || "driving";

			if (!(from && to)) {
				return;
			}

			this.$(".error").removeClass("visible");

			this.$(".loading").addClass("visible");

			this.$(".map-wrapper, .results").slideUp(function() {
				$(this).remove();
			});

			$.ajax({
				type: "GET",
				url: "https://maps.googleapis.com/maps/api/directions/json",
				data: {
					mode: method,
					origin: from,
					destination: to,
					alternatives: "true"
				},
				success: function(d) {
					if (!d || !d.status || d.status !== "OK" || !d.routes || !d.routes.length) {
						this.$(".loading").removeClass("visible");

						this.$(".error").addClass("visible");

						return;
					}

					_.assign(this.data, {
						to: to,
						from: from,
						method: method
					});

					this.utils.saveData(this.data);


					var data = _.clone(this.data),
						mapWidth = this.$el.outerWidth();

					data.mapsLink = "https://www.google.com/maps?saddr=" + encodeURIComponent(from) + "&daddr=" + encodeURIComponent(to);

					data.routes = _.compact(_.map(d.routes, function(e) {
						try {
							var ret = {
								summary: e.summary,
								copyrights: e.copyrights,
								time: e.legs[0].duration.text,
								distance: e.legs[0].distance.text,
								steps: _.map(e.legs[0].steps, function(e) {
									return {
										distance: e.distance.text,
										description: e.html_instructions
									};
								})
							};

							if (!data.map) {
								data.map = "https://maps.googleapis.com/maps/api/staticmap?" +
									"scale=2&" +
									"size=" + mapWidth + "x220&" +
									"markers=color:red%7Clabel:A%7C" + encodeURIComponent(e.legs[0].start_location.lat + "," + e.legs[0].start_location.lng) + "&" +
									"markers=color:red%7Clabel:B%7C" + encodeURIComponent(e.legs[0].end_location.lat + "," + e.legs[0].end_location.lng) + "&" +
									"path=weight:5%7Cenc:" + encodeURIComponent(e.overview_polyline.points);
							}

							return ret;
						}
						catch (err) {
							return null;
						}
					}));

					this.render(data);
				}.bind(this)
			});
		},

		render: function(data) {
			if (typeof data !== "object") {
				data = {};
			}

			data.from = data.from || this.data.from;
			data.to = data.to || this.data.to;
			data.method = data.method || this.data.method;

			if (!data.method) {
				data.method_driving = "active";
			}
			else {
				data["method_" + data.method] = "active";
			}

			this.utils.render(data);
		}
	});

	return {
		id: 44,
		sort: 340,
		size: 1,
		unlisted: true,
		nicename: "directions",
		sizes: ["variable"],
		config: {
			size: "variable"
		},
		data: {
			method: "driving"
		},
		render: function() {
			if (!this.view) {
				this.view = new (View.extend({
					utils: this.utils,
					config: this.config,
					data: this.data || {}
				}))({
					el: this.elm
				});
			}

			this.view.config = this.config;
			this.view.data = this.data || {};

			this.view.render();
		}
	};
});
/**
 * This creates an onHeadersReceived listener on an as-needed basis.
 */
define('widgets/framefix',["jquery", "browser/api"], function($, Browser) {
	var tabId = null,
		listening = false,
		attaching = false,
		callbacks = [];

	var check = function(cb, ctx, args) {
		if (listening) {
			return true;
		}

		callbacks.push(function() {
			cb.apply(ctx, args);
		});

		if (attaching) {
			return false;
		}

		attaching = true;

		Browser.tabs.getCurrent(function(tab) {
			tabId = tab.id;

			Browser.webRequest.onHeadersReceived.addListener(
				function(info) {
					var headers = info.responseHeaders || [];

					for (var i = headers.length - 1; i >= 0; --i) {
						var header = headers[i].name.toLowerCase();

						// if (header === "set-cookie") {
						// 	var val = headers[i].value;
						// 	if (val.indexOf("SameSite=") < 0) {
						// 		val = val + ";SameSite=None";

						// 		val.replace("SameSite=Lax", "SameSite=None");
						// 		val.replace("SameSite=Strict", "SameSite=None");


						// 		if (val.indexOf(";Secure") < 0) {
						// 			val = val + ";Secure";
						// 		}


						// 		headers[i].value = val;
						// 	}
						// }

						if (header === "x-frame-options" || header === "frame-options") {
							headers.splice(i, 1);
						}
						else if (header === "content-security-policy") {
							// Remove any frame-ancestors CSP directives, this is actually spec-compliant
							headers[i].value = headers[i].value.split(";").filter(function(e) {
								return e.trim().toLowerCase().indexOf("frame-ancestors") !== 0;
							}).join(";");
						}
					}

					[
						{ name:"access-control-allow-headers", value:"*" },
						{ name:"access-control-expose-headers", value:"*" },
						{ name:"access-control-allow-methods", value:"GET, HEAD, POST, PUT, PATCH, DELETE, OPTIONS" },
						{ name:"access-control-allow-origin", value:"*" }
					].forEach(function(el) {
						var found = false;
						for (var i = 0; i < headers.length; i++) {
							var header = headers[i].name.toLowerCase();
							if (el.name === header) {
								headers[i].value = el.value;
								found = true;
							}
						}							

						if (!found) {
							headers.push(el);
						}
					});

					
					return {
						responseHeaders: headers
					};
				},
				{
					tabId: tabId,
					urls: [ "*://*/*" ],
					types: [ "sub_frame" ]
				},
				//["blocking", "responseHeaders"]
				["blocking", "responseHeaders", "extraHeaders"]
			);

			listening = true;
			attaching = false;

			callbacks.forEach(function(cb) {
				cb();
			});

			callbacks = [];
		});

		return false;
	};

	check.getTabId = function() {
		return tabId;
	};

	return check;
});
/*
 * The Facebook widget.
 */
define('w/facebook',["jquery", "widgets/framefix"], function($, frameFix) {
	return {
		id: 31,
		sort: 240,
		size: 5,
		order: 13,
		nicename: "facebook",
		sizes: ["variable"],
		settings: [
			{
				type: "number",
				label: "i18n.settings.height",
				nicename: "height",
				min: 100,
				max: 800
			}
		],
		config: {
			height: 500,
			size: "variable"
		},
		render: function() {
			if (!frameFix(this.render, this, arguments)) {
				return;
			}

			this.utils.render({
				height: this.config.height || 500
			});

			this.elm.addClass("tabbed");
		}
	};
});
/*
 * The Feedly widget.
 */
define('w/feedly',["jquery", "moment", "oauth", "lodash"], function($, moment, OAuth, _) {
	var abbreviate = function(num, min, precision) {
		var newValue = num;

		min = min || 1000;
		precision = precision || 3;

		if (num >= min) {
			var suffixes = ["", "K", "M", "B","T"],
				suffixNum = Math.floor((("" + parseInt(num)).length - 1) / 3),
				shortValue = "";

			for (var length = precision; length >= 1; length--) {
				shortValue = parseFloat((suffixNum !== 0 ? (num / Math.pow(1000, suffixNum)) : num).toPrecision(length));

				var dotLessShortValue = (shortValue + "").replace(/[^A-z0-9 ]+/g, "");

				if (dotLessShortValue.length <= precision) {
					break;
				}
			}

			if (shortValue % 1 !== 0) {
				shortValue = shortValue.toFixed(1);
			}

			newValue = shortValue + suffixes[suffixNum];
		}
		else {
			newValue = newValue.toLocaleString();
		}

		return newValue;
	};

	return {
		id: 19,
		sort: 170,
		size: 6,
		order: 22,
		interval: 300000,
		nicename: "feedly",
		sizes: ["variable"],
		settings: [
			{
				type: "text",
				nicename: "title",
				label: "i18n.settings.title",
				placeholder: "i18n.settings.title_placeholder"
			},
			{
				type: "select",
				nicename: "source",
				label: "i18n.settings.source",
				options: "getSources"
			},
			{
				type: "radio",
				nicename: "show",
				label: "i18n.settings.show",
				options: {
					all: "i18n.settings.show_options.all",
					unread: "i18n.settings.show_options.unread"
				}
			},
			{
				type: "select",
				nicename: "view",
				label: "i18n.settings.layout",
				options: {
					list: "i18n.settings.layout_options.titles",
					magazine: "i18n.settings.layout_options.magazine",
					cards: "i18n.settings.layout_options.cards",
					"cards dual": "i18n.settings.layout_options.cards_columns",
				}
			},
			{
				type: "radio",
				nicename: "mark",
				label: "i18n.settings.mark",
				options: {
					scroll: "i18n.settings.mark_options.scroll",
					click: "i18n.settings.mark_options.click"
				}
			},
			{
				type: "radio",
				nicename: "sort",
				label: "i18n.settings.sort",
				options: {
					newest: "i18n.settings.sort_options.newest",
					oldest: "i18n.settings.sort_options.oldest"
				}
			},
			{
				type: "radio",
				nicename: "link",
				label: "i18n.settings.footer_link",
				options: {
					show: "i18n.settings.footer_link_options.show",
					hide: "i18n.settings.footer_link_options.hide"
				}
			}
		],
		config: {
			size: "variable",
			title: "i18n.name",
			source: "feed/http://feeds.gawker.com/lifehacker/vip/",
			show: "all",
			view: "cards dual",
			mark: "click",
			sort: "newest",
			link: "show"
		},
		data: {
			articles: [
				{
					id: "PSNTZO8gXFUe+cpCZyApw0vEKWPT4b14D6teBEocIAE=_14354a6731b:d089:623b9014",
					content: "<img alt=\"\" src=\"http://cdn1.sbnation.com/entry_photo_images/9627611/shutterstock_61775431_large.jpg\">\n<p>A few weeks ago, the Innocence Project of New York (IP) announced that it had helped to release another innocent person from prison. This time it was Gerard Richardson. As <a target=\"_blank\" href=\"http://www.theverge.com/2013/9/25/4770070/biting-controversy-forensic-dentistry-battles-to-prove-its-not-junk\"><i>The Verge</i> outlined in September</a>, Richardson was convicted of murdering a New Jersey woman in 1994 after a forensic odontologist concluded that the shape of Richardson’s jaw and the orientation of his teeth matched a bite mark on the murdered woman’s back.</p>\n<p>After years of legal wrangling, IP was finally allowed to conduct a DNA test to double-check the odontologist’s conclusions. Their goal: to determine whether saliva swabbed from the bite mark in 1994 matched Richardson’s genetic makeup. It didn’t. The odontologist’s conclusion was proven false. Given this new information, prosecutors dropped Richardson’s case, and a judge declared him exonerated. After serving 19 years behind bars for a crime he had nothing to do with, <a target=\"_blank\" href=\"http://www.usatoday.com/story/news/nation/2013/12/18/gerald-richardson-exonerated-dna/4107817/\">Richardson finally walked home to his family as a free man on December 17th</a>.</p>\n<p>Richardson’s ordeal is but one in a steadily increasing number of cases overturned using DNA evidence. To this day, IP is aware of <a target=\"_blank\" href=\"http://www.innocenceproject.org/know/\">311 such exonerations</a> — cases in which someone was declared innocent of a crime long after they had been convicted in court. About 70 percent of those exonerations relied on DNA evidence.</p>\n<p>But if you ask David A. Harris, that number should be much higher. Not only that; he also says new technology could accelerate such exonerations now — if only law enforcement would make the decision to use it.</p>\n<p><q>DNA has exonerated hundreds of innocent prisoners</q></p>\n<p>Harris is <a target=\"_blank\" href=\"http://law.pitt.edu/people/full-time-faculty/david-a-harris\">a law professor at the University of Pittsburgh</a> who focuses on police behavior and law enforcement regulation. Last year, he published his third book, <a target=\"_blank\" href=\"http://nyupress.org/books/book-details.aspx?bookid=7958#.UrNXR2RDt9c\"><i>Failed Evidence</i></a>, which argues that people in law enforcement are not only late to adopt state-of-the-art technology and scientific breakthroughs, they’re also fundamentally resistant to new innovations and to science.</p>\n<p>An example of this, he writes, can be found in law enforcement’s approach to DNA.</p>\n<p>While DNA evidence is often seen as a hyper-advanced, solve-anything, find-anyone technology from its portrayal on TV shows like <i>Law and Order: SVU</i> and <i>Dexter</i>, many of the FBI’s standards for DNA analysis are nearly 20 years old. (The <a target=\"_blank\" href=\"http://www.fbi.gov/about-us/lab/biometric-analysis/codis/swgdam-interpretation-guidelines\">FBI’s current standards cite a committee report</a> from the National Research Council titled, <i>An Update: The Evaluation of Forensic DNA Evidence</i>. That update occurred in 1996.)</p>\n<p>Those FBI standards, Harris writes, are way out of date. And as those standards sink further into obsolescence, many criminal cases are likely going unsolved, and many faulty convictions are likely going unchallenged.</p>\n<p>Today’s forensic DNA analysis relies on &quot;rules and procedures set up to allow relatively easy processing by lab personnel,&quot; Harris explains. Human beings, in other words, are expected to interpret DNA evidence one piece at a time, and then explain their analysis in court. Because current standards require a human being, and not a computer, to interact with every DNA sample, the analysis is labor intensive and can take a long time to carry out. As a result, crime labs can get bogged down if there’s a lot of evidence to analyze. And most DNA evidence gets tossed aside because it’s too complicated for a human to interpret.</p>\n<p><q>&quot;DNA evidence is much more complex than most labs can handle.&quot;</q></p>\n<p>About that: an ideal DNA swab has one clear contributor. The Gerard Richardson case is a perfect example: one <i>unknown</i> person bit into a <i>known</i> person’s flesh. Analysts needed only to determine whether Richardson’s DNA matched that of the <i>unknown</i> person. It didn’t, and so his charges were dropped.</p>\n<p>But when the number of unknown contributors to a DNA sample goes above one — or when the sample is tarnished in some way, or determined to be too miniscule to be analyzed by a person — there’s not much than can be done under current standards. Complicated DNA samples are thus called &quot;uninterpretable&quot; and often ignored.</p>\n<p>This is no secret, either. Even the quintessential document about forensic science written in the last decade — the National Academy of Sciences’ (NAS) <a target=\"_blank\" href=\"https://www.ncjrs.gov/pdffiles1/nij/grants/228091.pdf\">Strengthening Forensic Science in the United States</a>, published in August, 2009 — laments that &quot;DNA tests performed on a contaminated or otherwise compromised sample cannot be used reliably to identify or eliminate an individual as the perpetrator of a crime.&quot;</p>\n<p>In reality, that’s not true anymore. DNA analysis has moved way beyond both FBI standards and NAS’ depiction of DNA’s limits.</p>\n<p>Harris points to <a target=\"_blank\" href=\"http://www.cybgen.com/\">Cybergenetics</a>, a company based down the road from his university office in Pittsburgh, that’s developed software called TrueAllele. An allele is a gene form that helps distinguish one person’s DNA as unique. TrueAllele uses algorithms rather than the naked eye to identify contributors to a DNA sample. Because it’s computer-based, it can interpret a lot of DNA evidence at once. The technique can also interpret DNA evidence currently considered tarnished. And it can identify as many as five unknown contributors to a DNA sample instead of just one.</p>\n<p>&quot;DNA evidence is much more complex than most labs can handle,&quot; says Dr. Ria David, one of Cybergenetics’ principals, who says as much as 80 percent of the evidence collected at crime scenes gets thrown away or cast aside. Cybergenetics’ software has been used in a number of high-profile cases, she says, but its use is limited.</p>\n<p>According to Harris, law enforcement’s resistance to accepting computer-based DNA analysis amounts to a travesty. Think about it: if Dr. David is correct, and 80 percent of the DNA evidence collected at crime scenes today is neglected, what would happen if even half of that neglected evidence were able to be tested going forward? &quot;You would get many more convictions and probably many more exonerations, too,&quot; Harris says. &quot;If you thought DNA was a powerful tool for finding the truth, [Cybergenetics’] method is just that much more powerful and precise.&quot;</p>\n<p><q>&quot;If you thought DNA was a powerful tool for finding the truth...&quot;</q></p>\n<p>Harris sees computer-aided DNA analysis as &quot;indisputably better&quot; than what’s available today. (The technical descriptor for Cybergenetics’ software is &quot;automated short tandem repeat STR analysis,&quot; and other companies such as the <a target=\"_blank\" href=\"http://advancedforensicdna.com/corporate/management/\">Center for Advanced DNA Analysis</a>, <a target=\"_blank\" href=\"http://www.bodetech.com/forensic-solutions/dna-identification/\">Bode Technology</a>, and <a target=\"_blank\" href=\"http://www.zygem.com/about/the-company\">ZyGem</a> are making similar strides forward.) &quot;In five years,&quot; he predicts, &quot;law enforcement will have no choice. But that moment hasn't come yet.&quot; He imagines it could arrive, however, as more prisoners such as Gerard Richardson force courts to allow the retesting of old DNA evidence.</p>\n<p>&quot;It’s my belief that we’re just at the tip of the iceberg when it comes to exonerations,&quot; he says. &quot;Three hundred may not sound like a lot in comparison to the number of people who are in prison right now. But the number is only going to rise as advanced DNA analysis finds its way into the hands of more law enforcement agencies, more prosecutors, more defense attorneys.&quot;</p>",
					excerpt: "A few weeks ago, the Innocence Project of New York (IP) announced that it had helped to release another innocent person from prison. This time it was Gerard Richardson. As The Verge outlined in September, Richardson was convicted of murdering a New Jersey woman in 1994 after a forensic odontologist ",
					author: "mattstroud",
					title: "Is DNA analysis stuck in the past?",
					date: 1388692811000,
					link: "http://www.theverge.com/2014/1/2/5266196/is-dna-analysis-stuck-in-the-past",
					source: "The Verge -\tAll Posts",
					image: "http://b.vimeocdn.com/ts/452/218/452218069_1280.jpg",
					unread: true,
					recommendations: 35
				},
				{
					id: "PSNTZO8gXFUe+cpCZyApw0vEKWPT4b14D6teBEocIAE=_143548aea14:cd7b:623b9014",
					content: "<img alt=\"\" src=\"http://cdn3.sbnation.com/entry_photo_images/9628447/2013-09-09_21-23-13-1020_large.jpg\">\n<p>Intel spent much of the last year talking up its <a href=\"http://www.theverge.com/2013/2/12/3980948/intel-confirms-internet-tv-plans-complete-with-a-set-top-box\">ambitious plan to launch an internet TV service</a> — but its grand plans eventually <a href=\"http://www.theverge.com/2013/11/25/5145508/intel-looking-to-sell-internet-tv-technology-for-500-million\">fell by the wayside</a>. Now, we're hearing why: new CEO Brian Krzanich told <i>Recode</i> that Intel's plans went up in smoke because it wasn't able to get the content it needed. &quot;When you go and play with the content guys, it's all about volume,&quot; said Krzanich. &quot;and we come at it with no background, no experience, no volume. We were ramping from virtually zero.&quot;</p>\n<p>Verizon has been <a href=\"http://www.theverge.com/2013/10/30/5046510/intel-may-leave-web-tv-service-in-verizons-hands\">rumored to be the front-runner</a> to purchase Intel's failed venture, and Krzanich's quotes make it sound like they'd be a natural match for what Intel has developed thus far. &quot;What we've said is we are out looking for a partner that can help us scale that volume at a much quicker rate,&quot; he said. Verizon already has extensive relationships with content providers for its cable services — the hardware that Intel's been building could eventually power Verizon's content network if the deal comes to pass. Krzanich still sounds proud of that hardware, saying that Intel build a &quot;great device&quot; with &quot;great technology.&quot;</p>\n<p>Krzanich's admissions come after earlier reports said that Intel's new CEO <a href=\"http://www.theverge.com/tech/2013/11/21/5128592/why-intel-canned-its-planned-intel-tv-service\">decided not to focus on TV</a> almost immediately after he <a href=\"http://www.theverge.com/2013/5/2/4292976/intel-brian-krzanich-ceo\">took over in May of last year.</a> Breaking into the TV market would have ultimately been to costly and too much of a distraction to Intel, particularly as he tried to focus Intel's efforts on two bigger threats: the declining PC industry and Intel's lack of progress in the fast-growing mobile and tablet markets. The saga of Intel's failed TV venture still isn't quite over yet, though — despite the rumors of Verizon's interest, the company hasn't sold off its work just yet.</p>",
					excerpt: "Intel spent much of the last year talking up its ambitious plan to launch an internet TV service — but its grand plans eventually fell by the wayside. Now, we're hearing why: new CEO Brian Krzanich told Recode that Intel's plans went up in smoke because it wasn't able to get the content it needed. \"",
					author: "Nathan Ingraham",
					title: "Intel killed its internet TV project because it couldn't make content deals",
					date: 1388692408000,
					link: "http://www.theverge.com/2014/1/2/5266924/intel-killed-its-internet-tv-project-because-it-couldnt-make-content-deals",
					source: "The Verge -\tAll Posts",
					image: "http://cdn1.sbnation.com/entry_photo_images/9188405/LG_G_Flex-3_large_verge_medium_landscape.jpg",
					unread: true,
					recommendations: 35
				},
				{
					id: "PSNTZO8gXFUe+cpCZyApw0vEKWPT4b14D6teBEocIAE=_143548aea14:cd7a:623b9014",
					content: "<img alt=\"\" src=\"http://cdn3.sbnation.com/entry_photo_images/9628429/IMG_4234-1024_large.jpg\">\n<p>Microsoft has started updating the Intel processor in its Surface Pro 2 tablets. The software giant originally released the Surface Pro 2 on October 22nd, and after just two months the latest retail units now contain a processor clocked at 1.9GHz instead of the stock 1.6GHz Intel i5-4200U chip that originally shipped with the tablet.</p>\n<p>A Microsoft spokesperson confirmed the change in a statement to <i>The Verge</i>. &quot;Microsoft routinely makes small changes to internal components over the lifetime of a product, based on numerous factors including supply chain partnerships, availability, and value for our customers,&quot; says a Microsoft spokesperson. &quot;With any change to hardware or software, we work to ensure that the product experience remains excellent.&quot;</p>\n<p><q>New models appear to have started shipping in late December</q></p>\n<p>One Surface Pro 2 owner <a target=\"_blank\" href=\"http://answers.microsoft.com/en-us/surface/forum/surfpro2-surfhardware/surface-pro-25-i5-4300u-19-ghz-25-ghz/bb77fa47-1516-4979-ad74-af6b021d6656\">noticed the change</a> after swapping his faulty unit following a recent<a href=\"http://www.theverge.com/2013/12/18/5224996/microsoft-pulls-latest-surface-pro-2-firmware-update\"> firmware update issue</a>. Recent <a target=\"_blank\" href=\"http://browser.primatelabs.com/geekbench3/search?page=1&q=Surface+Pro+2&utf8=%E2%9C%93\">Geekbench scores</a> suggest Microsoft made the change in late December, but Microsoft has not provided timing to<i> The Verge</i>. Aside from the speed improvement, the two Intel i5 processors (<a target=\"_blank\" href=\"http://ark.intel.com/products/75459/\">4200U</a> and <a target=\"_blank\" href=\"http://ark.intel.com/products/76308/\">4300U</a>) are relatively similar. The new i5-4300U chipset is clocked higher, and it also includes Intel’s Trusted Execution Technology for improved software security.</p>\n<p>The rationale behind a processor speed bump is unclear, and Microsoft isn’t commenting on its decision to improve the Surface Pro 2 components after just two months. Several <a target=\"_blank\" href=\"http://mashable.com/2013/12/15/microsoft-surface-pro-2-and-surface-2-sold-out-at-many-locations/\">recent reports</a> have noted that Microsoft’s Surface 2 and Surface Pro 2 tablets have remained largely out of stock over the holidays, alongside the timing of the processor change on the Pro 2 model. The refreshed model is now filtering into retail channels, so any future stock should start to ship with the faster Intel processor.</p>\n<p><i>Thanks, Leonardo!</i></p>",
					excerpt: "Microsoft has started updating the Intel processor in its Surface Pro 2 tablets. The software giant originally released the Surface Pro 2 on October 22nd, and after just two months the latest retail units now contain a processor clocked at 1.9GHz instead of the stock 1.6GHz Intel i5-4200U chip that ",
					author: "Tom Warren",
					title: "Surface Pro 2 now shipping with faster processor, just two months after launch",
					date: 1388691929000,
					link: "http://www.theverge.com/2014/1/2/5266988/surface-pro-2-intel-i5-processor-updated-specifications",
					source: "The Verge -\tAll Posts",
					image: "http://cdn1.sbnation.com/entry_photo_images/9188405/LG_G_Flex-3_large_verge_medium_landscape.jpg",
					unread: true,
					recommendations: 35
				},
				{
					id: "PSNTZO8gXFUe+cpCZyApw0vEKWPT4b14D6teBEocIAE=_143546f6d54:ca14:623b9014",
					excerpt: "That was quick. BlackBerry is parting ways with Alicia Keys, less than a year after recording artist was hired to come on as the company's \"global creative director.\" The partnership was unveiled at an event last January when the company launched its BlackBerry 10 OS. Keys was tapped to \"inspire the",
					content: "<img alt=\"\" src=\"http://cdn2.sbnation.com/entry_photo_images/9628193/alicia-keys-blackberry-thorsten-heins-stock2_1020_large.jpg\">\n<p>That was quick. BlackBerry is parting ways with Alicia Keys, less than a year after recording artist was hired to<a href=\"http://www.theverge.com/2013/1/30/3932048/blackberry-announces-alicia-keys-as-global-creative-director\"> come on as the company's &quot;global creative director.</a>&quot; The partnership was unveiled at an event last January when the company launched its BlackBerry 10 OS. Keys was tapped to &quot;inspire the future&quot; of the company, which took years to ready a new platform to more readily compete with the burgeoning crop of smartphones and tablets from competitors like Google and Apple. In a statement to <a target=\"_blank\" href=\"http://www.ctvnews.ca/business/singer-alicia-keys-to-leave-blackberry-after-year-long-collaboration-1.1615273#ixzz2pGl0TGTH\">CTV News</a> today, the company thanked Keys for her service, without going detail about what exactly she had done during her tenure.</p>\n<hr>\n<p><q>Less than a year later</q></p>\n<p>Keys' hire was just the latest in <a href=\"http://www.theverge.com/2013/1/30/3934122/why-alicia-keys-for-blackberry-10\">a string of celebrity endorsements for tech companies</a>, though came with some controversy. Prior to signing on with BlackBerry, Keys was an avid iPhone user, and had even developed an iOS app that let users add her image to their own photos. Just a month after signing on with BlackBerry, she sent out <a href=\"http://www.theverge.com/2013/2/11/3977958/blackberry-creative-director-alicia-keys-tweeting-iphone-hacked\">a tweet from her iPhone</a>, something she later attributed to being hacked.\tShe also walked away from a very active, and well-followed Instagram account, which at the time was only available on iOS and Android.</p>\n<p>Keys already appears to be back to using other platforms; the artist tweeted from her iPad on New Year's Eve:</p>\n<blockquote lang=\"en\">\n<p>Wishing u a blissful new year! Let go of our shadows; Old things,old thoughts, old ways. Lets step nto our light! Here's 2 the best 2 come!</p>\n— Alicia Keys (@aliciakeys) <a href=\"https://twitter.com/aliciakeys/statuses/418257194308476928\">January 1, 2014</a>\n</blockquote>\n<p>\n</p>\n<p>The end of the partnership comes as BlackBerry continues its attempt at a comeback. The beleaguered company tallied up billions in losses last year, while shedding executives like CEO Thorsten Heins, who <a href=\"http://www.theverge.com/2013/11/4/5064278/blackberry-ceo-steps-down-as-company-secures-1-billion-funding-from\">left in November</a>, <a href=\"http://www.theverge.com/2013/11/25/5143144/three-key-blackberry-executives-ousted\">and was quickly followed by other top executives</a>. Attempts to take over the company have also been scrapped, <a href=\"http://www.theverge.com/2013/10/10/4824858/blackberry-co-founders-lazaridis-fregin-considering-acquisition\">including one from Mike Lazaridis</a>, who co-founded the company and was its CEO, though more recently has been <a target=\"_blank\" href=\"http://www.vancouversun.com/business/Lazaridis+sells+BlackBerry+shares/9327084/story.html\">selling off millions of his shares</a> in the company.</p>",
					author: "Josh Lowensohn",
					title: "BlackBerry and singer Alicia Keys part ways",
					date: 1388690688000,
					link: "http://www.theverge.com/2014/1/2/5266838/blackberry-and-singer-alicia-keys-part-ways",
					source: "The Verge -\tAll Posts",
					unread: true,
					recommendations: 35,
					image: "http://cdn0.sbnation.com/entry_photo_images/9628193/alicia-keys-blackberry-thorsten-heins-stock2_1020_large.jpg"
				},
				{
					id: "PSNTZO8gXFUe+cpCZyApw0vEKWPT4b14D6teBEocIAE=_143546f6d54:ca13:623b9014",
					excerpt: "Just as loud noises can make small objects jitter on a table, powerful acoustic vibrations can lift things like toothpicks or water droplets into mid-air. Rather than just letting them levitate, though, researchers from the University of Tokyo and Nagoya Institute of Technology set tiny particles in",
					content: "<img alt=\"\" src=\"http://cdn1.sbnation.com/entry_photo_images/9628187/Screen_Shot_2014-01-02_at_11.11.00_AM_large.png\">\n<p>Just as loud noises can make small objects jitter on a table, powerful acoustic vibrations can lift things like toothpicks or water droplets into mid-air. Rather than just letting them levitate, though, researchers from the University of Tokyo and Nagoya Institute of Technology set tiny particles in a dance between shifting, overlapping ultrasonic beams that could shift them around a small cubic space. The resulting video combines graceful, gravity-defying motion with an explanation of how the system actually works, and the <a target=\"_blank\" href=\"http://arxiv.org/pdf/1312.4006.pdf\">full research paper</a> goes deeper into the technology's precise details.</p>\n<p>The roughly millimeter-sized balls that perform the most impressive stunts are composed of polystyrene, but the group also tested screws, matchsticks, and other objects — other researchers have successfully levitated <a target=\"_blank\" href=\"http://www.nature.com/news/2006/061127/full/news061127-6.html\">ants and even small fish</a>. While the sound must be extremely intense, its high frequency makes it inaudible to human ears, and levitation can open up new ways for us to manipulate objects. Earlier this year, another group of researchers made a similar breakthrough in moving floating particles, <a target=\"_blank\" href=\"http://www.webcitation.org/6I9uYzTzr\">mixing together solutions</a> in mid-air without fear of contamination from a container.</p>\n<hr>\n<p><iframe height=\"315\" width=\"560\" src=\"http://www.youtube.com/embed/odJxJRAxdFU\"></iframe></p>",
					author: "Adi Robertson",
					title: "Watch the intricate dance of objects levitated by sound",
					date: 1388690282000,
					link: "http://www.theverge.com/2014/1/2/5266670/watch-the-intricate-dance-of-objects-levitated-by-sound",
					source: "The Verge -\tAll Posts",
					unread: true,
					recommendations: 35,
					image: "http://cdn1.sbnation.com/entry_photo_images/9628187/Screen_Shot_2014-01-02_at_11.11.00_AM_large.png"
				},
				{
					id: "PSNTZO8gXFUe+cpCZyApw0vEKWPT4b14D6teBEocIAE=_1435453eecb:c6f4:623b9014",
					content: "<img alt=\"\" src=\"http://cdn1.sbnation.com/entry_photo_images/9628153/_MG_7923_large.jpg\">\n<p>Mount Royal Avenue in Montreal has a new, comic book-inspired look — and all it took was some new lights. Created by Estelle Jugant and Yazid Belkhir from design firm Turn Me On, the &quot;<a target=\"_blank\" href=\"http://turnmeondesign.com/projets/idee-o-rama.html\">Idea-O-Rama</a>&quot; project has filled up the street with light fixtures reminiscent of cartoon speech bubbles. The new lamps were born from a city-wide competition, in which Turn Me On won, aimed at creating &quot;a unique winter atmosphere and conversation on the Avenue.&quot; Each light features original graphics from artists <a target=\"_blank\" href=\"http://misterastro.com/\">Astro</a> and <a target=\"_blank\" href=\"http://jaimelejaune.com/\">Jean-François Poliquin</a>. You can check out the installation from now until the end of February, but if you can't make it, don't worry — it's expected to pop up again over the following two winters.</p>\n<p><em>Image credit: <a target=\"new\" href=\"https://drive.google.com/a/theverge.com/folderview?id=0BwGYWIZt99SUSjVnbF8wUHVqclU&usp=drive_web#\">Bernard Fougères</a></em></p>\n<div>\n<br><img alt=\"3\" src=\"http://cdn3.sbnation.com/assets/3797451/_MG_7634.jpg\">\n</div>\n<div>\n<br><img alt=\"3\" src=\"http://cdn3.sbnation.com/assets/3797459/_MG_7652.jpg\">\n</div>\n<div>\n<br><img alt=\"3\" src=\"http://cdn1.sbnation.com/assets/3797467/_MG_7658.jpg\">\n</div>\n<div>\n<br><img alt=\"3\" src=\"http://cdn3.sbnation.com/assets/3797475/_MG_7669.jpg\">\n</div>\n<div>\n<br><img alt=\"3\" src=\"http://cdn0.sbnation.com/assets/3797483/_MG_7763.jpg\">\n</div>\n<div>\n<br><img alt=\"3\" src=\"http://cdn3.sbnation.com/assets/3797491/_MG_7917.jpg\">\n</div>\n<div>\n<br><img alt=\"3\" src=\"http://cdn0.sbnation.com/assets/3797499/_MG_7967.jpg\">\n</div>",
					excerpt: "Mount Royal Avenue in Montreal has a new, comic book-inspired look — and all it took was some new lights. Created by Estelle Jugant and Yazid Belkhir from design firm Turn Me On, the \"Idea-O-Rama\" project has filled up the street with light fixtures reminiscent of cartoon speech bubbles. The new lam",
					author: "Andrew Webster",
					title: "Street lamps transform Montreal into a living comic book",
					date: 1388688187000,
					link: "http://www.theverge.com/2014/1/2/5266704/street-lamps-transform-montreal-into-a-living-comic-book",
					source: "The Verge -\tAll Posts",
					image: "http://www.blogcdn.com/www.engadget.com/media/2013/10/irlbanner-1382819058.jpg",
					unread: true,
					recommendations: 35
				},
				{
					id: "PSNTZO8gXFUe+cpCZyApw0vEKWPT4b14D6teBEocIAE=_143541cf505:c032:623b9014",
					content: "<img alt=\"\" src=\"http://cdn1.sbnation.com/entry_photo_images/9627981/netflix-recommendations_1020_large.jpg\">\n<p>Netflix's extraordinarily specific micro-categories have become both a running joke and a <a href=\"http://www.theverge.com/2012/4/8/2934375/netflix-recommendation-system-explained\">surprisingly effective recommendation tool</a>, but how does it serve up personalized recommendations for &quot;violent sci-fi thrillers&quot; and &quot;gory action and adventure,&quot; and why are &quot;violent&quot; and &quot;gory&quot; separate descriptors? And why, when you reverse-engineer Netflix categories as <a target=\"_blank\" href=\"http://www.theatlantic.com/technology/archive/2014/01/how-netflix-reverse-engineered-hollywood/282679/\">Ian Bogost and Alexis Madrigal did</a> for <i>The Atlantic</i>, are there 19 genres dedicated to the man who played Perry Mason? By scraping the tens of thousands of possible Netflix categories (most of which users will never see), Bogost and Madrigal put together a strangely effective map of how Hollywood makes movies and how we seek them. And behind it all is Todd Yellin, the Netflix VP who envisioned the tagging system in the first place: &quot;Predicting something is 3.2 stars is kind of fun if you have an engineering sensibility, but it would be more useful to talk about dysfunctional families and viral plagues.&quot;</p>",
					excerpt: "Netflix's extraordinarily specific micro-categories have become both a running joke and a surprisingly effective recommendation tool, but how does it serve up personalized recommendations for \"violent sci-fi thrillers\" and \"gory action and adventure,\" and why are \"violent\" and \"gory\" separate descri",
					author: "Adi Robertson",
					title: "A quantum theory of Netflix's genre tags",
					date: 1388684996000,
					link: "http://www.theverge.com/2014/1/2/5266526/a-quantum-theory-of-netflixs-genre-tags",
					source: "The Verge -\tAll Posts",
					image: "http://b.vimeocdn.com/ts/451/794/451794956_1280.jpg",
					unread: true,
					recommendations: 35
				},
				{
					id: "PSNTZO8gXFUe+cpCZyApw0vEKWPT4b14D6teBEocIAE=_143541cf505:c031:623b9014",
					content: "<img alt=\"\" src=\"http://cdn2.sbnation.com/entry_photo_images/9627943/Moto_G_review11_1020_large.jpg\">\n<p>Verizon Wireless prepaid customers will be able to order the Moto G starting January 9th for $99.99. Motorola's budget handset will be available first online and will appear at the carrier's retail stores &quot;in the coming weeks.&quot; A picture of the Moto G in Verizon's prepaid retail packaging emerged at the end of December, and <a href=\"http://www.theverge.com/2013/12/31/5260988/moto-g-for-verizon-coming-to-best-buy-off-contract-for-99-99\">Best Buy confirmed it would be selling the device</a> almost immediately. In fact, Best Buy stores are reportedly allowed to sell the Moto G as soon as shipments arrive, so it may be a better option if you're eager to get a hold of the low-cost smartphone. As we've said before, it may be cheap (and Verizon's price is the lowest yet), but the Moto G is plenty capable for those core mobile tasks. The lack of LTE may be harder to swallow on &quot;America's largest LTE network,&quot; but it's still a fantastic device for the price.</p>\n<p>Separately, <a target=\"_blank\" href=\"http://newsroom.boostmobile.com/press-release/products-offers/boost-mobile-reunites-motorola-launch-smart-and-stylish-moto-g-nextrad\">Boost Mobile has announced</a> that it too will be selling the Moto G, but you'll have to wait a bit longer and pay slightly more. It's set to be released on January 14th for $129.99. If you can't wait until then, apparently Boost Mobile's version of the Moto G will be appearing on the Home Shopping Network (and its website) today.</p>",
					excerpt: "Verizon Wireless prepaid customers will be able to order the Moto G starting January 9th for $99.99. Motorola's budget handset will be available first online and will appear at the carrier's retail stores \"in the coming weeks.\" A picture of the Moto G in Verizon's prepaid retail packaging emerged at",
					author: "Chris Welch",
					title: "Moto G coming to Verizon Wireless on January 9th for $99.99 off-contract",
					date: 1388684565000,
					link: "http://www.theverge.com/2014/1/2/5266532/moto-g-verizon-release-date-january-9",
					source: "The Verge -\tAll Posts",
					image: "http://b.vimeocdn.com/ts/451/794/451794956_1280.jpg",
					unread: true,
					recommendations: 35
				},
				{
					id: "PSNTZO8gXFUe+cpCZyApw0vEKWPT4b14D6teBEocIAE=_1435401781b:bbf7:623b9014",
					excerpt: "Next week, LG will unveil new televisions running webOS, the ill-fated operating system it acquired in last February. Although LG is expected to retain some form of webOS’ interface, exactly what that will mean on a television instead of a phone or tablet is still a mystery. If LG has any luck at al",
					content: "<img alt=\"\" src=\"http://cdn3.sbnation.com/entry_photo_images/9627107/webos-lost-2-theverge-4_1020_large.jpg\">\n<p>Next week, <a href=\"http://www.theverge.com/2013/12/19/5226634/lg-webos-smart-tv-coming-at-ces-2014\">LG will unveil new televisions running webOS</a>, the ill-fated operating system <a href=\"http://www.theverge.com/2013/2/25/4027018/lg-buys-webos-smart-tv/in/2388197\">it acquired in last February</a>. Although LG is <a href=\"http://www.theverge.com/2013/12/30/5256186/lg-webos-smart-tv-cards-interface-rumor\">expected to retain some form of webOS’ interface</a>, exactly what that will mean on a television instead of a phone or tablet is still a mystery. If LG has any luck at all, it will be more successful than the last consumer webOS products. It's been over two years since HP’s TouchPad and the Pre 3 were released and then discontinued in a surprise decision from then-CEO Léo Apotheker. In fact, most people within HP were blindsided when executives decided to stop hardware production and left the software team twisting in the winds of uncertainty. Apotheker's decision ultimately led to the open sourcing of some parts of webOS and the sale of the rest to LG under current CEO Meg Whitman.</p>\n<p>But back in 2011, before and after Apotheker's fateful decision, Palm had been actively working on both new hardware and new software. <em>The Verge</em> has obtained documents describing Palm's plans and even a design prototype of a new smartphone. They tell a story of a company struggling to innovate in the face of daunting competition and perishingly few resources. They also show that, even at the end, Palm’s ambition outstretched its ability.</p>\n<p>This is the webOS that never was.</p>\n<div>\n<div>\n<img alt=\"Hp-web_640\" src=\"http://cdn3.sbnation.com/assets/820341/hp-web_640.jpg\"><h2>Embark</h2>\n<p>On February 9th, 2011, Palm's Jon Rubinstein took to the stage to unveil the first major products to come out of the division since the HP sale. The Pre 3 and Veer phones weren't much better than the Pre phones that came before them, but the TouchPad showed promise, at least on the software side. Unbeknownst to Rubinstein and his staff, the event — known internally as &quot;Embark&quot; — would be the high point of Palm's brief tenure at HP.</p>\n</div>\n</div>\n<div>\n<div>\n<p>But the good vibes from the event didn't last long. Apple announced the iPad 2 on March 2nd, less than one month later and well before Palm's TouchPad was released. Though webOS on the TouchPad had some clever features and an elegant software design, the TouchPad itself was a hulking, plastic monster. It was for all intents and purposes a glossy black look-alike of the original iPad.</p>\n<p>Apple's iPad 2 was as much of a revelation as the original iPad. It was radically thinner, lighter, and faster than what had come before and it immediately made the TouchPad — not to mention competing Android tablets — look stale by comparison. Apple released the iPad 2 to consumers just over a week after it was announced, while the TouchPad wasn't released until July.</p>\n</div>\n</div>\n<div>\n<div>\n<h2>Sapphire</h2>\n<div><img alt=\"Topaz-theverge-1_560\" src=\"http://cdn2.sbnation.com/assets/3796403/topaz-theverge-1_560.jpg\"></div>\n<p>If the documents we obtained detailing HP's product plans are any indication, the iPad 2 sent the company into a panic. In a document distributed in late March, HP admitted that the iPad 2 had &quot;changed the competitive trajectory&quot; and foresaw rapid responses from Samsung — which had shaved over 2mm from its Galaxy Tab tablet in response to the iPad 2. HP had also gotten pushback from the likes of AT&amp;T, which wasn't happy with the TouchPad's &quot;thickness, weight, [and industrial design].&quot;</p>\n<p>HP created a plan to refresh the TouchPad with the &quot;Sapphire&quot; (the TouchPad's codename was Topaz, and the Sapphire was also referred to as the &quot;Topaz2&quot;), with the unrealistic goal of developing it in &quot;record time&quot; and releasing it in late 2011. At the same time, it was working on another tablet that would feature a high resolution screen to be released in the latter half of 2012. The former would have brought the company to some kind of parity with Apple (albeit a year late), while the latter would have arrived a few months after Apple introduced a Retina display iPad. It also planned to work on a successor to the &quot;Opal,&quot; the 7-inch tablet that was nearly released as the TouchPad Go before it was canceled.</p>\n<p>HP's tablet plans looked reactionary in both specs and design. It was caught flat-footed by Apple and was rushing to make its traditional tablets competitive. It’s not clear how far along HP got with any of these plans, but it seems unlikely that any of them would have made their ship-date targets.</p>\n</div>\n</div>\n<div>\n<div><img alt=\"Webos-lost-2-theverge-1_1020\" src=\"http://cdn3.sbnation.com/assets/3796411/webos-lost-2-theverge-1_1020.jpg\"></div>\n</div>\n<div>\n<div>\n<h2>Mako</h2>\n<p>HP was also painfully aware that though the Palm faithful still liked hardware keyboards and the slide-out design of the Pre (and even the Veer), the rest of the world was moving to touchscreen-only phones. It had developed a version of the Pre 3 that had no physical keyboard, codenamed &quot;<a href=\"http://www.webosnation.com/windsornot-webos-slate-smartphone-never-was\">WindsorNot</a>.&quot; The WindsorNot was meant for AT&amp;T but didn’t have LTE, and it was delayed past the point when AT&amp;T would require all smartphones to have LTE.</p>\n<div><img alt=\"Webos-lost-2-theverge-2_1020\" src=\"http://cdn3.sbnation.com/assets/3796419/webos-lost-2-theverge-2_1020.jpg\"></div>\n<p>However, HP was also working on a significantly more advanced phone, codenamed &quot;Mako.&quot; <em>The Verge</em> obtained a design prototype of the device that reveals a new design direction eschewing the soft, nature-inspired pebble look of the Pre for something much more angular. It was to have a glass front and back, wireless charging, LTE, and a high-resolution screen. By today's standards, the Mako looks thick and this particular prototype isn't exactly beautiful — but it is at least unique and presumably the final hardware would have been fairly elegant, especially compared to other devices in late 2011 and early 2012.</p>\n<p>In terms of specs, we are told that it was to be about on par with the HTC One X, and had things gone according to plan it would have possibly been released in early 2012, beating the One X to market. Had Palm managed to pull it off, the Mako would have been one of the first Palm devices in a long time to feature competitive performance — albeit in a form that was still thicker than other devices at the time. However, development on the Mako never made it very far, and to our knowledge no working models ever got off the development board, much less into real-world testing.</p>\n</div>\n</div>\n<div>\n<div><img alt=\"Webos-lost-1-theverge-10_1020\" src=\"http://cdn1.sbnation.com/assets/3796435/webos-lost-1-theverge-10_1020.jpg\"></div>\n</div>\n<div>\n<div>\n<h2>Twain</h2>\n<p>But HP wasn't just working on &quot;traditional tablets&quot; like the Topaz2 and Opal and &quot;traditional&quot; phones like the Mako: it was also in the process of developing a hybrid device that would combine a tablet with a keyboard and a new sliding hinge. It would have been a precursor to the many hybrid Windows 8 devices on the market today. HP codenamed it &quot;Twain.&quot;</p>\n<p>Development on Twain was already underway by March, 2011, when Apple’s iPad 2 blindsided HP. The knock on iOS on the iPad was always that it wasn't great at being &quot;productive,&quot; and HP intended to take that perceived weakness head on. In an early presentation outlining Twain's features, HP asked &quot;Are traditional notebooks a thing of the past?&quot; and answered &quot;If they are, Twain is the notebook of the future.&quot;</p>\n<img alt=\"Webos-lost-1-theverge-8_1020\" src=\"http://cdn2.sbnation.com/assets/3796443/webos-lost-1-theverge-8_1020.jpg\"><p>Twain's core design involved a touchscreen that could slide out and then up to reveal a keyboard underneath. The proposed hardware specs were up to date, but most importantly it was to feature the stark new industrial design direction meant for all future Palm products.</p>\n<p>HP wanted to add a magnetic charger, NFC, HDMI-out, and a set of software features designed to make the Twain appeal to enterprise and productivity customers. HP also planned on extending the &quot;Touch to share&quot; feature it had introduced on the original TouchPad so that you could swipe data from the Twain to another webOS device using &quot;ultrasonic transmission to sense the location of fellow webOS devices.&quot;</p>\n</div>\n</div>\n<div>\n<div><img alt=\"Webos-lost-1-theverge-2_1020\" src=\"http://cdn1.sbnation.com/assets/3796467/webos-lost-1-theverge-2_1020.jpg\"></div>\n</div>\n<div>\n<div>\n<h2>Eel</h2>\n<p>While most of HP's tablet and phone plans (save the Twain) were reactionary and predictable, the software team was working on some truly innovative designs.</p>\n<div>\n<img alt=\"Webos-lost-1-theverge-4_1020\" src=\"http://cdn3.sbnation.com/assets/3796475/webos-lost-1-theverge-4_1020.jpg\"><br>\n</div>\n<p>For the Twain to have any success, HP would need to do more than just release the hardware with webOS as it was currently known. webOS has had a long and fractured history of rushing to get a less-than-ideal product out the door — putting off necessary and important projects like unifying the OS under a single backend framework. Unfortunately, that trend was still fully in play as Palm began work on the next version of webOS. But while the underpinnings were still in flux, the actual design and functionality of webOS was moving forward in a surprisingly good direction.</p>\n<p>Under the leadership of its then-director of human interface, Itai Vonshak, Palm was moving forward with a software strategy to complement the productivity targets it had set for Twain. That meant webOS would need to become more useful for traditional work tasks — without turning itself into something that looked and felt like Windows.</p>\n<div>\n<img alt=\"Webos-lost-1-theverge-3_1020\" src=\"http://cdn2.sbnation.com/assets/3796491/webos-lost-1-theverge-3_1020.jpg\"><br>\n</div>\n<p>The answer to both of those questions would be &quot;Eel,&quot; the codename for the next major version of webOS in 2011. At the heart of Eel was an attempt to expand on the &quot;card&quot; metaphor that Matias Duarte had first unveiled with the original Palm Pre in 2009.</p>\n<p>webOS had already introduced &quot;card stacks&quot; in an earlier version, letting you stack your active application cards into logical groupings. It had also introduced another concept that was finally beginning to gain widespread adoption: responsive panels. In essence, a &quot;panel&quot; presented different views depending on where you were in the app and how large a screen you had, but did so without requiring you to rewrite the app. Thus, in the email app, you could tap through your list of emails to a single email on a phone, or on a tablet see both side by side.</p>\n<div>\n<img alt=\"Webos-lost-1-theverge-5_1020\" src=\"http://cdn2.sbnation.com/assets/3796499/webos-lost-1-theverge-5_1020.jpg\"><br>\n</div>\n<p>Vonshak and his team were tasked with extending both of those two UX metaphors and making them more useful. To do it, the team essentially mixed them together. In Eel, you could tap on a link to open it up in a new panel, which would appear on the left. But instead of simply being a panel within an app, it would be a separate card, which you could slide left or right to have multiple cards visible. You could also &quot;shear&quot; off the card and put it into an entirely different stack. It wasn’t dissimilar from the way that Windows 8 allows you to &quot;snap&quot; windows, but on Eel it was to be more flexible in terms of window size and grouping. Panels and cards weren't quite the &quot;windows&quot; that we're used to on desktops, but it approached their utility while still being manageable on both phones and tablets.</p>\n</div>\n</div>\n<iframe name=\"38285-chorus-video-iframe\" src=\"http://www.theverge.com/videos/iframe?id=38285\"></iframe>\n<div>\n<div>\n<h2>Design</h2>\n<p>Though Eel added more power to the core interface of webOS (along with, it must be said, more complexity), it also did something more. Years before Apple went &quot;flat&quot; with its design for iOS 7 and even well before Android cleaned itself up, the Vonshak and visual design director Liron Damir were finalizing a new software design language it called &quot;Mochi.&quot;</p>\n<p>In fact, Palm had been working on two different design languages for Eel. One was significantly harsher and more industrial-looking, the better to match the hard lines of products like Twain and Mako. However, when Apotheker made the decision to scuttle webOS hardware, the team focused its efforts on the softer Mochi design — which was more in fitting with Palm's ethos.</p>\n<img alt=\"Webos-lost-1-theverge-11_1020\" src=\"http://cdn2.sbnation.com/assets/3796483/webos-lost-1-theverge-11_1020.jpg\"><p>As HP's management struggled to decide what to do with webOS, Palm's software team moved forward on redesigning the entire OS with a flatter, cleaner look. Soft white backgrounds were mixed with bold colors. At one point, the team had proposed creating subtle animations for the panels, having them &quot;breathe&quot; as though they were pieces of paper, so you could tell that they could be moved around more easily. In lieu of back buttons, panels had a small curved tab at the bottom that indicated they could be grabbed and resized.</p>\n<p>Mochi wasn't completely flat in the vein of Windows Phone, or even what we'd eventually see with iOS 7. There were still gradients and curves — but they were mixed with big typography and an elegant use of white space to help make data easier to parse. Fonts were improved and Eel made heavy use of circles — an homage to the Palm logo of old.</p>\n</div>\n</div>\n<div>\n<div><img alt=\"Twain-hardware-d2i_03162011-4\" src=\"http://cdn2.sbnation.com/assets/3794319/Twain-Hardware-D2I_03162011-4.jpg\"></div>\n</div>\n<div>\n<div>\n<p>Obviously, none of these webOS dreams came to pass — nor did other ideas like a stylus that could read color in the real world and then use it to draw on a tablet. Even if HP had not decided to give up on webOS hardware and all but abandon webOS software, the chances that any of these products would have seen the market and gained any sort of real success seems awfully small. Both Palm and HP had difficulties shipping on time and competing successfully even in the best of circumstances — and it was clear that HP didn't think it would be able to take on the challenges that would have lain ahead for webOS.</p>\n<p>The competitive landscape for tablets and phones wasn't quite as locked down in late 2011 and early 2012 as it is now — back then, it still seemed like there might be space for at least four major players in the market. However, since then we've seen BlackBerry implode almost as spectacularly as Palm, and a host of other companies have failed to make a dent. Microsoft may have established itself in third place behind iOS and Android — but with the benefit of hindsight it seems obvious now that there wouldn't have been much space for webOS to hang on.</p>\n<p>Though it's painful to Palm fans to have to admit it (especially when looking at the clean lines on Mochi), the marketplace probably would have doomed these webOS products if HP hadn't done it first. We'll never be able to say definitively that HP made the right call in killing off webOS and selling what was left for LG to put on televisions. But now, in 2014, <a href=\"http://www.theverge.com/2014/1/2/5265490/lgs-webos-tv-ui-photo-leak\">LG's forthcoming TV</a> will be yet another new beginning for webOS — a smaller ambition for a bigger screen.</p>\n<p><em>Photography by Michael Shane</em></p>\n</div>\n</div>\n<p> </p>",
					author: "Dieter Bohn",
					title: "The lost secrets of webOS",
					date: 1388683692000,
					link: "http://www.theverge.com/2014/1/2/5264580/the-lost-secrets-of-webos",
					source: "The Verge -\tAll Posts",
					unread: true,
					recommendations: 35,
					image: "http://cdn3.sbnation.com/entry_photo_images/9627107/webos-lost-2-theverge-4_1020_large.jpg"
				},
				{
					id: "PSNTZO8gXFUe+cpCZyApw0vEKWPT4b14D6teBEocIAE=_1435401781b:bbf6:623b9014",
					excerpt: "Reliving movies on Twitter has become a trend, and a cult classic just popped up online. Argentinean advertising creative Jorge Zacher used 15 Twitter accounts and 1,125 tweets to recreate the entire Reservoir Dogs script. He made each character a Twitter account where they all tweeted lines from th",
					content: "<img alt=\"\" src=\"http://cdn0.sbnation.com/entry_photo_images/9627253/Screen_Shot_2014-01-02_at_10.43.44_AM_large.png\">\n<p>Reliving movies on Twitter has become a <a target=\"_blank\" href=\"http://www.theverge.com/2013/12/3/5170068/mob-city-miniseries-script-twitter-adaptation\">trend</a>, and a cult classic just popped up online. Argentinean advertising creative Jorge Zacher used <a target=\"_blank\" href=\"http://cargocollective.com/zacher/Reservoir-Tweets\">15 Twitter accounts and 1,125 tweets</a> to recreate the entire <i>Reservoir Dogs</i> script. He made each character a Twitter account where they all tweeted lines from the movie, which were then retweeted by the <a target=\"_blank\" href=\"https://twitter.com/ReservoirDogs_\">@ReservoirDogs_</a> account in reverse order so it could be read on Twitter.</p>\n<blockquote lang=\"en\">\n<p>What was that? I'm sorry. I didn't catch it. Would you repeat it?</p>\n— Mr. White (@MrWhite_z) <a href=\"https://twitter.com/MrWhite_z/statuses/417710398763040768\">December 30, 2013</a>\n</blockquote>\n<p>\n</p>\n<blockquote lang=\"en\">\n<p>Are you going to bark all day, little doggie, or are you going to bite?</p>\n— Mr. Blonde (@MrBlonde_z) <a href=\"https://twitter.com/MrBlonde_z/statuses/417720208921358336\">December 30, 2013</a>\n</blockquote>\n<p>Some of the best tweets are the short and sweet exposition lines from the @ReservoirDogs_ that tie the entire story together, capturing both the violent essence of the movie's most memorable scenes as well as the small gestures that make the movie a strange and beloved classic. Other films like <a target=\"_blank\" href=\"https://twitter.com/_hillvalley/the-hill-valley-project\"><i>Back to the Future</i></a> have been revitalized in the same way, but there's something about reading a Tarantino film in tweets that's both unsettling and awesome.</p>\n<blockquote lang=\"en\">\n<p>Mr Orange is now rehearsing outside, by a grafitii-covered wall. He's much more smooth and confident now. Holdaway is watching and listening</p>\n— Reservoir Dogs (@ReservoirDogs_) <a href=\"https://twitter.com/ReservoirDogs_/statuses/417892081093201920\">December 31, 2013</a>\n</blockquote>\n<p>\n</p>",
					author: "Valentina Palladino",
					title: "The story of 'Reservoir Dogs' retold in over 1,000 tweets",
					date: 1388682591000,
					link: "http://www.theverge.com/2014/1/2/5266094/reservoir-dogs-script-in-tweets",
					source: "The Verge -\tAll Posts",
					unread: true,
					recommendations: 35,
					image: "http://cdn0.sbnation.com/entry_photo_images/9627253/Screen_Shot_2014-01-02_at_10.43.44_AM_large.png"
				}
			]
		},
		names: {
			"feed/http://www.theverge.com/rss/full.xml": "The Verge",
			"feed/http://feeds.gawker.com/lifehacker/vip": "Lifehacker",
			"feed/http://feeds.feedburner.com/Techcrunch": "TechCrunch",
			"feed/http://feeds.betakit.com/betakit": "Betakit",
			"feed/http://www.engadget.com/rss.xml": "Engadget",
			"feed/http://feeds.gawker.com/gizmodo/vip": "Gizmodo",
			"feed/http://feeds2.feedburner.com/Mashable": "Mashable!",
			"feed/http://readwrite.com/main/feed/articles.xml": "ReadWrite",
			"feed/http://feeds2.feedburner.com/thenextweb": "The Next Web",
			"feed/http://www.nytimes.com/services/xml/rss/nyt/HomePage.xml": "The New York Times",
			"feed/http://feeds.reuters.com/reuters/topNews?irpc=69": "Reuters",
			"feed/http://rss.cnn.com/rss/cnn_topstories.rss": "CNN",
			"feed/http://www.lemonde.fr/rss/sequence/0,2-3208,1-0,0.xml": "Le Monde",
			"feed/http://www.lefigaro.fr/rss/figaro_une.xml": "Le Figaro",
			"feed/http://www.rue89.com/homepage/feed": "Rue89",
			"feed/http://newsfeed.zeit.de/index": "Zeit Online",
			"feed/http://www.elpais.com/rss/feed.html?feedId=1022": "EL PAIS",
			"feed/http://www.guardian.co.uk/rssfeed/0,,1,00.xml": "The Guardian",
			"feed/http://newsrss.bbc.co.uk/rss/newsonline_world_edition/front_page/rss.xml": "BBC",
			"feed/http://feeds.feedburner.com/venturebeat": "VentureBeat",
			"feed/http://sethgodin.typepad.com/seths_blog/atom.xml": "Seth Godin",
			"feed/http://feeds.feedburner.com/AVc": "A VC : Venture Capital and Technology",
			"feed/http://feeds.feedburner.com/ommalik": "GigaOM",
			"feed/http://pandodaily.com/feed/": "Pando Daily",
			"feed/http://allthingsd.com/feed": "All Things D",
			"feed/http://www.calculatedriskblog.com/feeds/posts/default": "Calculated Risk",
			"feed/http://feeds.harvardbusiness.org/harvardbusiness/": "Harvard Business Review",
			"feed/http://www.polygon.com/rss/full.xml": "Polygon",
			"feed/http://www.joystiq.com/rss.xml": "Joystiq",
			"feed/http://feeds.feedburner.com/Massively": "Massively",
			"feed/http://www.indiegames.com/blog/atom.xml": "Indie Games",
			"feed/http://feeds.arstechnica.com/arstechnica/gaming/": "Opposable Thumbs",
			"feed/http://feed.500px.com/500px-editors": "500px",
			"feed/http://thomashawk.com/feed": "Thomas Hawk Digital Connection",
			"feed/http://www.boston.com/bigpicture/index.xml": "The Big Picture",
			"feed/http://www.nationalgeographic.com/rss/photography/photo-of-the-day": "National Geographic",
			"feed/http://wvs.topleftpixel.com/index.rdf": "Daily Dose Of Imagery",
			"feed/http://theimpossiblecool.tumblr.com/rss": "The Impossible Cool",
			"feed/http://feeds.feedburner.com/design-milk": "Design Milk",
			"feed/http://feeds.feedburner.com/FreshInspirationForYourHome": "Fresh Home",
			"feed/http://www.swiss-miss.com/feed": "Swiss Miss",
			"feed/http://www.home-designing.com/feed": "Home Designing",
			"feed/http://www.yatzer.com/feed/index.php": "Yatzer",
			"feed/http://feeds.feedburner.com/core77/blog": "Core77",
			"feed/http://www.yankodesign.com/feed/": "Yanko Design",
			"feed/http://feeds.feedburner.com/abduzeedo?format=xml": "Abduzeedo",
			"feed/http://blog.2modern.com/atom.xml": "2Modern",
			"feed/http://www.sfgirlbybay.com/feed/": "SF Girl By The Bay",
			"feed/http://feeds.feedburner.com/dezeen": "Dezeen",
			"feed/http://www.fastcodesign.com/rss.xml": "Co.Design",
			"feed/http://www.fubiz.net/en/feed/": "Fubiz",
			"feed/http://mocoloco.com/index.rdf": "Mocoloco",
			"feed/http://www.unplggd.com/unplggd/atom.xml": "Unplggd",
			"feed/http://www.apartmenttherapy.com/main/atom.xml": "Apartment Therapy",
			"feed/http://www.designspongeonline.com/feed": "Design*Sponge",
			"feed/http://ikeahacker.blogspot.com/feeds/posts/default": "IKEA Hackers",
			"feed/http://decor8blog.com/feed/": "Decor8",
			"feed/http://archinect.com/news.xml": "Archinect",
			"feed/http://www.archdaily.com/feed/": "Arch Daily",
			"feed/http://feeds.feedburner.com/contemporist": "Contemporist",
			"feed/http://www.trendir.com/house-design/atom.xml": "Modern House Designs",
			"feed/http://adsoftheworld.com/node/feed": "Ads Of The World",
			"feed/http://www.underconsideration.com/brandnew/atom.xml": "Brand New",
			"feed/http://feeds.feedburner.com/logodesignlove": "Logo Design World",
			"feed/http://www.corporate-identity-design.com/feed/": "Corporate Identity Design",
			"feed/http://feeds.frogdesign.com/frog-design-mind": "Design Mind",
			"feed/http://feeds.feedburner.com/whitneyhess": "Pleasure and Pain",
			"feed/http://feeds.feedburner.com/NirAndFar": "Nir and Far",
			"feed/http://metacool.typepad.com/metacool/atom.xml": "Metacool",
			"feed/http://www.jnd.org/index.xml": "JND",
			"feed/http://page2rss.com/rss/9fc3ae12a1465446684506f7461b9129": "Graphic Exchange",
			"feed/http://www.designworklife.com/feed/": "Design Work Life",
			"feed/http://feeds.feedburner.com/ucllc/fpo": "Under Consideration - For Print Only",
			"feed/http://www.aisleone.net/feed/": "Aisle One",
			"feed/http://grainedit.com/feed/": "Grain Edit",
			"feed/http://gridness.net/feed/": "Gridness",
			"feed/http://feeds.feedburner.com/TheDieline": "The Dieline",
			"feed/http://www.packagingoftheworld.com/feeds/posts/default": "Packaging Of The World",
			"feed/http://lovelypackage.com/feed/": "Lovely Package",
			"feed/http://ambalaj.se/feed/": "Ambalaj",
			"feed/http://thepackagingdesignblog.com/?feed=rss2": "The Packaging Design Blog",
			"feed/http://tdc.org/feed/": "tdc",
			"feed/http://feedproxy.google.com/ILoveTypography": "I Love Typography",
			"feed/http://www.typetoken.net/feed/": "Typetoken",
			"feed/http://feeds.feedburner.com/FontsInUse": "Fonts In Use",
			"feed/http://feeds.feedburner.com/TypographyDaily": "Typography Daily",
			"feed/http://ministryoftype.co.uk/words/rss/": "Ministry Of Type",
			"feed/http://feeds2.feedburner.com/veerlesblog": "Veerle's Blog",
			"feed/http://feeds.feedburner.com/adaptivepath": "Adaptive Path",
			"feed/http://feeds.feedburner.com/CssTricks": "CSS-Tricks",
			"feed/http://feeds.feedburner.com/cooper-journal": "Cooper",
			"http://feeds.feedburner.com/creativeapplicationsnet": "Creative Applications",
			"feed/http://feeds.feedburner.com/UXM": "UX Magazine",
			"feed/http://rss1.smashingmagazine.com/feed/": "Smashing Magazine",
			"feed/http://feeds.feedburner.com/FunctioningForm": "Luke W",
			"feed/http://feeds.feedburner.com/37signals/beMH": "Signal vs. Noise",
			"feed/http://www.chipple.net/rss/custom/alertbox/index.rdf": "Use It",
			"feed/http://feeds.feedburner.com/subtraction": "Subtraction",
			"feed/http://feeds.feedburner.com/52WeeksOfUx": "52 Weeks Of UX",
			"feed/http://feeds.feedburner.com/DesignStaff?format=xml": "Design Staff",
			"feed/http://feeds.feedburner.com/minimalsites": "Minimal Sites",
			"feed/http://feeds.feedburner.com/FlowingData": "Flowing Data",
			"feed/http://feeds.feedburner.com/Datavisualization": "Data Visualization",
			"feed/http://infosthetics.com/atom.xml": "Information Aesthetics",
			"feed/http://feeds.feedburner.com/thesartorialist": "The Sartorialist",
			"feed/http://seaofshoes.typepad.com/sea_of_shoes/atom.xml": "Sea of shoes",
			"feed/http://www.fashiontoast.com/feeds/posts/default": "fashiontoast",
			"feed/http://www.stylebubble.co.uk/style_bubble/atom.xml": "Style Bubble",
			"feed/http://www.theblondesalad.com/feeds/posts/default": "The Blonde Salad",
			"feed/http://www.cocosteaparty.com/feeds/posts/default": "Coco's Tea Party",
			"feed/http://feeds.feedburner.com/smittenkitchen": "smitten kitchen",
			"feed/http://cannelle-vanille.blogspot.com/feeds/posts/default": "Cannelle et Vanille",
			"feed/http://www.latartinegourmande.com/feed/": "La Tartine Gourmande",
			"feed/http://www.davidlebovitz.com/archives/index.rdf": "David Lebovitz",
			"feed/http://www.herbivoracious.com/atom.xml": "Herbivoracious",
			"feed/http://www.101cookbooks.com/index.rdf": "101 Cookbooks",
			"feed/http://feedproxy.google.com/elise/simplyrecipes": "Simply Recipes",
			"feed/http://daringfireball.net/index.xml": "Daring Fireball",
			"feed/http://www.macrumors.com/macrumors.xml": "MacRumors",
			"feed/http://www.tuaw.com/rss.xml": "The Unofficial Apple Weblog",
			"feed/http://feeds.arstechnica.com/arstechnica/apple/": "Infinite Loop",
			"feed/http://feeds.feedburner.com/cultofmac/bFow": "Cult of Mac",
			"feed/http://feeds.feedburner.com/theappleblog": "TheAppleBlog",
			"feed/http://www.mactrast.com/feed/": "MacTrast",
			"feed/http://androidandme.com/feed/": "Android and Me",
			"feed/http://androidcommunity.com/feed/": "Android Community",
			"feed/http://feeds.feedburner.com/blogspot/hsDu": "Android Developers Blog",
			"feed/http://www.androidcentral.com/feed": "Android Central",
			"feed/http://blog.makezine.com/index.xml": "Make",
			"feed/http://www.instructables.com/tag/type:instructable/rss.xml": "Instructables",
			"feed/http://blog.craftzine.com/index.xml": "Craft",
			"feed/http://www.hackaday.com/rss.xml": "Hack A Day",
			"feed/http://www.yougrowgirl.com/feed/": "You Grow Girl",
			"feed/http://www.gardenrant.com/my_weblog/atom.xml": "Garden Rant",
			"feed/http://awaytogarden.com/feed": "A Way To Garden",
			"feed/http://feeds.feedburner.com/LifeOnTheBalcony": "Life On The Balcony",
			"feed/http://feeds.feedburner.com/bridalmusings": "Bridal Musings",
			"feed/http://www.stylemepretty.com/feed/": "Style Me Pretty",
			"feed/http://ruffledblog.com/feed/": "Ruffled",
			"feed/http://bridalsnob.tumblr.com/rss": "Bridal Snob",
			"feed/http://thecinderellaproject.blogspot.com/feeds/posts/default": "The Cinderella Project",
			"feed/http://masterpieceweddings.blogspot.com/feeds/posts/default": "Adventures In Wedding Planning",
			"feed/http://bridechic.blogspot.com/feeds/posts/default": "Bride Chic",
			"feed/http://blogs.suntimes.com/ebert/atom.xml": "Roger Ebert's Journal",
			"feed/http://www.davidbordwell.net/blog/?feed=atom": "Observations On Film Art",
			"feed/http://feeds.feedburner.com/firstshowing": "First Showing",
			"feed/http://mubi.com/notebook/posts.atom": "The Daily Notebook",
			"feed/http://gdata.youtube.com/feeds/base/users/WSJDigitalNetwork/uploads?alt=rss&v=2&orderby=published&client=ytapi-youtube-profile": "WSJ Digital Network",
			"feed/http://gdata.youtube.com/feeds/base/users/NationalGeographic/uploads?alt=rss&v=2&orderby=published&client=ytapi-youtube-profile": "National Geographic",
			"feed/http://gdata.youtube.com/feeds/base/users/TEDtalksDirector/uploads?alt=rss&v=2&orderby=published&client=ytapi-youtube-profile": "Ted Talks",
			"feed/http://gdata.youtube.com/feeds/base/users/trailers/uploads?alt=rss&v=2&orderby=published&client=ytapi-youtube-profile": "Viso Trailers",
			"feed/http://gdata.youtube.com/feeds/base/users/TEDEducation/uploads?alt=rss&v=2&orderby=published&client=ytapi-youtube-profile": "TED Education",
			"feed/http://gdata.youtube.com/feeds/base/users/TheEllenShow/uploads?alt=rss&v=2&orderby=published&client=ytapi-youtube-profile": "The Ellen Show",
			"feed/http://gdata.youtube.com/feeds/base/users/JimmyKimmelLive/uploads?alt=rss&v=2&orderby=published&client=ytapi-youtube-profile": "Jimmy Kimmel Live",
			"feed/http://gdata.youtube.com/feeds/base/users/vsauce/uploads?alt=rss&v=2&orderby=published&client=ytapi-youtube-profile": "Vsauce",
			"feed/http://gdata.youtube.com/feeds/base/users/kevjumba/uploads?alt=rss&v=2&orderby=published&client=ytapi-youtube-profile": "Kevin Jumba",
			"feed/feed/http://gdata.youtube.com/feeds/base/users/GOODMagazine/uploads?alt=rss&v=2&orderby=published&client=ytapi-youtube-profile": "GOOD Magazine",
			"feed/http://vimeo.com/channels/staffpicks/videos/rss": "Vimeo Staff Pick",
			"feed/http://vimeo.com/channels/fubiz/videos/rss": "Fubiz",
			"feed/http://vimeo.com/channels/everythinganimated/videos/rss": "Everything Animated",
			"feed/http://vimeo.com/channels/nicetype/videos/rss": "Nice Type",
			"feed/http://vimeo.com/channels/documentaryfilm/videos/rss": "Documentary Film",
			"feed/http://vimeo.com/channels/40086/videos/rss": "Socially Minded Documentaries",
			"feed/http://vimeo.com/channels/hd/videos/rss": "The Vimeo HD Channel",
			"feed/http://www.etsy.com/shop/PerDozenDesign/rss": "Per Dozen Design",
			"feed/http://www.etsy.com/shop/TFrancisco/rss": "TFrancisco",
			"feed/http://www.etsy.com/shop/claireswilson/rss": "Claire S. Wilson",
			"feed/http://www.etsy.com/shop/skinblaster/rss": "Skinblaster",
			"feed/http://www.etsy.com/shop/SharonFosterArt/rss": "Sharon Foster Art",
			"feed/http://www.etsy.com/shop/tukeon/rss": "Tukeon",
			"feed/http://www.etsy.com/shop/dawndishawceramics/rss": "Dawn Dishaw Ceramics",
			"feed/http://www.etsy.com/shop/sarapaloma/rss": "Sara Paloma Pottery"
		},
		oAuth: false,
		setOAuth: function() {
			this.oAuth = new OAuth({
				id: "ichrome",
				name: "feedly",
				redirectURL: "http://localhost/",
				secret: "FE01EPSTO5GAZNO3MQZXLUCCV19T",
				scope: "https://cloud.feedly.com/subscriptions",
				tokenURL: "https://cloud.feedly.com/v3/auth/token",
				authURL: "https://cloud.feedly.com/v3/auth/auth?response_type=code&client_id={{clientID}}&redirect_uri={{redirectURL}}&scope={{scope}}"
			});
		},
		getSources: function(cb) {
			if (!this.oAuth) {
				this.setOAuth();
			}

			var oAuth = this.oAuth;

			oAuth.getToken(function(token, data) {
				var categories = {};

				categories["user/" + data.id + "/category/global.all"] = this.utils.translate("all");
				categories["user/" + data.id + "/tag/global.saved"] = this.utils.translate("saved");
				categories["user/" + data.id + "/category/global.uncategorized"] = this.utils.translate("uncategorized");

				oAuth.ajax({
					type: "GET",
					url: "https://cloud.feedly.com/v3/subscriptions",
					cache: false,
					success: function(d) {
						var feeds = {
							label: this.utils.translate("settings.source_feeds")
						};

						d.forEach(function(e) {
							e.categories.forEach(function(c) {
								categories[c.id] = c.label;
							});

							feeds[e.id] = e.title;
						});

						categories.feeds = feeds;

						cb(categories);
					}.bind(this)
				});
			}.bind(this));
		},
		knowDomains: [
			"www.reuters.com",
			"feeds.kinja.com",
			"www.lemonde.fr",
			"vimeo.com",
			"feeds.feedburner.com",
			"mubi.com",
			"ruffledblog.com",
			"daringfireball.net",
			"www.nationalgeographic.com",
			"www.lefigaro.fr",
			"www.theverge.com",
			"www.nytimes.com",
			"www.guardian.co.uk",
			"pandodaily.com",
			"www.calculatedriskblog.com",
			"www.indiegames.com",
			"feed.500px.com",
			"www.swiss-miss.com",
			"ikeahacker.blogspot.com",
			"adsoftheworld.com",
			"www.etsy.com"
		],
		fixlinks: function(item) {
			var fix = function(url) {
				if (!_.isEmpty(url)) {
					for (var i = 0; i < this.knowDomains.length; i++) {
						var domain = this.knowDomains[i];

						if (url.indexOf("http://" + domain) === 0) {
							return url.slice(0, 4) + "s" + url.slice(4);
						}
					}
				}

				return url;
			}.bind(this);

			item.image = fix(item.image);
		},
		getArticles: function(d) {
			if (!this.oAuth) {
				this.setOAuth();
			}

			var names = this.names,
				articles = [],
				oAuth = this.oAuth,
				getImage = function(article) {
					if (article.visual && article.visual.url && article.visual.url !== "none" && article.visual.url !== "") {
						if (article.visual.url.indexOf("files.wordpress.com") !== -1) {
							article.visual.url = article.visual.url.substr(0, article.visual.url.lastIndexOf("?")) + "?w=370&h=250&crop=1";
						}
						else if (article.visual.url.indexOf("blogcdn.com") !== -1) {
							article.visual.url = article.visual.url.replace("_thumbnail", "");
						}
						else if (article.visual.url.indexOf("img.gawkerassets.com") !== -1) {
							article.visual.url = article.visual.url.replace("ku-xlarge", "ku-medium");
						}

						return article.visual.url;
					}

					var image = false,
						srcs = [],
						html = $(("<div>" + (article.content || "") + "</div>")
									.replace(/ src="\/\//g, " data-src=\"https://")
									.replace(/ src="/g, " data-src=\"")
									.replace(/ src='\/\//g, " data-src='https://")
									.replace(/ src='/g, " data-src='"));

					Array.prototype.slice.apply(html[0].querySelectorAll(
						"img[data-src]" +
						':not(.mf-viral)' +								':not(.feedflare)' +
						':not([width="1"])' + 						':not([height="1"])' +
						':not([data-src*="feeds.wordpress.com"])' +		':not([data-src*="stats.wordpress.com"])' +
						':not([data-src*="feedads"])' +					':not([data-src*="tweet-this"])' +
						':not([data-src*="-ads"])' +					':not([data-src*="_ads"])' +
						':not([data-src*="zemanta"])' +					':not([data-src*="u.npr.org/iserver"])' +
						':not([data-src*="slashdot-it"])' +				':not([data-src*="smilies"])' +
						':not([data-src*="commindo-media.de"])' +		':not([data-src*="creatives.commindo-media"])' +
						':not([data-src*="i.techcrunch"])' +			':not([data-src*="adview"])' +
						':not([data-src*=".ads."])' +					':not([data-src*="/avw.php"])' +
						':not([data-src*="feed-injector"])' +			':not([data-src*="/plugins/"])' +
						':not([data-src*="_icon_"])' +					':not([data-src*="/ad-"])' +
						':not([data-src*="buysellads"])' +				':not([data-src*="holstee"])' +
						':not([data-src*="/ad_"])' +					':not([data-src*="/button/"])' +
						':not([data-src*="/sponsors/"])' +				':not([data-src*="googlesyndication.com"])' +
						':not([data-src*="/adx"])' +					':not([data-src*="assets/feed-fb"])' +
						':not([data-src*="feedburner.com/~ff"])' +		':not([data-src*="gstatic.com"])' +
						':not([data-src*="feedproxy"])' +				':not([data-src*="feedburner"])' +
						':not([data-src*="/~"])' +						':not([data-src*="googleadservices.com"])' +
						':not([data-src*="fmpub"])' +					':not([data-src*="pheedo"])' +
						':not([data-src*="openx.org"])' +				':not([data-src*="/ico-"])' +
						':not([data-src*="doubleclick.net"])' +			':not([data-src*="/feed.gif"])' +
						':not([data-src*="wp-digg-this"])' +			':not([data-src*="tweetmeme.com"])' +
						':not([data-src*="share-buttons"])' +			':not([data-src*="musictapp"])' +
						':not([data-src*="donate.png"])' +				':not([data-src*="/pagead"])' +
						':not([data-src*="assets/feed-tw"])' +			':not([data-src*="feedsportal.com/social"])'
					)).forEach(function(e) {
						srcs.push(e.getAttribute("data-src"));
					});

					if (srcs.length) {
						image = srcs[0];
					}
					else if (html.find("iframe[data-chomp-id]").length) {
						image = "http://img.youtube.com/vi/" + html.find("iframe[data-chomp-id]").attr("data-chomp-id") + "/1.jpg";
					}

					if (image && image.indexOf("files.wordpress.com") !== -1) {
						image = image.substr(0, image.lastIndexOf("?")) + "?w=370&h=250&crop=1";
					}
					else if (image && image.indexOf("blogcdn.com") !== -1) {
						image = image.replace("_thumbnail", "");
					}
					else if (image && image.indexOf("http://img.gawkerassets.com/") !== -1) {
						image = image.replace("ku-xlarge", "ku-medium");
					}
					else if (article.enclosure) { //checks if the enclosure object exist, then if it contains an image it uses the first found
						for (var i = 0; i < article.enclosure.length; i++) {
							if (["image/jpeg", "image/png"].indexOf(article.enclosure[i].type) >= 0) {
								image = article.enclosure[i].href;
								break;
							}
						}
					}

					return image;
				},
				div = document.createElement("div");

			if (!(typeof d.items === "object" && typeof d.items.forEach !== "undefined")) {
				return articles;
			}

			d.items.forEach(function(e) {
				var article = {
					id: e.id,
					title: e.title,
					author: e.author,
					unread: !!e.unread,
					date: e.published || 0,
					recommendations: abbreviate(parseInt(e.engagement || 0), 1000, 2)
				};

				if (e.content) {
					article.content = e.content.content || "";

					div.innerHTML = article.content;

					article.excerpt = div.textContent.trim().slice(0, 300).replace(/\n/g, "  ");
				}
				else if (e.summary) {
					article.content = e.summary.content || "";

					div.innerHTML = article.content;

					article.excerpt = div.textContent.trim().slice(0, 300).replace(/\n/g, "  ");
				}

				if (e.tags && e.tags[0]) {
					e.tags.forEach(function(t) {
						if (t.id === "user/" + oAuth.data.id + "/tag/global.saved") {
							article.saved = true;
						}
					});
				}

				if (e.alternate && e.alternate[0]) {
					article.link = e.alternate[0].href || "";
				}

				if (e.origin) {
					article.source = names[e.origin.streamId || ""] || e.origin.title || e.title;
				}

				if (e.enclosure) { //sometime this object contains the image
					article.enclosure = e.enclosure;
				}

				if (e.visual) {
					article.visual = e.visual;
				}

				article.image = getImage(article);

				this.fixlinks(article);

				articles.push(article);
			}.bind(this));

			return articles;
		},
		refresh: function() {
			var req;

			if (this.config.source.indexOf("feed/") === 0 && !this.oAuth.hasToken()) {
				req = $.ajax;
			}
			else {
				req = this.oAuth.ajax.bind(this.oAuth);
			}

			req({
				type: "GET",
				url: "https://cloud.feedly.com/v3/streams/contents?count=10&streamId=" + encodeURIComponent(this.config.source) + (this.config.show === "unread" ? "&unreadOnly=true" : "") + "&ranked=" + this.config.sort,
				cache: false,
				success: function(d) {
					if (!d) {
						return;
					}

					var data = {
						articles: this.getArticles(d),
						next: d.continuation || false
					};

					this.data = data;

					this.render.call(this);

					this.utils.saveData(this.data);
				}.bind(this)
			});
		},
		setHandlers: function() {
			if (!this.oAuth) {
				this.setOAuth();
			}

			var loading = false,
				that = this,
				last = 0,
				sent = {},
				sendout = "",
				outset = false,
				submitting = false,
				next = this.data.next,
				submit = function() {
					var parent = $(this),
						ptop = parent.offset().top,
						pheight = this.offsetHeight,
						ids = [],
						id, elm;

					parent.find(".item").each(function() {
						if (((elm = $(this)).offset().top - ptop) + this.offsetHeight - pheight <= 0 && !sent.hasOwnProperty(id = elm.attr("data-id"))) {
							ids.push(id);

							sent[id] = true;
						}
					});

					submitting = true;

					that.oAuth.ajax({
						type: "POST",
						data: JSON.stringify({
							action: "markAsRead",
							type: "entries",
							entryIds: ids
						}),
						contentType: "application/json",
						url: "https://cloud.feedly.com/v3/markers",
						success: function() {
							submitting = false;
						}
					});

					last = new Date().getTime();
				};

			this.elm.find(".items").on("mousedown", ".item", function() {
				// mousedown handles left, middle, and right clicks

				var id = $(this).attr("data-id");

				if (!sent.hasOwnProperty(id)) {
					sent[id] = true;

					that.oAuth.ajax({
						type: "POST",
						data: JSON.stringify({
							action: "markAsRead",
							type: "entries",
							entryIds: [id]
						}),
						contentType: "application/json",
						url: "https://cloud.feedly.com/v3/markers"
					});
				}
			}).on("click", ".item .recommendations", function(e) {
				e.preventDefault();
				e.stopPropagation();

				var elm = $(this);

				if (elm.hasClass("saved")) {
					that.oAuth.ajax({
						type: "DELETE",
						url: "https://cloud.feedly.com/v3/tags/" + encodeURIComponent("user/" + that.oAuth.data.id + "/tag/global.saved") + "/" + encodeURIComponent(elm.parents(".item").first().attr("data-id")),
						complete: function() {
							elm.removeClass("saved").text(parseInt(elm.text()) - 1);
						}
					});
				}
				else {
					that.oAuth.ajax({
						type: "PUT",
						data: JSON.stringify({
							entryId: elm.parents(".item").first().attr("data-id")
						}),
						url: "https://cloud.feedly.com/v3/tags/" + encodeURIComponent("user/" + that.oAuth.data.id + "/tag/global.saved"),
						complete: function() {
							elm.addClass("saved").text(parseInt(elm.text()) + 1);
						}
					});
				}
			}).on("scroll", function() {
				if (!loading && next && (this.scrollHeight - this.offsetHeight) < (this.scrollTop + this.offsetHeight)) {
					loading = true;

					that.oAuth.ajax({
						type: "GET",
						url: "https://cloud.feedly.com/v3/streams/contents?count=20&streamId=" + encodeURIComponent(that.config.source) + "&continuation=" + encodeURIComponent(next) + (that.config.show === "unread" ? "&unreadOnly=true" : "") + "&ranked=" + that.config.sort,
						cache: false,
						success: function(d) {
							if (!(d)) {
								return;
							}

							next = d.continuation || false;

							var articles = that.getArticles(d);

							if (that.config.view === "cards dual") {
								var column1 = [],
									column2 = [],
									columns = $(this).find(".column");

								articles.forEach(function(e, i) {
									e.age = moment(e.date).fromNow(true).replace("hour", "hr").replace("minute", "min").replace("an ", "1 ").replace("a ", "1 ").replace("a few ", "");

									if (i % 2 === 0) {
										column2.push(e);
									}
									else {
										column1.push(e);
									}
								});

								columns.first().append(that.utils.renderTemplate("articles", {
									articles: column1
								}));

								columns.last().append(that.utils.renderTemplate("articles", {
									articles: column2
								}));
							}
							else {
								articles.forEach(function(e) {
									e.age = moment(e.date).fromNow(true).replace("hour", "hr").replace("minute", "min").replace("an ", "1 ").replace("a ", "1 ").replace("a few ", "");
								});

								$(this).append(that.utils.renderTemplate("articles", {
									articles: articles
								}));
							}

							loading = false;

							articles = d = null;
						}.bind(this)
					});
				}

				if (that.config.mark === "scroll" && !submitting && new Date().getTime() - last > 5000) {
					clearTimeout(sendout);

					outset = false;

					submit.call(this);
				}
				else if (that.config.mark === "scroll" && !submitting && !outset) {
					setTimeout(function() {
						outset = false;

						submit.call(this);
					}.bind(this), 5000);

					outset = true;
				}
			});
		},
		render: function(demo) {
			var data = $.extend(true, {}, this.data || {articles:[]});

			if (this.config.view === "cards dual") {
				var articles = [],
					column2 = [];

				data.articles.forEach(function(e, i) {
					e.age = moment(e.date).fromNow(true).replace("hour", "hr").replace("minute", "min").replace("an ", "1 ").replace("a ", "1 ").replace("a few ", "");

					if (i % 2 === 0) {
						column2.push(e);
					}
					else {
						articles.push(e);
					}
				});

				data.articles = this.utils.renderTemplate("articles", {
					articles: articles
				});

				data.column2 = this.utils.renderTemplate("articles", {
					articles: column2
				});
			}
			else {
				data.articles.forEach(function(e) {
					e.age = moment(e.date).fromNow(true).replace("hour", "hr").replace("minute", "min").replace("an ", "1 ").replace("a ", "1 ").replace("a few ", "");
				});

				data.articles = this.utils.renderTemplate("articles", {
					articles: data.articles
				});
			}

			if (this.config.title && this.config.title !== "") {
				data.title = this.config.title;
			}

			data.link = this.config.link === "show";

			data.class = this.config.view;

			this.utils.render(data);

			if (!demo) {
				this.setHandlers();
			}
		}
	};
});

/*
 * HTML
 */
define('w/html',[],function() {
	return {
		id: 36,
		sort: 370,
		size: 4,
		order: 4,
		nicename: "html",
		sizes: ["variable"],
		settings: [
			{
				type: "textarea",
				nicename: "html",
				label: "i18n.settings.html",
				placeholder: "i18n.settings.html_placeholder"
			},
			{
				type: "textarea",
				nicename: "js",
				label: "i18n.settings.js"
			},
			{
				type: "number",
				label: "i18n.settings.height",
				nicename: "height",
				min: 100,
				max: 800
			},
			{
				type: "number",
				label: "i18n.settings.refresh",
				nicename: "refresh",
				min: 0,
				max: 100000
			},
		],
		config: {
			js: "",
			height: 400,
			refresh: 0,
			size: "variable",
			html: '<svg xmlns="http://www.w3.org/2000/svg" fill="#4CAF50" viewBox="0 0 24 24"><path d="M19 4h-4l-7.89 12.63-2.61-4.63 4.5-8h-4l-4.5 8 4.5 8h4l7.89-12.63 2.61 4.63-4.5 8h4l4.5-8z"/></svg>'
		},
		render: function() {
			//The legacy widget refresh functionality is not used because it does not allow to dynamically change the interval
			var currentRefresh = this.refreshInterval || 0;
			var expectedRefresh = this.config && this.config.refresh ? Number(this.config.refresh) : 0;

			if (currentRefresh !== expectedRefresh) {
				if (this.refreshTimerId) {
					window.clearInterval(this.refreshTimerId);
					delete this.refreshTimerId;
				}

				if (expectedRefresh > 0) {
					this.refreshTimerId = window.setInterval(function() {
						var iframes = this.elm.find("iframe");
						if (iframes.length > 0) {
							var iframe = iframes[0];
							if (iframe.contentWindow.location.protocol !== "chrome-extension:") {
								iframe.contentWindow.location.reload(true);
							}
						}
					}.bind(this), expectedRefresh * 1000);
				}

				this.refreshInterval = expectedRefresh;
			}

			this.utils.render({
				height: this.config.height || 400
			});

			var iframe = document.createElement("iframe");

			iframe.setAttribute("seamless", "seamless");
			iframe.style.height = (this.config.height || 400) + "px";

			iframe.onload = function() {
				iframe.contentWindow.document.open();
				iframe.contentWindow.document.write(this.config.html);
				iframe.contentWindow.document.close();

				if (this.config.js) {
					// Using the contentWindow's Function causes execution to happen in the frame
					(new (iframe.contentWindow.Function)(this.config.js))();
				}
			}.bind(this);

			// Future-proofing, instead of insertAfter
			this.elm.find("span.replace").replaceWith(iframe);

			this.elm.addClass("tabbed").css("height", this.config.height || 400); // This prevents a weird 5px gap at the bottom of the widget
		}
	};
});
/*
 * LinkedIn
 */
define('w/linkedin',["jquery", "lodash", "browser/api", "widgets/framefix"], function($, _, Browser, frameFix) {
	var headersListenerSet = false;

	return {
		id: 43,
		sort: 360,
		size: 5,
		nicename: "linkedin",
		sizes: ["variable"],
		settings: [
			{
				type: "number",
				label: "i18n.settings.height",
				nicename: "height",
				min: 100,
				max: 800
			}
		],
		config: {
			height: 500,
			size: "variable"
		},
		render: function() {
			if (!frameFix(this.render, this, arguments)) {
				return;
			}

			if (!headersListenerSet) {
				var tabId = frameFix.getTabId();

				Browser.webRequest.onBeforeSendHeaders.addListener(
					function(info) {
						var newHeaders = _.map(info.requestHeaders, function(e) {
							if (e.name.toLowerCase() === "user-agent") {
								return {
									name: "User-Agent",
									value: "Mozilla/5.0 (Linux; Android 6.0; Nexus 5 Build/MRA58N) AppleWebKit/537.36 " +
											"(KHTML, like Gecko) Chrome/69.0.3497.100 Mobile Safari/537.36"
								};
							}

							return e;
						});

						return {
							requestHeaders: newHeaders
						};
					},
					{
						tabId: tabId,
						urls: [ "*://*.linkedin.com/*" ],
						types: [ "sub_frame" ]
					},
					["blocking", "requestHeaders"]
				);

				headersListenerSet = true;
			}

			this.utils.render({
				height: this.config.height || 500
			});

			this.elm.addClass("tabbed").css("height", this.config.height || 500);
		}
	};
});
/*
 * The Notes widget.
 */
define('w/notes',["jquery"], function($) {
	return {
		id: 13,
		sort: 140,
		size: 2,
		order: 17,
		nicename: "notes",
		sizes: ["tiny", "variable"],
		settings: [
			{
				type: "size"
			},
			{
				type: "select",
				nicename: "color",
				label: "i18n.settings.color",
				options: {
					yellow: "i18n.settings.color_options.yellow",
					orange: "i18n.settings.color_options.orange",
					red: "i18n.settings.color_options.red",
					blue: "i18n.settings.color_options.blue",
					green: "i18n.settings.color_options.green",
					white: "i18n.settings.color_options.white",
				}
			},
			{
				type: "select",
				nicename: "face",
				label: "i18n.settings.font",
				options: {
					arial: "Arial",
					times: "Times New Roman",
					sans: "Open Sans",
					tahoma: "Tahoma",
					calibri: "Calibri",
					georgia: "Georgia"
				}
			},
			{
				type: "number",
				nicename: "fontsize",
				label: "i18n.settings.fontsize",
				min: 8,
				max: 45
			}
		],
		config: {
			fontsize: 14,
			face: "arial",
			color: "yellow",
			size: "variable"
		},
		syncData: {
			title: "Sample note title",
			content: 'This is sample note content.<br><br>This note widget can contain and display many things including images, <a href="https://www.google.com">links</a>, <b>bold</b>, <i>italic</i>&nbsp;and <u>underlined</u>&nbsp;text.<br><br>Via the settings menu (click the wrench icon in the top right) you can set the note color, font face and font size.<br><br>Have fun!'
		},
		saveNote: function() {
			if (this.titleElm && this.noteElm) {
				clearTimeout(this.timeout);

				// Speed is of the essence, use mostly vanilla JS here
				this.div.innerHTML = this.noteElm[0].innerHTML;

				[].forEach.call(this.div.querySelectorAll("div"), function(e) {
					$(e).replaceWith("<br>" + e.innerHTML);
				});

				[].forEach.call(this.div.querySelectorAll(":not(pre):not(blockquote):not(figure):not(hr):not(a):not(b):not(u):not(i):not(img):not(strong):not(p):not(sub):not(sup):not(br)"), function(e) {
					$(e).replaceWith(e.innerHTML);
				});

				[].forEach.call(this.div.querySelectorAll("pre, blockquote, figure, hr, a, b, u, i, img, strong, p, sub, sup, br"), function(e) {
					[].forEach.call(e.attributes, function(a) {
						if (a.name === "style" && a.value.indexOf("block;") !== -1) {
							e.innerHTML = "<br>" + e.innerHTML;

							e.removeAttribute(a.name);
						}
						else if (a.name !== "href" && a.name !== "src") {
							e.removeAttribute(a.name);
						}
					});
				});

				this.syncData.title = this.titleElm.val();
				this.syncData.content = this.div.innerHTML;

				this.timeout = setTimeout(function() {
					this.utils.saveConfig(this.syncData);
				}.bind(this), 500);
			}
		},
		render: function() {
			if (this.data) {
				this.syncData = $.extend(true, {}, this.data);

				delete this.data;
			}

			var data = {
				title: this.syncData.title,
				content: this.syncData.content
			},
			faces = {
				arial: "Arial, sans-serif",
				times: "Times New Roman, serif",
				sans: "Open Sans, sans-serif",
				tahoma: "Tahoma, sans-serif",
				calibri: "Calibri, sans-serif",
				georgia: "Georgia, serif"
			};

			data.size = this.config.fontsize || 14;
			data.face = faces[this.config.face || "arial"];
			data.color = this.config.color || "yellow";

			this.utils.render(data);

			this.titleElm = this.elm.find("input.header").on("input", this.saveNote.bind(this));
			this.noteElm = this.elm.find(".note .content").on("input", this.saveNote.bind(this));

			this.div = document.createElement("div");
		}
	};
});
/*
 * Google+ Notifications
 */
define('w/notifications',["jquery", "lodash", "widgets/framefix"], function($, _, frameFix) {
	return {
		id: 37,
		sort: 470,
		size: 5,
		order: 14,
		unlisted: true,
		nicename: "notifications",
		sizes: ["variable"],
		settings: [
			{
				type: "number",
				nicename: "user",
				label: "i18n.settings.account",
				help: "i18n.settings.account_help",
				placeholder: "i18n.settings.account_placeholder"
			}
		],
		config: {
			user: 0,
			size: "variable"
		},
		render: function() {
			if (!frameFix(this.render, this, arguments)) {
				return;
			}

			if (!this.frameId) {
				this.frameId = _.uniqueId(this.nicename);
			}

			this.utils.render({
				config: encodeURIComponent(JSON.stringify({
					maxHeight: 385,
					user: this.config.user || 0
				}))
			});

			this.elm.addClass("tabbed").css("height", "326px");

			var frame = this.elm.find("iframe")[0];

			$(window).off("message." + this.frameId).on("message." + this.frameId, function(e) {
				if (e.originalEvent.data && e.originalEvent.source === frame.contentWindow) {
					var data = e.originalEvent.data;

					if (data && data.height && data.height <= 415) {
						this.elm.css("height", data.height + "px");
					}
				}
			}.bind(this));
		}
	};
});
/*
 * The Google Now widget.
 */
define('w/now',["jquery", "oauth", "browser/api"], function($, OAuth, Browser) {
	return {
		id: 24,
		sort: 420,
		size: 1,
		order: 6,
		unlisted: true,
		interval: 300000,
		nicename: "now",
		sizes: ["variable"],
		config: {
			size: "variable"
		},
		data: {
			cards: [
				{
					"id": "10-NOR",
					"title": "Package: Shipped",
					"priority": -1,
					"desc": "Usually the name of the item you bought will go here  Shipped by UPS from Amazon.com",
					"icon": "http://www.gstatic.com/googlenow/chrome/v1/package_good.png",
					"buttons": [
						{
							"title": "Track package",
							"link": "http://www.fedex.com/fedextrack/",
							"btnIcon": "http://www.gstatic.com/googlenow/chrome/v1/globe.png"
						},
						{
							"title": "View email",
							"link": "https://mail.google.com/mail/",
							"btnIcon": "http://www.gstatic.com/googlenow/chrome/v1/mail.png"
						}
					],
					"btns": true
				},
				{
					"id": "1010-NOT",
					"title": "Reminder: Take out the garbage",
					"priority": -1,
					"desc": "This morning",
					"icon": "http://www.gstatic.com/googlenow/chrome/v1/reminders.png"
				},
				{
					"id": "11-NOR",
					"title": "Bucks 77 vs Heat 96",
					"priority": -1,
					"desc": "Final score",
					"icon": "http://www.gstatic.com/googlenow/chrome/v1/basketball.png",
					"link": "https://www.google.com/search?q=basketball+Miami+Heat&hl=en-US",
					"buttons": [
						{
							"title": "Box score",
							"link": "http://www.nba.com/games/20140402/MILMIA/gameinfo.html"
						}
					],
					"btns": true
				},
				{
					"id": "12-NOR",
					"title": "12 mins to Googleplex, 1600 Amphitheatre Pkwy, Mountain View, CA 94043",
					"priority": -1,
					"desc": "Normal traffic on US-101 S",
					"icon": "http://www.gstatic.com/googlenow/chrome/v1/traffic_normal.png",
					"buttons": [
						{
							"title": "Directions / 12 mins via US-101 S",
							"link": "https://maps.google.com/maps",
							"btnIcon": "http://www.gstatic.com/googlenow/chrome/v1/directions.png"
						}
					],
					"btns": true
				},
				{
					"id": "12-NOR",
					"title": "62° - Mostly Cloudy",
					"priority": -2,
					"desc": "San Francisco",
					"icon": "https://www.gstatic.com/onebox/weather/64/partly_cloudy.png",
					"link": "https://www.google.com/search?q=weather"
				}
			]
		},
		setOAuth: function() {
			var keys = [
					["1092601450132-elm3qva7di0gi13jvfr4dokp6lst9rcm.apps.googleusercontent.com", "jsE5F1qSqm4CCxpqlMAMJB8r"],
					["475386506072-d09fbkq2ggibju8dm0os2dpjt6mlmvgr.apps.googleusercontent.com", "xLZp4O6r7GPK-Q44l6AFI3WB"],
					["905766585722-eup1m0vja23fmr7gkr9bbfo5vrl2l62f.apps.googleusercontent.com", "LV-cjNecQrz0POXh1PLLBZfl"],
					["297119829873-mb1l6a6cd9g4srrf2kgfjpl3ngvfps6o.apps.googleusercontent.com", "xgHxL894nX-CotYQM6Himp8T"],
					["61552638141.apps.googleusercontent.com", "tWQxTe1hdRQklrDbhYdC8WiZ"],
					["564901828000-mcur4bngbbl7ocj7gsr19e2cadd9bs8v.apps.googleusercontent.com", "_2ckjNrRni_bzOZ2S5GsPnrr"],
					["568348197812-o4p7qoaf10fu849tagidncv0sokridus.apps.googleusercontent.com", "GByCaNN5jOSFh-OgqckxrPpo"],
					["504688753719-ijc8cb8qtpg566v51smqer9ga0q16opd.apps.googleusercontent.com", "47gm3KkJp16caJDsXvhsCtzu"],
					["288563396275-33pieggp736m90889r2ufa8f10ac6l36.apps.googleusercontent.com", "K6iKdHm0ZUqVXqqTJGXZcmQI"],
					["182058966659-60ujcv0310u9ndgvenvmp3ru4b1jq3qp.apps.googleusercontent.com", "J5W1T5VVdKfsBlOLrbjNRqHn"],
					["827243658242-36fidshv417d4ntaobqqvk4i2ut9imel.apps.googleusercontent.com", "jWj4As7ZsBFWguIElmLk23D5"],
					["565933460066-li1i03v3afucv3476mtlp84h35u5j2hq.apps.googleusercontent.com", "SKROXpWx0LbtYewnryUCE6i-"],
					["960034567410-gdr70kb9gggbbvlpv2ej7q81952q9nkr.apps.googleusercontent.com", "HWnWiZq-FfW2K0JjxPeditTL"],
					["125384267513-v1gpelluifnb5iqp48s39jgame61539a.apps.googleusercontent.com", "B4aEUEdSPwebDMYwMCGYEiVt"],
					["395311390958-6rddshfv97tkt9r11fvcidr51b44vo2q.apps.googleusercontent.com", "ruKNRqDf3h7R1XSMrFy-JcoS"],
					["97471935904-0lbpfjujqk9qq0fgkv9flm28u13lbek1.apps.googleusercontent.com", "p39G7BnRrIl_ICClwbVRZbqj"],
					["134474773808-p13i3uvca6d48go3b5glhotlmpnuiee4.apps.googleusercontent.com", "Wp_9ZrfcdC3pNd7z5zFzwhVm"],
					["578831884662-5l9kintvanlqm8hnj0omkr2b3obav3pg.apps.googleusercontent.com", "BWtCl-9WUr3ZYkNt-VvMIvRZ"],
					["757729443264-8l5120ej7h7hr8g0u45m3a5trf61a3tb.apps.googleusercontent.com", "oXX9RB5If0pTuMoOPJnqfrGb"],
					["318821747372-eia0n4v9itjdeo75r1vngkm6oeb89rrm.apps.googleusercontent.com", "yWjW54cvvoFTfSsWP3uh3Pm2"]
				],
				ls = Browser.storage.oauth,
				key;

			if (ls) {
				key = keys.filter(function(e) {
					return ls.indexOf(e[0]) !== -1;
				})[0];
			}

			if (!key) {
				key = keys[Math.floor(Math.random() * keys.length)];
			}

			this.oAuth = new OAuth({
				name: "now",
				id: key[0],
				secret: key[1],
				redirectURL: "https://ichro.me/auth/now",
				scope: "https://www.googleapis.com/auth/googlenow"
			});
		},
		refresh: function() {
			if (!this.oAuth) {
				this.setOAuth();
			}

			if (!this.oAuth.hasToken()) {
				return this.render("authorize");
			}

			var noTitle = this.utils.translate("no_title");

			this.oAuth.ajax({
				type: "GET",
				dataType: "json",
				url: "https://www.googleapis.com/chromenow/v1/notifications",
				success: function(d) {
					var cards = [];

					if (d && d.notifications) {
						d.notifications.forEach(function(e, i) {
							if (i > 15) {
								return;
							}

							var card = {
								index: cards.length,
								id: e.notificationId,
								cnId: e.chromeNotificationId,
								duration: (e.dismissal && e.dismissal.duration) || 21000
							};

							if (e.chromeNotificationOptions) {
								var co = e.chromeNotificationOptions;

								card.title = co.title || noTitle;

								card.priority = co.priority || -1;

								if (co.message) {
									card.desc = co.message.replace(/\n/g, "  ");
								}

								if (co.iconUrl) {
									card.icon = co.iconUrl;
								}

								if (co.imageUrl && co.imageUrl.length < 100000) {
									card.image = co.imageUrl;
								}

								if (co.isClickable && e.actionUrls && e.actionUrls.messageUrl) {
									card.link = e.actionUrls.messageUrl;
								}

								if (co.buttons && e.actionUrls && e.actionUrls.buttonUrls &&
									e.actionUrls.buttonUrls.length === co.buttons.length) {
									card.buttons = [];

									co.buttons.forEach(function(btn, i) {
										var button = {
											title: btn.title || noTitle,
											link: e.actionUrls.buttonUrls[i] || "#"
										};

										if (btn.iconUrl) {
											button.btnIcon = btn.iconUrl;
										}

										if (btn.title) {
											card.buttons.push(button);
										}
									});

									if (card.buttons.length) {
										card.btns = true;
									}
								}
							}

							cards.push(card);
						});

						cards.sort(function(a, b) {
							return b.priority - a.priority;
						});
					}

					this.data = {
						cards: cards
					};

					this.render();

					this.utils.saveData(this.data);
				}.bind(this)
			});
		},
		render: function(key) {
			if (!this.oAuth) {
				this.setOAuth();
			}

			if (key === "authorize") {
				this.utils.render({ authorize: true });

				return this.elm.find(".authorize").on("click", function(e) {
					e.preventDefault();

					this.oAuth.getToken(this.refresh.bind(this));
				}.bind(this));
			}

			var that = this; // Can't use .bind() since we need the element from this

			this.elm.off("click.now", ".dismiss, a.card").on("click.now", ".dismiss, a.card", function(e) {
				var elm = $(this);

				e.stopImmediatePropagation();

				if (elm.hasClass("dismiss")) {
					elm = elm.parent();

					e.preventDefault();
				}

				var card = that.data.cards[elm.attr("data-index")];

				if (!card) {
					return;
				}

				that.oAuth.ajax({
					type: "DELETE",
					url: "https://www.googleapis.com/chromenow/v1/notifications/" + card.id + "?chromeNotificationId=" + encodeURIComponent(card.cnId) + "&age=29&duration=" + card.duration,
					success: function() {
						this.data.cards.splice(this.data.cards.indexOf(card), 1);

						if (elm.hasClass("btns")) {
							elm.next(".buttons").remove().end().remove();
						}
						else {
							elm.remove();
						}

						this.utils.saveData(this.data);

						this.utils.render(this.data);
					}.bind(that)
				});
			});

			this.utils.render(this.data);
		}
	};
});
/*
 * The Google+ widget.
 */
define('w/plus',["jquery", "widgets/framefix"], function($, frameFix) {
	return {
		id: 30,
		size: 5,
		order: 14,
		unlisted: true,
		nicename: "plus",
		sizes: ["variable"],
		settings: [
			{
				type: "number",
				label: "i18n.settings.height",
				nicename: "height",
				min: 100,
				max: 800
			}
		],
		config: {
			height: 500,
			size: "variable"
		},
		render: function() {
			if (!frameFix(this.render, this, arguments)) {
				return;
			}

			this.utils.render({
				height: this.config.height || 500
			});

			this.elm.addClass("tabbed");
		}
	};
});
/*
 * Pocket
 */
define('w/pocket',["jquery", "lodash", "moment", "backbone", "browser/api", "oauth"], function($, _, moment, Backbone, Browser, OAuth) {
	var View = Backbone.View.extend({
		events: {
			"click .no-key button": function() {
				(this.oAuth || this.setOAuth()).startAuthFlow(this.refresh.bind(this));
			}
		},

		oAuth: false,

		/**
		 * Creates an OAuth instance for this widget
		 *
		 * @api  private
		 */
		setOAuth: function() {
			this.oAuth = new OAuth({
				name: "pocket",
				secret: "inapplicable",
				id: "88231-58b03e9476dd7b4eb07ec7de",
				authURL: "https://getpocket.com/auth/authorize?request_token={{requestToken}}&redirect_uri={{redirectURL}}"
			});


			// Pocket uses a modified version of OAuth that's incompatible with
			// the original OAuth library so we need to modify the library
			this.oAuth.startAuthFlow = function(cb) {
				var that = this;

				var createWindow = function() {
					that.openWindow = true;

					$.ajax({
						type: "POST",
						url: "https://getpocket.com/v3/oauth/request",
						data: {
							consumer_key: that.config.id,
							redirect_uri: that.config.redirectURL
						},
						beforeSend: function(xhr) {
							xhr.setRequestHeader("X-Accept", "application/json");
						},
						success: function(d) {
							if (typeof d !== "object" || !d.code) {
								that.openWindow = false;

								return;
							}

							var url = that.config.authURL
								.replace("{{requestToken}}", encodeURIComponent(d.code))
								.replace("{{redirectURL}}", encodeURIComponent(that.config.redirectURL));

							Browser.windows.create({
								url: 'https://ichro.me/redirect.html?' + url,
								width: 560,
								height: 600,
								type: "popup",
								focused: true,
								top: Math.round((screen.availHeight - 600) / 2),
								left: Math.round((screen.availWidth - 560) / 2)
							}, function(win) {
								that.openWindow = win.id;

								Browser.webRequest.onBeforeRequest.addListener(
									function() {
										this.exchangeCode(d.code, cb);

										Browser.windows.remove(win.id);

										return {
											cancel: true
										};
									}.bind(that),
									{
										windowId: win.id,
										types: ["main_frame"],
										urls: [that.config.redirectURL + "*"]
									},
									["blocking"]
								);
							});
						}
					});

					// Make sure we don't lock up the OAuth instance
					setTimeout(function() {
						if (that.openWindow === true) {
							that.openWindow = false;
						}
					}, 10000);
				};

				if (typeof this.openWindow === "number") {
					Browser.windows.get(this.openWindow, function(win) {
						if (Browser.runtime.lastError) {
							createWindow();
						}
						else {
							Browser.windows.update(win.id, { focused: true });
						}
					});
				}
				else if (this.openWindow === true) {
					return;
				}
				else {
					createWindow();
				}
			};

			this.oAuth.exchangeCode = function(code, cb) {
				$.ajax({
					type: "POST",
					url: "https://getpocket.com/v3/oauth/authorize",
					data: {
						code: code,
						consumer_key: this.config.id
					},
					beforeSend: function(xhr) {
						xhr.setRequestHeader("X-Accept", "application/json");
					},
					success: function(d) {
						if (typeof d !== "object") {
							d = JSON.parse(d);
						}

						if (!d.error && d.access_token) {
							var data = {
								token: d.access_token,
								type: d.token_type || "Bearer",
								expiry: new Date().getTime() + ((d.expires_in || 315569259) * 1000) // Defaults to +10 years if unavailable
							};

							if (d.refresh_token) {
								data.refreshToken = d.refresh_token;
							}

							// Add any extra data that's been included to the object
							_.assign(data, _.omit(d, "token_type", "access_token", "expires_in", "refresh_token", "type", "token", "expiry", "refreshToken"));

							this.data = data;

							this.saveStorage();

							cb.call(this, data.token, data);
						}
					}.bind(this)
				});
			};

			this.oAuth.ajax = function(config) {
				this.getToken(function(token) {
					if (!config.data) {
						config.data = {};
					}

					config.data.consumer_key = this.config.id;
					config.data.access_token = token;

					$.ajax(config);
				}.bind(this));
			};

			return this.oAuth;
		},


		/**
		 * Parses an image URL and returns a scaled img.readitlater.com URL
		 *
		 * @api     private
		 * @param   {String}  oUrl  The image URL to parse
		 * @return  {String}        The parsed, scaled URL
		 */
		getImageURL: function(oUrl) {
			if (!oUrl) {
				return;
			}

			var url = new URL(oUrl);

			//var vars = "?f=t&lq=1" + (url.protocol === "https:" ? "&ssl=1" : "");

			//The readitlater.com does not work on the moment.
			//It belongs to getpocket but returns 404.
			//The usual URL is used until the solution is found
			//return oUrl;

			if (url.protocol !== "http:" && url.protocol !== "https:") {
			 	return oUrl;
			}

			return "https://pocket-image-cache.com/100x90/filters:no_upscale()/" + encodeURIComponent(oUrl);

			// var ext = (/\.(jpg|gif|jpeg|png|ico)$/i.exec(url.pathname) || [])[1];

			// if (!ext) {
			// 	ext = "jpg";

			// 	vars += "&ne=1";
			// }

			// var qs = url.search && url.search.length > 1 ? "/QS/" + encodeURIComponent(encodeURIComponent(url.search.slice(1))) + "/EQS" : "";

			// return "https://img.readitlater.com/i/" + url.host + url.pathname.replace("." + ext, "") + qs + "/RS/w200-h190." + ext + vars;
		},

		refresh: function() {
			if (!this.oAuth) {
				this.setOAuth();
			}

			if (!this.oAuth.hasToken()) {
				return this.render();
			}

			var getImageURL = this.getImageURL,
				original = this.config.open === "original";

			this.oAuth.ajax({
				type: "POST",
				url: "https://getpocket.com/v3/get",
				data: {
					count: this.config.show,
					detailType: "complete"
				},
				success: function(d) {
					if (!d) {
						return;
					}

					this.data.links = _(d.list).sortBy("sort_id").map(function(e) {
						var ret = {
							id: e.item_id,
							title: e.given_title || e.resolved_title,
							domain: new URL(e.resolved_url).host.replace("www.", ""),
							date: moment(e.time_added * 1000).format("MMMM Do, YYYY"),
							url: original ? (e.given_url || e.resolved_url) : "https://getpocket.com/a/read/" + e.item_id
						};

						if (e.authors) {
							ret.author = _.values(e.authors)[0].name;
						}

						if (e.image) {
							ret.image = getImageURL(e.image.src);
						}
						else if (e.top_image_url) {
							ret.image = getImageURL(e.top_image_url);
						}
						else if (e.images && e.images[1]) {
							ret.image = getImageURL(e.images[1].src);
						}
						else {
							if (ret.title && ret.title.length > 0) {
								ret.image = "https://dummyimage.com/100x90/1e1754/ffffff.png&text=" + ret.title[0];
							}
						}

						return ret;
					}).take(this.config.show).value();

					this.utils.saveData(this.data);

					this.render();
				}.bind(this)
			});
		},

		render: function(demo) {
			if ((typeof demo === "undefined" || demo !== true) && !(this.oAuth || this.setOAuth()).hasToken()) {
				this.utils.render({
					noKey: true
				});
			}
			else {
				this.utils.render(this.data);
			}
		}
	});

	return {
		id: 45,
		sort: 350,
		size: 1,
		interval: 300000,
		nicename: "pocket",
		sizes: ["variable"],
		settings: [
			{
				min: 1,
				max: 10,
				type: "number",
				nicename: "show",
				label: "i18n.settings.links_shown"
			},
			{
				type: "radio",
				label: "i18n.settings.open",
				nicename: "open",
				options: {
					pocket: "i18n.settings.open_pocket",
					original: "i18n.settings.open_original"
				}
			}
		],
		config: {
			show: 5,
			open: "pocket",
			size: "variable"
		},
		data: {
			links: [
				{
					id: "922689190",
					title: "BBC - Autos - Mercedes-Benz C 111: The supercar that wasn’t",
					domain: "bbc.com",
					date: "July 23rd, 2015",
					url: "http://www.bbc.com/autos/story/20150512-mercedes-benz-c-111-the-supercar-that-wasnt",
					author: "Dan Carney",
					image: "https://img.readitlater.com/i/ichef.bbci.co.uk/wwfeatures/976_549/images/live/p0/2r/8h/p02r8hx7/RS/w200-h190.jpg?f=t&lq=1"
				},
				{
					id: "989873963",
					title: "The World’s Most Popular Genre is Cannibalizing Itself, and You Didn’t Even",
					domain: "medium.com",
					date: "July 23rd, 2015",
					url: "https://medium.com/cuepoint/the-world-s-most-popular-genre-is-cannibalizing-itself-and-you-didn-t-even-notice-efd06558d138",
					author: "Ross Hsu",
					image: "https://img.readitlater.com/i/d262ilb51hltx0.cloudfront.net/max/2000/1*bHAPgxzujxgEQXDfI61YAg/RS/w200-h190.jpeg?f=t&lq=1&ssl=1"
				},
				{
					id: "990356377",
					title: "BBC - Autos - Model M could put Tesla on two wheels",
					domain: "bbc.com",
					date: "July 23rd, 2015",
					url: "http://www.bbc.com/autos/story/20150723-london-based-designer",
					author: "Rowan Horncastle",
					image: "https://img.readitlater.com/i/ichef.bbci.co.uk/wwfeatures/976_549/images/live/p0/2x/v8/p02xv8j5/RS/w200-h190.jpg?f=t&lq=1"
				},
				{
					id: "990503685",
					title: "Facebook loses appeal over access to user data - CNN.com",
					domain: "cnn.com",
					date: "July 23rd, 2015",
					url: "http://www.cnn.com/2015/07/23/tech/facebook-search-warrants/index.html",
					author: "Tal Trachtman Alroy",
					image: "https://img.readitlater.com/i/i2.cdn.turner.com/cnnnext/dam/assets/130919214517-zuckerberg-2004-super-169/RS/w200-h190.jpg?f=t&lq=1"
				},
				{
					id: "984832743",
					title: "DeepDream: Inside Google's 'Daydreaming' Computers - YouTube",
					domain: "youtube.com",
					date: "July 20th, 2015",
					url: "https://www.youtube.com/watch?v=3hnWf_wdgzs",
					image: "https://img.readitlater.com/i/img.youtube.com/vi/3hnWf_wdgzs/0/RS/w200-h190.jpg?f=t&lq=1"
				}
			]
		},
		ensureView: function() {
			if (!this.view) {
				this.view = new (View.extend({
					utils: this.utils,
					config: this.config,
					data: this.data || {}
				}))({
					el: this.elm
				});
			}

			this.view.config = this.config;
			this.view.data = this.data || {};
		},
		refresh: function() {
			this.ensureView();

			this.view.refresh();
		},
		render: function(demo) {
			this.ensureView();

			this.view.render(demo);
		}
	};
});
/*
 * Pushbullet
 */
define('w/pushbullet',["jquery", "lodash", "moment", "backbone", "browser/api"], function($, _, moment, Backbone, Browser) {
	var View = Backbone.View.extend({
		events: {
			"click .no-key button": function() {
				Browser.tabs.create({
					url: "https://www.pushbullet.com/signin"
				});
			}
		},

		/**
		 * Updates the thumbnail resolver cache.
		 *
		 * Pushbullet doesn't provide thumbnails in push list requests
		 * so we need to assemble a list of our own to retrieve them.
		 */
		updateCache: function() {
			if (!this.config.apiKey) {
				return;
			}

			$.ajax({
				type: "GET",
				url: "https://api.pushbullet.com/v2/everything?active=true",
				beforeSend: function(xhr) {
					xhr.setRequestHeader("Authorization", "Basic " + btoa(this.config.apiKey));
				}.bind(this),
				success: function(d) {
					if (typeof d !== "object") {
						d = JSON.parse(d);
					}

					var cache = {
						users: {},
						channels: {},
						from: new Date().getTime()
					};

					var sizeImage = function(e) {
						if (e.indexOf("imgix.net") !== -1) {
							e += "?w=80";
						}
						else if (e.indexOf("googleusercontent.com") !== -1) {
							e += "=s80";
						}

						return e;
					};

					_.each(d.subscriptions, function(e) {
						if (e.channel && e.channel.image_url) {
							cache.channels[e.channel.iden] = cache.channels[e.channel.tag] = sizeImage(e.channel.image_url);
						}
					});

					_.each([].concat(d.accounts, d.contacts, _.pluck(d.chats, "with")), function(e) {
						if (e.image_url) {
							cache.users[e.iden] = cache.users[e.email_normalized] = sizeImage(e.image_url);
						}
					});

					if (Object.keys(cache.users).length + Object.keys(cache.channels).length === 0) {
						return;
					}

					this.data.cache = cache;

					this.utils.saveData();

					this.refresh();
				}.bind(this)
			});
		},

		initialize: function() {
			if (!this.config.apiKey) {
				return Browser.cookies.get({
					name: "api_key",
					url: "https://www.pushbullet.com"
				}, function(args, cookie) {
					if (cookie && cookie.value) {
						this.config.apiKey = cookie.value;

						this.utils.saveConfig(this.config);

						this.initialize.apply(this, args);
					}
					else {
						this.render();
					}
				}.bind(this, arguments));
			}

			this.render();

			this.refresh();

			this.bindSocket();

			if (!this.data.cache || (new Date().getTime() - this.data.cache.from) > 21600000) {
				this.updateCache();
			}
		},


		/**
		 * Creates a WebSocket connection to Pushbullet
		 */
		bindSocket: function() {
			this.socket = new WebSocket("wss://stream.pushbullet.com/websocket/" + this.config.apiKey);

			this.socket.onmessage = function(e) {
				var data = JSON.parse(e.data);

				if (data.type === "tickle" && data.subtype === "push") {
					this.refresh();
				}
			}.bind(this);
		},


		/**
		 * Gets the thumbnail image for the given push
		 *
		 * @api     private
		 * @param   {String}  d  The push to get a thumbnail for
		 * @return  {String}     The URL of the thumbnail image
		 */
		getThumb: function(d) {
			var cache = this.data.cache || {
				users: {},
				channels: {}
			};

			if ((d.channel_tag || d.channel_iden) && (cache.channels[d.channel_tag] || cache.channels[d.channel_iden])) {
				return cache.channels[d.channel_tag] || cache.channels[d.channel_iden];
			}
			else if ((d.sender_iden || d.sender_email_normalized) && (cache.users[d.sender_iden] || cache.users[d.sender_email_normalized])) {
				return cache.users[d.sender_iden] || cache.users[d.sender_email_normalized];
			}
			else {
				return null;
			}
		},


		/**
		 * Parses and formats an array of pushes
		 *
		 * @param   {Object[]}  d  An array of pushes
		 * @return  {Object[]}     An array of parsed pushes
		 */
		parsePushes: function(d) {
			return _(d)
				.filter("active")
				.sortBy(function(a, b) {
					return b.created - a.created;
				})
				.map(function(e) {
					try {
						var parsed = {
							id: e.iden,
							date: parseInt(e.created * 1000),
							type: e.type,
							sender: {
								name: e.sender_name || e.sender_email,
								email: e.sender_email || e.sender_email_normalized,
								thumb: this.getThumb(e)
							}
						};

						if (e.type === "note" || e.type === "link") {
							parsed.title = e.title;
							parsed.body = e.body;

							if (e.url) {
								if (e.url.indexOf("://") === 0) {
									e.url = "https" + e.url;
								}

								parsed.link = e.url;
								parsed.linkText = e.url;
							}
						}
						else if (e.type === "file") {
							parsed.body = e.body;
							parsed.link = e.file_url;
							parsed.linkText = e.file_name;

							if (e.image_url) {
								if (e.image_url.indexOf("imgix.net") !== -1) {
									e.image_url += "?w=370";
								}
								else if (e.image_url.indexOf("googleusercontent.com") !== -1) {
									e.image_url += "=s370";
								}

								parsed.image = e.image_url;
							}
						}

						return parsed;
					}
					catch (err) {
						return null;
					}
				}, this)
				.compact()
				.take(20)
			.valueOf();
		},

		refresh: function() {
			if (!this.config.apiKey) {
				return this.render;
			}

			$.ajax({
				type: "GET",
				url: "https://api.pushbullet.com/v2/pushes?active=true",
				beforeSend: function(xhr) {
					xhr.setRequestHeader("Authorization", "Basic " + btoa(this.config.apiKey));
				}.bind(this),
				success: function(d) {
					if (typeof d !== "object") {
						d = JSON.parse(d);
					}

					if (!d.pushes) {
						return;
					}

					this.data.pushes = this.parsePushes(d.pushes);

					this.utils.saveData();

					this.render();
				}.bind(this)
			});
		},

		render: function() {
			if (!this.config.apiKey) {
				return this.utils.render({
					noKey: true
				});
			}

			var pushes = this.data.pushes;

			var data = {
				hasPushes: pushes && pushes.length
			};

			var lData = moment.localeData();

			var momentSecondsFuture = lData._relativeTime.future.replace("%s", lData._relativeTime.s),
				momentSecondsPast = lData._relativeTime.past.replace("%s", lData._relativeTime.s);

			if (data.hasPushes) {
				data.pushes = pushes.map(function(e) {
					e = _.clone(e);

					e.date = moment(e.date).fromNow().replace( // Fix "in a few seconds" bug
						momentSecondsFuture,
						momentSecondsPast
					);

					return e;
				});
			}

			this.utils.render(data);
		}
	});

	return {
		id: 42,
		sort: 400,
		size: 4,
		nicename: "pushbullet",
		sizes: ["medium"],
		config: {
			size: "medium"
		},
		data: {},
		render: function() {
			if (!this.view) {
				this.view = new (View.extend({
					utils: this.utils,
					config: this.config,
					data: this.data || {}
				}))({
					el: this.elm
				});
			}

			this.view.config = this.config;
			this.view.data = this.data || {};

			this.view.render();
		}
	};
});
/*
 * Quotes
 */
define('w/quotes',["jquery", "lodash", "browser/api"], function($, _, Browser) {
	return {
		id: 35,
		sort: 40,
		size: 2,
		order: 12,
		nicename: "quotes",
		sizes: ["variable"],
		settings: [
			{
				type: "text",
				nicename: "title",
				label: "i18n.settings.title",
				placeholder: "i18n.settings.title_placeholder"
			},
			{
				type: "select",
				nicename: "source",
				options: {
					momentum: "Momentum",
					forbes: "Forbes",
					iheartquotes: "I Heart Quotes",
					quotationspage: "Quotations Page",
					thinkexist: "ThinkExist"
				},
				label: "i18n.settings.source"
			},
			{
				type: "select",
				nicename: "method",
				label: "i18n.settings.method",
				options: {
					daily: "i18n.settings.method_options.daily",
					random: "i18n.settings.method_options.random"
				}
			}
		],
		config: {
			title: "",
			size: "variable",
			source: "momentum",
			method: "random"
		},

		data: {},


		/**
		 * Contains a listing of sources.
		 *
		 * Each source must either be an array of quotes or a specification for
		 * a URL to fetch and a parser function.
		 *
		 * Quotes should be either an array where the first item is the body and
		 * the second the source or an object with body and source keys.
		 */
		sources: {
			forbes: {
				url: "http://www.forbes.com/forbesapi/thought/get.json?limit=1&random=true&stream=true",

				/**
				 * Parses the response data
				 *
				 * @api     public
				 * @param   {Object}  d        The response data
				 * @param   {String}  unknown  The string to use in place of a missing author, if applicable
				 * @return  {Object}           A parsed quote
				 */
				parse: function(d, unknown) {
					var quote = d.thoughtStream.thoughts[0];

					return {
						body: quote.quote,
						source: (quote.thoughtAuthor || {}).name || unknown,
						link: "http://www.forbes.com/quotes/" + quote.uri
					};
				}
			},


			iheartquotes: {
				url: "http://www.iheartquotes.com/api/v1/random?max_lines=4&max_characters=130&format=json",

				parse: function(d) {
					return {
						body: d.quote.trim(),
						noquotes: true,
						link: d.link
					};
				}
			},


			quotationspage: {
				url: "http://www.quotationspage.com/random.php3?number=1&collection%5B%5D=mgm&collection%5B%5D=motivate&collection%5B%5D=classic",

				parse: function(d) {
					d = $($.parseHTML(d
						.replace(/ src="\/\//g, " data-src=\"https://")
						.replace(/ src="/g, " data-src=\"")
						.replace(/ src='\/\//g, " data-src='https://")
						.replace(/ src='/g, " data-src='")
					));

					return {
						body: d.find("dl .quote a").text().trim(),
						source: d.find("dl .author b a").text().trim(),
						link: "http://www.quotationspage.com" + d.find("dl .quote a").attr("href")
					};
				}
			},


			thinkexist: {
				url: "http://en.thinkexist.com/rss.asp?special=random",

				parse: function(d) {
					d = $(d);

					return {
						body: d.find("item description").first().text().trim().replace(/^"|"$/g, ""),
						source: d.find("item title").first().text().trim(),
						link: d.find("item link").first().text()
					};
				}
			},


			/**
			 * These quotes are the ones used by the Momentum new tab page extension
			 */
			momentum: [
				["Yesterday, you said tomorrow.", "Nike"],
				["Don't compare your beginning to someone else's middle.", "Jon Acuff"],
				["The wisest mind has something yet to learn.", "George Santayana"],
				["Be the change you wish to see in the world.", "Mahatma Gandhi"],
				["When you're going through hell, keep going.", "Winston Churchill"],
				["Don't let perfection become procrastination. Do it now.", "Danielle LaPorte"],
				["Launch and learn. Everything is progress.", "Danielle LaPorte"],
				["A year from now you will wish you had started today.", "Karen Lamb"],
				["Failure is success if you learn from it.", 0],
				["If you don't like where you are, change it. You're not a tree.", "Jim Rohn"],
				["If it ain't fun, don't do it.", "Jack Canfield"],
				["A wet man does not fear the rain.", "Risa Rodil"],
				["Stay hungry; stay foolish.", "Whole Earth Epilog, 1974"],
				["No one saves us but ourselves. No one can and no one may. We ourselves must walk the path.", "Paul Carus, summarized from the Dhammapada, verse 165"],
				["Never give up. Never let things out of your control dictate who you are.", 0],
				["Be kind; everyone you meet is fighting a hard battle.", "Ian Maclaren"],
				["Impossible is just a big word thrown around by small men who find it easier to live in the world they've been given than to explore the power they have to change it.", "Muhammed Ali"],
				["People who are unable to motivate themselves must be content with mediocrity no matter how impressive their other talents.", "Andrew Carnegie"],
				["Progress is impossible without change, and those who cannot change their minds cannot change anything.", "George Bernard Shaw"],
				["Do more of what makes you happy.", "Carmel McConnell"],
				["Do a little more of what you want to do every day, until your idea becomes what's real.", 0],
				["You got this. Make it happen.", "Danielle LaPorte"],
				["Don't blame others as an excuse for your not working hard enough.", 0],
				["Care about what other people think and you will always be their prisoner.", "Lao Tzu"],
				["To escape criticism: do nothing, say nothing, be nothing.", "Elbert Hubbard"],
				["The world is moving so fast that the man who says it can't be done is generally interrupted by someone doing it.", "Elbert Hubbard"],
				["Be who you are and say what you feel, because those who mind don't matter and those who matter don't mind.", "Bernard Baruch"],
				["One day you will wake up and there won't be any more time to do the things you've always wanted. Do it now.", "Paulo Coelho"],
				["Never waste a minute thinking about people you don't like.", "Dwight D. Eisenhower"],
				["Never let your fear decide your fate.", "AWOLNATION, \"Kill Your Heroes\""],
				["Keep moving forward. One step at a time.", 0],
				["Life is simple. Are you happy? Yes? Keep going. No? Change something.", 0],
				["The journey of a thousand miles begins with a single step.", "Lao Tzu"],
				["First they ignore you. Then they laugh at you. Then they fight you. Then you win.", "Nicholas Klein"],
				["A man is but the product of his thoughts. What he thinks, he becomes.", "Mahatma Gandhi"],
				["Live as if you were to die tomorrow. Learn as if you were to live forever.", 0],
				["The future depends on what we do in the present.", "Mahatma Gandhi"],
				["I am strong because I've been weak. I am fearless because I've been afraid. I am wise because I've been foolish.", 0],
				["Believe in yourself.", 0],
				["Lower the cost of failure.", 0],
				["Keep your goals away from the trolls.", 0],
				["Respect yourself enough to walk away from anything that no longer serves you, grows you, or makes you happy.", "Robert Tew"],
				["Everything around you that you call life was made up by people, and you can change it.", "Steve Jobs"],
				["In times of change, learners inherit the earth, while the learned find themselves beautifully equipped to deal with a world that no longer exists.", "Eric Hoffer"],
				["If you fear failure, you will never go anywhere.", 0],
				["Go ahead, let them judge you.", 0],
				["The world breaks everyone and afterward many are strong at the broken places.", "Ernest Hemingway"],
				["The only disability in life is a bad attitude.", "Matthew Jeffers"],
				["If most of us are ashamed of shabby clothes and shoddy furniture, let us be more ashamed of shabby ideas and shoddy philosophies.", "Albert Einstein"],
				["It is no measure of health to be well adjusted to a profoundly sick society.", "J. Krishnamurti"],
				["Think lightly of yourself and deeply of the world.", "Miyamoto Musashi"],
				["Dude, suckin' at something is the first step to being sorta good at something.", "Jake, \"Adventure Time\""],
				["As you think, so shall you become.", 0],
				["Do not wish for an easy life. Wish for the strength to endure a difficult one.", "Bruce Lee"],
				["Showing off is the fool's idea of glory.", "Bruce Lee"],
				["Use only that which works, and take it from any place you can find it.", "Bruce Lee"],
				["I'm not in this world to live up to your expectations and you're not in this world to live up to mine.", "Bruce Lee"],
				["If you spend too much time thinking about a thing, you'll never get it done.", "Bruce Lee"],
				["Knowing is not enough, we must apply. Willing is not enough, we must do.", "Bruce Lee"],
				["Empty your cup so that it may be filled; become devoid to gain totality.", "Bruce Lee"],
				["It's not the daily increase but daily decrease. Hack away at the unessential.", "Bruce Lee"],
				["Be yourself. Everyone else is already taken.", "Oscar Wilde"],
				["Darkness cannot drive out darkness; only light can do that. Hate cannot drive out hate; only love can do that.", "Martin Luther King Jr."],
				["Yesterday is history; tomorrow is a mystery. Today is a gift, which is why we call it the present.", "Bil Keane"],
				["Imagination is more important than knowledge. Knowledge is limited. Imagination encircles the world.", "Albert Einstein"],
				["I have not failed. I've just found 10,000 ways that won't work.", "Thomas Edison"],
				["When I let go of what I am, I become what I might be.", "Lao Tzu"],
				["It is never too late to be what you might have been.", "George Eliot"],
				["Always be yourself, express yourself, have faith in yourself. Do not go out and look for a successful personality and duplicate it.", "Bruce Lee"],
				["When you are content to be simply yourself and don't compare or compete, everyone will respect you.", "Lao Tzu"],
				["If you want to awaken all of humanity, awaken all of yourself.", "Lao Tzu"],
				["Don't regret anything you do, because in the end it makes you who you are.", 0],
				["Tension is who you think you should be. Relaxation is who you are.", 0],
				["You are confined only by the walls you build yourself.", "Andrew Murphy"],
				["Unless you try to do something beyond what you have already mastered you will never grow.", "Ralph Waldo Emerson"],
				["Don't think about what might go wrong, think about what could be right.", 0],
				["What the caterpillar calls the end, the rest of the world calls a butterfly.", "Lao Tzu"],
				["To be beautiful means to be yourself. You don't need to be accepted by others. You need to be yourself.", "Thich Nhat Hanh"],
				["Let go of those who bring you down and surround yourself with those who bring out the best in you.", 0],
				["Don't let small minds convince you that your dreams are too big.", 0],
				["If you don't like something, change it. If you can't change it, change your attitude. Don't complain.", "Maya Angelou"],
				["You may not control all the events that happen to you, but you can decide not to be reduced by them.", "Maya Angelou"],
				["I've learned that you shouldn't go through life with a catcher's mitt on both hands; you need to be able to throw something back.", "Maya Angelou"],
				["Although the world is full of suffering, it is also full of the overcoming of it.", "Helen Keller"],
				["People will forget what you said, people will forget what you did, but people will never forget how you made them feel.", "Maya Angelou"],
				["You can't climb the ladder of success with your hands in your pockets.", "Arnold Schwarzenegger"],
				["You can feel sore tomorrow or you can feel sorry tomorrow. You choose.", 0],
				["It is more important to know where you are going than to get there quickly. Do not mistake activity for achievement.", "Isocrates"],
				["There are seven days in the week and someday isn't one of them.", 0],
				["Start where you are. Use what you can. Do what you can.", "Arthur Ashe"],
				["Your dreams don't work unless you do.", "John C. Maxwell"],
				["When you wake up in the morning you have two choices: go back to sleep, or wake up and chase those dreams.", 0],
				["Everybody comes to a point in their life when they want to quit, but it's what you do at that moment that determines who you are.", "David Goggins"],
				["This is your life. Do what you love, and do it often.", "Holstee Manifesto"],
				["Live your dream, and wear your passion.", "Holstee Manifesto"],
				["Today I will do what others won't, so tomorrow I can do what others can't.", "Jerry Rice"],
				["The biggest room in the world is room for improvement.", 0],
				["If people aren't laughing at your dreams, your dreams aren't big enough.", "Grayson Marshall"],
				["Never look back unless you are planning to go that way.", "Henry David Thoreau"],
				["Every dream begins with a dreamer. Always remember, you have within you the strength, the patience, and the passion to reach for the stars to change the world.", "Harriet Tubman"],
				["You are awesome.", 0],
				["Simplicity is the ultimate sophistication.", "Leonardo da Vinci"],
				["Anyone who stops learning is old.", "Henry Ford"],
				["The cure to boredom is curiosity. There is no cure for curiosity.", "Dorothy Parker"],
				["Never give up on a dream just because of the time it will take to accomplish it. The time will pass anyway.", "Earl Nightingale"],
				["It's time to start living the life you've only imagined.", 0],
				["You don't have to live your life the way other people expect you to.", 0],
				["The trouble with not having a goal is that you can spend your life running up and down the field and never score.", 0],
				["To be yourself in a world that is constantly trying to make you something else is the greatest accomplishment.", 0],
				["Incredible change happens in your life when you decide to take control of what you do have power over instead of craving control over what you don't.", "Steve Maraboli, \"Life, the Truth, and Being Free\""],
				["Do more with less.", 0],
				["Overthinking ruins you. Ruins the situation, twists it around, makes you worry and just makes everything much worse than it actually is.", 0],
				["Replace fear of the unknown with curiosity.", 0],
				["The surest way to find your dream job is to create it.", 0],
				["What you do today is important because you are exchanging a day of your life for it.", 0],
				["One man or woman with courage is a majority.", 0],
				["Do one thing every day that scares you.", "Eleanor Roosevelt"],
				["Failure is simply the opportunity to begin again, this time more intelligently.", "Henry Ford"],
				["Don't just wait for inspiration. Become it.", 0],
				["Don't limit your challenges - challenge your limits.", 0],
				["When you judge others, you do not define them; you define yourself.", "Earl Nightingale"],
				["Time you enjoy wasting is not wasted time.", 0],
				["Do small things with great love.", "Mother Teresa"],
				["Go forth and make awesomeness.", 0],
				["Your big opportunity may be right where you are now.", "Napolean Hill"],
				["Life begins at the end of your comfort zone.", "Neale Donald Walsch"],
				["Excuses are born out of fear. Eliminate your fear and there will be no excuses.", 0],
				["Happiness is not the absence of problems, it's the ability to deal with them.", 0],
				["The problem is not the problem. The problem is your attitude about the problem.", 0],
				["You don't have to be great to start, but you have to start to be great.", 0],
				["Cherish your visions and your dreams as they are the children of your soul, the blueprints of your ultimate achievements.", 0],
				["Decide that you want it more than you are afraid of it.", 0],
				["Adventure may hurt you, but monotony will kill you.", 0],
				["Obsessed is a word that the lazy use to describe the dedicated.", 0],
				["If they can do it, so can you.", 0],
				["Success isn't about being the best. It's about always getting better.", "Behance 99U"],
				["Success is the ability to go from failure to failure without losing your enthusiasm.", "Winston Churchill"],
				["A pessimist sees the difficulty in every opportunity; an optimist sees the opportunity in every difficulty.", "Winston Churchill"],
				["Failure is just practice for success.", 0],
				["Shipping beats perfection.", 0],
				["Failure is simply the opportunity to begin again. This time more intelligently.", "Henry Ford"],
				["While we are postponing, life speeds by.", "Seneca"],
				["It always seems impossible until it's done.", "Nelson Mandela"],
				["Don't let the mistakes and disappointments of the past control and direct your future.", "Zig Ziglar"],
				["It's not about where your starting point is, but your end goal and the journey that will get you there.", 0],
				["Waste no more time arguing about what a good person should be. Be one.", "Marcus Aurelius"],
				["Life shrinks or expands in proportion to one's courage.", "Anaïs Nin"],
				["Absorb what is useful. Discard what is not. Add what is uniquely your own.", "Bruce Lee"],
				["Don't find fault. Find a remedy.", "Henry Ford"],
				["Doubt kills more dreams than failure ever will.", "Suzy Kassem"],
				["Don't let someone who gave up on their dreams talk you out of going after yours.", "Zig Ziglar"],
				["Always remember that the future comes one day at a time.", "Dean Acheson"],
				["The creative adult is the child who survived.", "Ursula K. Le Guin"],
				["When you have exhausted all possibilities, remember this: you haven't.", "Thomas Edison"],
				["When you see a person without a smile, give them one of yours.", "Zig Ziglar"],
				["If you hear a voice within you say 'you cannot paint,' then by all means paint and that voice will be silenced.", "Vincent Van Gogh"],
				["The secret to happiness is freedom. And the secret to freedom is courage.", "Thucydides"],
				["May your choices reflect your hopes, not your fears.", "Nelson Mandela"],
				["Once a year, go some place you've never been before.", "Dalai Lama"],
				["Never underestimate the ability of a small group of dedicated people to change the world. Indeed, it is the only thing that ever has.", "Margaret Meade"],
				["To be free is not merely to cast off one's chains, but to live in a way that respects and enhances the freedom of others.", "Nelson Mandela"],
				["Today is the most important day of our lives.", "Thich Nhat Hanh"],
				["All great achievements require time.", "Maya Angelou"],
				["Winning starts with beginning.", 0],
				["If you're not doing what you love, you're wasting your time.", 0],
				["A goal is not always meant to be reached, it often serves simply as something to aim at.", "Bruce Lee"],
				["The struggle ends when the gratitude begins.", 0],
				["Muddy water is best cleared by leaving it alone.", "Alan Watts"],
				["Someone who thinks the world is always cheating him is right. He is missing that wonderful feeling of trust in someone or something.", "Eric Hoffer"],
				["We cannot teach people anything. We can only help them discover it within themselves.", "Galileo Galilei"],
				["How we spend our days is, of course, how we spend our lives.", "Annie Dillard"],
				["I would rather die of passion than of boredom.", "Vincent Van Gogh"],
				["Make sure your worst enemy doesn't live between your two ears.", "Laird Hamilton"],
				["You can't use up creativity. The more you use the more you have.", "Maya Angelou"],
				["The secret of change is to focus all of your energy, not on fighting the old but on building the new.", 0],
				["Whenever you see a successful business, someone once made a courageous decision.", "Peter Drucker"],
				["If you stumble make it part of the dance.", 0],
				["Each day wake up and ask yourself what will make you feel most alive that day.", 0],
				["Choose a job you love and you will never have to work a day of your life.", "Confucius"],
				["It is not the load that breaks you down. It's the way you carry it.", "Lou Holtz"],
				["If you want to go fast, go alone. If you want to go far, bring others along.", 0],
				["Decide that you want it more than you are afraid of it.", 0],
				["Children are wonderfully confident in their own imaginations. Most of us lose this confidence as we grow up.", "Sir Ken Robinson"],
				["It is possible to commit no mistakes and still lose. That is not a weakness; that is life.", "Jean Luc Picard"],
				["So many of our dreams at first seem impossible. Then they seem improbable. And then, when we summon the will, they soon become inevitable.", "Nelson Mandela"],
				["If you don't prioritize your life, someone else will.", "Greg McKeown"],
				["Argue for your limitations, and surely they’re yours.", "Richard Bach"],
				["There is only one person who could ever make you happy, and that person is you.", "David Burns"],
				["A goal without a plan is only a wish.", 0],
				["Every person is a new door to a different world.", "Six Degrees of Separation"],
				["On your journey through life, make sure your biography has at least one extraordinary chapter.", 0],
				["The journey is the reward.", "Steve Jobs"],
				["Know well what leads you forward and what holds you back, and choose the path that leads you to wisdom.", "Buddha"],
				["The meaning of life is to find your gift. The purpose of life is to give it away.", "Pablo Picasso"],
				["The master has failed more times than the beginner has even tried.", "Stephen McCranie"],
				["Jumping from failure to failure with undiminished enthusiasm is the big secret to success.", "Savas Dimopoulos"],
				["Fear does not prevent death. It prevents life.", "Naguib Mahfouz"],
				["Great things are done by a series of small things brought together.", "Vincent Van Gogh"],
				["The way to get started is to quit talking and begin doing.", "Walt Disney"],
				["What are the most powerful words in the universe? The ones you use to talk to yourself.", "Karen Salmansohn"],
				["Within you is a stillness and a sanctuary to which you can retreat at any time and be yourself.", "Hermann Hesse"],
				["Spend more time smiling than frowning and more time praising than criticizing.", "Richard Branson"],
				["Success is something you attract by the person you become.", "Jim Rohn"],
				["Always remember you are braver than you believe, stronger than you seem, and smarter than you think", "A. A. Milne"],
				["Don't underestimate the value of doing nothing, of just going along, listening to all the things you can't hear, and not bothering.", "Winnie the Pooh"],
				["It's up to you how far you go. If you don't try, you'll never know!", "Merlin, \"Sword in the Stone\""],
				["The only way to learn it is to do it.", "Archimedes, \"Sword in the Stone\""],
				["In matters of style swim with the current. In matters of principle, stand like a rock.", 0],
				["You are never too old to set another goal or to dream a new dream.", "C. S. Lewis"],
				["Whenever you are confronted with an opponent, conquer him with love.", "Mahatma Gandhi"],
				["The only way to do great work is to love what you do. If you haven't found it yet, keep looking. Don't settle.", "Steve Jobs"],
				["The best teachers are those who show you where to look, but don't tell you what to see.", "Alexandra K. Trenfor"],
				["It’s not what you look at that matters, it’s what you see.", "Henry David Thoreau"],
				["Rules for happiness: something to do, someone to love, something to hope for.", "Immanuel Kant"],
				["When feeling overwhelmed by a faraway goal, repeat the following: I have it within me right now, to get me to where I want to be later.", "Karen Salmansohn"],
				["If you have good thoughts they will shine out of your face like sunbeams and you will always look lovely.", "Roald Dahl"],
				["You have power over your mind, not outside events. Realize this, and you will find strength.", "Marcus Aurelius"],
				["You cannot protect yourself from sadness without protecting yourself from happiness.", "Jonathan Safran Foer"],
				["Act as if what you do makes a difference. It does.", "William James"],
				["Progress lies not in enhancing what is, but in advancing toward what will be.", "Khalil Gibran"],
				["Sitting quietly, doing nothing, Spring comes, and the grass grows by itself.", "Matsuo Basho"],
				["You can't be paralyzed by fear of failure or you will never push yourself.", "Arnold Schwarzenegger"],
				["Ask yourself, who do you want to be? Figure out for yourself what makes you happy, no matter how crazy it may sound to other people.", "Arnold Schwarzenegger"],
				["We either make ourselves miserable, or we make ourselves strong. The amount of work is the same.", "Carlos Castaneda"],
				["What weakens us is feeling offended by the deeds and misdeeds of our fellow men. Our self-importance requires that we spend most of our lives offended by someone.", "Carlos Castaneda"],
				["If you can dream it, you can do it.", "Walt Disney"],
				["Open your eyes, look within. Are you satisfied with the life you're living?", "Bob Marley"],
				["If I quit now, I will soon be back to where I started. And when I started I was desperately wishing to be where I am now.", 0],
				["Most people quit because they look how far they have to go, not how far they have come.", "Anonymous"],
				["If you have a dream, don’t just sit there. Gather courage to believe that you can succeed and leave no stone unturned to make it a reality.", "Dr Rooplen"],
				["Don’t let mental blocks control you. Set yourself free. Confront your fear and turn the mental blocks into building blocks.", "Dr Rooplen"],
				["Believe in yourself. Under-confidence leads to a self-fulfilling prophecy that you are not good enough for your work.", "Dr Rooplen"],
				["The only thing standing between you and your goal is the story you keep telling yourself as to why you can't achieve it.", "Jordan Belfort"],
				["The fear of death follows from the fear of life. One who lives life fully is prepared to die at any time.", "Mark Twain"],
				["There are only two ways to live your life. One is as though nothing is a miracle. The other is as though everything is a miracle.", "Albert Einstein"],
				["Good judgment comes from experience, and a lot of that comes from bad judgment.", "Will Rogers"],
				["As long as you're being a copycat, you will never be the best copycat.", "Eric Thomas"],
				["Life has no limitations, except the ones you make.", "Les Brown"],
				["Do what you can, with what you have, where you are.", "Theodore Roosevelt"],
				["Your world is a living expression of how you are using—and have used—your mind.", "Earl Nightingale"],
				["Learn to enjoy every minute of your life. Be happy now. Don't wait for something outside of yourself to make you happy in the future. ", "Earl Nightingale"],
				["Whatever we plant in our subconscious mind and nourish with repetition and emotion will one day become reality.", "Earl Nightingale"],
				["Our attitude toward life determines life's attitude towards us.", "Earl Nightingale"],
				["Courage doesn't always roar. Sometimes courage is the quiet voice at the end of the day whispering, 'I will try again tomorrow.'", "Mary Anne Radmacher"],
				["There is no small act of kindness. Every compassionate act makes large the world.", "Mary Anne Radmacher"],
				["No one has the power to shatter your dreams unless you give it to them.", "Maeve Greyson"],
				["If you really believe in what you're doing, work hard, take nothing personally and if something blocks one route, find another. Never give up.", "Laurie Notaro"],
				["The death of a dream is the day that you stop believing in the work it takes to get there.", "Chris Burkmenn"],
				["If you change nothing, nothing will change", "Tony Robbins"],
				["It doesn’t matter where you are, you are nowhere compared to where you can go.", "Bob Proctor"],
				["I can accept failure. Everyone fails at something. But I can’t accept not trying.", "Michael Jordan"],
				["The greatest mistake you can make in life is to be continually fearing you will make one.", "Elbert Hubbard"],
				["Nothing diminishes anxiety faster than action.", "Walter Anderson"],
				["Use what talents you possess, the woods will be very silent if no birds sang there except those that sang best.", "Henry van Dyke"],
				["Sometimes good things fall apart so better things can fall together.", "Marilyn Monroe"],
				["Fear, uncertainty and discomfort are your compasses toward growth.", 0],
				["If you cannot do great things, do small things in a great way.", "Napoleon Hill"],
				["Sometimes life hits you in the head with a brick. Don't lose faith.", "Steve Jobs"],
				["Without new experiences, something inside of us sleeps. The sleeper must awaken.", "Frank Herbert"],
				["What lies behind us and what lies before us are tiny matters compared to what lies within us.", "Ralph Waldo Emerson"],
				["Don't let the noise of others' opinions drown out your own inner voice. Have the courage to follow your own heart and intuition.", "Steve Jobs"],
				["Do not seek to follow in the footsteps of others, instead, seek what they sought.", "Matsuo Basho"],
				["If you wish to travel far and fast, travel light. Take off all your envies, jealousies, unforgiveness, selfishness, and fears.", "Glenn Clark"],
				["If you are still looking for that one person who will change your life, take a look in the mirror.", "Roman Price"],
				["Be who you were created to be, and you will set the world on fire.", "St. Catherine of Sienna"],
				["Forget all the reasons why it won't work and believe the one reason why it will.", 0],
				["Your value doesn't decrease based on someone's inability to see your worth.", 0],
				["Growth is painful. Change is painful. But nothing is as painful as staying stuck somewhere you don't belong.", "Mandy Hale"],
				["If you find yourself constantly trying to prove your worth to someone, you have already forgotten your value.", 0],
				["Don't let yesterday use up too much of today.", "Will Rogers"],
				["Kindness is more important than wisdom, and the recognition of this is the beginning of wisdom.", "Theodore Isaac Rubin"],
				["Dream big dreams. Small dreams have no magic.", "Dottie Boreyko"],
				["Destiny is not a matter of chance; it is a matter of choice. It is not a thing to be waited for, it is a thing to be achieved.", "William Jennings Bryan"],
				["What you seek is seeking you.", "Rumi"],
				["If you lose, don't lose the lesson.", "Dalai Lama"]
			]
		},

		refresh: function(force) {
			if (!force && this.config.method === "daily" && this.data.date && (new Date().getTime() - this.data.date) < 864E5) {
				return;
			}

			var source = this.sources[this.config.source];

			if (Array.isArray(source)) {
				var quote = _.sample(source);

				if (Array.isArray(quote)) {
					quote = {
						body: quote[0],
						source: quote[1],
						link: quote[2]
					};

					if (quote.source === 0) {
						quote.source = this.utils.translate("unknown_author");
					}

					if (!quote.link) {
						delete quote.link;
					}

					if (!quote.source) {
						delete quote.source;
					}
				}

				this.data = quote;

				this.data.date = new Date().getTime();

				this.render();

				this.utils.saveData(this.data);
			}
			else if (source && source.url && typeof source.parse === "function") {
				$.ajax({
					cache: false,
					method: "GET",
					url: _.result(source, "url"),
					success: function(d) {
						if (d) {
							var quote;

							try {
								quote = source.parse(d, this.utils.translate("unknown_author"));
							}
							catch (e) {
								quote = false;
							}

							if (!quote) {
								return;
							}

							if (!quote.link) {
								delete quote.link;
							}

							if (!quote.source) {
								delete quote.source;
							}

							this.data = quote;

							this.data.date = new Date().getTime();

							this.render();

							this.utils.saveData(this.data);
						}
					}.bind(this)
				});
			}
		},


		render: function(demo) {
			if (demo) {
				return this.refresh();
			}

			var data = _.clone(this.data);

			if (this.config.title) {
				data.title = this.config.title;
			}

			$(this.elm).off("click.quotes").on("click.quotes", ".tweet", function(e) {
				e.preventDefault();

				var d = this.data;

				Browser.tabs.create({
					url: "https://twitter.com/intent/tweet?" +
						"text=" + encodeURIComponent(d.noquotes ? d.body : '"' + d.body + '"' + (d.source ? ' — ' + d.source : "")) +
						"&via=iChromeHQ&related=iChromeHQ"
				});
			}.bind(this)).on("click.quotes", "footer .refresh", function(e) {
				e.preventDefault();

				this.refresh(true);
			}.bind(this));

			this.utils.render(data);
		}
	};
});
/*
 * The Reddit widget.
 */
define('w/reddit',["jquery", "moment"], function($, moment) {
	return {
		id: 18,
		sort: 210,
		size: 6,
		order: 30,
		interval: 300000,
		nicename: "reddit",
		sizes: ["variable"],
		settings: [
			{
				type: "text",
				nicename: "title",
				label: "i18n.settings.title",
				placeholder: "i18n.settings.title_placeholder"
			},
			{
				type: "text",
				nicename: "subreddit",
				label: "i18n.settings.subreddit",
				help: "i18n.settings.subreddit_help",
				placeholder: "i18n.settings.subreddit_placeholder"
			},
			{
				type: "select",
				nicename: "sort",
				label: "i18n.settings.sort",
				options: {
					hot: "i18n.settings.sort_options.hot",
					top: "i18n.settings.sort_options.top",
					"new": "i18n.settings.sort_options.new",
					gilded: "i18n.settings.sort_options.gilded",
					rising: "i18n.settings.sort_options.rising",
					controversial: "i18n.settings.sort_options.controversial",
				}
			},
			{
				type: "number",
				nicename: "number",
				label: "i18n.settings.links",
				min: 1,
				max: 10
			},
			{
				type: "radio",
				nicename: "click",
				label: "i18n.settings.click",
				options: {
					link: "i18n.settings.click_options.link",
					comments: "i18n.settings.click_options.comments"
				}
			},
			{
				type: "radio",
				nicename: "link",
				label: "i18n.settings.footer_link",
				options: {
					show: "i18n.settings.footer_link_options.show",
					hide: "i18n.settings.footer_link_options.hide"
				}
			}
		],
		config: {
			size: "variable",
			title: "i18n.name",
			number: 5,
			sort: "hot",
			subreddit: "all",
			link: "show",
			click: "link"
		},
		data: {
			links: [
				{
					id: "t3_1u5nzu",
					link: "https://imgur.com/pa5X7gH",
					user: "BigGulpsHuh7",
					score: 1740,
					title: "Worst lady of 2013 (fixed) (fixed)",
					domain: "imgur.com",
					subreddit: "funny",
					permalink: "/r/funny/comments/1u5nzu/worst_lady_of_2013_fixed_fixed/",
					created: 1388583609000,
					comments: "124",
					image: "http://f.thumbs.redditmedia.com/x1LB_aco57Z-zBEk.jpg"
				},
				{
					id: "t3_1u5j8t",
					link: "http://www.youtube.com/watch?v=-N_UuImPL4E",
					user: "untranslatable_pun",
					score: 2060,
					title: "THE WIRE: Snoop Buys a Nail Gun. My favorite scene from the entire series. (No spoilers)",
					domain: "youtube.com",
					subreddit: "videos",
					permalink: "/r/videos/comments/1u5j8t/the_wire_snoop_buys_a_nail_gun_my_favorite_scene/",
					created: 1388574231000,
					comments: "697",
					image: "http://b.thumbs.redditmedia.com/OINzo6WMdTbZUHQa.jpg"
				},
				{
					id: "t3_1u5m1r",
					link: "http://i.imgur.com/fBHxyZl.jpg",
					user: "hms90",
					score: 1471,
					title: "Meet the latest addition to our family, Slim Shady.",
					domain: "i.imgur.com",
					subreddit: "aww",
					permalink: "/r/aww/comments/1u5m1r/meet_the_latest_addition_to_our_family_slim_shady/",
					created: 1388579835000,
					comments: "78",
					image: "http://c.thumbs.redditmedia.com/oJNpAN5uFgXD9zH8.jpg"
				},
				{
					id: "t3_1u5gru",
					link: "http://i.imgur.com/Ia845vX.gif",
					user: "teap0ts",
					score: 2449,
					title: "Best use of my tax dollars I've seen yet",
					domain: "i.imgur.com",
					subreddit: "gifs",
					permalink: "/r/gifs/comments/1u5gru/best_use_of_my_tax_dollars_ive_seen_yet/",
					created: 1388569461000,
					comments: "209"
				},
				{
					id: "t3_1u5ier",
					link: "http://www.reuters.com/article/2014/01/01/us-hongkong-democracy-idUSBREA0005420140101?feedType=RSS&amp;feedName=worldNews",
					user: "Litteratur",
					score: 1967,
					title: "Thousands march in Hong Kong in escalating battle for democracy",
					domain: "reuters.com",
					subreddit: "worldnews",
					permalink: "/r/worldnews/comments/1u5ier/thousands_march_in_hong_kong_in_escalating_battle/",
					created: 1388572611000,
					comments: "365"
				},
				{
					id: "t3_1u5ieg",
					link: "http://www.aljazeera.com/indepth/opinion/2013/12/what-snowden-really-revealed-20131228113515573236.html",
					user: "jstratg",
					score: 1886,
					title: "What Snowden really revealed: We have sacrificed our freedoms and morals in order to make war on those abroad, and, more subtly, on ourselves",
					domain: "aljazeera.com",
					subreddit: "politics",
					permalink: "/r/politics/comments/1u5ieg/what_snowden_really_revealed_we_have_sacrificed/",
					created: 1388572589000,
					comments: "230"
				},
				{
					id: "t3_1u5dj5",
					link: "https://imgur.com/ISzszsN",
					user: "cp3woo",
					score: 2910,
					title: "Mike Tyson just posted this on twitter with the caption, \"Happy New Ears\"",
					domain: "imgur.com",
					subreddit: "funny",
					permalink: "/r/funny/comments/1u5dj5/mike_tyson_just_posted_this_on_twitter_with_the/",
					created: 1388563858000,
					comments: "217",
					image: "http://f.thumbs.redditmedia.com/bK1m2Urw9lDtWVoA.jpg"
				},
				{
					id: "t3_1u5gow",
					link: "http://i.imgur.com/6QXBwM9.jpg",
					user: "Our_gamers",
					score: 2148,
					title: "One of my favorite family guy scenes",
					domain: "i.imgur.com",
					subreddit: "funny",
					permalink: "/r/funny/comments/1u5gow/one_of_my_favorite_family_guy_scenes/",
					created: 1388569299000,
					comments: "59"
				},
				{
					id: "t3_1u5mwr",
					link: "http://i.imgur.com/COeUCqr.gif",
					user: "not_a_famous_actor",
					score: 1028,
					title: "Richie wouldn't let his blindness stop him from following his dreams of becoming a graffiti artist",
					domain: "i.imgur.com",
					subreddit: "wheredidthesodago",
					permalink: "/r/wheredidthesodago/comments/1u5mwr/richie_wouldnt_let_his_blindness_stop_him_from/",
					created: 1388581499000,
					comments: "17",
					image: "http://d.thumbs.redditmedia.com/JWoNW_i9l2zful9o.jpg"
				},
				{
					id: "t3_1u5e3d",
					link: "http://i.imgur.com/SglJI42.jpg",
					user: "queen_of_the_koopas",
					score: 2236,
					title: "Wicked awesome bunk bed my friend built her kid!",
					domain: "i.imgur.com",
					subreddit: "gaming",
					permalink: "/r/gaming/comments/1u5e3d/wicked_awesome_bunk_bed_my_friend_built_her_kid/",
					created: 1388564740000,
					comments: "107"
				}
			]
		},
		refresh: function() {
			var config = this.config;

			$.get("http://www.reddit.com/" + (config.subreddit && config.subreddit !== "" ? "r/" + config.subreddit : "") + (config.sort && config.sort !== "" && config.sort !== "hot" ? "/" + config.sort : "") + ".json?limit=10", function(d) {
				var links = [];

				d.data.children.slice(0, 10).forEach(function(e) {
					e = e.data;

					var link = {
						id: e.name,
						link: e.url,
						user: e.author,
						score: e.score,
						title: e.title,
						domain: e.domain,
						subreddit: e.subreddit,
						permalink: e.permalink,
						created: e.created_utc * 1000,
						comments: e.num_comments.toLocaleString()
					};

					if (e.thumbnail && e.thumbnail !== "" && e.thumbnail.trim().indexOf("http") === 0) {
						link.image = e.thumbnail.trim();
					}

					links.push(link);
				});

				this.data = {
					links: links
				};

				this.render.call(this);

				this.utils.saveData(this.data);
			}.bind(this));
		},
		render: function(demo) {
			var data = $.extend(true, {}, this.data || {links:[]});

			data.links = data.links.slice(0, this.config.number || 5);

			data.links.forEach(function(e) {
				if (demo) {
					e.created = moment(e.created).from([2014, 0, 1, 11]).replace("hour", "hr").replace("minute", "min").replace("a few ", "");
				}
				else {
					e.created = moment(e.created).fromNow().replace("hour", "hr").replace("minute", "min").replace("a few ", "");
				}

				if (!e.subreddit.toLowerCase || e.subreddit.toLowerCase() === this.config.subreddit.toLowerCase()) {
					e.subreddit = false;
				}

				if (this.config.click && this.config.click === "comments") {
					e.link = "http://www.reddit.com" + e.permalink;
				}

				if (e.score < 0) {
					e.direction = " down";
				}

				e.score = e.score.toLocaleString();
			}.bind(this));

			if (this.config.title && this.config.title !== "") {
				data.title = this.config.title;
			}

			if (this.config.link && this.config.link === "show") {
				data.link = "http://www.reddit.com/" + (this.config.subreddit && this.config.subreddit !== "" ? "r/" + this.config.subreddit : "");
			}

			this.utils.render(data);
			this.elm.addClass("tabbed");
		}
	};
});
/*
 * Search
 */
define('w/search',[], function() {
	return {
		id: 40,
		sort: 290,
		size: 1,
		nicename: "search",
		sizes: ["tiny", "small"],

		config: {
			param: "q",
			size: "small",
			url: "https://www.google.com/search",
			placeholder: "i18n.default_placeholder"
		},

		settings: [
			{
				type: "size"
			},
			{
				type: "text",
				nicename: "placeholder",
				label: "i18n.settings.placeholder",
				placeholder: "i18n.default_placeholder"
			},
			{
				type: "text",
				nicename: "url",
				label: "i18n.settings.search_url",
				placeholder: "https://www.google.com/search"
			},
			{
				type: "text",
				nicename: "param",
				label: "i18n.settings.param",
				placeholder: "i18n.settings.param_placeholder"
			}
		],

		render: function() {
			this.utils.render(this.config);

			this.elm.find("form").on("submit", function(e) {
				e.preventDefault();

				var a = document.createElement("a");

				a.href = this.config.url + (this.config.url.indexOf("?") !== -1 ? "&" : "?") + encodeURIComponent(this.config.param) + "=" + encodeURIComponent(this.elm.find(".searchbox").val());

				a.click();
			}.bind(this));
		}
	};
});
/*
 * Site Link
 */
define('w/sitelink',["jquery", "lodash", "browser/api"], function($, _, Browser) {
	return {
		id: 38,
		sort: 10,
		size: 1,
		nicename: "sitelink",
		sizes: ["tiny", "medium"],
		settings: [
			{
				type: "text",
				nicename: "title",
				label: "i18n.settings.title",
				placeholder: "i18n.settings.title_placeholder"
			},
			{
				type: "size"
			},
			{
				type: "text",
				nicename: "link",
				label: "i18n.settings.link",
				placeholder: "i18n.settings.link_placeholder"
			},
			{
				type: "text",
				nicename: "image",
				label: "i18n.settings.image",
				placeholder: "i18n.settings.image_placeholder",
				help: "i18n.settings.image_help",
			},
			{
				type: "color",
				label: "i18n.settings.color",
				nicename: "color"
			},
			{
				type: "select",
				nicename: "style",
				label: "i18n.settings.style",
				options: {
					fill: "i18n.settings.style_fill",
					center: "i18n.settings.style_center"
				}
			},
			{
				type: "radio",
				nicename: "target",
				label: "i18n.settings.target.title",
				options: {
					def: "i18n.settings.target.default",
					same: "i18n.settings.target.same",
					new: "i18n.settings.target.new"
				}
			},
		],
		config: {
			size: "tiny",
			style: "center",
			color: "#FFFFFF",
			title: "YouTube",
			link: "https://www.youtube.com/",
			image: "images/sitelink_demo.png",
			target: "def"
		},
		render: function() {
			var data = _.clone(this.config);

			data.hasIcon = data.image || data.color;

			this.utils.render(data);

			var open = function(href) {
				var template = "###productivitytab###";

				if (href.indexOf(template) > 0) {
					href = href.replace(template, Browser.app.id);
				}

				var targetInt = this.config.target || 0;						
				var target;
				switch (targetInt) {
					case "same": 
						target = "_self";
						break;
					case "new": 
						target = "_blank";
						break;
					default:
						target = $("base").attr("target") || "_blank";
						break;							
				}

				window.open(href, target);
			}.bind(this);			

			this.elm.off("click.sitelink").on("click.sitelink", "a", function(e) {
				var href = this.getAttribute("href");

				if (href.indexOf("chrome") === 0) { // chrome:// links can't be opened directly for security reasons, this bypasses that feature.
					e.preventDefault();

					Browser.tabs.getCurrent(function(d) {
						if (e.which === 2 || (e.currentTarget.target || $("base").attr("target")) === "_blank") {
							Browser.tabs.create({
								url: href,
								index: d.index + 1
							});
						}
						else {
							Browser.tabs.update(d.id, {
								url: href
							});
						}
					});
				} 
				else {
					e.preventDefault();
					open(href);
				}
			});
		}
	};
});
/*
 * System Stats
 */
define('w/stats',["lodash", "jquery", "moment", "browser/api"], function(_, $, moment, Browser) {
	return {
		id: 39,
		sort: 250,
		size: 1,
		interval: 300000,
		nicename: "stats",
		sizes: ["small"],

		config: {
			size: "small"
		},


		/**
		 * These are element and data caches for the CPU usage updater function
		 */
		cpuUsage: null,
		cpuCores: null,
		cpuCoreInfo: [],
		cpuInterval: null,


		/**
		 * Updates the CPU usage indicators
		 */
		updateCPU: function() {
			Browser.system.cpu.getInfo(function(d) {
				var val;

				this.cpuUsage.textContent = Math.floor(
					_.reduce(
						_.map(d.processors, function(d, i) {
							val = ((d.usage.user + d.usage.kernel) - this.cpuCoreInfo[i].usage) / (d.usage.total - this.cpuCoreInfo[i].total) * 100;

							if (val) {
								(this.cpuCores[i] || {}).value = val;
							}

							this.cpuCoreInfo[i] = { usage: (d.usage.user + d.usage.kernel), total: d.usage.total };

							return val;
						}.bind(this)),
						function(r, d) {
							return r + d;
						},
						0
					) / d.processors.length
				);
			}.bind(this));
		},


		refresh: function() {
			clearInterval(this.cpuInterval);

			var battery;

			var queries = {
				battery: function(cb) {
					navigator.getBattery().then(function(d) {
						var data = {
							status: d.charging ? (d.level === 1 ? this.utils.translate("charged") : this.utils.translate("charging")) : (d.level === 1 ? this.utils.translate("idle") : this.utils.translate("discharging")),
							percent: Math.floor(d.level * 100)
						};

						var time = d.dischargingTime === Infinity ? d.chargingTime : d.dischargingTime;

						if (time !== Infinity && time !== 0) {
							data.remaining = moment.duration(time, "seconds").humanize();
						}

						battery = d;

						cb.call(this, data);
					}.bind(this));
				},

				cpu: function(cb) {
					Browser.system.cpu.getInfo(function(d) {
						var coreInfo = this.cpuCoreInfo;

						var data = {
							name: d.modelName,
							cores: d.processors.map(function(d, i) {
								if (coreInfo[i]) {
									var val = ((d.usage.user + d.usage.kernel) - coreInfo[i].usage) / (d.usage.total - coreInfo[i].total) * 100;

									coreInfo[i] = { usage: (d.usage.user + d.usage.kernel), total: d.usage.total };

									return val;
								}
								else {
									coreInfo.push({ usage: (d.usage.user + d.usage.kernel), total: d.usage.total });

									return (d.usage.user + d.usage.kernel) / d.usage.total * 100;
								}
							})
						};

						data.usage = Math.floor(_.reduce(data.cores, function(r, d) { return r + d; }, 0) / d.processors.length);

						cb.call(this, data);
					}.bind(this));
				},

				ram: function(cb) {
					Browser.system.memory.getInfo(function(d) {
						var formatNum = function(num) {
							var exp = Math.floor(Math.log(num) / Math.log(1024));

							return (num / Math.pow(1024, exp)).toFixed(2) * 1 + " " + (exp === 0 ? "bytes": "KMGTPEZY"[exp - 1] + "iB");
						};

						var data = {
							usage: formatNum(d.capacity - d.availableCapacity),
							total: formatNum(d.capacity),
							usagePercent: ((d.capacity - d.availableCapacity) / d.capacity) * 100
						};

						cb.call(this, data);
					}.bind(this));
				}
			};


			var i = 0,
				result = {},
				total = Object.keys(queries).length;

			_.each(queries, function(type, key) {
				type.call(this, function(data) {
					result[key] = data;

					if (++i === total) {
						if (battery) {
							var updateStatus = _.throttle(function() {
								battery.removeEventListener("levelchange", updateStatus);
								battery.removeEventListener("chargingchange", updateStatus);
								battery.removeEventListener("chargingtimechange", updateStatus);
								battery.removeEventListener("dischargingtimechange", updateStatus);

								this.refresh();
							}.bind(this), 30000);

							battery.addEventListener("levelchange", updateStatus);
							battery.addEventListener("chargingchange", updateStatus);
							battery.addEventListener("chargingtimechange", updateStatus);
							battery.addEventListener("dischargingtimechange", updateStatus);
						}

						// Cache this so the widget renders immediately instead of flashing
						this.data = result;

						this.render();

						this.utils.saveData(this.data);
					}
				});
			}, this);
		},

		render: function(demo) {
			if (this.cpuInterval) {
				clearInterval(this.cpuInterval);
			}

			if (demo) {
				this.refresh();
			}

			this.utils.render(this.data);

			if (this.cpuCoreInfo.length) {
				this.cpuUsage = this.elm.find(".cpu .usage")[0];
				this.cpuCores = this.elm.find(".cpu progress");
				this.cpuInterval = setInterval(this.updateCPU.bind(this), 1000);

				this.updateCPU();
			}
		}
	};
});
/*
 * The Tasks widget.
 */
define('w/tasks',["lodash", "jquery", "moment", "oauth"], function(_, $, moment, OAuth) {
	return {
		id: 34,
		sort: 330,
		size: 2,
		order: 8,
		interval: 300000,
		nicename: "tasks",
		sizes: ["variable"],
		settings: [
			{
				type: "text",
				nicename: "title",
				label: "i18n.settings.title",
				placeholder: "i18n.settings.title_placeholder"
			},
			{
				type: "select",
				nicename: "list",
				label: "i18n.settings.list",
				options: "getLists"
			}
		],
		config: {
			title: "i18n.title",
			size: "variable",
			list: ""
		},
		data: {
			items: [
				{
					"id": "1",
					"title": "Sample task"
				},
				{
					"id": "2",
					"title": "An overdue task",
					"due": 1425186000000
				},
				{
					"id": "3",
					"title": "This one has a note, click to see what it says.",
					"notes": "Here's the note, type in this box to edit it.  You can use the buttons at the left below this box to move and delete this task."
				}
			]
		},

		oAuth: false,

		/**
		 * Creates an OAuth instance for this widget
		 *
		 * @api  private
		 */
		setOAuth: function() {
			this.oAuth = new OAuth({
				name: "tasks",
				id: "559765430405-jtbjv5ivuc17nenpsl4dfk9r53a3q0hg.apps.googleusercontent.com",
				secret: "uzvC025Z3R12syGZ52hFDyHx",
				scope: "https://www.googleapis.com/auth/tasks"
			});
		},


		/**
		 * Queries and returns a list of task list from the user's Tasks
		 *
		 * @api     public
		 * @param   {Function}  cb  The callback function
		 */
		getLists: function(cb) {
			if (!this.oAuth) {
				this.setOAuth();
			}

			this.oAuth.ajax({
				type: "GET",
				dataType: "json",
				url: "https://www.googleapis.com/tasks/v1/users/@me/lists?fields=items(id%2Ctitle)",
				success: function(d) {
					if (!d || !d.items) {
						return cb("error");
					}

					var taskLists = {};

					d.items.forEach(function(e) {
						taskLists[e.id] = e.title;
					});

					cb(taskLists);
				}
			});
		},

		refresh: function() {
			if (!this.oAuth) {
				this.setOAuth();
			}

			if (!this.config.list) {
				return false;
			}

			var url = "https://www.googleapis.com/tasks/v1/lists/" + this.config.list + "/tasks?fields=items(completed%2Cdue%2Cid%2Cnotes%2Cstatus%2Ctitle%2Cposition%2Cparent)"; 
			url += "&nc=" + new Date().getTime();

			this.oAuth.ajax({
				type: "GET",
				dataType: "json",
				url: url,
				success: function(d) {
					if (d && d.items) {
						var items = d.items.map(function(e) {
							var ret = {
								id: e.id,
								title: (e.title || '').trim(),
								done: e.status === "completed",
								parent: e.parent || '',
								pos: e.position || ''
							};

							if (e.notes) {
								ret.notes = e.notes.trim();
							}

							if (e.due) {
								// Parsing with this format avoids timezone issues by reducing the precision to YMD
								ret.due = moment(e.due, "YYYY-MM-DD").valueOf();
							}

							return ret;
						});

						var groupedItems = _.groupBy(items, function(item) {
							return item.parent;
						});

						var order = function(i) {
							return i.sort(function(a, b) {
								if (a.parent < b.parent) { return -1; }
								if (a.parent > b.parent) { return 1; }
								if (a.pos < b.pos) { return -1; }
								if (a.pos > b.pos) { return 1; }
								return 0;
							});
						};

						items = order(groupedItems[''] || []);
						items.forEach(function(e) {
							var children = groupedItems[e.id];
							if (children) {
								e.children = order(children);
							}
						});


						this.data = {
							items: items
						};

						this.render();

						this.utils.saveData(this.data);
					}
				}.bind(this)
			});
		},


		/**
		 * Handles the edit/create form save event
		 *
		 * @api     private
		 * @param   {Event}  elm  The edit form
		 */
		save: function(elm) {
			var that = this,
				oAuth = this.oAuth || { ajax: function() {} };

			elm.addClass("transitioning");


			var dta = {
				title: elm.find(".title").val().trim(),
				due: elm.find(".due-date").val().trim() || null,
				notes: elm.find(".notes").val().trim() || null
			};

			if (dta.due) {
				var date = moment(dta.due);

				if (!date.isValid()) {
					date = moment(dta.due, "MMMM D YYYY");
				}

				if (!date.isValid()) {
					dta.due = null;
				}
				else {
					dta.due = date.valueOf();
				}
			}

			var item;

			if (elm.is(this.addForm)) {
				item = $('<div class="item">' + this.utils.renderTemplate("item", this.formatItem(dta)) + "</div>").insertAfter(elm);

				if (dta.due) {
					dta.due = new Date(dta.due);
				}

				var lastitem = _.last(that.data.items);
				var url = "https://www.googleapis.com/tasks/v1/lists/" + this.config.list + "/tasks?fields=id";
				if (lastitem) {
					url += "&previous=" + lastitem.id;
				}

				oAuth.ajax({
					type: "POST",
					url: url,
					data: JSON.stringify(dta),
					contentType: "application/json",
					complete: function(xhr) {
						if (xhr.status === 200 && xhr.responseJSON && xhr.responseJSON.id) {
							item.attr("data-id", xhr.responseJSON.id);

							if (dta.due) {
								dta.due = dta.due.getTime();
							}

							dta.id = xhr.responseJSON.id;

							that.data.items.push(dta);

							that.utils.saveData(that.data);
						}
						else {
							item.remove();
						}
					}
				});

				elm.animate({ height: 0 }, 200, function() {
					elm.remove();

					that.addForm = null;
				});
			}
			else {
				var id = elm.attr("data-id");

				item = that.findItem(id);
				
				_.assign(item, dta);

				this.utils.saveData(this.data);

				if (dta.due) {
					dta.due = new Date(dta.due).toISOString();
				}

				oAuth.ajax({
					type: "PATCH",
					url: "https://www.googleapis.com/tasks/v1/lists/" + this.config.list + "/tasks/" + id + "?fields=id",
					data: JSON.stringify(dta),
					contentType: "application/json"
				});

				setTimeout(function() {
					elm.removeClass("edit").html(that.utils.renderTemplate("item", that.formatItem(item))).removeClass("transitioning");
				}, 150);
			}
		},


		findItem: function(id) {
			var pattern = { id : id };
			var result = _.find(this.data.items, pattern);
			if (result) {
				return result;
			}

			for (var i = 0; i < this.data.items.length; i++) {
				result = _.find(this.data.items[i].children, pattern);
				if (result) {
					return result;
				}
			}

			return null;
		},


		/**
		 * Formats a task object for display
		 *
		 * @api     private
		 * @param   {Object}  e  The task object
		 * @return  {Object}     The formatted object
		 */
		formatItem: function(e) {
			var ret = _.clone(e);

			if (e.due) {
				var date = moment(e.due);

				if (Math.abs(date.diff(new Date(), "days")) + 1 > 7) {
					ret.due = date.format("MMMM Do");
				}
				else {
					ret.due = date.calendar().replace(" at 12:00 AM", "").replace("Today at ", "");
				}


				if (date.isBefore(moment().subtract(1, "days"))) {
					ret.overdue = true;
				}
				else if (moment().isSame(date, "day")) {
					ret.duetoday = true;
				}
			}

			return ret;
		},

		render: function(demo) {
			var data = {
				title: this.config.title
			};

			if (!demo && !this.config.list) {
				data.authorize = true;

				return this.utils.render(data);
			}


			data.items = _.map((this.data || {}).items, this.formatItem);

			this.utils.render(data, {
				item: this.utils.getTemplate("item")
			});


			var oAuth = this.oAuth;

			// If this is a demo, or not authenticated, it shouldn't attempt any requests
			if (demo || !this.oAuth) {
				oAuth = {
					ajax: function() {}
				};
			}

			var that = this;

			var moveChildren = function(item, children) {
				var current = item;
				for (var i = 0; i < children.length; i++)
				{
					var el = children[i];
					$(el).insertAfter(current);
					current = el;
				}
			};

			this.elm.off(".tasks")
				.on("click.tasks", "button.add", function() {
					if (that.addForm) {
						return;
					}

					that.addForm = $('<div class="item edit transitioning add" style="height: 0;">' + that.utils.renderTemplate("item", { edit: true }) + '</div>');

					$(this).parent().siblings(".items").append(that.addForm);

					requestAnimationFrame(function() {
						that.addForm.removeClass("transitioning").css("height", "").find(".title").focus();
					});
				})
				.on("click.tasks", ".item:not(.edit)", function(e) {
					if ($(e.target).is(".check")) {
						return;
					}

					var item = $(this);

					item.addClass("transitioning");

					setTimeout(function() {
						var itm = _.clone(that.findItem(item.attr("data-id")));

						if (itm && itm.due) {
							itm.due = moment(itm.due).format("MMMM Do YYYY");
						}

						item.addClass("edit").html(that.utils.renderTemplate("item", _.assign(
							{},
							itm,
							{ edit: true }
						))).removeClass("transitioning");

						var val = item.find(".title").focus().val();

						item.find(".title").val(val);
					}, 150);
				})
				.on("click.tasks", ".item.edit .done", function() {
					that.save($(this).parent());
				})
				.on("keydown.tasks", ".item.edit input, .item.edit .done", function(e) {
					if (e.which === 13) {
						that.save($(this).parent());
					}
				})
				.on("keydown.tasks", ".item.edit textarea", function(e) {
					if (e.which === 13 && e.shiftKey) {
						that.save($(this).parent());
					}
				})
				.on("click.tasks", ".item.edit .delete", function() {
					var item = $(this).parent(),
						id = item.attr("data-id");

					item.css({
						height: 0,
						padding: 0
					}).removeClass("edit");

					oAuth.ajax({
						type: "DELETE",
						url: "https://www.googleapis.com/tasks/v1/lists/" + that.config.list + "/tasks/" + item.attr("data-id") + "",
						complete: function(xhr) {
							if (xhr.status === 200 || xhr.status === 204) {
								setTimeout(function() {
									item.remove();

									_.remove(that.data.items, { id: id });

									that.utils.saveData(that.data);
								}, 200);
							}
							else {
								item.css({
									height: "",
									padding: ""
								}).addClass("edit");
							}
						}
					});
				})
				.on("click.tasks", ".item.edit .move-up", function() {
					var item = $(this).parent(),
						id = item.attr("data-id"),
						level = item.data("level");


					var prevs = item.prevAll('[data-level="' + level + '"]');

					var prev0 = prevs.first();
					if (!prev0.length) {
						return;
					}

					var prev1 = prevs[1];

					var children = item.parent().find('div[data-level="' + id +  '"]');

					item.insertBefore(prev0);

					moveChildren(item, children);

					var url = "https://www.googleapis.com/tasks/v1/lists/" + that.config.list + "/tasks/" + id + "/move";
					url += "?parent=" + level;
					if (prev1) {
						url += "&previous=" + $(prev1).attr("data-id");
					}

					oAuth.ajax({
						type: "POST",
						url: url,
						success: function() {
							var idx = _.findIndex(that.data.items, { id: id });

							that.data.items.splice(idx - 1, 0, that.data.items.splice(idx, 1)[0]);

							that.utils.saveData(that.data);
						}
					});
				})
				.on("click.tasks", ".item.edit .move-down", function() {
					var item = $(this).parent(),
						id = item.attr("data-id"),
						level = item.data("level");

					var next = item.nextAll('[data-level="' + level + '"]').first();

					if (!next.length) {
						return;
					}

					var nextChildren = item.parent().find('div[data-level="' + next.data("id") +  '"]');

					var children = item.parent().find('div[data-level="' + id +  '"]');

					item.insertAfter(nextChildren.length ? nextChildren.last() : next);

					moveChildren(item, children);

					var url = "https://www.googleapis.com/tasks/v1/lists/" + that.config.list + "/tasks/" + id + "/move" +
						"?parent=" + level +
						"&previous=" + next.attr("data-id");
						
					oAuth.ajax({
						type: "POST",
						url: url,
						success: function() {
							var idx = _.findIndex(that.data.items, { id: id });

							that.data.items.splice(idx + 1, 0, that.data.items.splice(idx, 1)[0]);

							that.utils.saveData(that.data);
						}
					});
				})
				.on("focusout.tasks", ".item.edit .due-date", function() {
					if (this.value) {
						var date = moment(this.value);

						if (!date.isValid()) {
							date = moment(this.value, "MMMM D YYYY");
						}

						this.value = date.format("MMMM Do YYYY");
					}
				})
				.on("change.tasks", ".item .check", function() {
					var check = this,
						id = this.parentNode.getAttribute("data-id");

					oAuth.ajax({
						type: "PATCH",
						url: "https://www.googleapis.com/tasks/v1/lists/" + that.config.list + "/tasks/" + id + "?fields=id",
						data: JSON.stringify({
							status: this.checked ? "completed" : "needsAction",
							completed: this.checked ? new Date() : null
						}),
						contentType: "application/json",
						complete: function(xhr) {
							if (xhr.status !== 200) {
								check.checked = false;
							}
							else {
								that.findItem(id).done = check.checked;
								that.utils.saveData(that.data);
							}
						}
					});
				});
		}
	};
});
define('lib/cryptojs',[], function() {
    if (!window.cryptojs)
    {
        /*
            CryptoJS v3.1.2
            code.google.com/p/crypto-js
            (c) 2009-2013 by Jeff Mott. All rights reserved.
            code.google.com/p/crypto-js/wiki/License
        */
        /* jshint ignore:start */
        var CryptoJS=CryptoJS||function(g,l){var e={},d=e.lib={},m=function(){},k=d.Base={extend:function(a){m.prototype=this;var c=new m;a&&c.mixIn(a);c.hasOwnProperty("init")||(c.init=function(){c.$super.init.apply(this,arguments)});c.init.prototype=c;c.$super=this;return c},create:function(){var a=this.extend();a.init.apply(a,arguments);return a},init:function(){},mixIn:function(a){for(var c in a)a.hasOwnProperty(c)&&(this[c]=a[c]);a.hasOwnProperty("toString")&&(this.toString=a.toString)},clone:function(){return this.init.prototype.extend(this)}},
        p=d.WordArray=k.extend({init:function(a,c){a=this.words=a||[];this.sigBytes=c!=l?c:4*a.length},toString:function(a){return(a||n).stringify(this)},concat:function(a){var c=this.words,q=a.words,f=this.sigBytes;a=a.sigBytes;this.clamp();if(f%4)for(var b=0;b<a;b++)c[f+b>>>2]|=(q[b>>>2]>>>24-8*(b%4)&255)<<24-8*((f+b)%4);else if(65535<q.length)for(b=0;b<a;b+=4)c[f+b>>>2]=q[b>>>2];else c.push.apply(c,q);this.sigBytes+=a;return this},clamp:function(){var a=this.words,c=this.sigBytes;a[c>>>2]&=4294967295<<
        32-8*(c%4);a.length=g.ceil(c/4)},clone:function(){var a=k.clone.call(this);a.words=this.words.slice(0);return a},random:function(a){for(var c=[],b=0;b<a;b+=4)c.push(4294967296*g.random()|0);return new p.init(c,a)}}),b=e.enc={},n=b.Hex={stringify:function(a){var c=a.words;a=a.sigBytes;for(var b=[],f=0;f<a;f++){var d=c[f>>>2]>>>24-8*(f%4)&255;b.push((d>>>4).toString(16));b.push((d&15).toString(16))}return b.join("")},parse:function(a){for(var c=a.length,b=[],f=0;f<c;f+=2)b[f>>>3]|=parseInt(a.substr(f,
        2),16)<<24-4*(f%8);return new p.init(b,c/2)}},j=b.Latin1={stringify:function(a){var c=a.words;a=a.sigBytes;for(var b=[],f=0;f<a;f++)b.push(String.fromCharCode(c[f>>>2]>>>24-8*(f%4)&255));return b.join("")},parse:function(a){for(var c=a.length,b=[],f=0;f<c;f++)b[f>>>2]|=(a.charCodeAt(f)&255)<<24-8*(f%4);return new p.init(b,c)}},h=b.Utf8={stringify:function(a){try{return decodeURIComponent(escape(j.stringify(a)))}catch(c){throw Error("Malformed UTF-8 data");}},parse:function(a){return j.parse(unescape(encodeURIComponent(a)))}},
        r=d.BufferedBlockAlgorithm=k.extend({reset:function(){this._data=new p.init;this._nDataBytes=0},_append:function(a){"string"==typeof a&&(a=h.parse(a));this._data.concat(a);this._nDataBytes+=a.sigBytes},_process:function(a){var c=this._data,b=c.words,f=c.sigBytes,d=this.blockSize,e=f/(4*d),e=a?g.ceil(e):g.max((e|0)-this._minBufferSize,0);a=e*d;f=g.min(4*a,f);if(a){for(var k=0;k<a;k+=d)this._doProcessBlock(b,k);k=b.splice(0,a);c.sigBytes-=f}return new p.init(k,f)},clone:function(){var a=k.clone.call(this);
        a._data=this._data.clone();return a},_minBufferSize:0});d.Hasher=r.extend({cfg:k.extend(),init:function(a){this.cfg=this.cfg.extend(a);this.reset()},reset:function(){r.reset.call(this);this._doReset()},update:function(a){this._append(a);this._process();return this},finalize:function(a){a&&this._append(a);return this._doFinalize()},blockSize:16,_createHelper:function(a){return function(b,d){return(new a.init(d)).finalize(b)}},_createHmacHelper:function(a){return function(b,d){return(new s.HMAC.init(a,
        d)).finalize(b)}}});var s=e.algo={};return e}(Math);
        (function(){var g=CryptoJS,l=g.lib,e=l.WordArray,d=l.Hasher,m=[],l=g.algo.SHA1=d.extend({_doReset:function(){this._hash=new e.init([1732584193,4023233417,2562383102,271733878,3285377520])},_doProcessBlock:function(d,e){for(var b=this._hash.words,n=b[0],j=b[1],h=b[2],g=b[3],l=b[4],a=0;80>a;a++){if(16>a)m[a]=d[e+a]|0;else{var c=m[a-3]^m[a-8]^m[a-14]^m[a-16];m[a]=c<<1|c>>>31}c=(n<<5|n>>>27)+l+m[a];c=20>a?c+((j&h|~j&g)+1518500249):40>a?c+((j^h^g)+1859775393):60>a?c+((j&h|j&g|h&g)-1894007588):c+((j^h^
        g)-899497514);l=g;g=h;h=j<<30|j>>>2;j=n;n=c}b[0]=b[0]+n|0;b[1]=b[1]+j|0;b[2]=b[2]+h|0;b[3]=b[3]+g|0;b[4]=b[4]+l|0},_doFinalize:function(){var d=this._data,e=d.words,b=8*this._nDataBytes,g=8*d.sigBytes;e[g>>>5]|=128<<24-g%32;e[(g+64>>>9<<4)+14]=Math.floor(b/4294967296);e[(g+64>>>9<<4)+15]=b;d.sigBytes=4*e.length;this._process();return this._hash},clone:function(){var e=d.clone.call(this);e._hash=this._hash.clone();return e}});g.SHA1=d._createHelper(l);g.HmacSHA1=d._createHmacHelper(l)})();
        (function(){var g=CryptoJS,l=g.enc.Utf8;g.algo.HMAC=g.lib.Base.extend({init:function(e,d){e=this._hasher=new e.init;"string"==typeof d&&(d=l.parse(d));var g=e.blockSize,k=4*g;d.sigBytes>k&&(d=e.finalize(d));d.clamp();for(var p=this._oKey=d.clone(),b=this._iKey=d.clone(),n=p.words,j=b.words,h=0;h<g;h++)n[h]^=1549556828,j[h]^=909522486;p.sigBytes=b.sigBytes=k;this.reset()},reset:function(){var e=this._hasher;e.reset();e.update(this._iKey)},update:function(e){this._hasher.update(e);return this},finalize:function(e){var d=
        this._hasher;e=d.finalize(e);d.reset();return d.finalize(this._oKey.clone().concat(e))}})})();
        (function(){var h=CryptoJS,i=h.lib.WordArray;h.enc.Base64={stringify:function(b){var e=b.words,f=b.sigBytes,c=this._map;b.clamp();for(var b=[],a=0;a<f;a+=3)for(var d=(e[a>>>2]>>>24-8*(a%4)&255)<<16|(e[a+1>>>2]>>>24-8*((a+1)%4)&255)<<8|e[a+2>>>2]>>>24-8*((a+2)%4)&255,g=0;4>g&&a+0.75*g<f;g++)b.push(c.charAt(d>>>6*(3-g)&63));if(e=c.charAt(64))for(;b.length%4;)b.push(e);return b.join("")},parse:function(b){var b=b.replace(/\s/g,""),e=b.length,f=this._map,c=f.charAt(64);c&&(c=b.indexOf(c),-1!=c&&(e=c));
        for(var c=[],a=0,d=0;d<e;d++)if(d%4){var g=f.indexOf(b.charAt(d-1))<<2*(d%4),h=f.indexOf(b.charAt(d))>>>6-2*(d%4);c[a>>>2]|=(g|h)<<24-8*(a%4);a++}return i.create(c,a)},_map:"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/="}})();
        /* jshint ignore:end */

        window.cryptojs = CryptoJS;
    }
    
    return window.cryptojs;
});
/*
 * The Twitter widget.
 */
define('w/twitter',["jquery", "moment", "browser/api", "lib/cryptojs"], function($, moment, Browser, CryptoJS) {
	return {
		id: 26,
		sort: 200,
		size: 1,
		order: 15,
		interval: 300000,
		nicename: "twitter",
		sizes: ["variable"],
		settings: [
			{
				type: "text",
				nicename: "title",
				label: "i18n.settings.title",
				placeholder: "i18n.settings.title_placeholder"
			},
			{
				type: "select",
				nicename: "source",
				label: "i18n.settings.source",
				options: "getSources"
			},
			{
				type: "number",
				nicename: "tweets",
				label: "i18n.settings.show",
				min: 1,
				max: 10
			}
		],
		config: {
			source: "home",
			title: "i18n.name",
			size: "variable",
			tweets: "5"
		},
		data: {
			tweets: [
				{
					id: "453275760728367104",
					content: "Video: What are Games Developers looking for in the Cloud? <a href=\"http://t.co/V4qdADsn5m\" target=\"_blank\">goo.gl/R9Strw</a>  /by <a href=\"http://www.twitter.com/tekgrrl\" target=\"_blank\" title=\"Mandy Waite\">@tekgrrl</a> <a href=\"http://www.twitter.com/search?q=%23gaming&amp;src=hash\" target=\"_blank\">#gaming</a> <a href=\"http://www.twitter.com/search?q=%23cloud&amp;src=hash\" target=\"_blank\">#cloud</a> <a href=\"http://www.twitter.com/search?q=%23developers&amp;src=hash\" target=\"_blank\">#developers</a>",
					user: "Google Developers",
					username: "googledevs",
					image: "https://pbs.twimg.com/profile_images/440636713354817536/I_Z3SDmE_normal.png",
					age: 1396904337000
				},
				{
					id: "453275245143916545",
					content: "Explore archives &amp; exhibits about Tezuka Osamu, the godfather of <a href=\"http://www.twitter.com/search?q=%23manga&amp;src=hash\" target=\"_blank\">#manga</a>. <a href=\"http://t.co/QyYNRCnmuf\" target=\"_blank\">goo.gl/LeHLIa</a>",
					user: "A Googler",
					username: "google",
					image: "https://pbs.twimg.com/profile_images/2504370963/6u5qf6cl9jtwew6poxcj_normal.png",
					age: 1396904214000
				},
				{
					id: "453238414838493185",
					content: "New video from <a href=\"http://www.twitter.com/ade_oshineye\" target=\"_blank\" title=\"Adewale Oshineye\">@ade_oshineye</a>: Grow with Google(+) <a href=\"http://t.co/uuyw94RFFh\" target=\"_blank\">goo.gl/5lU7Hs</a>",
					user: "Google Developers",
					username: "googledevs",
					image: "https://pbs.twimg.com/profile_images/440636713354817536/I_Z3SDmE_normal.png",
					age: 1396895433000
				},
				{
					id: "452513890287370241",
					content: "RT <a href=\"http://www.twitter.com/jaffathecake\" target=\"_blank\" title=\"Jake Archibald\">@jaffathecake</a>: The Extensible Web Summit was bloody great &amp; should be done again. Notes at <a href=\"http://t.co/wdQIaH9G6i\" target=\"_blank\">lanyrd.com/2014/extensibl…</a> - nice one <a href=\"http://www.twitter.com/torgo\" target=\"_blank\" title=\"Daniel Appelquist\">@torgo</a> <a href=\"http://www.twitter.com/annevk\" target=\"_blank\" title=\"Anne van Kesteren\">@annevk</a> <a href=\"http://www.twitter.com/domenic\" target=\"_blank\" title=\"Domenic Denicola\">@domenic</a> et al",
					user: "Google Developers",
					username: "googledevs",
					image: "https://pbs.twimg.com/profile_images/440636713354817536/I_Z3SDmE_normal.png",
					age: 1396722693000
				},
				{
					id: "452161945513103360",
					content: "RT <a href=\"http://www.twitter.com/addyosmani\" target=\"_blank\" title=\"Addy Osmani\">@addyosmani</a>: Writing Accessible Web Components: <a href=\"http://t.co/Tlkl7ucRsK\" target=\"_blank\">polymer-project.org/articles/acces…</a> - Part 1 of a new guide by <a href=\"http://www.twitter.com/sundress\" target=\"_blank\" title=\"Alice Boxhall\">@sundress</a> and I. <a href=\"http://www.twitter.com/search?q=%23a11y&amp;src=hash\" target=\"_blank\">#a11y</a>",
					user: "Google Developers",
					username: "googledevs",
					image: "https://pbs.twimg.com/profile_images/440636713354817536/I_Z3SDmE_normal.png",
					age: 1396638783000
				}
			]
		},
		getSources: function(cb) {
			if (!this.config.token) {
				return cb({ "home": this.utils.translate("authorize") });
			}

			this.ajax({
				type: "GET",
				url: "https://api.twitter.com/1.1/lists/list.json",
				success: function(d) {
					var sources = {
						home: this.utils.translate("home"),
						mentions: this.utils.translate("mentions"),
						retweets: this.utils.translate("retweets")
					};

					if (d && d.length) {
						sources.lists = {
							label: this.utils.translate("lists")
						};

						d.forEach(function(e) {
							sources.lists[e.id_str] = e.name;
						});
					}

					cb(sources);
				}.bind(this)
			});
		},
		authorize: function(e) {
			e.preventDefault();

			var getFinal = function(token, secret, verifier) {
				this.ajax({
					type: "POST",
					data: {
						oauth_verifier: verifier
					},
					url: "https://api.twitter.com/oauth/access_token",
					success: function(d) {
						if (d && d.indexOf("&") !== -1) {
							var t = d.split("&"),
								token = "",
								secret = "";

							t.forEach(function(e) {
								var split = e.split("=");

								if (split[0] === "oauth_token") {
									token = split[1];
								}
								else if (split[0] === "oauth_token_secret") {
									secret = split[1];
								}
							});

							if (token && secret) {
								this.config.token = token;
								this.config.secret = secret;

								this.utils.saveConfig(this.config);

								this.refresh();
							}
						}
					}.bind(this)
				}, token, secret);
			}.bind(this);

			this.ajax({
				type: "POST",
				data: {
					oauth_callback: "https://www.ichro.me/twitter_redirect"
				},
				url: "https://api.twitter.com/oauth/request_token",
				success: function(d) {
					if (d && d.indexOf("&") !== -1) {
						var t = d.split("&"),
							token = "",
							secret = "";

						t.forEach(function(e) {
							var split = e.split("=");

							if (split[0] === "oauth_token") {
								token = split[1];
							}
							else if (split[0] === "oauth_token_secret") {
								secret = split[1];
							}
						});

						if (token && secret) {
							var a = document.createElement("a");

							a.target = "_blank";
							a.href = "https://api.twitter.com/oauth/authorize?oauth_token=" + token;

							a.click();

							Browser.webRequest.onBeforeRequest.addListener(
								function extract(info) {
									Browser.webRequest.onBeforeRequest.removeListener(extract);

									var verifier = info.url.match(/[&\?]oauth_verifier=([^&]+)/)[1];

									if (verifier) {
										getFinal(token, secret, verifier);

										Browser.tabs.remove(info.tabId);
									}
								},
								{
									urls: [ "https://www.ichro.me/twitter_redirect*" ]
								},
								["blocking", "requestBody"]
							);
						}
					}
				}
			}, false);
		},
		ajax: function(options, t, s) {
			var token = t || this.config.token || "",
				secret = s || this.config.secret || "";

			var method = (options.type || "GET").toUpperCase(),
				code = "",
				key, url,
				parameters = {};

			// Parse parameters
			if (options.data) {
				url = options.url;
				parameters = options.data;
			}
			else {
				url = options.url.split("?");

				((url && url[1]) || "").split("&").forEach(function(e) {
					var param = e.split("=");

					if (param[0]) {
						parameters[param[0]] = param[1] || "";
					}
				});

				url = url[0];
			}

			// Generate nonce
			for (var i = 0; i < 33; i++) {
				code += Math.floor((Math.random() * 100) % 10);
			}

			// Set parameters
			var consumer_key = "nYjEzkjKdyWotLXmbSjjA",
				nonce = encodeURIComponent(btoa(code)),
				timestamp = Math.floor(new Date().getTime() / 1000);

			token = encodeURIComponent(token);

			var params = [
				"oauth_consumer_key=" + consumer_key,
				"oauth_nonce=" + nonce,
				"oauth_signature_method=HMAC-SHA1",
				"oauth_timestamp=" + timestamp,
				"oauth_version=1.0",
				"oauth_token=" + (token || "")
			];

			// Encode parameters
			for (key in parameters) {
				if (parameters.hasOwnProperty(key)) {
					params.push(encodeURIComponent(key) + "=" + encodeURIComponent(parameters[key]));
				}
			}

			// Build base string
			var baseString = method + "&" + encodeURIComponent(url) + "&" +
				encodeURIComponent(params.sort(function(a, b) { return a < b ? -1 : a > b; }).join("&"));

			// Generate signature
			var signature = CryptoJS.HmacSHA1(baseString, "SLttwt44jAhngHqY2ALRzKT4M1uUzna3leJEak5fCCc" + "&" + encodeURIComponent(secret)).toString(CryptoJS.enc.Base64);

			// Generate OAuth header
			options.beforeSend = function(xhr) {
				xhr.setRequestHeader("Authorization", 'OAuth ' +
					'oauth_consumer_key="' + consumer_key + '", ' +
					'oauth_nonce="' + nonce + '", ' +
					'oauth_signature="' + encodeURIComponent(signature) + '", ' +
					'oauth_signature_method="HMAC-SHA1", ' +
					'oauth_timestamp="' + timestamp + '", ' +
					'oauth_token="' + (token || "") + '", ' +
					'oauth_version="1.0"');

			};

			// Send request
			return $.ajax(options);
		},
		refresh: function() {
			if (!this.config.token) {
				return this.render("authorize");
			}

			var url = "",
				source = this.config.source;

			if (source === "home" || !source) {
				url = "https://api.twitter.com/1.1/statuses/home_timeline.json?tweet_mode=extended&";
			}
			else if (source === "retweets") {
				url = "https://api.twitter.com/1.1/statuses/retweets_of_me.json?tweet_mode=extended&";
			}
			else if (source === "mentions") {
				url = "https://api.twitter.com/1.1/statuses/mentions_timeline.json?tweet_mode=extended&";
			}
			else {
				url = "https://api.twitter.com/1.1/lists/statuses.json?tweet_mode=extended&list_id=" + source + "&";
			}

			this.ajax({
				type: "GET",
				url: url + "count=" + (this.config.tweets || 5),	
				success: function(d) {
					var tweets = [];

					if (d && d.forEach) {
						var hEscape = function(str) {
							str = String(str || "");

							// Based off of Hogan.js' escape method
							var amp		= /&/g,
								lt		= /</g,
								gt		= />/g,
								apos	= /\'/g,
								quot	= /\"/g,
								brace	= /\{/g,
								all		= /[&<>\{\"\']/;

							if (all.test(str)) {
								return str.replace(amp, "&amp;").replace(lt, "&lt;").replace(gt, "&gt;").replace(apos, "&#39;").replace(quot, "&quot;").replace(brace, "&#123;");
							}
							else {
								return str;
							}
						};

						d.forEach(function(e) {
							var retweet = e.retweeted_status || false;

							var tweet = {
								id: e.id_str,
								content: (retweet ? (retweet.full_text ? retweet.full_text : retweet.text) : (e.full_text ? e.full_text : e.text)),
								user: e.user.name,
								username: e.user.screen_name,
								image: e.user.profile_image_url_https,
								age: moment(e.created_at).toDate().getTime()
							};

							var replaces = [];

							(retweet ? retweet.entities : e.entities).hashtags.forEach(function(e) {
								replaces.push({
									loc: e.indices,
									text: '<a href="http://www.twitter.com/search?q=%23' +
												hEscape(encodeURIComponent(e.text)) +
											'&amp;src=hash" target="_blank">#' +
												hEscape(e.text) +
											'</a>'
								});
							});

							(retweet ? retweet.entities : e.entities).urls.forEach(function(e) {
								replaces.push({
									loc: e.indices,
									text: '<a href="' + hEscape(e.url) + '" target="_blank">' + hEscape(e.display_url) + '</a>'
								});
							});

							(retweet ? retweet.entities : e.entities).user_mentions.forEach(function(e) {
								replaces.push({
									loc: e.indices,
									text: '<a href="http://www.twitter.com/' +
												hEscape(encodeURIComponent(e.screen_name)) +
											'" target="_blank" title="' +
												hEscape(e.name) +
											'">@' + hEscape(e.screen_name) + '</a>'
								});
							});

							replaces.sort(function(a, b) {
								return b.loc[1] - a.loc[1];
							});

							replaces.forEach(function(e) {
								tweet.content = tweet.content.substr(0, e.loc[0]) + e.text + tweet.content.substr(e.loc[1]);
							});

							if (retweet) {
								tweet.content = 'RT <a href="http://www.twitter.com/' +
												hEscape(encodeURIComponent(retweet.user.screen_name)) +
											'" target="_blank" title="' +
												hEscape(retweet.user.name) +
											'">@' + hEscape(retweet.user.screen_name) + '</a>: ' + tweet.content;
							}

							tweets.push(tweet);
						});

						this.data = {
							tweets: tweets
						};

						this.render();

						this.utils.saveData(this.data);
					}
				}.bind(this)
			});
		},
		render: function(key) {
			if (key === "authorize" || (!this.config.token && !key)) {
				this.utils.render({
					authorize: true,
					title: (this.config.title && this.config.title !== "" ? this.config.title : false)
				});

				return this.elm.find(".authorize").on("click", this.authorize.bind(this));
			}

			var data = $.extend(true, {}, this.data);

			data.tweets.forEach(function(e) {
				e.age = moment(e.age).fromNow(true)
							.replace(" years", "y").replace(" months", "mth")
							.replace(" weeks", "w").replace(" days", "d")
							.replace(" hours", "h").replace(" minutes", "m")
							.replace("a year", "1y").replace("a month", "1mth")
							.replace("a week", "1w").replace("a day", "1d")
							.replace("an hour", "1h").replace("a minute", "1m")
							.replace("a few seconds", "5s").replace("a second", "1s")
							.replace(" seconds", "s");
			});

			if (this.config.title && this.config.title !== "") {
				data.title = this.config.title;
			}

			this.utils.render(data);
		}
	};
});
/*
 * The Wolfram|Alpha widget.
 */
define('w/wolfram',[],function() {
	return {
		id: 5,
		sort: 410,
		size: 1,
		order: 32,
		nicename: "wolfram",
		sizes: ["small"],
		config: {
			size: "small"
		},
		render: function() {
			this.utils.render();
			this.elm.addClass("tabbed");
		}
	};
});
/*
 * The Youtube widget.
 */
define('w/youtube',["lodash", "jquery", "moment"], function(_, $, moment) {
	var abbreviate = function(num, min, precision) {
		var newValue = num;

		min = min || 1000;
		precision = precision || 3;

		if (num >= min) {
			var suffixes = ["", "K", "M", "B","T"],
				suffixNum = Math.floor((("" + parseInt(num)).length - 1) / 3),
				shortValue = "";

			for (var length = precision; length >= 1; length--) {
				shortValue = parseFloat((suffixNum !== 0 ? (num / Math.pow(1000, suffixNum)) : num).toPrecision(length));

				var dotLessShortValue = (shortValue + "").replace(/[^A-z0-9 ]+/g, "");

				if (dotLessShortValue.length <= precision) {
					break;
				}
			}

			if (shortValue % 1 !== 0) {
				shortValue = shortValue.toFixed(1);
			}

			newValue = shortValue + suffixes[suffixNum];
		}
		else {
			newValue = newValue.toLocaleString();
		}

		return newValue;
	};

	return {
		id: 29,
		sort: 300,
		size: 6,
		order: 18,
		interval: 300000,
		nicename: "youtube",
		sizes: ["variable"],
		settings: [
			{
				type: "text",
				nicename: "title",
				label: "i18n.settings.title",
				placeholder: "i18n.settings.title_placeholder"
			},
			{
				type: "select",
				nicename: "view",
				label: "i18n.settings.format",
				options: {
					large: "i18n.settings.format_options.large",
					large_2: "i18n.settings.format_options.large_2",
					large_4: "i18n.settings.format_options.large_4",
					four: "i18n.settings.format_options.four",
					six: "i18n.settings.format_options.six",
				}
			},
			{
				type: "text",
				nicename: "user",
				label: "i18n.settings.from",
				help: "i18n.settings.from_help",
				placeholder: "i18n.settings.from_placeholder"
			},
			{
				type: "radio",
				nicename: "target",
				label: "i18n.settings.open",
				options: {
					_self: "i18n.settings.open_options.current",
					_blank: "i18n.settings.open_options.blank"
				}
			}
		],
		config: {
			title: "i18n.name",
			size: "variable",
			view: "large_2",
			target: "_self",
			user: ""
		},
		data: {
			videos: [
				{
					title: "Official Extended Trailer | GOTHAM | FOX BROADCASTING",
					url: "https://www.youtube.com/watch?v=0d1zpt6k5OI&feature=youtube_gdata",
					uploader: "FOX",
					duration: "2:07",
					thumb: "https://i1.ytimg.com/vi/0d1zpt6k5OI/0.jpg",
					views: 1143620
				},
				{
					title: "Rick Grimes vs Walter White.  Epic Rap Battles of History Season 3.",
					url: "https://www.youtube.com/watch?v=krQHQvtIr6w&feature=youtube_gdata",
					views: 2980000,
					uploader: "ERB",
					duration: "2:18",
					thumb: "https://i1.ytimg.com/vi/krQHQvtIr6w/0.jpg"
				},
				{
					title: "Usher - Good Kisser",
					url: "https://www.youtube.com/watch?v=1lQtoRFaLsA&feature=youtube_gdata",
					views: 790000,
					uploader: "UsherVEVO",
					duration: "5:04",
					thumb: "https://i1.ytimg.com/vi/1lQtoRFaLsA/0.jpg"
				},
				{
					title: "Linkin Park - \"Until It's Gone\" [Official Lyric Video]",
					url: "https://www.youtube.com/watch?v=Nym1P-BO_ws&feature=youtube_gdata",
					views: 714000,
					uploader: "Linkin Park",
					duration: "3:41",
					thumb: "https://i1.ytimg.com/vi/Nym1P-BO_ws/0.jpg"
				},
				{
					title: "Internet Citizens: Defend Net Neutrality",
					url: "https://www.youtube.com/watch?v=wtt2aSV8wdw&feature=youtube_gdata",
					views: 368000,
					uploader: "CGP Grey",
					duration: "3:34",
					thumb: "https://i1.ytimg.com/vi/wtt2aSV8wdw/0.jpg"
				}
			]
		},
		refresh: function() {
			var that = this;

			var url = "https://www.googleapis.com/youtube/v3/";

			if (this.config.user && this.config.user.trim() !== "") {
				if (!this.config.resolvedId || this.config.resolvedUser !== this.config.user) {
					return $.get(url + "channels?part=contentDetails&forUsername=" + encodeURIComponent(this.config.user) + "&fields=items/contentDetails/relatedPlaylists/uploads&maxResults=1&key=AIzaSyBWWt5WxgH6uX2Q39CkPdJqm4RVIPidJeo", function(d) {
						try {
							this.config.resolvedId = d.items[0].contentDetails.relatedPlaylists.uploads;

							this.config.resolvedUser = this.config.user;
						}
						catch (e) {
							delete this.config.resolvedId;

							delete this.config.resolvedUser;

							this.config.user = "";
						}

						this.refresh();
					}.bind(this));
				}

				url += "playlistItems?playlistId=" + encodeURIComponent(this.config.resolvedId) + "&part=snippet&fields=items(id,snippet(title,description,thumbnails/high/url,resourceId/videoId,channelTitle))";
			}
			else {
				url += "videos?part=snippet,statistics,contentDetails&chart=mostPopular&regionCode=us&fields=items(id,snippet(title,description,thumbnails/high/url,channelTitle),statistics/viewCount,contentDetails/duration)";
			}

			url += "&maxResults=6&key=AIzaSyBWWt5WxgH6uX2Q39CkPdJqm4RVIPidJeo";


			$.get(url, function(d) {
				if (d && d.items && d.items.length) {
					var videos = d.items.map(function(e) {
						var d = e.contentDetails && e.contentDetails.duration && moment.duration(e.contentDetails.duration);

						return {
							title: e.snippet.title,
							uploader: e.snippet.channelTitle,
							description: e.snippet.description,
							views: parseInt((e.statistics && e.statistics.viewCount) || 0),
							thumb: (e.snippet && e.snippet.thumbnails && e.snippet.thumbnails.high && e.snippet.thumbnails.high.url) || "",
							duration: (d ? (d.hours() ? d.hours() + ":" + _.padLeft(d.minutes(), 2, "0") : d.minutes()) + ":" + _.padLeft(d.seconds(), 2, "0") : "0:00"),
							url: "https://www.youtube.com/watch?v=" + encodeURIComponent((e.snippet && e.snippet.resourceId && e.snippet.resourceId.videoId) || e.id)
						};
					});

					that.data = {
						videos: videos
					};

					that.utils.saveData(that.data);

					that.render.call(that);
				}
			});
		},
		render: function() {
			var data = $.extend(true, {}, this.data);

			switch (this.config.view) {
				case "large":
					data.featured = data.videos.shift();

					delete data.videos;
				break;
				case "large_2":
					data.featured = data.videos.shift();

					data.videos.splice(2);
				break;
				case "large_4":
					data.featured = data.videos.shift();

					data.videos.splice(4);
				break;
				case "four":
					data.videos.splice(4);
				break;
				case "six":
					data.videos.splice(6);
				break;
			}

			if (this.config.title && this.config.title !== "") {
				data.title = this.config.title;
			}

			if (data.featured) {
				data.featured.views = data.featured.views.toLocaleString();
			}

			if (data.videos) {
				data.videos.forEach(function(e) {
					e.views = abbreviate(e.views);
				});
			}

			data.newTab = this.config.target === "_blank";

			this.utils.render(data);
		}
	};
});
define('fbanalytics',[],function() {
	var sdkReady = false,
		eventQueue = [],
		purchaseQueue = [],
		userType;

	(function(d, s, id){
		var js, fjs = d.getElementsByTagName(s)[0];
		if (d.getElementById(id)) {return;}
		js = d.createElement(s); js.id = id;
		js.src = "https://connect.facebook.net/en_US/sdk.js";
		fjs.parentNode.insertBefore(js, fjs);
	}(document, 'script', 'facebook-jssdk'));

	/* global FB */
	window.fbAsyncInit = function() {
		FB.init({
			appId: "1646068945432680",
			xfbml: false,
			version: "v2.10"
		});

		require(["lodash", "core/auth", "storage/storage", "browser/api"], function(_, Auth, Storage, Browser) {
			Storage.on("done", function() {
				userType = Auth.isPro ? "Pro" : Auth.adFree ? "Ad-free" : Auth.isSignedIn ? "Signed in" : "Anonymous";

				try {
					if (Auth.get("user")) {
						FB.AppEvents.setUserID(Auth.get("user"));
					}
					else {
						if (!Browser.storage.uuid) {
							function s4() { // jshint ignore:line
								return Math.floor((1 + Math.random()) * 0x10000).toString(16).substring(1);
							}

							Browser.storage.uuid = s4() + s4() + "-" + s4() + "-" + s4() + "-" + s4() + "-" + s4() + s4() + s4();
						}

						FB.AppEvents.setUserID(Browser.storage.uuid);
					}

					FB.AppEvents.updateUserProperties({
						"$user_type": userType
					});
				}
				catch (e) {}

				FB.AppEvents.setAppVersion(Browser.app.version + "-" + (Browser.app.newTab ? "nt" : "hp"));

				// This is all FB.AppEvents.activateApp() does, minus the userType parameter
				FB.AppEvents.logEvent("fb_mobile_activate_app", null, { userType: userType });

				// Again, the same as FB.AppEvents.logPageView()
				FB.AppEvents.logEvent(FB.AppEvents.EventNames.PAGE_VIEW, null, { userType: userType });

				sdkReady = true;

				api.FB = FB;

				_.each(eventQueue, function(e) {
					e[2] = e[2] || {};

					e[2].userType = userType;

					FB.AppEvents.logEvent(FB.AppEvents.EventNames[e[0]] || e[0], e[1], e[2]);
				});

				_.each(purchaseQueue, function(e) {
					e[2] = e[2] || {};

					e[2].userType = userType;

					FB.AppEvents.logPurchase(e[0], e[1], e[2]);
				});

				purchaseQueue = eventQueue = [];
			});
		});
	};


	var api = {
		logEvent: function(name, value, params) {
			if (sdkReady) {
				params = params || {};

				params.userType = userType;

				return FB.AppEvents.logEvent(FB.AppEvents.EventNames[name] || name, value, params);
			}

			eventQueue.push([name, value, params]);
		},
		logPurchase: function(amount, currency, params) {
			if (sdkReady) {
				params = params || {};

				params.userType = userType;

				return FB.AppEvents.logPurchase(amount, currency, params);
			}

			purchaseQueue.push([amount, currency, params]);
		}
	};

	return api;
});
define('i18n/locales',{"bn":{"lang_code":"bn","language":"বাংলা","extName":"ProductivityTab — Custom Homepage Dashboard","newtabName":"ProductivityTab — Custom New Tab Dashboard","extDescription":"A remarkably customizable personal homepage featuring 50+ widgets, breathtaking backgrounds and much more.","newtabDescription":"A customizable personal dashboard on your new tab page featuring 50+ widgets, breathtaking backgrounds and much more.","defaults":{"tab":"মূল পাতা","me":"আমি"},"remove_widget":"বাতিল","hide_banner":"Hide this banner","hide_ad":{"content":"Hey! We're not crazy about ads either, but we're only able to make ProductivityTab available and continue developing features for our free users (that's you!) by showing ads. If you'd like to support ProductivityTab directly and get rid of ads for free, we would really appreciate if you upgraded to our pro version","upgrade":"Upgrade","hide":"বিজ্ঞাপন লুকান"},"alert":{"default_button":"বাদ দিন","confirm_title":"আপনি কি নিশ্চিত যে আপনি এটি করতে চান?","confirm_continue":"চালিয়ে যান","confirm_cancel":"বাতিল"},"onboarding":{"modal":{"tagline":"All the sites and apps you use, in one place","wrong_extension":"Want ProductivityTab on your new tab page instead?","wrong_extension_newtab":"Want ProductivityTab on your home page instead?","wrong_extension_action":"এখানে ক্লিক করুন","about":"ProductivityTab's all about tabs and widgets","about_desc":"Tabs are pages filled with widgets - blocks that show things like the weather, news, and your email. You can customize most widgets and add as many as you want.","terms":"By checking, you agree to ProductivityTab's <a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\">Terms</a> and <a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\">Privacy Policy</a>","sign_in":"Sign in with your Google account","sign_in_desc":"Sign in with your Google account before getting started to securely save your changes online.","sign_in_desc2":"You can stay signed out if you want, but your page won't be saved online and you won't be able to access it from other computers.","sign_in_button":"গুগল দিয়ে সাইন ইন করুন","have_account":"দেখে মনে হচ্ছে আপনার ইতিমধ্যে একটি অ্যাকাউন্ট আছে!","have_account_desc":"All your tabs and widgets are ready to use!","get_started":"চলুন শুরু করা যাক!","get_started_desc":"You're good to go! Let's get your page set up."},"widgets":{"configure":"Let's configure a widget.","configure_desc":"Click the wrench to open a widget's <b>settings</b>.","configure_skip":"Skip Tutorial","settings":"Replace <b>Link URL</b> with your favorite site, then press <b>Save</b>.","move":"You can <b>reposition</b> widgets by clicking and dragging the three dots highlighted here.","remove":"To <b>delete</b>, simply click the red trash bin icon.","done":"বুঝেছি"},"settings":{"intro":"Now let’s add a new widget. This highlighted button is where you can access the Widget Menu.","instructions":"Click the new widget button on to open the widget menu!","skip":"এড়ান","tooltips":{"settings":"Change the way ProductivityTab looks and works","widgets":"Add new widgets - you can have as many as you want","editing":"Show or hide the editing buttons on widgets","links":"This is a list of links, add sites you use often in the settings","tabs":"এইগুলি হল আপনার ট্যাব। আপনি সেটিংসে আরো যোগ করতে পারেন","support":"এখানে আমাদের বার্তা দিন বা পর্যালোচনা লিখুন"},"finished":"এটাই!","finished_next":"Choose an option from the menu (try starting with <b>Widgets</b>) and set your page up!","finished_contact":"Use the support link if you need any help and we'll get back to you ASAP."}},"storage":{"signin":"Sign in with Google now to securely save and sync your configuration","signin_btn":"সাইন ইন করুন","signin_dismiss":"বাদ দিন","signin_confirm":{"title":"স্থানীয় উপাত্ত রাখবেন?","desc":"Would you like to keep your local data, and replace the configuration in your account with it, or replace this computer's configuration with the one already in your account?","keep_account":"একাউন্ট ব্যবহার করুন","keep_local":"স্থানীয় রাখুন"},"signout_confirm":"Signing out will erase your local backups","pastdue":"Your subscription is past due","pastdue_desc":"Please update your billing information in the settings"},"toolbar":{"placeholder":"আপনার অনুসন্ধানের শব্দ লিখুন","placeholder_ok":"আপনার শব্দ লিখুন বা \"OK, Google\" বলুন","suggestions":{"url_subtext":"Visit URL","capture_notice":"ProductivityTab handles searches you normally make from the Omnibox. You can disable this at any time from the settings"},"apps":{"search":"অনুসন্ধান","youtube":"ইউটিউব","maps":"মানচিত্র","play":"প্লে","news":"সংবাদ","gmail":"জিমেইল","drive":"ড্রাইভ","calendar":"পঞ্জিকা","more":"আরও"}},"menu":{"settings":"সেটিংস","widgets":"উইজেট","editing":"সম্পাদনা","editing_enabled":"সক্রিয়","editing_disabled":"নিষ্ক্রিয়","plus":"গুগল প্লাস","tabs":"ট্যাব","footer":{"support":"সমর্থন","feedback":"প্রতিক্রিয়া","review":"পর্যালোচনা","terms":"শর্তাবলী","privacy":"গোপনীয়তা","by":"Avi Kohn কর্তৃক"}},"voice":{"listening":"শুনছেন...","searching":"অনুসন্ধান করছেন: %s","missed":"এটা বুঝা যায়নি। <a>আবার চেষ্টা করুন</a>"},"settings":{"title":"সেটিংস","exit":"প্রস্থান সেটিংস","saved":"সেটিংস সংরক্ষণ করা হয়েছে","nav":{"visual":"চাক্ষুষ","visual_sections":{"background":"পটভূমি","layout":"লেআউট","theme":"অ্যাপ থিম","ad_placement":"Ad placement"},"toolbar":"সরঞ্জামদণ্ড","toolbar_sections":{"style":"শৈলী","search":"অনুসন্ধান","links":"সংযোগ"},"tabs":"ট্যাব","widgets":"উইজেট","ads":"বিজ্ঞাপন","pro":"Pro","accounts":"Account","misc":"Miscellaneous","advanced":"Advanced","advanced_sections":{"backups":"Backup and restore","css":"Custom CSS","debug_tools":"Debug tools"},"support":"Help and support","suggest":"Suggest a feature"},"visual":{"background":{"title":"পটভূমি","desc":"This is the image or set of images shown as a background to your tabs","current":"বর্তমান পটভূমি","custom":"স্বনির্ধারিত","unnamed":"থিম %s","select":"থিম নির্বাচন করুন","or":"অথবা","url_placeholder":"চিত্রের URL লিখুন"},"layout":{"title":"লেআউট","desc":"Here you can adjust the type and number of columns in each tab","columns":"কলাম","grid":"বর্গজালি","columns_number":"কলামের সংখ্যা","column_width":"কলামের প্রস্থ","column_width_fixed":"নির্ধারিত","column_width_fluid":"তরল","column_warning":{"column_to_grid":"Changing to a grid-based layout will move all of your widgets to the top left corner.","grid_to_column":"Changing to a column-based layout will move all of your widgets to the first column."}},"theme":{"title":"অ্যাপ থিম","desc":"The app theme controls the style of ProductivityTab itself and all widgets","preview":"প্রাকদর্শন","light":"Light (default)","dark":"গাঢ়","transparent":"স্বচ্ছ","transparent_darker":"স্বচ্ছ (কালো)"}},"toolbar":{"style":{"title":"শৈলী","desc":"This controls the style of the toolbar.  It can either appear normally or as an out of the way button","normal":"স্বাভাবিক","button":"বোতাম"},"search":{"title":"অনুসন্ধান","desc":"These settings control how the search box and voice search function","engine":"অনুসন্ধান ইঞ্জিন","engines_default":"পূর্ব-নির্ধারিত","engines_custom":"স্বনির্ধারিত","engines_custom_desc":"Enter a URL that queries should be sent to, with <b>%s</b> where the query should go.","omnibox_capture":"Handle searches normally made in the Omnibox","voice":"কন্ঠস্বর অনুসন্ধান সক্ষম করুন","ok_google":"Enable \"OK Google\" hotword detection","search_tab":"Open search results in a new tab"},"links":{"title":"সংযোগ","desc":"These are the items shown at the right of the toolbar","apps":"অ্যাপ মেনু","custom":"Custom links","custom_note1":"সর্বোচ্চ ৩টি মঞ্জুরিপ্রাপ্ত","custom_note2":"users get 8","custom_name_placeholder":"Link text","custom_url_placeholder":"Link URL, i.e. https://www.google.com/"}},"misc":{"link_tab":"Open links in a new tab by default"},"tabs":{"create_new":"নতুন তৈরি করুন","make_default":"Make default","desc1":"Tabs are pages inside ProductivityTab. Each tab has its own set of widgets that is completely separate from every other tab.","desc2":"You can switch between tabs by clicking the buttons that appear at the left and right of the screen when you move your mouse over a tab or by using the arrow keys on your keyboard.","name_placeholder":"ট্যাবের নাম লিখুন","delete_confirm":"This action is irreversible. All data from all widgets in the tab will be permanently lost."},"accounts":{"status":{"title":"অবস্থা","signed_in":"You are currently <b>signed in</b> as %s (%s).","reset_account":"Reset account","sign_out":"সাইন আউট","signed_out":"You are <b>not currently signed in</b>. Sign in with your Google account now to securely store and sync your configuration.","sign_in":"Sign in with Google"},"reset_confirm_desc":"This will erase all local and synced data, there is no backup and no way to undo this.","reset_confirm_desc2":"You will lose your entire current configuration on all computers connected to this account."},"advanced":{"backups":{"title":"Backup and restore","desc":"Backups are complete copies of all your tabs, settings, and widgets. They're automatically created when you first open ProductivityTab each day.","desc2":"Use the buttons below to roll ProductivityTab back to a particular date or download one of your backups.","backup":"Backup now","upload":"Restore from file","download":"ডাউনলোড","restore":"পুনঃস্থাপন","download_name":"ProductivityTab ব্যাকআপ","restore_confirm":"This will overwrite all local and synced data. You will lose your entire current configuration on all computers under this account.","restore_error":"An error occurred while trying to parse the provided data, please try again later."},"css":{"title":"স্বনির্ধারিত CSS","desc":"You can use CSS (<a href=\"https://developer.mozilla.org/en-US/docs/Web/CSS\" target=\"blank\">definition</a>) to customize almost any part of ProductivityTab.","placeholder":"Enter up to 1000 characters of CSS here"},"debug_tools":{"title":"Debug tools","desc":"<b>WARNING:</b> These tools can erase your entire configuration in a single click. Only use them if your developer instructs you to.","open":"Open tools"}},"widgets":{"desc1":"Widgets have their own settings and can't be customized here.","desc2":"To edit a widget's settings, follow these steps:","steps1":"Move your mouse over any widget","steps2":"Click the wrench icon that appears at the top right of the widget. If none appears then the widget doesn't have any settings that can be customized.","steps3":"Edit any of the settings shown in the dialog that's displayed","steps4":"Click Save to save your changes, or any part of the background to discard of them"},"pro":{"promo":{"monthly_price":"মাস প্রতি $4.99","yearly_price":"বা বছর প্রতি $29.99","upgrade_btn":"Upgrade Now","business":"Interested in buying Pro for your business or school?","business_contact":"আমাদের সাথে যোগাযোগ","themes":"থিমসমূহ","themes_desc":"See more of your backgrounds with dark and transparent themes","bgs":"Live backgrounds","bgs_desc":"Bring your page to life with 20 live high-definition backgrounds","widgets":"Maximizable widgets","widgets_desc":"Take ProductivityTab to another level with maximizable widgets","more_header":"And more","stocks":"Realtime stocks with extended and historical information","rss":"Support for multiple RSS feeds per widget","sports":"General and league-specific sports news","tabbed_widgets":"Tabbed news and RSS widgets","bg_downloads":"Downloadable backgrounds","weather":"Hourly weather forecasts up to 10 days out","toolbar":"More toolbar links","ads":"A completely ad-free experience","support":"Prioritized support and suggestions","buy_pro":"Pro কিনুন"},"checkout":{"title":"Checkout","updating_title":"হালনাগাদ পরিকল্পনা","payment_options":"Pay","pay_monthly":"মাসিক ($4.99)","pay_yearly":"বাত্সরিক ($29.99)","cancel":"বাতিল","update":"হালনাগাদ","subscribe":"সদস্যতা","braintree_notice":"Payments securely processed by Braintree.","monthly_notice":"By subscribing, you authorize ProductivityTab to charge you $4.99 every month until you cancel your subscription.","yearly_notice":"By subscribing, you authorize ProductivityTab to charge you $29.99 every year until you cancel your subscription.","update_notice":"Although billing cycle changes take effect immediately, you won't be charged until your current cycle ends.","thank_you":"Thank you for buying ProductivityTab Pro!","thank_you2":"ProductivityTab will reload in a few seconds and you'll be all set!","error":"Something went wrong while trying to process your payment.","error2":"Please try again later or email us at support@ichro.me","signin":"Sign in","signin_desc":"You need to sign in before buying Pro so we can make sure it's you","signin_btn":"Sign in"},"plan":{"title":"পরিকল্পনা","desc":"You are currently subscribed to ProductivityTab Pro (%s)","types":{"monthly":"মাসিক","yearly":"বাত্সরিক","business":"ব্যবসা","education":"শিক্ষা","custom":"স্বনির্ধারিত"},"uneditable_desc":"Business, education, and custom plans cannot be updated from within ProductivityTab. Please <a href=\"mailto:support@ichro.me\">contact us</a> to update or cancel your subscription.","status":"অবস্থা","status_active":"সক্রিয়","status_trial":"Trial","status_pastdue":"Past due","subscription_date":"Subscription date","paid_through":"Paid through","next_bill":"Next bill","next_bill_value":"$%s on %s","update_plan":"হালনাগাদ পরিকল্পনা","update_billing":"Update billing","cancel":"Cancel subscription","cancel_notice":"Your subscription will be canceled immediately","cancel_notice2":"If you would like a refund, please contact us at support@ichro.me"}},"ads":{"text1":"ProductivityTab displays a few small ads to pay for server, support and development costs. With these ads, we can afford to offer ProductivityTab free to everyone.","text2":"Here you can choose where those ads are shown, or buy ad-free to permanently remove them.","text3":"Ad-free is a one-time purchase that permanently removes ads from ProductivityTab wherever you're signed in. You can also upgrade to Pro for extra features in addition to an ad-free experience.","upgrade_btn":"Upgrade to ad-free","already_upgraded":"It looks like you've already upgraded to ad-free","signin":"Sign in","signin_desc":"Sign in before upgrading so we can link your purchase to your account","signin_btn":"Sign in","thank_you":"Thank you for upgrading to ad-free!","placement":{"title":"Ad placement","left":"In the leftmost column","right":"In the rightmost column","top":"Above the tab","bottom":"Floating at the bottom"}}},"store":{"installation":"ইনস্টলেশন","description":"বিবরণ","preview":"প্রাকদর্শন","instructions":"Drag and drop any size onto your homepage"},"widgets":{"sizes":{"tiny":"ক্ষুদ্র","small":"ছোট","medium":"মাঝারি","large":"বড়","variable":"Variable"},"settings":{"title":"উইজেট সেটিংস","save":"সংরক্ষণ","size":"উইজেটের আকার"},"minimize":"Minimize","maximize":"Maximize","delete_confirm":"Are you really sure you want to delete this widget?\r\nThis action is irreversible; all data from this widget will be permanently lost.","permissions_request":{"title":"Access required","button":"Grant Access","desc":"This widget needs extra permissions before it can be used. Grant them using the button below."},"error":{"explanation":"Something went wrong while we were trying to display this widget.","advice":"Try reinstalling the widget or reloading the page. Contact us if you see this message often.","support":"সমর্থন","refresh":"পুনঃসতেজ"},"auth":{"message":"You'll need to give this widget access to your account before you can use it.","button":"Grant Access"},"shared":{"settings":{"title":"উইজেটের শিরোনাম","title_placeholder":"উইজেটের একটি শিরোনাম লিখুন বা আড়াল করতে ফাঁকা রেখে দিন","height":"উইজেটের উচ্চতা","open_options":{"current":"বর্তমান ট্যাব","blank":"একটি নতুন ট্যাব"},"footer_link":"Footer Link","footer_link_options":{"show":"দেখান","hide":"লুকান"},"account":"Account ID","account_help":"If you're signed into multiple accounts, this is the \"authuser=\" value.\n<br /><br />\nFor example, if you're signed into two accounts, jsmith1@gmail.com and jsmith2@gmail.com, the \"authuser\" value for jsmith2@gmail.com would be 1 since it's the second account (counting from zero) that you're signed into.","account_placeholder":"আপনার \"authuser=\" মান","on":"চালু","off":"বন্ধ"}},"apps":{"name":"অ্যাপসমূহ","desc":"আপনার বর্তমানে ইনস্টল করা গুগল ক্রোম অ্যাপ্লিকেশনসমূহ প্রদর্শন করে।","settings":{"format":"উইজেটের বিন্যাস","format_options":{"tiles":"টালি","list":"তালিকা"},"display":"দেখান","display_options":{"all":"সব অ্যাপসমূহ","enabled":"শুধুমাত্র সক্রিয় অ্যাপসমূহ"},"sort":"বাছাই করুন","sort_options":{"id":"ID","alphabetically":"বর্ণানুক্রমে","offline":"অফলাইন সক্ষমিত","available":"প্রাপ্যতা"},"open":"এতে অ্যাপসমূহ খুলুন"},"store_app":"দোকান"},"bookmarks":{"name":"বুকমার্ক","desc":"নির্বাচিত এবং স্বনির্ধারিত বুকমার্ক ও অন্যান্য লিংক প্রদর্শন করে।","settings":{"title_placeholder":"উইজেটের একটি শিরোনাম লিখুন","layout":"লেআউট","layout_options":{"single":"একক কলাম","double":"দ্বৈত কলাম"},"open":"এতে বুকমার্ক খুলুন"},"edit":{"dialog_title":"বুকমার্ক সম্পাদনা","title":"বুকমার্কের শিরোনাম","title_placeholder":"গুগল","url":"বুকমার্ক URL","url_placeholder":"https://www.google.com.bd/","save":"সংরক্ষণ"},"new_caption":"নতুন","new_bookmark":"বুকমার্ক","new_folder":"ফোল্ডার","drop_link":"এখানে লিংক ছেড়ে দিন"},"chrome_bookmarks":{"name":"বুকমার্ক","desc":"ঐচ্ছিকভাবে একটি নির্দিষ্ট ফোল্ডার থেকে, আপনার ক্রোম বুকমার্কসসমূহ প্রদর্শন করে।","settings":{"title_placeholder":"উইজেটের একটি শিরোনাম লিখুন","from":"এ থেকে বুকমার্ক প্রদর্শন করান","open":"এতে বুকমার্ক খুলুন"}},"calc":{"name":"ক্যালকুলেটর","desc":"মৌলিক অপারেটরদের জন্য সমর্থনসহ একটি ক্যালকুলেটর প্রদর্শন করে।","error":"ত্রুটি!","infinity":"অসীম","mismatch":"বন্ধনী মেলেনি"},"calendar":{"name":"পঞ্জিকা","desc":"আপনার এক বা একাধিক গুগল পঞ্জিকা থেকে আসন্ন ঘটনাবলী প্রদর্শন করে।","settings":{"calendar":"পঞ্জিকা","show":"ইভেন্ট দেখান","show_options":{"all":"সব সময়ের","today":"শুধুমাত্র আজকের"}},"title":"Agenda","calendar":"পঞ্জিকা","noevents":"No events found in the near future, it looks like your schedule's clear!"},"clock":{"name":"ঘড়ি","desc":"Offers alarm, time, timer, and stopwatch functionality.","settings":{"timezone":"সময় অঞ্চল","timezone_local":"স্থানীয়","format":"ঘড়ির বিন্যাস","format_options":{"ampm":"পুর্বাহ্ন/অপরাহ্ন - ডিজিটাল","24hour":"২৪ ঘণ্টা - ডিজিটাল","analog":"১২ ঘণ্টা - এনালগ","ampmseconds":"পুর্বাহ্ন/অপরাহ্ন - ডিজিটাল, সেকেন্ডবিহীন","24hourseconds":"২৪ ঘণ্টা - ডিজিটাল, সেকেন্ডবিহীন"},"sound":"সতর্কতা শব্দ"},"title":"ঘড়ি","alarm":"অ্যালার্ম","clock":"ঘড়ি","timer":"সময় গণক","stopwatch":"বিরামঘড়ি","set":"নির্ধারন","unset":"Unset","dismiss":"Dismiss","enable_audio":"অডিও সক্রিয় করুন"},"facebook":{"name":"ফেসবুক","desc":"উইজেটে ফেসবুক এম্বেড করুন"},"feedly":{"name":"Feedly","desc":"Displays articles from your Feedly account in a configurable format.","settings":{"source":"নিবন্ধ দেখান","source_feeds":"ফীড","show":"দেখান","show_options":{"all":"সকল নিবন্ধ","unread":"শুধু অপঠিত নিবন্ধ"},"layout":"লেআউট","layout_options":{"titles":"শুধুমাত্র শিরোনাম","magazine":"পত্রিকা","cards":"কার্ড","cards_columns":"কার্ড (দুই কলাম)"},"mark":"একটি নিবন্ধ পঠিত হিসাবে চিহ্নিত করুন যখন আমি","mark_options":{"scroll":"এটিতে স্ক্রল বা এটিতে ক্লিক করি","click":"শুধু এটিতে ক্লিক করি"},"sort":"সজ্জাক্রম","sort_options":{"newest":"নবীনতম প্রথমে","oldest":"পুরনোতম প্রথমে"}},"all":"সব","saved":"পরের জন্য সংরক্ষিত","uncategorized":"শ্রেণীবিহীন","author":"কর্তৃক","go_to_feedly":"Feedly-এ যান"},"notes":{"name":"নোট","desc":"Inserts a simple, editable, note.","settings":{"color":"নোটের রঙ","color_options":{"yellow":"হলুদ","orange":"কমলা","red":"লাল","blue":"নীল","green":"সবুজ","white":"সাদা"},"font":"ফন্টের মুখ","fontsize":"ফন্টের মাপ"}},"now":{"name":"গুগল নাও","desc":"Displays cards from Google Now including flight status and package tracking.","authorize":"You'll need to give ProductivityTab permission to view your Google Now cards before anything will show up here.","authorize_btn":"অনুমোদন","caught_up":"All caught up, nothing here.","no_title":"কোন শিরোনাম নেই"},"plus":{"name":"গুগল+","desc":"Embeds Google Plus in a widget"},"notifications":{"name":"Google Notifications","desc":"Displays your Google Notifications from services such as Google+"},"reddit":{"name":"Reddit","desc":"Displays the top items on Reddit for any given subreddit.","settings":{"subreddit":"Subreddit","subreddit_help":"Enter any subreddit by the part past <b>/r/</b> when on Reddit.\n<br /><br />\nFor example, Technology is at: <a href=\"https://www.reddit.com/r/technology\">https://www.reddit.com/r/technology</a>, therefore you would enter <b>technology</b>","subreddit_placeholder":"Enter a subreddit to show links from. (i.e. technology)","sort":"সজ্জাক্রম","sort_options":{"hot":"গরম","top":"শীর্ষ","new":"নতুন","gilded":"Gilded","rising":"Rising","controversial":"বিতর্কিত"},"links":"Links Shown","click":"When I click a link show me","click_options":{"link":"The link","comments":"মন্তব্য"}},"more":"আরও"},"tasks":{"name":"কার্যসমূহ","desc":"Displays an editable list of tasks from one of your Google Tasks lists.","title":"কার্যসমূহ","settings":{"list":"তালিকা"},"task_title":"শিরোনাম","due_date":"Due date","notes":"নোট","add":"আইটেম যোগ করুন","delete_task":"Delete Task","move_up":"উপরে উঠান","move_down":"নিচে নামান","done":"সম্পন্ন","due_today":"Due today","overdue":"Overdue","authorize":"You'll need to select a list from your Google Tasks via the settings before anything can be displayed here."},"twitter":{"name":"টুইটার","desc":"Displays tweets from your home stream or a specified list.","settings":{"source":"Show Tweets from","show":"Tweets Shown"},"authorize":"You'll need to authorize ProductivityTab first","authorize_msg":"You'll need to give ProductivityTab permission to view tweets from your account before anything will show up here.","authorize_btn":"অনুমোদন","no_tweets":"There don't seem to be any tweets here...","home":"মূল পাতা","mentions":"উল্লেখ","retweets":"Retweets of me","lists":"তালিকা","more":"আরও","reply":"উত্তর দিন","retweet":"পুনঃটুইট","favorite":"পছন্দ"},"wolfram":{"name":"Wolfram|Alpha","desc":"Inserts a small Wolfram|Alpha search box."},"youtube":{"name":"ইউটিউব","desc":"Displays either popular videos or videos from a specified user.","settings":{"format":"বিন্যাস","format_options":{"large":"একটি বড়","large_2":"একটি বড়, দুটি ছোট","large_4":"একটি বড়, চারটি ছোট","four":"চারটি ছোট","six":"ছয়টি ছোট"},"from":"এ থেকে ভিডিও দেখান","from_help":"This must be an <b>exact</b> username as shown in the URL of the page when you're viewing their profile.\n<br /><br />\nThis value never includes spaces.","from_placeholder":"Leave blank to show Top Videos","open":"Open search results in"},"search":"ইউটিউবে অনুসন্ধান করুন","num_views":"বার দেখা"},"quotes":{"name":"উদ্ধৃতি","desc":"Displays a quote picked either every time you load the page or once daily.","settings":{"source":"উৎস","method":"নতুন উদ্ধৃতি লোড করুন","method_options":{"daily":"দৈনিক একবার","random":"প্রত্যেক বার আমি পৃষ্ঠা লোড করার সময়"}},"unknown_author":"অজানা"},"html":{"name":"HTML","desc":"Displays completely custom HTML in an iframe.","settings":{"html":"HTML","js":"JavaScript","height":"উইজেটের উচ্চতা"}},"sitelink":{"name":"Site Link","desc":"Displays a link, optionally with a title and thumbnail","settings":{"link":"Link URL","link_placeholder":"https://www.google.com.bd/","image":"চিত্রের URL","image_placeholder":"https://www.example.com/image.png","color":"Image Background Color","style":"Image Style","style_fill":"Fill","style_center":"কেন্দ্রে"}},"stats":{"name":"সিস্টেম পরিসংখ্যান","desc":"Keep an eye on your system with realtime statistics","memory":"মেমরি","battery":"ব্যাটারি","usage":"ব্যবহৃত","in_use":"in use","remaining":"অবশিষ্ট আছে","charged":"Fully Charged","idle":"Idle","charging":"Charging","discharging":"Discharging"},"search":{"name":"অনুসন্ধান","desc":"Embeds a search box in your page for easy access","settings":{"placeholder":"Search Field Placeholder","search_url":"URL অনুসন্ধান","param":"Query Parameter","param_placeholder":"The parameter where the query goes, i.e. \"q\""},"default_placeholder":"গুগল অনুসন্ধান"},"pushbullet":{"name":"Pushbullet","desc":"Keep track of notifications from your phone and other devices","no_pushes":"No pushes found","sign_in":"Sign in","no_key":"It doesn't look like you're signed in to Pushbullet.  Sign in now to connect this widget."},"linkedin":{"name":"LinkedIn","desc":"Displays your LinkedIn home stream"},"directions":{"name":"দিকনির্দেশনা","desc":"Get directions to and from nearly anywhere right from your homepage","driving":"Driving","transit":"পাবলিক পরিবহন","walking":"হাঁটা","cycling":"Cycling","from":"Enter a starting point","to":"Enter a destination","loading":"Loading directions, please wait...","error":"Something went wrong while trying to load the directions you requested.","error2":"Please check the start and destination addresses you entered.","open_in_maps":"গুগল মানচিত্রে খুলুন","via":"হয়ে"},"pocket":{"name":"পকেট","desc":"Display a list of your saved articles, videos, and web pages from Pocket","settings":{"links_shown":"Number of links shown","open":"Open links","open_pocket":"In Pocket","open_original":"At their original URL"},"by":"কর্তৃক","no_links":"No links found","grant_access":"Grant access","no_key":"You'll need to give ProductivityTab access to your Pocket account before it can load your links."}},"themes":{"title":"থিমসমূহ","all":"সব","custom":"স্বনির্ধারিত","create":"থিম তৈরি করুন","url_or_upload":"অথবা","upload_image":"ছবি আপলোড করুন","edit_btn":"সম্পাদনা","delete":"মুছে ফেলুন","use":"ব্যবহার","preview":"প্রাকদর্শন","author":"কর্তৃক","images":"%sটি চিত্র","resolution":"রেজল্যুশন","categories":"বিষয়শ্রেণীসমূহ","cached":"This theme has been cached and is available offline","random":"This theme displays a random image every time you load the page","random_daily":"This theme displays an image picked randomly every day","sunrise_sunset":"This theme displays an image based on the time of day","feed":"This theme displays an image selected daily from an external feed","video":"This theme displays a live video","pro_only":"This theme is only available to Pro users. Buy Pro in the settings.","delete_confirm":"Are you really sure you would like to delete this theme?\r\nThis action is irreversible; the entire theme will be permanently lost.","delete_error":"An error occurred while trying to delete the theme.  Please try again later.","feed_fetching":"Please wait, fetching feed...","feed_error":"Something went wrong while trying to fetch the feed.  Please try again later.","caching":"Please wait, caching theme...","cache_status":"%s of %s images cached","cache_error":"An error occurred while trying to cache the theme.  Please try again later","bginfo":{"view":"দেখুন","source":"উৎস","unknown":"অজানা","download":"ডাউনলোড","pro_only":"Only Pro users can download background images and videos"},"edit":{"title":"থিম সম্পাদনা করুন","create_title":"থিম তৈরি করুন","name":"থিমের নাম","default_name":"নতুন থিম","name_placeholder":"থিম নাম প্রবেশ করাএ","image":"চিত্রের URL","image_placeholder":"পটভূমি চিত্রের URL লিখুন","image_help":"Uploaded images <b>cannot be synced</b> between computers.<br /><br />If this is important to you, please upload your image to a service such as <a href=\"https://imgur.com/\" target=\"_blank\">imgur</a>. Then copy the URL ending with an extension (i.e. .jpg) and paste it into the field on the left.","color":"Fallback Color","color_placeholder":"যে কোন রঙের নাম লিখুন","position":"অবস্থান","position_options":{"center":"কেন্দ্রে","top_left":"উপরে বামে","top_center":"উপরে কেন্দ্রে","top_right":"উপরে ডানে","bottom_left":"নিচে বামে","bottom_center":"নিচে কেন্দ্রে","bottom_right":"নিচে ডানে"},"scaling":"Scaling","scaling_options":{"auto":"স্বয়ংক্রিয়","width":"পূর্ণ প্রস্থ","height":"পূর্ণ উচ্চতা","none":"No Scaling (preview may be inaccurate)"},"repeat":"Image Repeat","repeat_options":{"none":"No Repeat","horizontal":"Repeat Horizontally","vertical":"Repeat Vertically","both":"Repeat Both"},"attach":"Attach Image To","attach_tab":"ট্যাব","attach_window":"উইন্ডো","preview":"প্রাকদর্শন","save":"সংরক্ষণ ও বন্ধ করুন","cache_error":"An error occurred while trying to cache the image you provided, please double-check the URL.","upload_error":"An error occurred while trying to upload the file you provided, please make sure that it's a reasonable size and an image."}}},"ca":{"lang_code":"ca","language":"Català","extName":"ProductivityTab — Custom Homepage Dashboard","newtabName":"ProductivityTab — Custom New Tab Dashboard","extDescription":"A remarkably customizable personal homepage featuring 50+ widgets, breathtaking backgrounds and much more.","newtabDescription":"A customizable personal dashboard on your new tab page featuring 50+ widgets, breathtaking backgrounds and much more.","defaults":{"tab":"Inici","me":"Jo"},"remove_widget":"Treure","hide_banner":"Hide this banner","hide_ad":{"content":"Hey! We're not crazy about ads either, but we're only able to make ProductivityTab available and continue developing features for our free users (that's you!) by showing ads. If you'd like to support ProductivityTab directly and get rid of ads for free, we would really appreciate if you upgraded to our pro version","upgrade":"Upgrade","hide":"Hide ads"},"alert":{"default_button":"Ignorar","confirm_title":"Segur que ho vols fer?","confirm_continue":"Continuar","confirm_cancel":"Cancelar"},"onboarding":{"modal":{"tagline":"Tots els llocs webs i les apps que utilitzes, en un mateix lloc","wrong_extension":"Hi vols ProductivityTab a la pestanya nova?","wrong_extension_newtab":"Hi vols ProductivityTab a la pestanya nova?","wrong_extension_action":"Fes clic aquí","about":"Tot sobre pestanyes i widgets d'ProductivityTab","about_desc":"Les pestanyes són pàgines amb widgets - blocs que mostren coses com ara el temps, notícies i l'email. Es pot personalitzar la majoria dels widgets i afegir-ne tants com es vulgui.","terms":"Continuant, acceptes els <a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\">Termes</a> d' ProductivityTab i la <a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\">Política de privacitat</a>","sign_in":"Inicia sessió amb el teu compte de Google","sign_in_desc":"Inicia sessió amb el compte de Google abans de començar per guardar els canvis online.","sign_in_desc2":"Si vols pots continuar sense registrar-te, però la teva pàgina web no es desarà online i per tant no serà accessible des d'altres ordinadors.","sign_in_button":"Inicia la sessió amb Google","have_account":"Sembla que ja tens un compte!","have_account_desc":"Totes les teves pestanyes i widgets estan a punt per ser utilitzats!","get_started":"Comencem!","get_started_desc":"Estàs preparat per començar! Anem a configurar la pàgina."},"widgets":{"configure":"Anem a configurar un widget.","configure_desc":"Click the wrench to open a widget's <b>settings</b>.","configure_skip":"Skip Tutorial","settings":"Replace <b>Link URL</b> with your favorite site, then press <b>Save</b>.","move":"You can <b>reposition</b> widgets by clicking and dragging the three dots highlighted here.","remove":"To <b>delete</b>, simply click the red trash bin icon.","done":"Ho tinc"},"settings":{"intro":"Now let’s add a new widget. This highlighted button is where you can access the Widget Menu.","instructions":"Click the new widget button on to open the widget menu!","skip":"Ometre","tooltips":{"settings":"Canvia l'aspecte de l' ProductivityTab i com funciona","widgets":"Afegir widgets nous - en pots tenir tants com vulguis","editing":"Mostra o amaga els botons d'edició en els widgets","links":"Això és una llista d'enllaços, afegeix-hi llocs web que utilitzes sovint en la configuració","tabs":"Aquestes són les teves pestanyes. En pots afegir més en la configuració","support":"Envia'ns un missatge o deixa un comentari aquí"},"finished":"Això es tot!","finished_next":"Selecciona una opció del menú (prova començant amb <b>Widgets</b>) i configura la teva pàgina!","finished_contact":"Utilitza l'enllaç de suport si necessites ajuda i ens posarem en contacte amb tu el més aviat possible."}},"storage":{"signin":"Inicia sessió amb Google per desar de forma segura i sincronitzar la configuració","signin_btn":"Iniciar sessió","signin_dismiss":"Ignorar","signin_confirm":{"title":"Mantenir les dades locals?","desc":"Vols mantenir les dades locals i substituir la configuració que hi ha al teu compte amb elles, o substituir la configuració d'aquest ordinador amb les dades que ja tens al compte?","keep_account":"Utilitzar compte","keep_local":"Mantenir dades locals"},"signout_confirm":"Si tanques la sessió s'esborraran les les còpies de seguretat locals","pastdue":"La subscripció ha vençut","pastdue_desc":"Si us plau actualitza la informació de facturació en la configuració"},"toolbar":{"placeholder":"Introdueix els termes a cercar","placeholder_ok":"Introdueix els termes a cercar o digues \"OK, Google\"","suggestions":{"url_subtext":"Visit URL","capture_notice":"ProductivityTab handles searches you normally make from the Omnibox. You can disable this at any time from the settings"},"apps":{"search":"Cerca","youtube":"YouTube","maps":"Mapes","play":"Play","news":"News","gmail":"Gmail","drive":"Drive","calendar":"Calendari","more":"Més"}},"menu":{"settings":"Configuració","widgets":"Widgets","editing":"Editant","editing_enabled":"Activat","editing_disabled":"Desactivat","plus":"Google Plus","tabs":"Pestanyes","footer":{"support":"Suport","feedback":"Comentaris","review":"Ressenya","terms":"Termes","privacy":"Privacitat","by":"Per Avi Kohn"}},"voice":{"listening":"Escoltant...","searching":"Cercant: %s","missed":"No s'ha aconseguit. <a>Torna-ho a provar</a>"},"settings":{"title":"Configuració","exit":"Sortir de la configuració","saved":"Configuració desada","nav":{"visual":"Visual","visual_sections":{"background":"Fons de pantalla","layout":"Disseny","theme":"Tema de l'app","ad_placement":"Ad placement"},"toolbar":"Barra d'eines","toolbar_sections":{"style":"Estil","search":"Cerca","links":"Enllaços"},"tabs":"Pestanyes","widgets":"Widgets","ads":"Ads","pro":"Pro","accounts":"Compte","misc":"Misceŀlània","advanced":"Avançat","advanced_sections":{"backups":"Còpia de seguretat i recuperació","css":"CSS personalizat","debug_tools":"Eines de depuració"},"support":"Ajuda i suport tècnic","suggest":"Suggereix una nova característica"},"visual":{"background":{"title":"Fons de pantalla","desc":"Aquesta es la imatge o grup de imatges mostrades com a fons de les pastanyes","current":"Fons actual","custom":"Personalitzat","unnamed":"Tema %s","select":"Selecciona un tema","or":"o","url_placeholder":"Introduïu un URL d'imatge"},"layout":{"title":"Disseny","desc":"Aquí pots ajustar el tipus i nombre de columnes en cada pestanya","columns":"Columnes","grid":"Quadrícula","columns_number":"Nombre de columnes","column_width":"Amplada de la columna","column_width_fixed":"Fixat","column_width_fluid":"Fluid","column_warning":{"column_to_grid":"Canviar a un disseny basat en quadrícula mourà tots els widgets a la cantonada superior esquerra.","grid_to_column":"Canviar a un disseny basat en columnes mourà tots els widgets a la primera columna."}},"theme":{"title":"Tema de l'app","desc":"El tema de la app controla per si mateix l'estil de ProductivityTab i tots els widgets","preview":"Vista prèvia","light":"Clar (predetermitat)","dark":"Fosc","transparent":"Transparent","transparent_darker":"Transparent (fosc)"}},"toolbar":{"style":{"title":"Estil","desc":"Aquí es controla l'estil de la barra d'eines.  Pot aparèixer normalment o com un botó a part","normal":"Normal","button":"Botó"},"search":{"title":"Cerca","desc":"Aquesta configuració controla com funcionen el quadre de cerca i la cerca per veu","engine":"Motor de cerca","engines_default":"Default","engines_custom":"Personalitzat","engines_custom_desc":"Introduïu la URL a la que s'enviaran les consultes, amb <b>%s</b> on hauria d'anar la consulta.","omnibox_capture":"Handle searches normally made in the Omnibox","voice":"Habilita la cerca per veu","ok_google":"Activar la detecció de la paraula clau \"OK Google\"","search_tab":"Obre els Resultats de la cerca en una pestanya nova"},"links":{"title":"Enllaços","desc":"Aquests són els elements mostrats a la dreta de la barra d'eines","apps":"Menú d'aplicacions","custom":"Enllaços personalitzats","custom_note1":"3 com a màxim","custom_note2":"8 per als usuaris","custom_name_placeholder":"Text de l'enllaç","custom_url_placeholder":"URL de l'enllaç, p. ex. https://www.google.com/"}},"misc":{"link_tab":"Obrir enllaços en una pestanya nova per defecte"},"tabs":{"create_new":"Crear nova","make_default":"Posar per defecte","desc1":"Les pestanyes són pàgines dins ProductivityTab. Cada pestanya té el seu propi conjunt de widgets que està completament separat de totes les altres pestanyes.","desc2":"Es pot canviar entre pestanyes clicant els botons que apareixen a l'esquerra i a la dreta de la pantalla quan es mou el ratolí sobre una pestanya o utilitzant les tecles de fletxa del teclat.","name_placeholder":"Introduir un nom de pestanya","delete_confirm":"Aquesta acció és irreversible. Totes les dades de tots els widgets de la pestanya es perdran definitivament."},"accounts":{"status":{"title":"Estat","signed_in":"Actualment has <b>iniciat sessió</b> com %s (%s).","reset_account":"Restablir el compte","sign_out":"Tancar sessió","signed_out":"<b>Sessió no iniciada</b>. Inicia sessió amb el teu compte de Google ara per emmagatzemar i sincronitzar la teva configuració de forma segura.","sign_in":"Inicia sessió amb Google"},"reset_confirm_desc":"Això esborrarà totes les dades locals i sincronitzades, no hi ha cap còpia de seguretat i no hi ha manera de desfer-ho.","reset_confirm_desc2":"Es perdrà la configuració actual en tots els ordinadors connectats a aquest compte."},"advanced":{"backups":{"title":"Còpia de seguretat i recuperació","desc":"Les còpies de seguretat són còpies complertes de totes les teves pestanyes, configuració i widgets. Que són creades automàticament en obrir l'ProductivityTab cada dia.","desc2":"Utilitza els botons de sota per retornar l'ProductivityTab a una data determinada o descarregar una de les còpies de seguretat.","backup":"Fer còpia de seguretat ara","upload":"Restaurar des d'un arxiu","download":"Descarregar","restore":"Restaura","download_name":"Copia de seguretat d'ProductivityTab","restore_confirm":"Se sobreescriuran totes les dades locals i sincronitzades. Perdràs la configuració actual a tots els ordinadors amb aquest compte.","restore_error":"S'ha produït un error en intentar analitzar les dades facilitades, si us plau torna-ho a provar més tard."},"css":{"title":"CSS personalizat","desc":"Es pot utilitzar CSS (<a href=\"https://developer.mozilla.org/en-US/docs/Web/CSS\" target=\"blank\"> definició</a>) per personalitzar gairebé qualsevol part de l'ProductivityTab.","placeholder":"Introduir fins a 1000 caràcters de CSS aquí"},"debug_tools":{"title":"Eines de depuració","desc":"<b>Avís:</b> Aquestes eines poden esborrar la configuració sencera en un sol clic. Útilitza-les només si el teu desenvolupador t'ho indica.","open":"Obrir eines"}},"widgets":{"desc1":"Els widgets tenen la seva pròpia configuració i no es poden personalitzar aquí.","desc2":"Per editar la configuració d'un widget, segueix aquests passos:","steps1":"Mou el ratolí sobre qualsevol widget","steps2":"Fes clic a la icona de la clau anglesa que apareix a la part superior dreta del widget. Si no apareix llavors el widget no té configuracions que es puguin personalitzar.","steps3":"Edita alguna configuració de les que es mostren al diàleg","steps4":"Fes clic a Desar per desar els canvis, o a qualsevol part del fons per descartar-los"},"pro":{"promo":{"monthly_price":"4.99$ al mes","yearly_price":"o 29.99$ per any","upgrade_btn":"Actualitza ara","business":"T' Interessa comprar la versió Pro per al teu negoci o per l'escola?","business_contact":"Contacta amb nosaltres","themes":"Temes","themes_desc":"Veure més fons de pantalla amb temes foscos i transparents","bgs":"Fons interactius","bgs_desc":"Dona vida a la teva pàgina amb 20 fons d'alta definició","widgets":"Widgets maximizables","widgets_desc":"Porta l'ProductivityTab a un altre nivell amb widgets maximizables","more_header":"I més","stocks":"La borsa en temps real amb informació ampliada i històrica","rss":"Suport per a RSS múltiples per widget","sports":"Notícies d'esport generals i de lligues específiques","tabbed_widgets":"Widgets de noticies i RSS amb pestanyes","bg_downloads":"Fons descarregables","weather":"Previsions meteorològiques horàries fins a 10 dies vista","toolbar":"Més enllaços a la barra d'eines","ads":"A completely ad-free experience","support":"Assistència prioritària i suggeriments","buy_pro":"Comprar la versió Pro"},"checkout":{"title":"Verificar","updating_title":"Pla d'actualització","payment_options":"Pagar","pay_monthly":"Mensual (4.99$)","pay_yearly":"Anual (29.99$)","cancel":"Cancelar","update":"Actualitzar","subscribe":"Subscriure’s","braintree_notice":"Pagaments processats de manera segura per Braintree.","monthly_notice":"Subscrivint-te, autoritzes l' ProductivityTab a cobrar 4.99$ cada mes fins que es cancel·li la subscripció.","yearly_notice":"Subscrivint-te, autoritzes l' ProductivityTab a cobrar 29.99$ cada any fins que es cancel·li la subscripció.","update_notice":"Encara que els canvis als cicles de facturació tenen efecte immediat, no se't cobrarà fins que acabi el cicle actuals.","thank_you":"Gràcies per comprar l'ProductivityTab Pro!","thank_you2":"ProductivityTab es recarregarà d'aquí a pocs segons i estarà tot a punt!","error":"Alguna cosa ha sortit malament mentre s'intentava processar el pagament.","error2":"Si us plau torna-ho a provar una altra vegada d'aquí a una estona o envia un email a support@ichro.me","signin":"Iniciar sessió","signin_desc":"Cal que inicïis la sessió abans de comprar la versió Pro per què ens puguem assegurar de que ets tú","signin_btn":"Iniciar sessió"},"plan":{"title":"Pla","desc":"Actualment estàs subscrit a ProductivityTab Pro (%s)","types":{"monthly":"Mensualment","yearly":"Anualment","business":"Negocis","education":"Educació","custom":"Personalitzat"},"uneditable_desc":"Els plans de negocis, educació i personalitzats no es poden actualitzar des de dins de l'ProductivityTab. Si us plau <a href=\"mailto:support@ichro.me\"> Contacti amb nosaltres</a> per actualitzar o anul·lar la seva subscripció.","status":"Estat","status_active":"Actiu","status_trial":"Prova","status_pastdue":"Vençut","subscription_date":"Data de subscripció","paid_through":"Pagat a través de","next_bill":"Propera factura","next_bill_value":"$%s en %s","update_plan":"Pla d'actualització","update_billing":"Actualitzar la facturació","cancel":"Cancel·lar la subscripció","cancel_notice":"La subscripció es cancel·larà immediatament","cancel_notice2":"If you would like a refund, please contact us at support@ichro.me"}},"ads":{"text1":"ProductivityTab displays a few small ads to pay for server, support and development costs. With these ads, we can afford to offer iChrome free to everyone.","text2":"Here you can choose where those ads are shown, or buy ad-free to permanently remove them.","text3":"Ad-free is a one-time purchase that permanently removes ads from ProductivityTab wherever you're signed in. You can also upgrade to Pro for extra features in addition to an ad-free experience.","upgrade_btn":"Upgrade to ad-free","already_upgraded":"It looks like you've already upgraded to ad-free","signin":"Sign in","signin_desc":"Sign in before upgrading so we can link your purchase to your account","signin_btn":"Sign in","thank_you":"Thank you for upgrading to ad-free!","placement":{"title":"Ad placement","left":"In the leftmost column","right":"In the rightmost column","top":"Above the tab","bottom":"Floating at the bottom"}}},"store":{"installation":"Installation","description":"Description","preview":"Preview","instructions":"Drag and drop any size onto your homepage"},"widgets":{"sizes":{"tiny":"Tiny","small":"Small","medium":"Medium","large":"Large","variable":"Variable"},"settings":{"title":"Widget Settings","save":"Save","size":"Widget Size"},"minimize":"Minimize","maximize":"Maximize","delete_confirm":"Are you really sure you want to delete this widget?\r\nThis action is irreversible; all data from this widget will be permanently lost.","permissions_request":{"title":"Access required","button":"Grant Access","desc":"This widget needs extra permissions before it can be used. Grant them using the button below."},"error":{"explanation":"Something went wrong while we were trying to display this widget.","advice":"Try reinstalling the widget or reloading the page. Contact us if you see this message often.","support":"Suport","refresh":"Refresh"},"auth":{"message":"You'll need to give this widget access to your account before you can use it.","button":"Grant Access"},"shared":{"settings":{"title":"Widget Title","title_placeholder":"Enter a widget title or leave blank to hide","height":"Widget Height","open_options":{"current":"The current tab","blank":"A new tab"},"footer_link":"Footer Link","footer_link_options":{"show":"Show","hide":"Hide"},"account":"Account ID","account_help":"If you're signed into multiple accounts, this is the \"authuser=\" value.\n<br /><br />\nFor example, if you're signed into two accounts, jsmith1@gmail.com and jsmith2@gmail.com, the \"authuser\" value for jsmith2@gmail.com would be 1 since it's the second account (counting from zero) that you're signed into.","account_placeholder":"Your \"authuser=\" value","on":"On","off":"Off"}},"apps":{"name":"Apps","desc":"Mostra les aplicacions de Google Chrome que tens instal·lades actualment.","settings":{"format":"Format del Widget","format_options":{"tiles":"Mosaic","list":"Llista"},"display":"Mostrar","display_options":{"all":"Totes les apps","enabled":"Només les apps habilitades"},"sort":"Ordenar","sort_options":{"id":"ID","alphabetically":"Alfabèticament","offline":"Activat fora de línia","available":"Disponibilitat"},"open":"Apps obertes a"},"store_app":"Botiga"},"bookmarks":{"name":"Adreces d'interès","desc":"Mostra les adreces d'interès seleccionades i personalitzades i altres enllaços.","settings":{"title_placeholder":"Introdueix un títol de widget","layout":"Disseny","layout_options":{"single":"Columna única","double":"Doble columna"},"open":"Obre adreces d'interès a"},"edit":{"dialog_title":"Edita l'adreça d'interès","title":"Títol de l'adreça d'interès","title_placeholder":"Google","url":"URL de l'adreça d'interès","url_placeholder":"https://www.Google.com/","save":"Desa"},"new_caption":"Nou","new_bookmark":"Adreça d'interès","new_folder":"Carpeta","drop_link":"Llença l'enllaç aquí"},"chrome_bookmarks":{"name":"Adreces d'interès","desc":"Mostra les adreces d'interès de Chrome, opcionalment d'una carpeta específica.","settings":{"title_placeholder":"Introdueix un títol de widget","from":"Mostra les adreces d'interès de","open":"Obre adreces d'interès a"}},"calc":{"name":"Calculadora","desc":"Mostra una calculadora amb suport per a operadors bàsics.","error":"Error!","infinity":"Infinit","mismatch":"Parèntesis que no coincideixen"},"calendar":{"name":"Calendari","desc":"Mostra els esdeveniments futurs d'un o més dels teus calendaris de Google.","settings":{"calendar":"Calendari","show":"Mostra els esdeveniments de","show_options":{"all":"Tot el temps","today":"Només avui"}},"title":"Ordre del dia","calendar":"Calendari","noevents":"No hi ha esdeveniments en un futur proper, sembla que el teu horari és net!"},"clock":{"name":"Rellotge","desc":"Ofereix funcionalitats d'alarma, temps, temporitzador i cronòmetre.","settings":{"timezone":"Zona horaria","timezone_local":"Local","format":"Format del rellotge","format_options":{"ampm":"AM/PM - Digital","24hour":"24 hores - Digital","analog":"12 hores - Analògic","ampmseconds":"AM/PM - Digital, sense segons","24hourseconds":"24 hores - Digital, sense segons"},"sound":"So d'alerta"},"title":"Rellotge","alarm":"Alarma","clock":"Rellotge","timer":"Temporitzador","stopwatch":"Cronòmetre","set":"Aplicar","unset":"Anul·lar","dismiss":"Ignorar","enable_audio":"Enable audio"},"facebook":{"name":"Facebook","desc":"Embeds Facebook in a widget"},"feedly":{"name":"Feedly","desc":"Displays articles from your Feedly account in a configurable format.","settings":{"source":"Show articles from","source_feeds":"Feeds","show":"Show","show_options":{"all":"All articles","unread":"Only unread articles"},"layout":"Disseny","layout_options":{"titles":"Titles only","magazine":"Magazine","cards":"Cards","cards_columns":"Cards (two columns)"},"mark":"Mark an article as read when I","mark_options":{"scroll":"Scroll past it or click it","click":"Just click it"},"sort":"Sort Order","sort_options":{"newest":"Newest first","oldest":"Oldest first"}},"all":"All","saved":"Saved for later","uncategorized":"Uncategorized","author":"by","go_to_feedly":"Go To Feedly"},"notes":{"name":"Notes","desc":"Inserts a simple, editable, note.","settings":{"color":"Note Color","color_options":{"yellow":"Yellow","orange":"Orange","red":"Red","blue":"Blue","green":"Green","white":"White"},"font":"Font Face","fontsize":"Font Size"}},"now":{"name":"Google Now","desc":"Displays cards from Google Now including flight status and package tracking.","authorize":"You'll need to give ProductivityTab permission to view your Google Now cards before anything will show up here.","authorize_btn":"Authorize","caught_up":"All caught up, nothing here.","no_title":"No Title"},"plus":{"name":"Google+","desc":"Embeds Google Plus in a widget"},"notifications":{"name":"Google Notifications","desc":"Displays your Google Notifications from services such as Google+"},"reddit":{"name":"Reddit","desc":"Displays the top items on Reddit for any given subreddit.","settings":{"subreddit":"Subreddit","subreddit_help":"Enter any subreddit by the part past <b>/r/</b> when on Reddit.\n<br /><br />\nFor example, Technology is at: <a href=\"https://www.reddit.com/r/technology\">https://www.reddit.com/r/technology</a>, therefore you would enter <b>technology</b>","subreddit_placeholder":"Enter a subreddit to show links from. (i.e. technology)","sort":"Sort Order","sort_options":{"hot":"Hot","top":"Top","new":"Nou","gilded":"Gilded","rising":"Rising","controversial":"Controversial"},"links":"Links Shown","click":"When I click a link show me","click_options":{"link":"The link","comments":"The comments"}},"more":"Més"},"tasks":{"name":"Tasks","desc":"Displays an editable list of tasks from one of your Google Tasks lists.","title":"Tasks","settings":{"list":"Llista"},"task_title":"Title","due_date":"Due date","notes":"Notes","add":"Add Item","delete_task":"Delete Task","move_up":"Move Up","move_down":"Move Down","done":"Done","due_today":"Due today","overdue":"Overdue","authorize":"You'll need to select a list from your Google Tasks via the settings before anything can be displayed here."},"twitter":{"name":"Twitter","desc":"Displays tweets from your home stream or a specified list.","settings":{"source":"Show Tweets from","show":"Tweets Shown"},"authorize":"You'll need to authorize ProductivityTab first","authorize_msg":"You'll need to give ProductivityTab permission to view tweets from your account before anything will show up here.","authorize_btn":"Authorize","no_tweets":"There don't seem to be any tweets here...","home":"Inici","mentions":"Mentions","retweets":"Retweets of me","lists":"Lists","more":"Més","reply":"Reply","retweet":"Retweet","favorite":"Favorite"},"wolfram":{"name":"Wolfram|Alpha","desc":"Inserts a small Wolfram|Alpha search box."},"youtube":{"name":"YouTube","desc":"Displays either popular videos or videos from a specified user.","settings":{"format":"Format","format_options":{"large":"One large","large_2":"One large, two small","large_4":"One large, four small","four":"Four small","six":"Six small"},"from":"Show Videos From","from_help":"This must be an <b>exact</b> username as shown in the URL of the page when you're viewing their profile.\n<br /><br />\nThis value never includes spaces.","from_placeholder":"Leave blank to show Top Videos","open":"Open search results in"},"search":"Search YouTube","num_views":"views"},"quotes":{"name":"Quotes","desc":"Displays a quote picked either every time you load the page or once daily.","settings":{"source":"Source","method":"Load new quotes","method_options":{"daily":"Once daily","random":"Every time I load the page"}},"unknown_author":"Unknown"},"html":{"name":"HTML","desc":"Displays completely custom HTML in an iframe.","settings":{"html":"HTML","js":"JavaScript","height":"Widget Height"}},"sitelink":{"name":"Site Link","desc":"Displays a link, optionally with a title and thumbnail","settings":{"link":"Link URL","link_placeholder":"https://www.Google.com/","image":"Image URL","image_placeholder":"https://www.example.com/image.png","color":"Image Background Color","style":"Image Style","style_fill":"Fill","style_center":"Center"}},"stats":{"name":"System Statistics","desc":"Keep an eye on your system with realtime statistics","memory":"Memory","battery":"Battery","usage":"usage","in_use":"in use","remaining":"remaining","charged":"Fully Charged","idle":"Idle","charging":"Charging","discharging":"Discharging"},"search":{"name":"Cerca","desc":"Embeds a search box in your page for easy access","settings":{"placeholder":"Search Field Placeholder","search_url":"Search URL","param":"Query Parameter","param_placeholder":"The parameter where the query goes, i.e. \"q\""},"default_placeholder":"Search Google"},"pushbullet":{"name":"Pushbullet","desc":"Keep track of notifications from your phone and other devices","no_pushes":"No pushes found","sign_in":"Sign in","no_key":"It doesn't look like you're signed in to Pushbullet.  Sign in now to connect this widget."},"linkedin":{"name":"LinkedIn","desc":"Displays your LinkedIn home stream"},"directions":{"name":"Directions","desc":"Get directions to and from nearly anywhere right from your homepage","driving":"Driving","transit":"Public Transit","walking":"Walking","cycling":"Cycling","from":"Enter a starting point","to":"Enter a destination","loading":"Loading directions, please wait...","error":"Something went wrong while trying to load the directions you requested.","error2":"Please check the start and destination addresses you entered.","open_in_maps":"Open in Google Maps","via":"via"},"pocket":{"name":"Pocket","desc":"Display a list of your saved articles, videos, and web pages from Pocket","settings":{"links_shown":"Number of links shown","open":"Open links","open_pocket":"In Pocket","open_original":"At their original URL"},"by":"By","no_links":"No links found","grant_access":"Grant access","no_key":"You'll need to give ProductivityTab access to your Pocket account before it can load your links."}},"themes":{"title":"Themes","all":"All","custom":"Custom","create":"Create a theme","url_or_upload":"or","upload_image":"Upload an image","edit_btn":"Edit","delete":"Delete","use":"Use","preview":"Preview","author":"By","images":"%s images","resolution":"Resolution","categories":"Categories","cached":"This theme has been cached and is available offline","random":"This theme displays a random image every time you load the page","random_daily":"This theme displays an image picked randomly every day","sunrise_sunset":"This theme displays an image based on the time of day","feed":"This theme displays an image selected daily from an external feed","video":"This theme displays a live video","pro_only":"This theme is only available to Pro users. Buy Pro in the settings.","delete_confirm":"Are you really sure you would like to delete this theme?\r\nThis action is irreversible; the entire theme will be permanently lost.","delete_error":"An error occurred while trying to delete the theme.  Please try again later.","feed_fetching":"Please wait, fetching feed...","feed_error":"Something went wrong while trying to fetch the feed.  Please try again later.","caching":"Please wait, caching theme...","cache_status":"%s of %s images cached","cache_error":"An error occurred while trying to cache the theme.  Please try again later","bginfo":{"view":"View","source":"Source","unknown":"Unknown","download":"Descarregar","pro_only":"Only Pro users can download background images and videos"},"edit":{"title":"Edit Theme","create_title":"Create Theme","name":"Theme Name","default_name":"New Theme","name_placeholder":"Enter a theme name","image":"Image URL","image_placeholder":"Enter a background image URL","image_help":"Uploaded images <b>cannot be synced</b> between computers.<br /><br />If this is important to you, please upload your image to a service such as <a href=\"https://imgur.com/\" target=\"_blank\">imgur</a>. Then copy the URL ending with an extension (i.e. .jpg) and paste it into the field on the left.","color":"Fallback Color","color_placeholder":"Enter any color name","position":"Position","position_options":{"center":"Center","top_left":"Top Left","top_center":"Top Center","top_right":"Top Right","bottom_left":"Bottom Left","bottom_center":"Bottom Center","bottom_right":"Bottom Right"},"scaling":"Scaling","scaling_options":{"auto":"Auto","width":"Full Width","height":"Full Height","none":"No Scaling (preview may be inaccurate)"},"repeat":"Image Repeat","repeat_options":{"none":"No Repeat","horizontal":"Repeat Horizontally","vertical":"Repeat Vertically","both":"Repeat Both"},"attach":"Attach Image To","attach_tab":"The tab","attach_window":"The window","preview":"Preview","save":"Save & Close","cache_error":"An error occurred while trying to cache the image you provided, please double-check the URL.","upload_error":"An error occurred while trying to upload the file you provided, please make sure that it's a reasonable size and an image."}}},"cs":{"lang_code":"cs","language":"Česky","extName":"ProductivityTab — Custom Homepage Dashboard","newtabName":"ProductivityTab — Custom New Tab Dashboard","extDescription":"A remarkably customizable personal homepage featuring 50+ widgets, breathtaking backgrounds and much more.","newtabDescription":"A customizable personal dashboard on your new tab page featuring 50+ widgets, breathtaking backgrounds and much more.","defaults":{"tab":"Domovská stránka","me":"Já"},"remove_widget":"Odstranit","hide_banner":"Hide this banner","hide_ad":{"content":"Hey! We're not crazy about ads either, but we're only able to make ProductivityTab available and continue developing features for our free users (that's you!) by showing ads. If you'd like to support ProductivityTab directly and get rid of ads for free, we would really appreciate if you upgraded to our pro version","upgrade":"Upgrade","hide":"Hide ads"},"alert":{"default_button":"Odmítnout","confirm_title":"Opravdu to chcete provést?","confirm_continue":"Pokračovat","confirm_cancel":"Zrušit"},"onboarding":{"modal":{"tagline":"Všechny weby a aplikace, které používáte, na jednom místě","wrong_extension":"Chcete mít ProductivityTab na vaší nové kartě?","wrong_extension_newtab":"Chcete mít ProductivityTab jako domovskou stránku?","wrong_extension_action":"Klikněte zde","about":"ProductivityTab je celý o kartách a widgetech","about_desc":"Karty jsou stránky s widgety - bloky, které ukazují věci, jako je například počasí, zpravodajství a nebo váš email. Většinu widgetů si můžete upravit jakkoliv chcete a mít jich kolik jen chcete.","terms":"Pokračováním souhlasíte s <a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\">Podmínkami</a> a <a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\">Ochranou soukromí</a> dle ProductivityTab","sign_in":"Přihlásit se pomocí účtu Google","sign_in_desc":"Pro bezpečné online ukládání Vašich změn se nejprve přihlaste pomocí Vašeho účtu Google.","sign_in_desc2":"Pokud chcete, můžete zůstat odhlášeni, ale vaše stránka nebude ukládána online a nebudete k ní mít přístup z jiných počítačů.","sign_in_button":"Přihlásit se přes Google+","have_account":"Vypadá to, že už jeden účet máte!","have_account_desc":"Vaše karty a widgety jsou připraveny k použití!","get_started":"Pojďme na to!","get_started_desc":"Jste připraveni začít! Pojďme nastavit Vaše stránky."},"widgets":{"configure":"Pojďme si nastavit widget.","configure_desc":"Click the wrench to open a widget's <b>settings</b>.","configure_skip":"Skip Tutorial","settings":"Replace <b>Link URL</b> with your favorite site, then press <b>Save</b>.","move":"You can <b>reposition</b> widgets by clicking and dragging the three dots highlighted here.","remove":"To <b>delete</b>, simply click the red trash bin icon.","done":"Rozumím"},"settings":{"intro":"Now let’s add a new widget. This highlighted button is where you can access the Widget Menu.","instructions":"Click the new widget button on to open the widget menu!","skip":"Přeskočit","tooltips":{"settings":"Změňte vzhled i fungování ProductivityTab","widgets":"Přidat nový widget - můžete jich mít kolik jen budete chtít","editing":"Zobrazit nebo skrýt tlačítka pro úpravu widgetů","links":"Toto je seznam odkazů, přidejte si odkazy na webové stránky, které často navštěvujete. Změnu provedete v nastavení","tabs":"Toto jsou vaše karty. Další si můžete přidat v nastavení","support":"Pošlete nám zprávu nebo nám nechte recenzi zde"},"finished":"A je to!","finished_next":"Vyberte volbu z menu (zkuste začít s volbou <b>Widgety</b>) a nastavte si Vaši stránku!","finished_contact":"Použijte odkaz na podporu pokud potřebujete jakoukoli pomoc a my Vám odpovíme co nejrychleji to půjde."}},"storage":{"signin":"Přihlaste se nyní pomocí Google pro bezpečné ukládání a synchronizaci Vaší konfigurace","signin_btn":"Přihlásit se","signin_dismiss":"Odmítnout","signin_confirm":{"title":"Ponechat místní data?","desc":"Chcete uchovat svou lokální konfiguraci a přepsat podle ní konfiguraci uloženou ve vašem účtu nebo přepsat lokální konfiguraci konfigurací z účtu?","keep_account":"Použít účet","keep_local":"Ponechat místní"},"signout_confirm":"Odhlášení vymaže místní zálohy","pastdue":"Vaše předplatné je po splatnosti","pastdue_desc":"Prosím aktualizujte Vaše platební informace v nastavení"},"toolbar":{"placeholder":"Co hledáte?\n","placeholder_ok":"Zadejte dotaz, nebo řekněte \"OK, Google\"","suggestions":{"url_subtext":"Visit URL","capture_notice":"ProductivityTab handles searches you normally make from the Omnibox. You can disable this at any time from the settings"},"apps":{"search":"Hledat","youtube":"YouTube","maps":"Mapy","play":"Play","news":"Zprávy","gmail":"Gmail","drive":"Disk","calendar":"Kalendář","more":"Více"}},"menu":{"settings":"Nastavení","widgets":"Widgety","editing":"Editování","editing_enabled":"Zapnuto","editing_disabled":"Vypnuto","plus":"Google Plus","tabs":"Záložky","footer":{"support":"Podpora","feedback":"Zpětná vazba","review":"Recenze","terms":"Podmínky","privacy":"Ochrana soukromí","by":"Avi Kohn"}},"voice":{"listening":"Poslouchám...","searching":"Hledání: %s","missed":"Nerozumím. <a>Zkuste to znovu.</a>"},"settings":{"title":"Nastavení","exit":"Opustit nastavení","saved":"Nastavení bylo uloženo","nav":{"visual":"Vzhled","visual_sections":{"background":"Pozadí","layout":"Rozložení","theme":"Motiv aplikace","ad_placement":"Ad placement"},"toolbar":"Panel nástrojů","toolbar_sections":{"style":"Styl","search":"Hledat","links":"Odkazy"},"tabs":"Záložky","widgets":"Widgety","ads":"Ads","pro":"Pro","accounts":"Účet","misc":"Ostatní","advanced":"Pokročilé nastavení","advanced_sections":{"backups":"Záloha a obnova","css":"Vlastní CSS","debug_tools":"Debugovací nástroje"},"support":"Pomoc a podpora","suggest":"Navrhnout funkcionalitu"},"visual":{"background":{"title":"Pozadí","desc":"Toto je obrázek nebo sada obrázků zobrazovaná jako pozadí do Vašich karet","current":"Aktuální pozadí","custom":"Vlastní","unnamed":"Motiv %s","select":"Vybrat motiv","or":"nebo","url_placeholder":"Vložte URL obrázku"},"layout":{"title":"Rozložení","desc":"Zde můžete nastavit typ a počet sloupců pro každou záložku","columns":"Sloupce","grid":"Mřížka","columns_number":"Počet sloupců","column_width":"Šířka sloupce","column_width_fixed":"Pevná","column_width_fluid":"Pružná","column_warning":{"column_to_grid":"Změna na dlaždicové rozložení přesune všechny Vaše aktuální widgety do levého horního rohu.","grid_to_column":"Změna na sloupcové rozložení přesune všechny Vaše aktuální widgety do prvního sloupce."}},"theme":{"title":"Motiv aplikace","desc":"Motiv aplikace ovlivňuje styl samotného ProductivityTab a všech widgetů","preview":"Náhled","light":"Světlý (výchozí)","dark":"Tmavý","transparent":"Průhledný","transparent_darker":"Průhledný (tmavší)"}},"toolbar":{"style":{"title":"Styl","desc":"Zde se nastavuje styl zobrazení panelu nástrojů. Může být zobrazen normálně nebo jako menu při stisknutí tlačítka v rohu","normal":"Normální","button":"Tlačítko"},"search":{"title":"Hledat","desc":"Toto nastavení mění fungování vyhledávacího pole a hlasového vyhledávání","engine":"Vyhledávač","engines_default":"Default","engines_custom":"Vlastní","engines_custom_desc":"Toto je adresa, na kterou se budou odesílat dotazy vyhledávání. V adrese se <b>%s</b> nahradí vyhledávaným textem.","omnibox_capture":"Handle searches normally made in the Omnibox","voice":"Povolit vyhledávání pomocí hlasu","ok_google":"Zapnout detekci klíčového slova \"OK Google\"","search_tab":"Otevřít výsledky hledání v nové záložce"},"links":{"title":"Odkazy","desc":"Toto jsou položky zobrazené v pravé části panelu nástrojů","apps":"Menu aplikací","custom":"Vlastní odkazy","custom_note1":"Jsou povoleny maximálně 3","custom_note2":"uživatelé dostanou 8","custom_name_placeholder":"Text odkazu","custom_url_placeholder":"Adresa odkazu, např. https://www.google.com/"}},"misc":{"link_tab":"Otevírat odkazy v nové kartě jako výchozí chování"},"tabs":{"create_new":"Vytvořit novou","make_default":"Nastavit jako výchozí","desc1":"Karty jsou stránky uvnitř ProductivityTab. Každá karta má vlastní sadu widgetů, zcela nezávisle na ostatních kartách.","desc2":"Můžete přepínat mezi kartami kliknutím na tlačítka, která se zobrazí na levé a pravé straně obrazovky, když přejedete myší přes kartu nebo pomocí kláves se šipkami na Vaší klávesnici.","name_placeholder":"Zadejte název karty","delete_confirm":"Tato akce je nezvratná. Všechna data widgetů na kartě budou navždy ztracena."},"accounts":{"status":{"title":"Stav","signed_in":"Jste <b>přihlášeni</b> jako %s (%s).","reset_account":"Resetovat účet","sign_out":"Odhlásit","signed_out":"Nyní <b>nejste přihlášeni</b>. Přihlaste se nyní pomocí Vašeho Google účtu aby mohla být vaše konfigurace bezpečně ukládána a synchronizována.","sign_in":"Přihlásit se přes Google"},"reset_confirm_desc":"Tato akce vymaže Vaše lokální i synchronizovaná data. Neexistuje žádná záloha ani způsob jak tuto akci vrátit zpět.","reset_confirm_desc2":"Stratíte věškerou aktuální konfiguraci na všech počítačích připojených k tomuto účtu."},"advanced":{"backups":{"title":"Záloha a obnova","desc":"Zálohy jsou plné kopie všech vašich záložek, nastavení a widgetů. Jsou generovány automaticky, když poprvé otevřete ProductivityTab každý den.","desc2":"Použijte tlačítka níže pro vrácení ProductivityTab do stavu k určitému datu nebo stáhněte některou ze svých záloh.","backup":"Zálohovat nyní","upload":"Obnovit ze souboru","download":"Stáhnout","restore":"Obnovit","download_name":"ProductivityTab zálohování","restore_confirm":"Toto přepíše všechna lokální i synchronizovaná data. Ztratíte celou svoji aktuální konfiguraci na všech počítačích s tímto účtem.","restore_error":"Nastala chyba při pokusu o čtení poskytnutých dat, zkuste to prosím později."},"css":{"title":"Vlastní CSS","desc":"Můžete použít CSS (<a href=\"https://developer.mozilla.org/en-US/docs/Web/CSS\" target=\"blank\">definice</a>) a nastavit si téměř každou část ProductivityTab.","placeholder":"Zde vložte až 1000 znaků CSS"},"debug_tools":{"title":"Debugovací nástroje","desc":"<b>POZOR:</b> Tyto nástroje mohou smazat veškeré vaše nastavení jedním klikem. Použijte je pouze pokud vás navede váš developer.","open":"Otevřít nástroje"}},"widgets":{"desc1":"Widgety mají vlastní nastavení a nemůžete je upravovat zde.","desc2":"Pro úpravu nastavení widgetu postupujte následovně:","steps1":"Najeďte kurzorem na jakýkoli widget","steps2":"Klikněte na ikonu klíče, která se objevý v pravé horní části widgetu. Pokud se ikona neobjeví, widget nemá možnost úpravy žádného nastavení.","steps3":"Upravte kterékoliv nastavení zobrazené v zobrazeném dialogu","steps4":"Pro uložení vašich změn klikněte na Uložit, pro jejich zrušení klikněte kdekoli na pozadí"},"pro":{"promo":{"monthly_price":"$4.99 za měsíc","yearly_price":"nebo $29.99 za rok","upgrade_btn":"Vylepšit teď","business":"Máte zájem koupit Pro verzi pro vaši firmu nebo školu?","business_contact":"Kontaktujte nás","themes":"Motivy","themes_desc":"Poznejte více z Vašich pozadí s tmavými a průhlednými motivy","bgs":"Živé pozadí","bgs_desc":"Oživte svoji stránku jedním z 20ti živých pozadí ve vysokém rozlišení","widgets":"Maximalizovatelné widgety","widgets_desc":"Poznejte novou úroveň ProductivityTab použitím maximalizovatelných widgetů","more_header":"A další","stocks":"Akcie v reálném čase s jejich detaily a historií","rss":"Podpora více RSS feedů v jednom widgetu","sports":"Obecné i ligové sportovní novinky","tabbed_widgets":"Widgety pro karty novinek a RSS kanály","bg_downloads":"Stahovatelné pozadí","weather":"Hodinové předpovědi počasí až na 10 dní dopředu","toolbar":"Více odkazů v panelu nástrojů","ads":"A completely ad-free experience","support":"Rychlejší podpora a nápověda","buy_pro":"Koupit Pro"},"checkout":{"title":"Platba","updating_title":"Aktualizovat plán","payment_options":"Zaplatit","pay_monthly":"Měsíčně($4.99)","pay_yearly":"Ročně ($29.99)","cancel":"Zrušit","update":"Aktualizovat","subscribe":"Předplatit","braintree_notice":"Platby jsou bezpečně zpracovávány přes Braintree.","monthly_notice":"Předplacením povolujete ProductivityTab aby Vám účtoval $4.99 každý měsíc, dokud nezrušíte své předplatné.","yearly_notice":"Předplacením povolujete ProductivityTab aby Vám účtoval $29.99 každý měsíc, dokud nezrušíte své předplatné.","update_notice":"Ačkoliv změny účtovacího cyklu se projeví okamžitě, částka Vám nebude účtována dokud neskončí aktuální cyklus.","thank_you":"Děkujeme za zakoupení ProductivityTab Pro!","thank_you2":"ProductivityTab se znovu načte za pár sekund a poté budete připraveni!","error":"Něco se nepodařilo během zpracování Vaší platby.","error2":"Prosím zkuste to později nebo nás kontaktujte na support@ichro.me","signin":"Přihlásit se","signin_desc":"Pro koupení Pro verze se nejprve přihlaste, abychom věděli, že jste to Vy","signin_btn":"Přihlásit se"},"plan":{"title":"Plán","desc":"Právě jste přihlášeni k předplatnému ProductivityTab Pro (%s)","types":{"monthly":"Měsíčně","yearly":"Ročně","business":"Pro firmy","education":"Pro školy","custom":"Vlastní"},"uneditable_desc":"Plány pro firmy, školy a speciální plány nelze aktualizovat přes ProductivityTab. Prosím <a href=\"mailto:support@ichro.me\">kontaktujte nás</a> pro aktualizaci nebo zrušení Vašeho předplatného.","status":"Stav","status_active":"Aktivní","status_trial":"Zkušební verze","status_pastdue":"Po splatnosti","subscription_date":"Datum předplatného","paid_through":"Zaplaceno do","next_bill":"Další platba","next_bill_value":"$%s k %s","update_plan":"Aktualizovat plán","update_billing":"Aktualizovat účtování","cancel":"Zrušit předplatné","cancel_notice":"Vaše předplatné bude zrušeno okamžitě","cancel_notice2":"Pokud si přejete vrátit peníze, kontaktujte nás prosím na support@ichro.me"}},"ads":{"text1":"ProductivityTab displays a few small ads to pay for server, support and development costs. With these ads, we can afford to offer ProductivityTab free to everyone.","text2":"Here you can choose where those ads are shown, or buy ad-free to permanently remove them.","text3":"Ad-free is a one-time purchase that permanently removes ads from ProductivityTab wherever you're signed in. You can also upgrade to Pro for extra features in addition to an ad-free experience.","upgrade_btn":"Upgrade to ad-free","already_upgraded":"It looks like you've already upgraded to ad-free","signin":"Přihlásit se","signin_desc":"Sign in before upgrading so we can link your purchase to your account","signin_btn":"Přihlásit se","thank_you":"Thank you for upgrading to ad-free!","placement":{"title":"Ad placement","left":"In the leftmost column","right":"In the rightmost column","top":"Above the tab","bottom":"Floating at the bottom"}}},"store":{"installation":"Instalace","description":"Popis","preview":"Náhled","instructions":"Protáhňete libovolnou velikost na domovskou stránku"},"widgets":{"sizes":{"tiny":"Drobné","small":"Malé","medium":"Střední","large":"Velké","variable":"Proměnná"},"settings":{"title":"Nastavení widgetu","save":"Ulož","size":"Velikost widgetu"},"minimize":"Minimalizovat","maximize":"Maximalizovat","delete_confirm":"Opravdu chcete odstranit tento widget?\nTato akce nemůže být vrácena zpět a všechna data z tohoto widgetu budou ztracena.","permissions_request":{"title":"Povolení k přístupu vyžadováno","button":"Povolit přístup","desc":"Tento widget vyžaduje před použitím speciální pověření. Povolte jej pomocí tlačítka níže."},"error":{"explanation":"Při zobrazení widgetu došlo k potížím.","advice":"Pokuste se widget přeinstalovat nebo obnovit stránku. Pokud se vám tato zpráva zobrazuje často, kontaktujte nás.","support":"Podpora","refresh":"Obnovit"},"auth":{"message":"Pokud chcete používat tento widget, musíte mu povolit přístup k vašemu účtu.","button":"Povolit přístup"},"shared":{"settings":{"title":"Název widgetu","title_placeholder":"Zadejte název widgetu a nebo nezadávejte nic. V takovém případě se název nezobrazí.","height":"Výška widgetu","open_options":{"current":"Současná záložka (tab)","blank":"Nová záložka"},"footer_link":"Odkaz v zápatí","footer_link_options":{"show":"Zobrazit","hide":"Skrýt"},"account":"ID účtu","account_help":"Pokud jste přihlášeni na více účtech, toto je \"authuser =\" hodnota. < br / > < br / > Například pokud jste přihlášeni na dvou účtech, jnovak1@gmail.com a jnovak2@gmail.com, \"authuser\" hodnota pro jnovak2@gmail.com je 1, protože je to druhý účet (počítáno od nuly) .","account_placeholder":"Vaše \"authuser =\" hodnota","on":"Zapnout","off":"Vypnout"}},"apps":{"name":"Aplikace","desc":"Zobrazit aktuálně nainstalované Google Chrome aplikace.","settings":{"format":"Formát widgetu","format_options":{"tiles":"Dlaždice","list":"Seznam"},"display":"Zobrazit","display_options":{"all":"Všechny aplikace","enabled":"Pouze povolené aplikace"},"sort":"Seřadit","sort_options":{"id":"ID","alphabetically":"Abecedně","offline":"Použitelné offline","available":"Dostupnost"},"open":"Otevírat aplikace v"},"store_app":"Obchod"},"bookmarks":{"name":"Záložky","desc":"Zobrazí vybrané a upravené záložky a další odkazy.","settings":{"title_placeholder":"Zadejte název widgetu","layout":"Rozložení","layout_options":{"single":"Jeden sloupec","double":"Dva sloupce"},"open":"Otevřít záložky v"},"edit":{"dialog_title":"Upravit záložku","title":"Název záložky","title_placeholder":"Google","url":"URL záložky","url_placeholder":"https://www.google.com/","save":"Uložit"},"new_caption":"Nový","new_bookmark":"Záložka","new_folder":"Složka","drop_link":"Sem přetáhněte odkaz"},"chrome_bookmarks":{"name":"Záložky","desc":"Zobrazí Vaše záložky z Chrome, volitelně z určité složky.","settings":{"title_placeholder":"Zadejte název widgetu","from":"Zobrazit záložky z","open":"Otevři záložky v"}},"calc":{"name":"Kalkulačka","desc":"Zobrazí kalkulačka s podporou pro základní operátory.","error":"Chyba!","infinity":"Nekonečno","mismatch":"Neodpovídající závorky"},"calendar":{"name":"Kalendář","desc":"Zobrazuje nadcházející události z jednoho nebo více vašich Google kalendářů.","settings":{"calendar":"Kalendář","show":"Zobrazit události z","show_options":{"all":"Kdykoli","today":"Pouze dnes"}},"title":"Agenda","calendar":"Kalendář","noevents":"Nenalezeny žádné události v blízké době, vypadá to, že váš kalendář je prázdný!"},"clock":{"name":"Hodiny","desc":"Nabízí budík, čas, odpočet a stopky.","settings":{"timezone":"Časové pásmo","timezone_local":"Místní","format":"Formát hodin","format_options":{"ampm":"AM/PM - digitální","24hour":"24 hodinové - digitální","analog":"12 hodinové - analogové","ampmseconds":"DOP/ODP - Digitální, bez sekund","24hourseconds":"24 hodin -  - Digitální, bez sekund"},"sound":"Zvuk upozornění"},"title":"Hodiny","alarm":"Alarm","clock":"Hodiny","timer":"Odpočet","stopwatch":"Stopky","set":"Nastavit","unset":"Zrušit nastavení","dismiss":"Odmítnout","enable_audio":"Povolit zvuk"},"facebook":{"name":"Facebook","desc":"Vloží Facebook widget"},"feedly":{"name":"Feedly","desc":"Zobrazit články z vašeho účtu Feedly v konfigurovatelném formátu.","settings":{"source":"Zobrazit články z","source_feeds":"Kanály","show":"Zobrazit","show_options":{"all":"Všechny příspěvky","unread":"Pouze nepřečtené příspěvky"},"layout":"Uspořádání","layout_options":{"titles":"Pouze nadpisy","magazine":"Časopis","cards":"Karty","cards_columns":"Karty (dva sloupce)"},"mark":"Označit články jako přečtené, když","mark_options":{"scroll":"Posuň \"vložit\" nebo \"kliknout\"","click":"Stačí kliknout"},"sort":"Řadit podle","sort_options":{"newest":"Od nejnovějších","oldest":"Od nejstarších"}},"all":"Vše","saved":"Uloženo pro později","uncategorized":"Nezařazeno","author":"od","go_to_feedly":"Přejít na Feedly"},"notes":{"name":"Poznámky","desc":"Vloží jednoduchou, upravitelnou poznámku.","settings":{"color":"Barva poznámky","color_options":{"yellow":"Žlutá","orange":"Oranžová","red":"Červená","blue":"Modrá","green":"Zelená","white":"Bílá"},"font":"Řez písma","fontsize":"Velikost písma"}},"now":{"name":"Google Now","desc":"Zobrazí karty z Google Now včetně letového provozu a sledování zásilek.","authorize":"Budete muset dát ProductivityTab oprávnění k zobrazení karet Google Now dříve, než se tady něco objeví.","authorize_btn":"Povolit","caught_up":"Vše zachyceno","no_title":"Bez názvu"},"plus":{"name":"Google+","desc":"Vloží Google Plus widget"},"notifications":{"name":"upozornění Google","desc":"Zobrazuje Vaše upozornění Google ze služeb jako Google+"},"reddit":{"name":"Reddit","desc":"Zobrazí top položky na Reddit-u pro daný subreddit.","settings":{"subreddit":"Subreddit","subreddit_help":"Pokud používáte Reddit, na termín se odkazujte textem umístěným za <b>/r/</b>. < br /><br />\nNapříklad termín Technology je na: <a href=\"https://www.reddit.com/r/technology\"> https://www.reddit.com/r/technology</a>, tedy zadáte <b>technology</b>","subreddit_placeholder":"Zadejte subreddit pro zobrazení odkazů. (například: technologie)","sort":"Řadit podle","sort_options":{"hot":"Populární","top":"Nejlepší","new":"Nový","gilded":"Gilded","rising":"Rostoucí","controversial":"Kontroverzní"},"links":"Zobrazené odkazy","click":"Když kliknu na odkaz, zobraz","click_options":{"link":"Odkaz","comments":"Komentáře"}},"more":"Více"},"tasks":{"name":"Úkoly","desc":"Zobrazuje upravitelný list úkolů z jednoho Vašeho listu Google Tasks.","title":"Úkoly","settings":{"list":"seznam"},"task_title":"Nadpis","due_date":"Datum konce","notes":"Poznámky","add":"Přidat položku","delete_task":"Odstranit úkol","move_up":"Posunout nahoru","move_down":"Posunout dolu","done":"Hotovo","due_today":"Končící dnes","overdue":"Po konci","authorize":"Před tím, než zde může být cokoliv zobrazeno, v nastavení musíte vybrat list z  Vašeho Google Tasks."},"twitter":{"name":"Twitter","desc":"Zobrazí tweety z vašeho domácího streamu a nebo určitého seznamu.","settings":{"source":"Zobrazit Tweety od","show":"Zobrazené Tweety"},"authorize":"Je zapotřebí nejprve autorizovat ProductivityTab","authorize_msg":"Je potřeba nejprve udělit ProductivityTab povolení k prohlížení tweetů z vašeho účtu, než bude možné zde něco zobrazit.","authorize_btn":"Povolit","no_tweets":"Nezdá se, že by zde byly nějaké tweety...","home":"Domovská stránka","mentions":"Citace","retweets":"Retweety o mě","lists":"Seznamy","more":"Více","reply":"Odpovědět","retweet":"Retweet","favorite":"Oblíbené"},"wolfram":{"name":"Wolfram|Alpha","desc":"Vloží malé Wolfram|Alpha vyhledávací pole."},"youtube":{"name":"YouTube","desc":"Zobrazí populární videa nebo videa od zadaného uživatele.","settings":{"format":"Formát","format_options":{"large":"Jeden velký","large_2":"Jeden velký, dva malé","large_4":"Jeden velký, čtyři malé","four":"Čtyři malé","six":"Šest malých"},"from":"Zobrazí videa z","from_help":"Toto musí být <b>přesné</b> uživatelské jméno, jak je uvedeno v URL stránky, když zobrazujete jejich profil.\n<br /><br />\nTato hodnota nikdy obsahuje mezery.","from_placeholder":"Pro zobrazení top videí ponechejte prázdné","open":"Otevřít výsledky vyhledávání v"},"search":"Prohledat YouTube","num_views":"zhlédnutí"},"quotes":{"name":"Nabídky","desc":"Zobrazí nabídku buď při každém načtení stránky, nebo jednou denně.","settings":{"source":"Zdroj","method":"Nahrát nové nabídky","method_options":{"daily":"Jednou za den","random":"Pokaždé, když načtu stránku"}},"unknown_author":"Neznámý"},"html":{"name":"HTML","desc":"Zobrazuje Váš HTML kód v iFramu.","settings":{"html":"HTML","js":"JavaScript","height":"Výška widgetu"}},"sitelink":{"name":"Odkaz na stránku","desc":"Vytvoří odkaz - volitelně s názvem a náhledem","settings":{"link":"URL odkazu","link_placeholder":"https://www.google.com/","image":"URL adresa obrázku","image_placeholder":"https://www.example.com/image.png","color":"Barva pozadí obrázku","style":"Styl obrázku","style_fill":"Vyplnit","style_center":"Uprostřed"}},"stats":{"name":"Systémové statistiky","desc":"Sledujte aktualizované statistiky vašeho systému","memory":"Paměť","battery":"Baterie","usage":"využito","in_use":"používáno","remaining":"zbývající","charged":"Plně nabito","idle":"Nečinný","charging":"Nabíjení","discharging":"Vybíjení"},"search":{"name":"Hledat","desc":"Vložte vyhledávací pole na svoji stránku pro snadný přístup","settings":{"placeholder":"Zástupný symbol vyhledávacího pole","search_url":"Hledat URL","param":"Parametr pro dotaz","param_placeholder":"Parametr ve které je hledaný výraz předáván, například \"q\""},"default_placeholder":"Prohledat Google"},"pushbullet":{"name":"Pushbullet","desc":"Udržovat přehled o oznámení z vašeho telefonu a jiných zařízení","no_pushes":"Nenalezeny žádné pushe","sign_in":"Přihlásit se","no_key":"Nevypadá to, že jste přihlášeni do Pushbullet.  Přihlaste se nyní pro připojení tohoto widgetu."},"linkedin":{"name":"LinkedIn","desc":"Zobrazí váš LinkedIn domácí stream"},"directions":{"name":"Směry","desc":"Najděte instrukce odkud a kam téměř kdekoliv, přímo z Vaší domovské stránky","driving":"Jízda autem","transit":"Veřejná doprava","walking":"Pěšky","cycling":"Cyklistika","from":"Zadejte počáteční bod","to":"Zadejte cíl","loading":"Načítám instrukce, prosím čekejte...","error":"Při načítání požadovaných instrukcí došlo k nečekané chybě.","error2":"Zkontrolujte, prosím, počáteční a cílovou adresu, kterou jste zadali.","open_in_maps":"Otevřít v Mapách Google","via":"přes"},"pocket":{"name":"Pocket","desc":"Zobrazuje seznam vašich uložených článků, videí a stránek z Pocket","settings":{"links_shown":"Počet zobrazených odkazů","open":"Otevřené odkazy","open_pocket":"V Pocket","open_original":"Na jejich původní URL"},"by":"Od","no_links":"Nenalezeny žádné odkazy","grant_access":"Udělit přístup","no_key":"Budete muset dát ProductivityTab přístup k vašemu účtu Pocket, aby mohl načíst vaše odkazy."}},"themes":{"title":"Motivy","all":"Vše","custom":"Vlastní","create":"Vytvoření motivu","url_or_upload":"nebo","upload_image":"Nahrát obrázek","edit_btn":"Upravit","delete":"Smazat","use":"Použít","preview":"Náhled","author":"Od","images":"%s obrázků","resolution":"Rozlišení","categories":"Kategorie","cached":"Tento motiv je uložen ve vyrovnávací paměti a je dostupný offline","random":"Tento motiv zobrazuje náhodný obrázek pří každém načtení stránky","random_daily":"Motiv zobrazuje každý den náhodný obrázek","sunrise_sunset":"Tento motiv zobrazuje náhodný obrázek dle aktuálního času","feed":"Tento motiv zobrazí obrázek z externího kanálu dle denního výběru","video":"Tento motiv zobrazuje živé video","pro_only":"Tento motiv je k dispozici pouze pro uživatele Pro. Koupit Pro v nastavení.","delete_confirm":"Jste si opravdu jisti, že chcete vymazat tento motiv?\nTato akce je nevratná; celý motiv bude navždy ztracen.","delete_error":"Došlo k chybě při pokusu odstranit motiv.  Prosím opakujte akci později.","feed_fetching":"Počkejte prosím, stahuji kanál...","feed_error":"Při pokusu o načtení informačního kanálu došlo k chybě.  Opakujte prosím akci později.","caching":"Čekejte prosím, stahuji motiv...","cache_status":"%s z %s obrázků uložených v mezipaměti","cache_error":"Došlo k chybě při pokusu načíst motiv do mezipaměti.  Prosím opakujte akci později","bginfo":{"view":"Zobrazit","source":"Zdroj","unknown":"Neznámý","download":"Stáhnout","pro_only":"Pouze uživatelé Pro mohou stahovat obrázky pozadí a videa"},"edit":{"title":"Upravit motiv","create_title":"Vytvořit motiv","name":"Název motivu","default_name":"Nový motiv","name_placeholder":"Zadejte název motivu","image":"URL adresa obrázku","image_placeholder":"Zadejte URL obrázku pozadí","image_help":"Nahrané obrázky <b>nelze synchronizovat</b> mezi počítači.<br /><br />Pokud je to pro vás důležité, prosím nahrajte obrázek na webovou službu jako například <a href=\"https://imgur.com/\" target=\"_blank\">imgur</a>. Poté zkopírujte a vložte URL adresu s příponou (tj. jpg) a vložte ji do pole vlevo.","color":"Základní barva","color_placeholder":"Zadejte libovolný název barvy","position":"Pozice","position_options":{"center":"Uprostřed","top_left":"Vlevo nahoře","top_center":"Uprostřed nahoře","top_right":"Vpravo nahoře","bottom_left":"Vlevo dole","bottom_center":"Uprostřed dole","bottom_right":"Vpravo dole"},"scaling":"Velikost","scaling_options":{"auto":"Automatická detekce","width":"Plná šířka","height":"Plná výška","none":"Bez zoomování (náhled může být nepřesný)"},"repeat":"Opakování obrázku","repeat_options":{"none":"Žádné","horizontal":"Opakovat vodorovně","vertical":"Opakovat svisle","both":"Opakovat v obou směrech"},"attach":"Připojit obrázek","attach_tab":"Ke kartě","attach_window":"K oknu","preview":"Náhled","save":"Uložit a zavřít","cache_error":"Došlo k chybě při pokusu načíst obrázek který jste zadali do mezipaměti, prosím zkontrolujte URL adresu.","upload_error":"Došlo k chybě při pokusu o uložení souboru, který jste zadali, prosím ujistěte se, že je přiměřené velikosti a je to obrázek."}}},"da":{"lang_code":"da","language":"Dansk","extName":"ProductivityTab — Custom Homepage Dashboard","newtabName":"ProductivityTab — Custom New Tab Dashboard","extDescription":"A remarkably customizable personal homepage featuring 50+ widgets, breathtaking backgrounds and much more.","newtabDescription":"A customizable personal dashboard on your new tab page featuring 50+ widgets, breathtaking backgrounds and much more.","defaults":{"tab":"Hjem","me":"Mig"},"remove_widget":"Fjern","hide_banner":"Hide this banner","hide_ad":{"content":"Hey! We're not crazy about ads either, but we're only able to make ProductivityTab available and continue developing features for our free users (that's you!) by showing ads. If you'd like to support ProductivityTab directly and get rid of ads for free, we would really appreciate if you upgraded to our pro version","upgrade":"Upgrade","hide":"Hide ads"},"alert":{"default_button":"Slet","confirm_title":"Er du sikker på du vil gøre dette?","confirm_continue":"Fortsæt","confirm_cancel":"Anuller"},"onboarding":{"modal":{"tagline":"Alle de websteder og programmer, du bruger, på ét sted","wrong_extension":"Vil du have ProductivityTab på dit ny faneblad i stedet?","wrong_extension_newtab":"Vil du have ProductivityTab på startside i stedet?","wrong_extension_action":"Klik her","about":"ProductivityTab er lutter faner og widgets","about_desc":"Faner er sider fyldt med widgets - blokke, der viser ting som vejret, nyheder og din e-mail. Du kan tilpasse de fleste widgets og tilføje så mange som du ønsker.","terms":"Hvis du fortsætter, accepterer du ProductivityTab's <a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\">Terms</a> and <a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\">Privat Politik</a>","sign_in":"Log ind med din Google-konto","sign_in_desc":"Log ind med din Google konto før du starter, så du kan gemme dine ændringer online.","sign_in_desc2":"Du kan forblive logget ud, hvis du ønsker det, men din side vil ikke blive gemt online og du vil ikke kunne tilgå din side fra andre computere.","sign_in_button":"Log på med Google","have_account":"Det ser ud til, at du allerede har en konto!","have_account_desc":"Alle dine faner og widgets er klar til brug!","get_started":"Lad os komme i gang!","get_started_desc":"Du er klar! Lad os få din side er oprettet."},"widgets":{"configure":"Lad os konfigurere en widget.","configure_desc":"Click the wrench to open a widget's <b>settings</b>.","configure_skip":"Skip Tutorial","settings":"Replace <b>Link URL</b> with your favorite site, then press <b>Save</b>.","move":"You can <b>reposition</b> widgets by clicking and dragging the three dots highlighted here.","remove":"To <b>delete</b>, simply click the red trash bin icon.","done":"Forstået"},"settings":{"intro":"Now let’s add a new widget. This highlighted button is where you can access the Widget Menu.","instructions":"Click the new widget button on to open the widget menu!","skip":"Spring over","tooltips":{"settings":"Skift ProductivityTabs udseende og funktion","widgets":"Tilføje nye widgets - du kan have så mange som du ønsker","editing":"Vis eller skjul redigeringsknapperne på widgets","links":"Dette er en liste over links, tilføj websteder, du bruger ofte i indstillingerne","tabs":"Her er dine faner. Du kan tilføje flere i indstillingerne","support":"Send os en besked eller skriv en anmeldelse her"},"finished":"Sådan!","finished_next":"Vælg en indstilling i menuen (Begynd med <b>Widgets</b>) og opret din side!","finished_contact":"Brug linket support, hvis du har brug for hjælp, og vi vil vende tilbage til dig hurtigst."}},"storage":{"signin":"Log på med Google for sikkert at gemme og synkronisere din konfiguration","signin_btn":"Log på","signin_dismiss":"Afvis","signin_confirm":{"title":"Beholde lokale data?","desc":"Vil du beholde dine lokale data og erstatte kontoindstillingerne med disse, eller vil du erstatte denne computers indstillinger med dine eksisterende kontoindstillinger?","keep_account":"Brug konto","keep_local":"Forbliv lokal"},"signout_confirm":"Log ud vil slette dine lokale backups","pastdue":"Dit abonnement er udløbet","pastdue_desc":"Opdater venligst dine faktureringsoplysninger i indstillingerne"},"toolbar":{"placeholder":"Indtast dine betingelser","placeholder_ok":"Indtast dine betingelser eller sig \"OK, Google\"","suggestions":{"url_subtext":"Visit URL","capture_notice":"ProductivityTab handles searches you normally make from the Omnibox. You can disable this at any time from the settings"},"apps":{"search":"Søg","youtube":"Youtube","maps":"Kort","play":"Afspil","news":"Nyheder","gmail":"Gmail","drive":"Drev","calendar":"Kalender","more":"Mere"}},"menu":{"settings":"Indstillinger","widgets":"Widgets","editing":"Redigering","editing_enabled":"Aktiveret","editing_disabled":"Deaktiveret","plus":"Google Plus","tabs":"Faner","footer":{"support":"Hjælp","feedback":"Feedback","review":"Gennemse","terms":"Vilkår","privacy":"Beskyttelse af personlige oplysninger","by":"Af Avi Kohn"}},"voice":{"listening":"Lytter...","searching":"Søger: %s","missed":"Dette blev ikke forstået. <a>Prøv igen</a>"},"settings":{"title":"Indstillinger","exit":"Afslut indstillinger","saved":"Indstillinger gemt","nav":{"visual":"Visuel","visual_sections":{"background":"Baggrund","layout":"Opsætning","theme":"App tema","ad_placement":"Ad placement"},"toolbar":"Værktøjsbjælke","toolbar_sections":{"style":"Udseende","search":"Søg","links":"Links"},"tabs":"Faner","widgets":"Widgets","ads":"Ads","pro":"Pro","accounts":"Konto","misc":"Diverse","advanced":"Avanceret","advanced_sections":{"backups":"Backup og gendan","css":"Custom CSS","debug_tools":"Fejlfindingsværktøj"},"support":"Hjælp og support","suggest":"Foreslå en funktion"},"visual":{"background":{"title":"Baggrund","desc":"Dette/disse billeder vises som baggrund for din faneblade","current":"Aktuelle baggrund","custom":"Egen","unnamed":"Tema %s","select":"Vælg et tema","or":"eller","url_placeholder":"Angiv et billede URL"},"layout":{"title":"Opsætning","desc":"Her kan du justere type og antal kolonner i hvert faneblad","columns":"Kolonner","grid":"Oversigt","columns_number":"Antal kolonner","column_width":"Kolonnebredde","column_width_fixed":"Fast","column_width_fluid":"Flydende","column_warning":{"column_to_grid":"Ændring til et oversigt-layout vil flytte alle dine widgets til øverste venstre hjørne.","grid_to_column":"Skifter du til en søjle baseret visning, vil det flytte alle dine widgets til den første kolonne."}},"theme":{"title":"App tema","desc":"App temaet styrer udseendet af ProductivityTab og alle widgets","preview":"Forhåndsvisning","light":"Lys (standard)","dark":"Mørk","transparent":"Gennemsigtig","transparent_darker":"Gennemsigtig (mørkere)"}},"toolbar":{"style":{"title":"Udseende","desc":"Dette bestemmer udseendet på din værktøjslinje. Den kan enten vises normalt eller vises som trykknapper","normal":"Normal","button":"Knap"},"search":{"title":"Søg","desc":"Disse indstillinger kontrollerer hvordan søgeboks og stemmesøgning fungerer","engine":"Søgemaskine","engines_default":"Default","engines_custom":"Brugerdefineret","engines_custom_desc":"Enter a URL that queries should be sent to, with <b>%s</b> where the query should go.","omnibox_capture":"Handle searches normally made in the Omnibox","voice":"Aktiver stemmesøgning","ok_google":"Aktiver \"OK Google\" nøgleord detektion","search_tab":"Åben søgeresultater i en ny fane"},"links":{"title":"Links","desc":"Dette er de elementer, der vises til højre for værktøjslinjen","apps":"Apps menu","custom":"Brugerdefinerede links","custom_note1":"Maksimum 3 er tilladt","custom_note2":"brugere får 8","custom_name_placeholder":"Link tekst","custom_url_placeholder":"Link webadresse, for eksempel https://www.google.com"}},"misc":{"link_tab":"Åben link i en ny fane som standard"},"tabs":{"create_new":"Opret ny","make_default":"Vælg som standard","desc1":"Faner er sider indeni ProductivityTab. Hver fane har sit eget sæt af widgets, der er helt uafhængig fra alle andre faner.","desc2":"Du kan skifte mellem faner ved at klikke på knapperne, der vises til venstre og højre side af skærmen, når du flytter musen hen over en fane eller ved at bruge piletasterne på dit tastatur.","name_placeholder":"Angiv et fanenavn","delete_confirm":"Denne aktion er uigenkaldelig. Alle data fra alle widgets i fanebladet mistes."},"accounts":{"status":{"title":"Status","signed_in":"Du er i øjeblikket <b>logget ind</b> som %s (%s).","reset_account":"Nulstil konto","sign_out":"Log ud","signed_out":"Du er <b>ikke i øjeblikket logget ind</b>. Log ind med din Google konto nu, for sikkert at gemme og synkronisere dine indstillinger.","sign_in":"Log ind med Google"},"reset_confirm_desc":"Dette vil slette alle lokale indstillinger og synkroniserede data. Der laves ikke backup og du kan ikke fortryde handlingen.","reset_confirm_desc2":"Du vil miste hele din nuværende konfiguration på alle computere, der er forbundet med denne konto."},"advanced":{"backups":{"title":"Backup og gendan","desc":"Backups er komplette kopier af alle dine tabs, indstillinger og widgets. De bliver automatisk genereret hver dag når du starter ProductivityTab første gang.","desc2":"Brug nedenstående knapper for at vælge en specifik ProductivityTab genskabelses dato, eller download en af dine backups.","backup":"Sikkerhedskopi nu","upload":"Gendan fra fil","download":"Download","restore":"Gendan","download_name":"ProductivityTab sikkerhedskopi","restore_confirm":"Dette vil overskrive alle lokale og synkroniserede data. Du vil miste din hele aktuelle konfiguration på alle computere under denne konto.","restore_error":"An error occurred while trying to parse the provided data, please try again later."},"css":{"title":"Custom CSS","desc":"You can use CSS (<a href=\"https://developer.mozilla.org/en-US/docs/Web/CSS\" target=\"blank\">definition</a>) to customize almost any part of ProductivityTab.","placeholder":"Indtast op til 1000 tegn i CSS her"},"debug_tools":{"title":"Fejlfindingsværktøj","desc":"<b>WARNING:</b> These tools can erase your entire configuration in a single click. Only use them if your developer instructs you to.","open":"Åben værktøjer"}},"widgets":{"desc1":"Widgets har deres egne indstillinger og kan ikke tilpasses her.","desc2":"Følg disse trin for at redigere indstillingerne for en widget:","steps1":"Bevæg musen hen over en widget","steps2":"Klik på skruenøgle ikonet oppe i højre hjørne af en widget. Hvis der ikke findes et skruenøgle ikon betyder dette at denne widget ikke har indstillinger der kan tilpasses.","steps3":"Rediger tilgængelige indstillinger i den viste dialogboks","steps4":"Klik på Gem for at gemme dine ændringer, eller en del af baggrunden for at skille sig af med dem"},"pro":{"promo":{"monthly_price":"$4.99 per måned","yearly_price":"eller $29.99 per år","upgrade_btn":"Opdater nu","business":"Interesseret i at købe Pro version til din virksomhed eller uddannelsesinstitution?","business_contact":"Kontakt os","themes":"Temaer","themes_desc":"Se flere af dine baggrunde med mørke og gennemsigtige temaer","bgs":"Levende baggrunde","bgs_desc":"Giv din side liv med 20 live HD baggrunde","widgets":"Widget kan maksimeres","widgets_desc":"Få mere ud af ProductivityTab med widgets der kan maksimeres","more_header":"Og meget mere","stocks":"Aktier i realtid, med udvidet og historisk information","rss":"Understøttelse af simultane RSS feeds per widget","sports":"General og liga specifikke sportsnyheder","tabbed_widgets":"Nyheder vist i tabs og via RSS widgets","bg_downloads":"Baggrunde kan downloades","weather":"Time for time vejrudsigter op til 10 dage frem","toolbar":"Flere værktøjslinje-links","ads":"A completely ad-free experience","support":"Prioriteret hjælp og forslag","buy_pro":"Køb Pro"},"checkout":{"title":"CheckUd","updating_title":"Opdaterings plan","payment_options":"Betal","pay_monthly":"Månedlig ($4.99)","pay_yearly":"Årlig ($29.99)","cancel":"Anuller","update":"Opdater","subscribe":"Abonnér","braintree_notice":"Betaling håndteres sikkert via Braintree.","monthly_notice":"Ved at abonnere giver du ProductivityTab ret til at trække 4.99$ hver måned indtil du opsiger dit abonnement.","yearly_notice":"Ved at abonnere giver to ProductivityTab ret til at trække 29.99$ hvert år indtil du opsiger dit abonnement.","update_notice":"Ændringer i betalings cyklus sker med det samme, men der trækkes ikke penge før den nuværende cyklus er afsluttet.","thank_you":"Tak for at du købte ProductivityTab Pro!","thank_you2":"ProductivityTab genstarter om få sekunder, herefter vil alt være klart!","error":"Noget gik galt under behandlingen af din betaling.","error2":"Prøv venligst igen senere, eller send os en mail på support@ichro.me","signin":"Log ind","signin_desc":"Log ind før du køber Pro, så er vi sikre på at det er dig","signin_btn":"Log ind"},"plan":{"title":"Planlæg","desc":"Du abonnerer på ProductivityTab Pro (%s)","types":{"monthly":"Månedlig","yearly":"Årlig","business":"Erhverv","education":"Uddannelse","custom":"Brugerdefineret"},"uneditable_desc":"Erhverv, uddannelse og brugerdefinerede planer kan ikke opdateres indefra ProductivityTab. Venligst <a href=\"mailto:support@ichro.me\">kontakt os</a> for at opdatere eller annullere dit abonnement.","status":"Status","status_active":"Aktiv","status_trial":"Prøveversion","status_pastdue":"Udløbet","subscription_date":"Abonnements dato","paid_through":"Betalt via","next_bill":"Næste regning","next_bill_value":"$%s på %s","update_plan":"Opdater abonnement","update_billing":"Opdater regning","cancel":"Afmeld abonnement","cancel_notice":"Dit abonnement vil blive annulleret øjeblikkeligt","cancel_notice2":"Ønsker du refusion, venligst kontakt os på support@ichro.me"}},"ads":{"text1":"ProductivityTab displays a few small ads to pay for server, support and development costs. With these ads, we can afford to offer ProductivityTab free to everyone.","text2":"Here you can choose where those ads are shown, or buy ad-free to permanently remove them.","text3":"Ad-free is a one-time purchase that permanently removes ads from ProductivityTab wherever you're signed in. You can also upgrade to Pro for extra features in addition to an ad-free experience.","upgrade_btn":"Upgrade to ad-free","already_upgraded":"It looks like you've already upgraded to ad-free","signin":"Sign in","signin_desc":"Sign in before upgrading so we can link your purchase to your account","signin_btn":"Sign in","thank_you":"Thank you for upgrading to ad-free!","placement":{"title":"Ad placement","left":"In the leftmost column","right":"In the rightmost column","top":"Above the tab","bottom":"Floating at the bottom"}}},"store":{"installation":"Installation","description":"Beskrivelse","preview":"Forhåndsvisning","instructions":"Træk og slip alle størrelser ind på din hjemmeside"},"widgets":{"sizes":{"tiny":"Meget lille","small":"Lille","medium":"Medium","large":"Stor","variable":"Variabel"},"settings":{"title":"Widget indstilling","save":"Gem","size":"Widget størrelse"},"minimize":"Minimer","maximize":"Maksimer","delete_confirm":"Er du sikker på, at du ønsker at slette denne widget?\nDenne handling kan ikke fortrydes; alle data fra denne widget vil blive permanent tabt.","permissions_request":{"title":"Adgang kræves","button":"Tildel adgang","desc":"Denne widget skal bruge yderligere tilladelser før den kan bruges. Giv tilladelserne ved hjælp af knappen nedenunder."},"error":{"explanation":"Noget gik galt da vi prøvede at vise denne widget.","advice":"Prøv at geninstallere widget eller genindlæs siden. Kontakt os hvis denne besked vises ofte.","support":"Hjælp","refresh":"Opdater"},"auth":{"message":"Denne widget kræver adgang til din konto, før du kan anvende den.","button":"Tildel adgang"},"shared":{"settings":{"title":"Widget titel","title_placeholder":"Indtast en widget titel. Indtastes ingen titel, skjules titlen","height":"Widget højde","open_options":{"current":"Nuværende fane","blank":"Ny fane"},"footer_link":"Link til sidefod","footer_link_options":{"show":"Vis","hide":"Skjul"},"account":"Konto ID","account_help":"If you're signed into multiple accounts, this is the \"authuser=\" value.\n<br /><br />\nFor example, if you're signed into two accounts, jsmith1@gmail.com and jsmith2@gmail.com, the \"authuser\" value for jsmith2@gmail.com would be 1 since it's the second account (counting from zero) that you're signed into.","account_placeholder":"Your \"authuser=\" value","on":"Aktiv","off":"Slået fra"}},"apps":{"name":"Apps","desc":"Displays your currently installed Google Chrome applications.","settings":{"format":"Widget Format","format_options":{"tiles":"Tiles","list":"Liste"},"display":"Vis","display_options":{"all":"Alle apps","enabled":"Kun aktiveret apps"},"sort":"Sortér","sort_options":{"id":"ID","alphabetically":"Alphabetically","offline":"Offline Enabled","available":"Availability"},"open":"Åben apps i"},"store_app":"Butik"},"bookmarks":{"name":"Bogmærker","desc":"Viser valgte og tilpassede bogmærker, og andre links.","settings":{"title_placeholder":"Enter a widget title","layout":"Opsætning","layout_options":{"single":"Single column","double":"Double column"},"open":"Open bookmarks in"},"edit":{"dialog_title":"Edit Bookmark","title":"Bookmark Title","title_placeholder":"Google","url":"Bookmark URL","url_placeholder":"https://www.google.com/","save":"Gem"},"new_caption":"New","new_bookmark":"Bookmark","new_folder":"Folder","drop_link":"Drop link here"},"chrome_bookmarks":{"name":"Bogmærker","desc":"Displays your Chrome bookmarks, optionally from a specific folder.","settings":{"title_placeholder":"Enter a widget title","from":"Show bookmarks from","open":"Open bookmarks in"}},"calc":{"name":"Calculator","desc":"Displays a calculator with support for basic operators.","error":"Error!","infinity":"Infinity","mismatch":"Mismatched parentheses"},"calendar":{"name":"Kalender","desc":"Displays upcoming events from one or more of your Google calendars.","settings":{"calendar":"Kalender","show":"Show events from","show_options":{"all":"All time","today":"Today only"}},"title":"Agenda","calendar":"Kalender","noevents":"No events found in the near future, it looks like your schedule's clear!"},"clock":{"name":"Clock","desc":"Offers alarm, time, timer, and stopwatch functionality.","settings":{"timezone":"Time Zone","timezone_local":"Local","format":"Clock Format","format_options":{"ampm":"AM/PM - Digital","24hour":"24 Hour - Digital","analog":"12 Hour - Analog","ampmseconds":"AM/PM - Digital, No Seconds","24hourseconds":"24 Hour - Digital, No Seconds"},"sound":"Alert Sound"},"title":"Clock","alarm":"Alarm","clock":"Clock","timer":"Timer","stopwatch":"Stopwatch","set":"Set","unset":"Unset","dismiss":"Dismiss","enable_audio":"Enable audio"},"facebook":{"name":"Facebook","desc":"Embeds Facebook in a widget"},"feedly":{"name":"Feedly","desc":"Displays articles from your Feedly account in a configurable format.","settings":{"source":"Show articles from","source_feeds":"Feeds","show":"Vis","show_options":{"all":"All articles","unread":"Only unread articles"},"layout":"Opsætning","layout_options":{"titles":"Titles only","magazine":"Magazine","cards":"Cards","cards_columns":"Cards (two columns)"},"mark":"Mark an article as read when I","mark_options":{"scroll":"Scroll past it or click it","click":"Just click it"},"sort":"Sort Order","sort_options":{"newest":"Newest first","oldest":"Oldest first"}},"all":"Alle","saved":"Saved for later","uncategorized":"Uncategorized","author":"by","go_to_feedly":"Go To Feedly"},"notes":{"name":"Notes","desc":"Inserts a simple, editable, note.","settings":{"color":"Note Color","color_options":{"yellow":"Yellow","orange":"Orange","red":"Red","blue":"Blue","green":"Green","white":"White"},"font":"Font Face","fontsize":"Font Size"}},"now":{"name":"Google Now","desc":"Displays cards from Google Now including flight status and package tracking.","authorize":"You'll need to give ProductivityTab permission to view your Google Now cards before anything will show up here.","authorize_btn":"Authorize","caught_up":"All caught up, nothing here.","no_title":"No Title"},"plus":{"name":"Google+","desc":"Embeds Google Plus in a widget"},"notifications":{"name":"Google Notifications","desc":"Displays your Google Notifications from services such as Google+"},"reddit":{"name":"Reddit","desc":"Displays the top items on Reddit for any given subreddit.","settings":{"subreddit":"Subreddit","subreddit_help":"Enter any subreddit by the part past <b>/r/</b> when on Reddit.\n<br /><br />\nFor example, Technology is at: <a href=\"https://www.reddit.com/r/technology\">https://www.reddit.com/r/technology</a>, therefore you would enter <b>technology</b>","subreddit_placeholder":"Enter a subreddit to show links from. (i.e. technology)","sort":"Sort Order","sort_options":{"hot":"Hot","top":"Top","new":"New","gilded":"Gilded","rising":"Rising","controversial":"Controversial"},"links":"Links Shown","click":"When I click a link show me","click_options":{"link":"The link","comments":"The comments"}},"more":"Mere"},"tasks":{"name":"Tasks","desc":"Displays an editable list of tasks from one of your Google Tasks lists.","title":"Tasks","settings":{"list":"Liste"},"task_title":"Title","due_date":"Due date","notes":"Notes","add":"Add Item","delete_task":"Delete Task","move_up":"Move Up","move_down":"Move Down","done":"Done","due_today":"Due today","overdue":"Overdue","authorize":"You'll need to select a list from your Google Tasks via the settings before anything can be displayed here."},"twitter":{"name":"Twitter","desc":"Displays tweets from your home stream or a specified list.","settings":{"source":"Show Tweets from","show":"Tweets Shown"},"authorize":"You'll need to authorize ProductivityTab first","authorize_msg":"You'll need to give ProductivityTab permission to view tweets from your account before anything will show up here.","authorize_btn":"Authorize","no_tweets":"There don't seem to be any tweets here...","home":"Hjem","mentions":"Mentions","retweets":"Retweets of me","lists":"Lists","more":"Mere","reply":"Reply","retweet":"Retweet","favorite":"Favorite"},"wolfram":{"name":"Wolfram|Alpha","desc":"Inserts a small Wolfram|Alpha search box."},"youtube":{"name":"Youtube","desc":"Displays either popular videos or videos from a specified user.","settings":{"format":"Format","format_options":{"large":"One large","large_2":"One large, two small","large_4":"One large, four small","four":"Four small","six":"Six small"},"from":"Show Videos From","from_help":"This must be an <b>exact</b> username as shown in the URL of the page when you're viewing their profile.\n<br /><br />\nThis value never includes spaces.","from_placeholder":"Leave blank to show Top Videos","open":"Open search results in"},"search":"Search YouTube","num_views":"views"},"quotes":{"name":"Quotes","desc":"Displays a quote picked either every time you load the page or once daily.","settings":{"source":"Source","method":"Load new quotes","method_options":{"daily":"Once daily","random":"Every time I load the page"}},"unknown_author":"Unknown"},"html":{"name":"HTML","desc":"Displays completely custom HTML in an iframe.","settings":{"html":"HTML","js":"JavaScript","height":"Widget højde"}},"sitelink":{"name":"Site Link","desc":"Displays a link, optionally with a title and thumbnail","settings":{"link":"Link URL","link_placeholder":"https://www.google.com/","image":"Image URL","image_placeholder":"https://www.example.com/image.png","color":"Image Background Color","style":"Image Style","style_fill":"Fill","style_center":"Center"}},"stats":{"name":"System Statistics","desc":"Keep an eye on your system with realtime statistics","memory":"Memory","battery":"Battery","usage":"usage","in_use":"in use","remaining":"remaining","charged":"Fully Charged","idle":"Idle","charging":"Charging","discharging":"Discharging"},"search":{"name":"Søg","desc":"Embeds a search box in your page for easy access","settings":{"placeholder":"Search Field Placeholder","search_url":"Search URL","param":"Query Parameter","param_placeholder":"The parameter where the query goes, i.e. \"q\""},"default_placeholder":"Search Google"},"pushbullet":{"name":"Pushbullet","desc":"Keep track of notifications from your phone and other devices","no_pushes":"No pushes found","sign_in":"Sign in","no_key":"It doesn't look like you're signed in to Pushbullet.  Sign in now to connect this widget."},"linkedin":{"name":"LinkedIn","desc":"Displays your LinkedIn home stream"},"directions":{"name":"Directions","desc":"Get directions to and from nearly anywhere right from your homepage","driving":"Driving","transit":"Public Transit","walking":"Walking","cycling":"Cycling","from":"Enter a starting point","to":"Enter a destination","loading":"Loading directions, please wait...","error":"Something went wrong while trying to load the directions you requested.","error2":"Please check the start and destination addresses you entered.","open_in_maps":"Open in Google Maps","via":"via"},"pocket":{"name":"Pocket","desc":"Display a list of your saved articles, videos, and web pages from Pocket","settings":{"links_shown":"Number of links shown","open":"Open links","open_pocket":"In Pocket","open_original":"At their original URL"},"by":"Af","no_links":"No links found","grant_access":"Grant access","no_key":"You'll need to give ProductivityTab access to your Pocket account before it can load your links."}},"themes":{"title":"Temaer","all":"Alle","custom":"Brugerdefineret","create":"Lav et tema","url_or_upload":"eller","upload_image":"Upload et billede","edit_btn":"Rediger","delete":"Slet","use":"Brug","preview":"Forhåndsvisning","author":"Af","images":"%s billeder","resolution":"Opløsning","categories":"Kategorier","cached":"Dette tema er blevet cachet og er tilgængeligt offline","random":"Dette tema viser et tilfældigt billede hver gang du indlæser siden","random_daily":"Dette tema viser et tilfældigt valgt billede hver dag","sunrise_sunset":"Dette tema viser et billede svarende til tid på dagen","feed":"Dette tema viser et billede valgt dagligt fra en ekstern feed","video":"Dette tema viser en video","pro_only":"Dette tema er kun tilgængeligt for Pro brugere. Køb Pro i indstillingerne.","delete_confirm":"Er du virkelig sikker på, du gerne vil slette dette tema? Denne handling er uigenkaldelig; hele temaet mistes permanent.","delete_error":"Der opstod en fejl under forsøg på at slette tema.  Prøv igen senere.","feed_fetching":"Please wait, fetching feed...","feed_error":"Something went wrong while trying to fetch the feed.  Please try again later.","caching":"Please wait, caching theme...","cache_status":"%s of %s images cached","cache_error":"An error occurred while trying to cache the theme.  Please try again later","bginfo":{"view":"View","source":"Source","unknown":"Unknown","download":"Download","pro_only":"Only Pro users can download background images and videos"},"edit":{"title":"Edit Theme","create_title":"Create Theme","name":"Theme Name","default_name":"New Theme","name_placeholder":"Enter a theme name","image":"Image URL","image_placeholder":"Enter a background image URL","image_help":"Uploaded images <b>cannot be synced</b> between computers.<br /><br />If this is important to you, please upload your image to a service such as <a href=\"https://imgur.com/\" target=\"_blank\">imgur</a>. Then copy the URL ending with an extension (i.e. .jpg) and paste it into the field on the left.","color":"Fallback Color","color_placeholder":"Enter any color name","position":"Position","position_options":{"center":"Center","top_left":"Top Left","top_center":"Top Center","top_right":"Top Right","bottom_left":"Bottom Left","bottom_center":"Bottom Center","bottom_right":"Bottom Right"},"scaling":"Scaling","scaling_options":{"auto":"Auto","width":"Full Width","height":"Full Height","none":"Ingen skalering (preview kan unøjagtig)"},"repeat":"Billedgentagelse","repeat_options":{"none":"Ingen gentagelse","horizontal":"Gentag horisontalt","vertical":"Gentag vertikalt","both":"Gentag begge"},"attach":"Vedhæft billede til","attach_tab":"The tab","attach_window":"Vinduet","preview":"Forhåndsvisning","save":"Gem & luk","cache_error":"An error occurred while trying to cache the image you provided, please double-check the URL.","upload_error":"An error occurred while trying to upload the file you provided, please make sure that it's a reasonable size and an image."}}},"de":{"lang_code":"de","language":"Deutsch","extName":"ProductivityTab — Custom Homepage Dashboard","newtabName":"ProductivityTab — Custom New Tab Dashboard","extDescription":"A remarkably customizable personal homepage featuring 50+ widgets, breathtaking backgrounds and much more.","newtabDescription":"A customizable personal dashboard on your new tab page featuring 50+ widgets, breathtaking backgrounds and much more.","defaults":{"tab":"Home","me":"Ich"},"remove_widget":"Löschen","hide_banner":"Hide this banner","hide_ad":{"content":"Hey! We're not crazy about ads either, but we're only able to make ProductivityTab available and continue developing features for our free users (that's you!) by showing ads. If you'd like to support ProductivityTab directly and get rid of ads for free, we would really appreciate if you upgraded to our pro version","upgrade":"Upgrade","hide":"Hide ads"},"alert":{"default_button":"Verwerfen","confirm_title":"Sind Sie sicher?","confirm_continue":"Fortsetzen","confirm_cancel":"Abbrechen"},"onboarding":{"modal":{"tagline":"Alle Webseiten und Programme die Sie nutzen an einem Platz","wrong_extension":"Neue-Tab-Seite durch ProductivityTab ersetzen?","wrong_extension_newtab":"ProductivityTab als Startseite festlegen?","wrong_extension_action":"Hier klicken","about":"Bei ProductivityTab geht es um Tabs und Widgets","about_desc":"Tabs sind Seiten voller Widgets - Blöcke die einem Dinge zeigen wie z. B. das Wetter, Nachrichten und deine E-Mails. Viele kannst du an deinen Stil anpassen. Hinzufügen kannst du so viele wie du möchtest.","terms":"Indem Sie fortfahren erklären Sie sich mit ProductivityTab's <a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\">Nutzungsbedingungen</a> und <a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\">Datenschutzrichtlinien</a> einverstanden","sign_in":"Google Account zum einloggen nutzen","sign_in_desc":"Bevor Sie anfangen, melden Sie sich mit Ihrem Google Account an, um Ihre Änderungen sicher online speichern zu können.","sign_in_desc2":"Sie müssen sich nicht einloggen, aber Ihre Seite wird nicht online gespeichert und kann nicht von anderen Computern aufgerufen werden.","sign_in_button":"Mit Google anmelden","have_account":"Sieht aus als hätten Sie schon einen Account!","have_account_desc":"Alle Ihre Tabs und Widgets sind bereit!","get_started":"Los gehts!","get_started_desc":"Wunderbar! Lassen Sie uns jetzt Ihre Seite eingerichtet."},"widgets":{"configure":"Konfigurieren wir ein Widget.","configure_desc":"Click the wrench to open a widget's <b>settings</b>.","configure_skip":"Skip Tutorial","settings":"Replace <b>Link URL</b> with your favorite site, then press <b>Save</b>.","move":"You can <b>reposition</b> widgets by clicking and dragging the three dots highlighted here.","remove":"To <b>delete</b>, simply click the red trash bin icon.","done":"Verstanden"},"settings":{"intro":"Now let’s add a new widget. This highlighted button is where you can access the Widget Menu.","instructions":"Click the new widget button on to open the widget menu!","skip":"Überspringen","tooltips":{"settings":"Ändern Sie Aussehen und Funktionen von ProductivityTab","widgets":"Fügen Sie neue Widgets hinzu - Sie können so viele nutzen, wie Sie möchten","editing":"Zeige oder verberge die Editier-Schaltfläche der Widgets","links":"Dies ist eine Liste mit Links, die Sie in den Einstellungen um Seiten erweitern können, die Sie oft verwenden","tabs":"Hier finden Sie Ihre Tabs. Sie können weitere Tabs in den Einstellungen hinzufügen.","support":"Schicken Sie uns eine Nachricht oder schreiben Sie hier eine Rezension"},"finished":"Das war's!","finished_next":"Wählen Sie eine Option aus dem Menü (versuchen Sie es mit <b>Widgets</b>) und richten Sie Ihre Seite ein!","finished_contact":"Nutzen Sie den Support-Link und wir helfen Ihnen so schnell wie möglich."}},"storage":{"signin":"Melden Sie sich nun bei Google an, um Ihre Konfiguration zu sichern / zu synchronisieren","signin_btn":"Registrieren","signin_dismiss":"Verwerfen","signin_confirm":{"title":"Lokal gespeicherte Daten behalten?","desc":"Möchten Sie Ihre lokalen Einstellungen behalten und mit diesen die Einstellungen in Ihrem Account ersetzen, oder sollen die in Ihrem Benutzerkonto vorhandenen Einstellungen die lokalen Daten überschreiben?","keep_account":"Benutzerkonto verwenden","keep_local":"Lokale Einstellungen behalten"},"signout_confirm":"Wenn Sie sich ausloggen, wird das lokales Backup gelöscht","pastdue":"Ihr Abonnement ist überfällig","pastdue_desc":"Bitte aktualisieren Sie Ihre Zahlungsinformationen in den Einstellungen"},"toolbar":{"placeholder":"Begriff eingeben","placeholder_ok":"Begriff eingeben oder \"OK, Google\"","suggestions":{"url_subtext":"URL besuchen","capture_notice":"ProductivityTab sucht generell mittels Omnibox. Dies kann jederzeit in den Einstellungen deaktiviert werden."},"apps":{"search":"Suche","youtube":"YouTube","maps":"Karten","play":"Play","news":"Nachrichten","gmail":"Gmail","drive":"Drive","calendar":"Kalender","more":"Mehr"}},"menu":{"settings":"Einstellungen","widgets":"Widgets","editing":"Anpassen","editing_enabled":"aktiviert","editing_disabled":"deaktiviert","plus":"Google Plus","tabs":"Reiter","footer":{"support":"Support","feedback":"Feedback","review":"Beurteilung","terms":"Nutzungsbedingungen","privacy":"Datenschutz","by":"Von Avi Kohn"}},"voice":{"listening":"Höre...","searching":"Suche nach: %s","missed":"Nicht verstanden. <a>Versuche es erneut</a>"},"settings":{"title":"Einstellungen","exit":"Einstellungen verlassen","saved":"Einstellungen gespeichert","nav":{"visual":"Design","visual_sections":{"background":"Hintergrund","layout":"Design","theme":"App-Design","ad_placement":"Ad placement"},"toolbar":"Werkzeugleiste","toolbar_sections":{"style":"Aussehen","search":"Suche","links":"Links"},"tabs":"Reiter","widgets":"Widgets","ads":"Ads","pro":"Pro","accounts":"Benutzerkonto","misc":"Sonstiges","advanced":"Erweitert","advanced_sections":{"backups":"Sichern und Wiederherstellen","css":"Benutzerdefiniertes CSS","debug_tools":"Debug-Tools"},"support":"Hilfe und Support","suggest":"Funktion vorschlagen"},"visual":{"background":{"title":"Hintergrund","desc":"Dies ist das Bild oder die Bilderfolge, die als Hintergrund für Ihre Tabs angezeigt werden","current":"Aktueller Hintergrund","custom":"Benutzerdefiniert","unnamed":"Thema %s","select":"Ein Design auswählen","or":"oder","url_placeholder":"Geben Sie eine Bilder-URL ein"},"layout":{"title":"Design","desc":"Here können Sie Anzahl und Form der Spalten auf jedem Tab anpassen","columns":"Spalten","grid":"Raster","columns_number":"Anzahl der Spalten","column_width":"Spaltenbreite","column_width_fixed":"fixiert","column_width_fluid":"Flexibel","column_warning":{"column_to_grid":"Eine Änderung auf ein am Raster ausgerichtetes Layout verschiebt alle Ihre Widgets in die obere linke Ecke.","grid_to_column":"Eine Änderung zu einem spaltenbasiertem Layout verschiebt alle Ihre Widgets in die erste Spalte."}},"theme":{"title":"App-Design","desc":"Das App-Thema bestimmt den Stil von ProductivityTab selbst und aller Widgets","preview":"Vorschau","light":"Hell (Standard)","dark":"Dunkel","transparent":"Transparent","transparent_darker":"Transparent (dunkler)"}},"toolbar":{"style":{"title":"Aussehen","desc":"Dies bestimmt das Format der Symbolleiste, sie kann entweder normal angezeigt werden oder sich automatisch ausblenden","normal":"Normal","button":"Schaltfläche"},"search":{"title":"Suche","desc":"Diese Einstellungen bestimmen die Funktion des Suchfeldes und der Sprachsuche","engine":"Suchmaschine","engines_default":"Voreinstellung","engines_custom":"Benutzerdefiniert","engines_custom_desc":"Bitte eine URL eingeben an die Abfragen gesendet werden sollen, <b>%s</b> enthält das Ziel.","omnibox_capture":"Handhabung von Suchen welche generell in der Omnibox erfolgen","voice":"Sprachsuche aktivieren","ok_google":"Aktivieren Sie die \"OK-Google\" -Erkennung","search_tab":"Öffnet Suchergebnisse in einem neuen Tab"},"links":{"title":"Links","desc":"Dies sind die Elemente, die rechts in der Symbolleiste angezeigt werden","apps":"App-Menü","custom":"Benutzerdefinierte Links","custom_note1":"Maximal 3 sind zulässig","custom_note2":"Benutzer erhalten 8","custom_name_placeholder":"Link-Text","custom_url_placeholder":"Link-URL, z.B. https://www.google.com/"}},"misc":{"link_tab":"Standardmäßig Links in einem neuen Tab öffnen"},"tabs":{"create_new":"Neuen erstellen","make_default":"Als Standard festlegen","desc1":"Tabs sind Seiten in ProductivityTab. Ein jeder Tab hat seine eigenen Widgets und ist völlig eigenständig.","desc2":"Sie können zwischen den Registerkarten wechseln, indem Sie die Pfeiltasten der Tastatur nutzen oder mittels der Schaltflächen, die links oder rechts angezeigt werden, wenn Sie die Maus auf einem Tab bewegen.","name_placeholder":"Benennen Sie den Tab","delete_confirm":"Diese Aktion ist endgültig. Alle Daten aller Widgets auf dem Tab werden dauerhaft gelöscht."},"accounts":{"status":{"title":"Status","signed_in":"Sie sind derzeit als %s (%s) <b>angemeldet</b>.","reset_account":"Konto zurücksetzen","sign_out":"Abmelden","signed_out":"Sie sind <b>derzeit nicht angemeldet</b>. Melden Sie sich jetzt mit Ihrem Google-Konto an, um Ihre Einstellungen sicher speichern und synchronisieren zu können.","sign_in":"Mit Google anmelden"},"reset_confirm_desc":"Dies wird alle lokalen und synchronisierte Daten dauerhaft ohne eine Möglichkeit der Wiederherstellung dauerhaft löschen.","reset_confirm_desc2":"Sie verlieren Ihre gesamte aktuelle Konfiguration auf allen Computern, die mit diesem Konto verbunden sind."},"advanced":{"backups":{"title":"Sichern und Wiederherstellen","desc":"Die Sicherungen sind vollständige Kopien aller Tabs, Einstellungen und Widgets. Sie werden täglich automatisch bei der ersten Öffnung von ProductivityTab erstellt.","desc2":"Verwenden Sie die Schaltflächen unten, um ProductivityTab auf ein bestimmtes Datum zurückzusetzen oder um eines Ihre Backups zu laden.","backup":"Jetzt sichern","upload":"Aus Datei wiederherstellen","download":"Herunterladen","restore":"Wiederherstellen","download_name":"ProductivityTab Sicherung","restore_confirm":"Hiermit werden sowohl lokale als auch synchronisierte Daten überschrieben. Sie verlieren Ihre vollständige aktuelle Konfiguration auf allen Computern, die mit diesem Konto verbunden sind.","restore_error":"Fehler beim Versuch, die bereitgestellten Daten zu analysieren; versuchen Sie es bitte später erneut."},"css":{"title":"Benutzerdefiniertes CSS","desc":"Sie können mit CSS (<a href=\"https://developer.mozilla.org/en-US/docs/Web/CSS\" target=\"blank\">definition</a>) beinahe alles in ProductivityTab individualisieren.","placeholder":"Geben Sie hier bis zu 1000 Zeichen in CSS ein"},"debug_tools":{"title":"Debug-Tools","desc":"<b>Warnung:</b> Diese Tools können ihre gesamte Konfiguration mit einem einzigen Klick löschen. Verwenden Sie sie nur, wenn Ihr Entwickler Sie damit beauftragt.","open":"Werkzeuge öffnen"}},"widgets":{"desc1":"Widgets hab eigene Einstellungen und können hier nicht individualisiert werden.","desc2":"Um Einstellungen eines Widgets anzupassen, folgen sie diesen Schritten:","steps1":"Bewegen Sie die Maus über ein beliebiges Widget","steps2":"Klicken Sie auf das Schraubenschlüssel-Symbol oben rechts im Widget. Erscheint dort keins, kann das Widget nicht personalisiert werden.","steps3":"Bearbeiten Sie alle Einstellungen im angezeigten Dialog","steps4":"Klicken Sie \"Speichern\", oder auf ein beliebige Stelle im Hintergrund, um sie zu verwerfen"},"pro":{"promo":{"monthly_price":"$4.99 pro Monat","yearly_price":"oder $29.99 pro Jahr","upgrade_btn":"Vollversion kaufen","business":"Interessiert, für Ihr Unternehmen oder Ihre Schule Pro zu erwerben?","business_contact":"Nehmen Sie mit uns Kontakt auf","themes":"Themes","themes_desc":"Sehen Sie mehr von Ihrem Hintergrund mit dunklen oder transparente Themen","bgs":"Live Hintergründe","bgs_desc":"Gestalten Sie Ihre Seite mit 20 Live-Hd-Hintergründen lebendig","widgets":"Maximierbare Widgets","widgets_desc":"Bring ProductivityTab auf ein anderes Level mit unbegrenzt vielen Widgets","more_header":"Und mehr","stocks":"Echtzeit Kurse mit erweiterter historischer Information","rss":"Unterstützung für mehrere RSS Feeds pro Widget","sports":"Allgemeine und Liga-spezifische Sportnachrichten","tabbed_widgets":"Reiter-Nachrichten und RSS-widgets","bg_downloads":"Herunterladbare Hintergründe","weather":"Stündliche Wettervorhersagen bis zu 10 Tagen voraus","toolbar":"Weitere Toolbar Links","ads":"A completely ad-free experience","support":"Bevorzugter Support und Empfehlungen","buy_pro":"Pro-Version kaufen"},"checkout":{"title":"Zur Kasse gehen","updating_title":"Updateplan","payment_options":"Bezahlen","pay_monthly":"Monatlich ($4.99)","pay_yearly":"Jährlich ($29.99)","cancel":"Abbrechen","update":"Update","subscribe":"Abonnieren","braintree_notice":"Die Zahlungen werden sicher von Braintree bearbeitet.","monthly_notice":"Durch ankreuzen bestätigen Sie, dass ProductivityTab monatlich 4.99$ von ihnen berechnen darf, bis Sie kündigen.","yearly_notice":"Durch ankreuzen bestätigen Sie, dass ProductivityTab jährlich 29.99$ von ihnen berechnen darf, bis Sie kündigen.","update_notice":"Obwohl die Abrechnungszyklus-Änderungen sofort wirksam werden, werden Sie nicht belastet bis Ihr aktueller Zyklus endet.","thank_you":"Vielen Dank für den Kauf von ProductivityTab Pro!","thank_you2":"ProductivityTab ladet in wenigen Sekunden neu und du hast es geschafft!","error":"Etwas ist falsch gelaufen beim verarbeiten ihrer Zahlung.","error2":"Bitte versuchen sie es später erneut, oder senden sie uns eine E-Mail an support@ichro.me","signin":"Einloggen","signin_desc":"Du must dich erst anmelden um Pro zu kaufen","signin_btn":"Einloggen"},"plan":{"title":"Tarif","desc":"Sie haben zurzeit ProductivityTab Pro (%s) erworben","types":{"monthly":"monatlich","yearly":"jährlich","business":"Business","education":"Bildung","custom":"Benutzerdefiniert"},"uneditable_desc":"Wirtschaft, Bildung und benutzerdefinierte Pläne können nicht innerhalb ProductivityTab aktualisiert werden. Bitte <a href=\"mailto:support@ichro.me\"> kontaktieren Sie uns</a>, für Anpassungen oder um Ihr Abonnement kündigen.","status":"Status","status_active":"aktiv","status_trial":"Trial","status_pastdue":"Überfällig","subscription_date":"Datum der Abonnierung","paid_through":"Bezahlt mit","next_bill":"Nächste Rechnung","next_bill_value":"$%s auf %s","update_plan":"Updateplan","update_billing":"Rechnung aktualisieren","cancel":"Abonnement kündigen","cancel_notice":"Ihr Abonnement wird sofort abgebrochen","cancel_notice2":"Wenn du eine Rückerstattung willst, kontaktiere bitte support@ichro.me"}},"ads":{"text1":"ProductivityTab displays a few small ads to pay for server, support and development costs. With these ads, we can afford to offer ProductivityTab free to everyone.","text2":"Here you can choose where those ads are shown, or buy ad-free to permanently remove them.","text3":"Ad-free is a one-time purchase that permanently removes ads from ProductivityTab wherever you're signed in. You can also upgrade to Pro for extra features in addition to an ad-free experience.","upgrade_btn":"Upgrade to ad-free","already_upgraded":"It looks like you've already upgraded to ad-free","signin":"Einloggen","signin_desc":"Sign in before upgrading so we can link your purchase to your account","signin_btn":"Einloggen","thank_you":"Thank you for upgrading to ad-free!","placement":{"title":"Ad placement","left":"In the leftmost column","right":"In the rightmost column","top":"Above the tab","bottom":"Floating at the bottom"}}},"store":{"installation":"Installation","description":"Beschreibung","preview":"Vorschau","instructions":"Verschiebe jede Größe beliebig auf der Homepage"},"widgets":{"sizes":{"tiny":"Winzig","small":"Klein","medium":"Medium","large":"Groß","variable":"Variabel"},"settings":{"title":"Widget-Einstellungen","save":"Speichern","size":"Widget Größe"},"minimize":"Minimieren","maximize":"Maximieren","delete_confirm":"Bist du sicher, dass du das Widget wirklich löschen willst?\nDiese Aktion ist irreversibel, alle mit diesen Widget verbundenen Daten werden dauerhaft gelöscht.","permissions_request":{"title":"Zugang erforderlich","button":"Zugriff gewähren","desc":"Dieses Widget benötigt zusätzliche Berechtigungen, bevor es verwendet werden kann. Erlauben Sie sie mit dem Button unten."},"error":{"explanation":"Irgendetwas ging schief, während wir versuchten, dieses Widget anzuzeigen.","advice":"Versuchen Sie das Widget neu zu installieren oder die Seite neu zu laden. Kontaktieren Sie uns, wenn Sie diese Meldung, oft sehen.","support":"Support","refresh":"Aktualisieren"},"auth":{"message":"Sie müssen diesem Widget Zugang zu Ihrem Konto geben, bevor Sie es verwenden können.","button":"Zugriff gewähren"},"shared":{"settings":{"title":"Widget Titel","title_placeholder":"Widget-Bezeichnung eingeben oder leer lassen um zu verbergen","height":"Widget Höhe","open_options":{"current":"Aktuelle Registerkarte","blank":"Neue Registerkarte"},"footer_link":"Fußzeilen-Link","footer_link_options":{"show":"Anzeigen","hide":"Ausblenden"},"account":"Account-ID","account_help":"Wenn Du bei mehreren Konten angemeldet bist ist dies der \"Authuser =\" Wert.\n<br /> <br />\nZum Beispiel, wenn Du in zwei Konten angemeldet bist, jsmith1@gmail.com und jsmith2@gmail.com, ist der \"Authuser\"-Wert für jsmith2@gmail.com 1, da es das zweite angemeldete Konto ist (gezählt ab 0).","account_placeholder":"Ihr \"authuser=\" Wert","on":"An","off":"Aus"}},"apps":{"name":"Apps","desc":"Zeige die zurzeit installierten Google Chrome Applikationen.","settings":{"format":"Widget-Format","format_options":{"tiles":"Kacheln","list":"Liste"},"display":"Anzeigen","display_options":{"all":"Alle Apps","enabled":"Nur aktivierte Apps"},"sort":"Sortieren","sort_options":{"id":"ID","alphabetically":"Alphabetisch","offline":"Offline aktiviert","available":"Verfügbarkeit"},"open":"Anwendungen öffnen in"},"store_app":"Store"},"bookmarks":{"name":"Lesezeichen","desc":"Zeigt ausgewählte und angepasste Lesezeichen und andere Links.","settings":{"title_placeholder":"Geben Sie einen Widget-Titel ein","layout":"Design","layout_options":{"single":"Einzelne Spalte","double":"Doppelspalte"},"open":"Lesezeichen öffnen in"},"edit":{"dialog_title":"Lesezeichen editieren","title":"Lesezeichen-Bezeichnung","title_placeholder":"Google","url":"Lesezeichen URL","url_placeholder":"https://www.google.com/","save":"Speichern"},"new_caption":"Neu","new_bookmark":"Lesezeichen","new_folder":"Verzeichnis","drop_link":"Link hierher ziehen"},"chrome_bookmarks":{"name":"Lesezeichen","desc":"Zeigt Deine Chrome-Favoriten, optional die eines bestimmten Ordners.","settings":{"title_placeholder":"Geben Sie einen Widget-Titel ein","from":"Zeige Favoriten von","open":"Lesezeichen öffnen in"}},"calc":{"name":"Taschenrechner","desc":"Zeigt einen Taschenrechner mit Unterstützung für grundlegende Operatoren an.","error":"Fehler!","infinity":"Unendlich","mismatch":"Nicht übereinstimmende Klammern"},"calendar":{"name":"Kalender","desc":"Zeigt bevorstehende Veranstaltungen aus einem oder mehrerer Deiner Google-Kalender.","settings":{"calendar":"Kalender","show":"Zeige Events von","show_options":{"all":"zeitlich unbegrenzt","today":"Nur heute"}},"title":"Agenda","calendar":"Kalender","noevents":"Keine Termine in naher Zukunft gefunden, der Terminkalender ist leer!"},"clock":{"name":"Uhr","desc":"Stellt Alarm-, Zeit-, Timer- und Stoppuhr-Funktionen zur Verfügung.","settings":{"timezone":"Zeitzone","timezone_local":"lokal","format":"Uhrzeit-Format","format_options":{"ampm":"AM/PM - Digital","24hour":"24-Stunden - Digital","analog":"12-Stunden - Analog","ampmseconds":"AM/PM - Digital, keine Sekunden","24hourseconds":"24-Stunden - Digital, keine Sekunden"},"sound":"Benachrichtigungston"},"title":"Uhr","alarm":"Alarm","clock":"Uhr","timer":"Timer","stopwatch":"Stoppuhr","set":"Anwenden","unset":"Zurücksetzen","dismiss":"Verwerfen","enable_audio":"Audio aktivieren"},"facebook":{"name":"Facebook","desc":"Bettet Facebook in einem Widget ein"},"feedly":{"name":"Feedly","desc":"Zeigt Artikel aus Deinem Feedly Konto in einem konfigurierbaren Format.","settings":{"source":"Zeigt Artikel von","source_feeds":"Feeds","show":"Zeigen","show_options":{"all":"Alle Artikel","unread":"Nur ungelesene Artikel"},"layout":"Design","layout_options":{"titles":"Nur Titel","magazine":"Magazin","cards":"Karten","cards_columns":"Karten (zwei Spalten)"},"mark":"Artikel als gelesen markieren wenn ich","mark_options":{"scroll":"Vorbeiscrollen oder anklicken","click":"Einfach anklicken"},"sort":"Sortierreihenfolge","sort_options":{"newest":"Neueste zuerst","oldest":"Älteste zuerst"}},"all":"Alle","saved":"Für später gespeichert","uncategorized":"Unkategorisiert","author":"von","go_to_feedly":"Gehe zu Feedly"},"notes":{"name":"Notizen","desc":"Fügt eine einfache, editierbare Notiz ein.","settings":{"color":"Notiz-Farbe","color_options":{"yellow":"Gelb","orange":"Orange","red":"Rot","blue":"Blau","green":"Grün","white":"Weiß"},"font":"Schriftart","fontsize":"Schriftgröße"}},"now":{"name":"Google Now","desc":"Zeigt Karten von Google Now an, einschließlich Flugstatus und Paketverfolgung.","authorize":"Erlaube ProductivityTab, Google Now-Karten anzuzeigen, bevor diese hier auftauchen.","authorize_btn":"Autorisieren","caught_up":"Alles erledigt, hier gibt es nichts.","no_title":"Kein Titel"},"plus":{"name":"Google+","desc":"Bettet Google Plus in einem Widget ein"},"notifications":{"name":"Google-Benachrichtigungen","desc":"Zeigt Ihre Google-Benachrichtigungen von Diensten wie z. b. Google+ an"},"reddit":{"name":"Reddit","desc":"Zeigt die Top-Elemente auf Reddit für jeden Subreddit.","settings":{"subreddit":"Subreddit","subreddit_help":"Gebe einen Subreddit mit dem Teil hinter <b>/r/</b> ein, wenn auf Reddit.\n<br /><br />\nBeispielsweise, für Technologie: <a href=\"https://www.reddit.com/r/technology\">https://www.reddit.com/r/technology</a>, daher gib <b>Technologie</b> ein","subreddit_placeholder":"Geben Sie eine Subreddit zum Anzeigen von Links aus (z.B. Technologie)","sort":"Sortierreihenfolge","sort_options":{"hot":"Heiß","top":"Top","new":"Neu","gilded":"Vergoldet","rising":"Ansteigend","controversial":"Kontrovers"},"links":"Angezeigte Links","click":"Beim Klicken auf einen Link, zeige","click_options":{"link":"Der Link","comments":"Die Kommentare"}},"more":"Mehr"},"tasks":{"name":"Aufgaben","desc":"Zeigt eine anpassbare Liste der Aufgaben von einer Deiner Google-Aufgabenlisten.","title":"Aufgaben","settings":{"list":"Liste"},"task_title":"Titel","due_date":"Fällig am","notes":"Notizen","add":"Element  hinzufügen","delete_task":"Aufgabe löschen","move_up":"Nach oben","move_down":"Nach unten","done":"Fertig","due_today":"Heute fällig","overdue":"Überfällig","authorize":"Du musst eine Liste aus Deinen Google-Aufgaben über die Einstellungen auswählen, bevor hier etwas angezeigt werden kann."},"twitter":{"name":"Twitter","desc":"Tweets des Standardstreams oder einer angegebenen Liste anzeigen.","settings":{"source":"Zeige Tweets von","show":"Tweets angezeigt"},"authorize":"Du musst ProductivityTab zuerst autorisieren","authorize_msg":"Du musst ProductivityTab die Berechtigung zum Anzeigen von Tweets von Ihrem Konto geben, bevor diese hier auftauchen werden.","authorize_btn":"Autorisieren","no_tweets":"Es scheint hier keine Tweets zu geben...","home":"Home","mentions":"Erwähnungen","retweets":"Retweets von mir","lists":"Listen","more":"Mehr","reply":"Antworten","retweet":"Retweeten","favorite":"Favorit"},"wolfram":{"name":"Wolfram| Alpha","desc":"Fügt ein kleines Wolfram|Alpha Suchfeld ein."},"youtube":{"name":"YouTube","desc":"Zeigt entweder beliebte Videos oder Videos von einem bestimmten Benutzer.","settings":{"format":"Format","format_options":{"large":"Ein großes","large_2":"Ein großes, zwei kleine","large_4":"Ein großes, vier kleine","four":"Vier kleine","six":"Sechs kleine"},"from":"Videos anzeigen von","from_help":"Dies muss ein <b>exakter</b> Benutzername sein, wie dieser auf der Profilseite angezeigt wird.\n<br /><br />\nDieser Wert schließt niemals mit einem Leerzeichen.","from_placeholder":"Freilassen um Top Videos anzuzeigen","open":"Öffne Suchergebnisse in"},"search":"In Youtube suchen","num_views":"Ansichten"},"quotes":{"name":"Zitate","desc":"Zeigt ein Zitat jedes Mal, wenn die Seite neu geladen wird oder einmal täglich.","settings":{"source":"Quelle","method":"Neue Zitate laden","method_options":{"daily":"Einmal täglich","random":"Jedes Mal wenn die Seite geladen wird"}},"unknown_author":"Unbekannt"},"html":{"name":"HTML","desc":"Zeigt vollständig benutzerdefiniertes HTML in einem Iframe.","settings":{"html":"HTML","js":"JavaScript","height":"Widget Höhe"}},"sitelink":{"name":"Seiten-Link","desc":"Zeigt einen Link an, optional mit Titel und Bild","settings":{"link":"Link-URL","link_placeholder":"https://www.google.com/","image":"Bild-URL","image_placeholder":"https://www.example.com/image.png","color":"Hintergrundfarbe des Bildes","style":"Bildstil","style_fill":"Füllung","style_center":"Mittig"}},"stats":{"name":"Betriebssystem-Statistiken","desc":"Behalten Sie Ihr System mit den Echtzeit-Statistiken im Auge","memory":"RAM","battery":"Akku","usage":"belegt","in_use":"belegt","remaining":"verbleibend","charged":"Vollständig aufgeladen","idle":"Vollständig aufgeladen","charging":"Wird aufgeladen","discharging":"Akku wird entladen"},"search":{"name":"Suche","desc":"Betten Sie ein Suchfeld in Ihre Seite für den einfachen Zugriff ein","settings":{"placeholder":"Suchfeld-Platzhalter","search_url":"Such-URL","param":"Abfrageparameter","param_placeholder":"Der Parameter, der den Suchbegriff einleitet, z.B. \"q\""},"default_placeholder":"Google-Suche"},"pushbullet":{"name":"Pushbullet","desc":"Behalten Sie den Überblick über Benachrichtigungen auf Ihrem Handy und anderen Geräten","no_pushes":"Keine Einträge für Pushbullet vorhanden","sign_in":"Einloggen","no_key":"Es sieht nicht so aus, als wären Sie bei Pushbullet eingeloggt.  Loggen Sie sich jetzt ein, um das Widget zu verwenden."},"linkedin":{"name":"LinkedIn","desc":"Zeigt Ihren LinkedIn Home-Stream an"},"directions":{"name":"Routenplanung","desc":"Bietet Ihnen Zugriff auf Wegbeschreibungen direkt auf Ihrer Startseite","driving":"Fahren","transit":"Öffentliche Verkehrsmittel","walking":"Gehen","cycling":"Radfahren","from":"Geben Sie einen Ausgangspunkt an","to":"Geben Sie ein Ziel an","loading":"Routeninformationen werden geladen, bitte warten...","error":"Irgendetwas ging beim Versuch die Routeninformationen zu laden schief.","error2":"Bitte überprüfen Sie die eingegebenen Start- und Zieladressen.","open_in_maps":"In Google Maps öffnen","via":"über"},"pocket":{"name":"Pocket","desc":"Zeigt eine Liste aller gespeicherten Artikel, Videos und Internetseiten von Pocket an","settings":{"links_shown":"Anzahl der angezeigten Links","open":"Links öffnen","open_pocket":"Aus Pocket","open_original":"Orginal URL"},"by":"Von","no_links":"Keine Links gefunden","grant_access":"Zugriff gewähren","no_key":"Sie müssen ProductivityTab Zugriff zu Ihrem Pocket-Konto gewähren damit Ihre Verknüpfungen geladen werden können."}},"themes":{"title":"Themes","all":"Alle","custom":"Benutzerdefiniert","create":"Theme erstellen","url_or_upload":"oder","upload_image":"Bild hochladen","edit_btn":"Bearbeiten","delete":"Löschen","use":"Verwenden","preview":"Vorschau","author":"Von","images":"%s Bilder","resolution":"Auflösung","categories":"Kategorien","cached":"Dieses Theme wurde zwischengespeichert und ist offline verfügbar","random":"Dieses Theme zeigt ein Zufallsbild, jedes Mal wenn Du die Seite lädst","random_daily":"Dieses Theme zeigt jeden Tag ein neues Zufalls-Bild","sunrise_sunset":"Dieses Theme zeigt ein Bild basierend auf der Tageszeit","feed":"Dieses Theme zeigt täglich ein Bild von einem externen Feed","video":"Dieses Thema zeigt eine Live-Video","pro_only":"Dieses Thema ist nur für Pro-User. Kaufen Sie Pro in den Einstellungen.","delete_confirm":"Bist Du wirklich sicher, dass Du dieses Theme löschen möchtest? Dieser Vorgang ist unumkehrbar, das gesamte Theme wird dauerhaft gelöscht.","delete_error":"Fehler beim Versuch, das Theme zu löschen.  Bitte versuche es später erneut.","feed_fetching":"Bitte warte, Feed wird abgerufen...","feed_error":"Fehler beim Verusch den Feed zu laden, bitte versuche es später erneut.","caching":"Bitte warten, Theme wird zwischengespeichert...","cache_status":"%s von %s Bilder zwischengespeichert","cache_error":"Fehler beim Versuch, das Theme zwischenzuspeichern.  Bitte versuche es später erneut","bginfo":{"view":"Anzeigen","source":"Quelle","unknown":"Unbekannt","download":"Herunterladen","pro_only":"Nur Pro User können Hintergründe und Videos herunterladen"},"edit":{"title":"Theme bearbeiten","create_title":"Theme erstellen","name":"Theme Name","default_name":"Neues Theme","name_placeholder":"Theme Namen eingeben","image":"Bild-URL","image_placeholder":"Gebe eine Hintergrundbild-URL ein","image_help":"Hochgeladen Bilder <b>können zwischen Computern nicht synchronisiert werden</b>. <br /> <br /> Falls dies wichtig ist, das Bild bitte mit einem Dienst wie <a href=\"https://imgur.com/\" target=\"_blank\">Imgur</a> hochladen. Dann kopiere die URL, welche mit einer Erweiterung endet (d.h. .jpg), und füge diese in das Feld auf der linken Seite ein.","color":"Reserve-Farbe","color_placeholder":"Gebe eine Farbbezeichnung ein","position":"Position","position_options":{"center":"Mittig","top_left":"Oben links","top_center":"Oben mittig","top_right":"Oben rechts","bottom_left":"Unten links","bottom_center":"Unten mittig","bottom_right":"Unten rechts"},"scaling":"Skalierung","scaling_options":{"auto":"Automatisch","width":"Volle Breite","height":"Volle Höhe","none":"Keine Skalierung (Vorschau kann ungenau sein)"},"repeat":"Bild wiederholen","repeat_options":{"none":"Nicht wiederholen","horizontal":"Horizontal wiederholen","vertical":"Vertikal wiederholen","both":"Beides wiederholen"},"attach":"Bild anfügen","attach_tab":"Die Registerkarte","attach_window":"Das Fenster","preview":"Vorschau","save":"Speichern & Schließen","cache_error":"Fehler beim Versuch, das eingetragene Bild zwischenzuspeichern, bitte überprüfe die URL.","upload_error":"Fehler beim Hochladen der Datei, bitte sicherstellen, dass es eine vernünftige Dateigröße und ein Bild ist."}}},"en":{"lang_code":"en","language":"English","extName":"ProductivityTab — Custom Homepage Dashboard","newtabName":"ProductivityTab — Custom New Tab Dashboard","extDescription":"A remarkably customizable personal homepage featuring 50+ widgets, breathtaking backgrounds and much more.","newtabDescription":"A customizable personal dashboard on your new tab page featuring 50+ widgets, breathtaking backgrounds and much more.","defaults":{"tab":"Home","me":"Me"},"remove_widget":"Remove","hide_banner":"Hide this banner","hide_ad":{"content":"Hey! We're not crazy about ads either, but we're only able to make ProductivityTab available and continue developing features for our free users (that's you!) by showing ads. If you'd like to support ProductivityTab directly and get rid of ads for free, we would really appreciate if you upgraded to our pro version","upgrade":"Upgrade","hide":"Hide ads"},"upgrade_to_pro":{"title-weather":"Hourly Weather","title-default":"Upgrade","content-default":"Please upgrade to Pro version to view hourly weather.","upgrade":"Upgrade","close":"Close"},"upgrade_tooltips":{"weather":"for only $4.99 month see hourly weather","sport":"for only $4.99 month read sport news","news":"for only $4.99 month use tabs and maximize news","rss":"for only $4.99 month use multiple feeds and maximize widget","stocks":"for only $4.99 month get realtime stocks with history"},"alert":{"default_button":"Dismiss","confirm_title":"Are you sure you want to do this?","confirm_continue":"Continue","confirm_cancel":"Cancel"},"onboarding":{"next":"Next","modal":{"intro_title":"Welcome to ProductivityTab!","intro_moto":"ProductivityTab’s all about tabs and widgets.","intro_desc":"Tabs are pages filled with widgets - blocks that show things like weather, news and pretty much anything else you could imagine. You can customize how these widgets work, and add as many as you want!","signin_title":"Don’t lose your settings!","signin_desc1":"Sign in with your Google account to use our secure online settings saving feature, and get complimentary access to all ProductivityTab Pro features free for 30 days! (no payment info required).","signin_desc2":"You can stay signed out if you want, but your settings won’t be saved online and you won’t be able to access it from other computers. ProductivityTab Pro free trial is only available for signed in users.","signin_desc3":"Sign in with Google now to access Pro features and save your settings!","pro_desc1":"ProductivityTab Pro includes:","pro_desc2":"Ad-free experience","pro_desc3":"Hourly Weather Forecasts up to 10 days out","pro_desc4":"Team-specific sports news","pro_desc5":"Real Time stock prices with extended and historical data","pro_desc6":"Dark and Transparent Themes - See more of your background","pro_desc7":"A completely ad-free experience","pro_desc8":"Prioritized Support and Suggestions","pro_desc9":"And more…","signin_desc4":"You can stay signed out if you want, but your settings won’t be saved online and you won’t be able to access it from other computers. ProductivityTab Pro free trial is only available for signed in users.","sign_in_button":"Sign in with Google","tagline":"All the sites and apps you use, in one place","wrong_extension":"Want ProductivityTab on your new tab page instead?","wrong_extension_newtab":"Want ProductivityTab on your home page instead?","wrong_extension_action":"Click here","about":"ProductivityTab's all about tabs and widgets","about_desc":"Tabs are pages filled with widgets - blocks that show things like the weather, news, and your email. You can customize most widgets and add as many as you want.","terms":"By checking, you agree to ProductivityTab's <a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\">Terms</a> and <a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\">Privacy Policy</a>","terms_desc":"ProductivityTab collects the minimum amount of Personal and Non-personal user information required to fulfill core functions of the service. This includes communicating with users, fulfilling requests, and customizing, operating, and improving our services. For a detailed description of our data usage and collection, please refer to the full ProductivityTab Privacy Policy.","sign_in":"Sign in with your Google account","sign_in_desc":"Sign in with your Google account before getting started to securely save your changes online.","sign_in_desc2":"You can stay signed out if you want, but your page won't be saved online and you won't be able to access it from other computers.","pro_title":"ProductivityTab Pro","pro_upgrade":"Upgrade to Pro for only $4.99","pro_mback":"Try ProductivityTab Pro Risk Free with our 30 Day Money Back Guarantee","have_account":"It looks like you already have an account!","have_account_desc":"All your tabs and widgets are ready to use!","get_started":"Let's get started!","get_started_desc":"You're good to go! Let's get your page set up."},"widgets":{"configure":"Let's configure a widget.","configure_desc":"Click the wrench to open a widget's <b>settings</b>.","configure_skip":"Skip Tutorial","settings":"Replace <b>Link URL</b> with your favorite site, then press <b>Save</b>.","move":"You can <b>reposition</b> widgets by clicking and dragging the three dots highlighted here.","remove":"To <b>delete</b>, simply click the red trash bin icon.","done":"Got it"},"settings":{"intro":"Now let’s add a new widget. This highlighted button is where you can access the Widget Menu.","instructions":"Click the new widget button on to open the widget menu!","skip":"Skip","tooltips":{"settings":"Change the way ProductivityTab looks and works","widgets":"Add new widgets - you can have as many as you want","editing":"Show or hide the editing buttons on widgets","links":"This is a list of links, add sites you use often in the settings","tabs":"These are your tabs. You can add more in the settings","support":"Send us a message or leave a review here"},"finished":"That's it!","finished_next":"Choose an option from the menu (try starting with <b>Widgets</b>) and set your page up!","finished_contact":"Use the support link if you need any help and we'll get back to you ASAP."}},"storage":{"signin":"Sign in with Google now to securely save and sync your configuration","signin_btn":"Sign in","signin_dismiss":"Dismiss","signin_confirm":{"title":"Keep local data?","desc":"Would you like to keep your local data, and replace the configuration in your account with it, or replace this computer's configuration with the one already in your account?","keep_account":"Use account","keep_local":"Keep local"},"signout_confirm":"Signing out will erase your local backups","pastdue":"Your subscription is past due","pastdue_desc":"Please update your billing information in the settings"},"toolbar":{"placeholder":"Search the web","placeholder_ok":"Enter your terms or say \"OK, Google\"","suggestions":{"url_subtext":"Visit URL","capture_notice":"ProductivityTab handles searches you normally make from the Omnibox. You can disable this at any time from the settings"},"apps":{"search":"Search","youtube":"YouTube","maps":"Maps","play":"Play","news":"News","gmail":"Gmail","drive":"Drive","calendar":"Calendar","more":"More"}},"menu":{"notifications":"Notifications","settings":"Settings","widgets":"Widgets","support":"Support","upgrade":"Upgrade to Pro","editing":"Editing","editing_enabled":"Enabled","editing_disabled":"Disabled","plus":"Google Plus","tabs":"Tabs","footer":{"support":"Support","feedback":"Feedback","review":"Review","terms":"Terms","privacy":"Privacy","permissions":"Permissions","by":"By Avi Kohn"}},"voice":{"listening":"Listening...","searching":"Searching for: %s","missed":"Didn't get that. <a>Try Again</a>"},"settings":{"title":"Settings","exit":"Exit settings","saved":"Settings saved","nav":{"visual":"Visual","visual_sections":{"background":"Background","layout":"Layout","theme":"App theme","ad_placement":"Ad placement"},"toolbar":"Toolbar","toolbar_sections":{"style":"Style","search":"Search","links":"Links"},"tabs":"Tabs","widgets":"Widgets","ads":"Ads","pro":"Pro","accounts":"Account","misc":"Miscellaneous","advanced":"Advanced","advanced_sections":{"backups":"Backup and restore","css":"Custom CSS","debug_tools":"Debug tools"},"support":"Help and support","suggest":"Suggest a feature"},"visual":{"background":{"title":"Background","desc":"This is the image or set of images shown as a background to your tabs","current":"Current background","custom":"Custom","unnamed":"Theme %s","select":"Select a theme","or":"or","url_placeholder":"Enter an image URL"},"layout":{"title":"Layout","desc":"Here you can adjust the type and number of columns in each tab","columns":"Columns","grid":"Grid","columns_number":"Number of columns","column_width":"Column width","column_width_fixed":"Fixed","column_width_fluid":"Fluid","column_warning":{"column_to_grid":"Changing to a grid-based layout will move all of your widgets to the top left corner.","grid_to_column":"Changing to a column-based layout will move all of your widgets to the first column."}},"theme":{"title":"App theme","desc":"The app theme controls the style of ProductivityTab itself and all widgets","preview":"Preview","light":"Light (default)","dark":"Dark","transparent":"Transparent","transparent_darker":"Transparent (darker)"}},"toolbar":{"style":{"title":"Style","desc":"This controls the style of the toolbar.  It can either appear normally or as an out of the way button","normal":"Normal","button":"Button","button_ns":"No search bar"},"search":{"title":"Search","desc":"These settings control how the search box and voice search function","engine":"Search engine","engines_default":"Default","engines_custom":"Custom","engines_custom_desc":"Enter a URL that queries should be sent to, with <b>%s</b> where the query should go.","omnibox_capture":"Handle searches normally made in the Omnibox","voice":"Enable voice search","ok_google":"Enable \"OK Google\" hotword detection","search_tab":"Open search results in a new tab"},"links":{"title":"Links","desc":"These are the items shown at the right of the toolbar","apps":"Apps menu","custom":"Custom links","custom_note1":"Maximum of 3 allowed","custom_note2":"users get 8","custom_name_placeholder":"Link text","custom_url_placeholder":"Link URL, i.e. https://www.google.com/"}},"misc":{"link_tab":"Open links in a new tab by default"},"tabs":{"create_new":"Create new","make_default":"Make default","desc1":"Tabs are pages inside ProductivityTab. Each tab has its own set of widgets that is completely separate from every other tab.","desc2":"You can switch between tabs by clicking the buttons that appear at the left and right of the screen when you move your mouse over a tab or by using the arrow keys on your keyboard.","name_placeholder":"Enter a tab name","delete_confirm":"This action is irreversible. All data from all widgets in the tab will be permanently lost."},"accounts":{"status":{"title":"Status","signed_in":"You are currently <b>signed in</b> as %s (%s).","reset_account":"Reset account","sign_out":"Sign out","signed_out":"You are <b>not currently signed in</b>. Sign in with your Google account now to securely store and sync your configuration.","sign_in":"Sign in with Google"},"reset_confirm_desc":"This will erase all local and synced data, there is no backup and no way to undo this.","reset_confirm_desc2":"You will lose your entire current configuration on all computers connected to this account."},"advanced":{"backups":{"title":"Backup and restore","desc":"Backups are complete copies of all your tabs, settings, and widgets. They're automatically created when you first open ProductivityTab each day.","desc2":"Use the buttons below to roll ProductivityTab back to a particular date or download one of your backups.","backup":"Backup now","upload":"Restore from file","download":"Download","restore":"Restore","download_name":"ProductivityTab Backup","restore_confirm":"This will overwrite all local and synced data. You will lose your entire current configuration on all computers under this account.","restore_error":"An error occurred while trying to parse the provided data, please try again later."},"css":{"title":"Custom CSS","desc":"You can use CSS (<a href=\"https://developer.mozilla.org/en-US/docs/Web/CSS\" target=\"blank\">definition</a>) to customize almost any part of ProductivityTab.","placeholder":"Enter up to 1000 characters of CSS here"},"debug_tools":{"title":"Debug tools","desc":"<b>WARNING:</b> These tools can erase your entire configuration in a single click. Only use them if your developer instructs you to.","open":"Open tools"}},"widgets":{"desc1":"Widgets have their own settings and can't be customized here.","desc2":"To edit a widget's settings, follow these steps:","steps1":"Move your mouse over any widget","steps2":"Click the wrench icon that appears at the top right of the widget. If none appears then the widget doesn't have any settings that can be customized.","steps3":"Edit any of the settings shown in the dialog that's displayed","steps4":"Click Save to save your changes, or any part of the background to discard of them"},"pro":{"promo":{"monthly_price":"$4.99 per month","yearly_price":"or $29.99 per year","upgrade_btn":"Upgrade Now","business":"Interested in buying Pro for your business or school?","business_contact":"Contact us","themes":"Themes","themes_desc":"See more of your backgrounds with dark and transparent themes","bgs":"Live backgrounds","bgs_desc":"Bring your page to life with 20 live high-definition backgrounds","widgets":"Maximizable widgets","widgets_desc":"Take ProductivityTab to another level with maximizable widgets","more_header":"And more","stocks":"Realtime stocks with extended and historical information","rss":"Support for multiple RSS feeds per widget","sports":"General and league-specific sports news","tabbed_widgets":"Tabbed news and RSS widgets","bg_downloads":"Downloadable backgrounds","weather":"Hourly weather forecasts up to 10 days out","toolbar":"More toolbar links","ads":"A completely ad-free experience","support":"Prioritized support and suggestions","buy_pro":"Buy Pro"},"checkout":{"title":"Checkout","updating_title":"Update plan","payment_options":"Pay","pay_monthly":"Monthly ($4.99)","pay_yearly":"Yearly ($29.99)","cancel":"Cancel","update":"Update","subscribe":"Subscribe","braintree_notice":"Payments securely processed by Braintree.","monthly_notice":"By subscribing, you authorize ProductivityTab to charge you $4.99 every month until you cancel your subscription.","yearly_notice":"By subscribing, you authorize ProductivityTab to charge you $29.99 every year until you cancel your subscription.","update_notice":"Although billing cycle changes take effect immediately, you won't be charged until your current cycle ends.","thank_you":"Thank you for buying ProductivityTab Pro!","thank_you2":"ProductivityTab will reload in a few seconds and you'll be all set!","error":"Something went wrong while trying to process your payment.","error2":"Please try again later or email us at support@ichro.me","signin":"Sign in","signin_desc":"You need to sign in before buying Pro so we can make sure it's you","signin_btn":"Sign in"},"plan":{"title":"Plan","desc":"You are currently subscribed to ProductivityTab Pro (%s)","types":{"monthly":"Monthly","yearly":"Yearly","business":"Business","education":"Education","custom":"Custom"},"uneditable_desc":"Business, education, and custom plans cannot be updated from within ProductivityTab. Please <a href=\"mailto:support@ichro.me\">contact us</a> to update or cancel your subscription.","status":"Status","status_active":"Active","status_trial":"Trial","status_pastdue":"Past due","subscription_date":"Subscription date","paid_through":"Paid through","next_bill":"Next bill","next_bill_value":"$%s on %s","update_plan":"Update plan","update_billing":"Update billing","cancel":"Cancel subscription","cancel_notice":"Your subscription will be canceled immediately","cancel_notice2":"If you would like a refund, please contact us at support@ichro.me"}},"ads":{"text1":"ProductivityTab displays a few small ads to pay for server, support and development costs. With these ads, we can afford to offer ProductivityTab free to everyone.","text2":"Here you can choose where those ads are shown, or buy ad-free to permanently remove them.","text3":"Ad-free is a one-time purchase that permanently removes ads from ProductivityTab wherever you're signed in. You can also upgrade to Pro for extra features in addition to an ad-free experience.","upgrade_btn":"Upgrade to ad-free","already_upgraded":"It looks like you've already upgraded to ad-free","signin":"Sign in","signin_desc":"Sign in before upgrading so we can link your purchase to your account","signin_btn":"Sign in","thank_you":"Thank you for upgrading to ad-free!","placement":{"title":"Ad placement","left":"In the leftmost column","right":"In the rightmost column","top":"Above the tab","bottom":"Floating at the bottom"}}},"store":{"installation":"Installation","description":"Description","preview":"Preview","instructions":"Drag and drop any size onto your homepage"},"widgets":{"sizes":{"tiny":"Tiny","small":"Small","medium":"Medium","large":"Large","variable":"Variable"},"settings":{"title":"Widget Settings","save":"Save","size":"Widget Size"},"minimize":"Minimize","maximize":"Maximize","delete_confirm":"Are you really sure you want to delete this widget?\r\nThis action is irreversible; all data from this widget will be permanently lost.","permissions_request":{"title":"Access required","button":"Grant Access","desc":"This widget needs extra permissions before it can be used. Grant them using the button below."},"error":{"explanation":"Something went wrong while we were trying to display this widget.","advice":"Try reinstalling the widget or reloading the page. Contact us if you see this message often.","support":"Support","refresh":"Refresh"},"auth":{"message":"You'll need to give this widget access to your account before you can use it.","button":"Grant Access"},"shared":{"settings":{"title":"Widget Title","title_placeholder":"Enter a widget title or leave blank to hide","height":"Widget Height","sync":"Synchronization by","sync_options":{"id":"Identity","path":"Path"},"open_options":{"current":"The current tab","blank":"A new tab"},"footer_link":"Footer Link","footer_link_options":{"show":"Show","hide":"Hide"},"account":"Account ID","account_help":"If you're signed into multiple accounts, this is the \"authuser=\" value.\n<br /><br />\nFor example, if you're signed into two accounts, jsmith1@gmail.com and jsmith2@gmail.com, the \"authuser\" value for jsmith2@gmail.com would be 1 since it's the second account (counting from zero) that you're signed into.","account_placeholder":"Your \"authuser=\" value","on":"On","off":"Off"}},"apps":{"name":"Apps","desc":"Displays your currently installed Google Chrome applications.","settings":{"format":"Widget Format","format_options":{"tiles":"Tiles","list":"List"},"display":"Show","display_options":{"all":"All apps","enabled":"Only enabled apps"},"sort":"Sort","sort_options":{"id":"ID","alphabetically":"Alphabetically","offline":"Offline Enabled","available":"Availability"},"open":"Open apps in"},"store_app":"Store"},"bookmarks":{"name":"Bookmarks","desc":"Displays selected and customized bookmarks, and other links.","settings":{"title_placeholder":"Enter a widget title","layout":"Layout","layout_options":{"single":"Single column","double":"Double column"},"open":"Open bookmarks in"},"edit":{"dialog_title":"Edit Bookmark","title":"Bookmark Title","title_placeholder":"Google","url":"Bookmark URL","url_placeholder":"https://www.google.com/","save":"Save"},"new_caption":"New","new_bookmark":"Bookmark","new_folder":"Folder","drop_link":"Drop link here"},"chrome_bookmarks":{"name":"Bookmarks","desc":"Displays your Chrome bookmarks, optionally from a specific folder.","settings":{"title_placeholder":"Enter a widget title","from":"Show bookmarks from","open":"Open bookmarks in"}},"calc":{"name":"Calculator","desc":"Displays a calculator with support for basic operators.","error":"Error!","infinity":"Infinity","mismatch":"Mismatched parentheses"},"calendar":{"name":"Calendar","desc":"Displays upcoming events from one or more of your Google calendars.","settings":{"calendar":"Calendar","show":"Show events from","show_options":{"all":"All time (up to 40 events)","today":"Today only"},"view":"Calendar view","view_options":{"agenda1d":"Agenda Day","list2w":"List","short1d":"Short Day"},"range":{"start":"Agenda Start Time","end":"Agenda End Time"},"text":{"color":"Events Text Color","placeholder":"Examples: black, #000, #000000, rgb(0,0,0), ..."},"timezone":{"title":"Events Timezone","calendar":"Calendars settings","local":"Local"}},"title":"Agenda","calendar":"Calendar","noevents":"No events found in the near future, it looks like your schedule's clear!","nocalendars":"Please select the calendar in the settings"},"clock":{"name":"Clock","desc":"Offers alarm, time, timer, and stopwatch functionality.","settings":{"timezone":"Time Zone","timezone_local":"Local","group_byregion":"Regions","group_UTC":"Universal Time","format":"Clock Format","format_options":{"ampm":"AM/PM - Digital","24hour":"24 Hour - Digital","analog":"12 Hour - Analog","ampmseconds":"AM/PM - Digital, No Seconds","24hourseconds":"24 Hour - Digital, No Seconds"},"sound":"Alert Sound"},"title":"Clock","alarm":"Alarm","clock":"Clock","timer":"Timer","stopwatch":"Stopwatch","set":"Set","unset":"Unset","dismiss":"Dismiss","enable_audio":"Enable audio"},"facebook":{"name":"Facebook","desc":"Embeds Facebook in a widget"},"feedly":{"name":"Feedly","desc":"Displays articles from your Feedly account in a configurable format.","settings":{"source":"Show articles from","source_feeds":"Feeds","show":"Show","show_options":{"all":"All articles","unread":"Only unread articles"},"layout":"Layout","layout_options":{"titles":"Titles only","magazine":"Magazine","cards":"Cards","cards_columns":"Cards (two columns)"},"mark":"Mark an article as read when I","mark_options":{"scroll":"Scroll past it or click it","click":"Just click it"},"sort":"Sort Order","sort_options":{"newest":"Newest first","oldest":"Oldest first"}},"all":"All","saved":"Saved for later","uncategorized":"Uncategorized","author":"by","go_to_feedly":"Go To Feedly"},"notes":{"name":"Notes","desc":"Inserts a simple, editable, note.","settings":{"color":"Note Color","color_options":{"yellow":"Yellow","orange":"Orange","red":"Red","blue":"Blue","green":"Green","white":"White"},"font":"Font Face","fontsize":"Font Size"}},"now":{"name":"Google Now","desc":"Displays cards from Google Now including flight status and package tracking.","authorize":"You'll need to give ProductivityTab permission to view your Google Now cards before anything will show up here.","authorize_btn":"Authorize","caught_up":"All caught up, nothing here.","no_title":"No Title"},"plus":{"name":"Google+","desc":"Embeds Google Plus in a widget"},"notifications":{"name":"Google Notifications","desc":"Displays your Google Notifications from services such as Google+"},"reddit":{"name":"Reddit","desc":"Displays the top items on Reddit for any given subreddit.","settings":{"subreddit":"Subreddit","subreddit_help":"Enter any subreddit by the part past <b>/r/</b> when on Reddit.\n<br /><br />\nFor example, Technology is at: <a href=\"https://www.reddit.com/r/technology\">https://www.reddit.com/r/technology</a>, therefore you would enter <b>technology</b>","subreddit_placeholder":"Enter a subreddit to show links from. (i.e. technology)","sort":"Sort Order","sort_options":{"hot":"Hot","top":"Top","new":"New","gilded":"Gilded","rising":"Rising","controversial":"Controversial"},"links":"Links Shown","click":"When I click a link show me","click_options":{"link":"The link","comments":"The comments"}},"more":"More"},"tasks":{"name":"Tasks","desc":"Displays an editable list of tasks from one of your Google Tasks lists.","title":"Tasks","settings":{"list":"List"},"task_title":"Title","due_date":"Due date","notes":"Notes","add":"Add Item","delete_task":"Delete Task","move_up":"Move Up","move_down":"Move Down","done":"Done","due_today":"Due today","overdue":"Overdue","authorize":"You'll need to select a list from your Google Tasks via the settings before anything can be displayed here."},"twitter":{"name":"Twitter","desc":"Displays tweets from your home stream or a specified list.","settings":{"source":"Show Tweets from","show":"Tweets Shown"},"authorize":"You'll need to authorize ProductivityTab first","authorize_msg":"You'll need to give ProductivityTab permission to view tweets from your account before anything will show up here.","authorize_btn":"Authorize","no_tweets":"There don't seem to be any tweets here...","home":"Home","mentions":"Mentions","retweets":"Retweets of me","lists":"Lists","more":"More","reply":"Reply","retweet":"Retweet","favorite":"Favorite"},"wolfram":{"name":"Wolfram|Alpha","desc":"Inserts a small Wolfram|Alpha search box."},"youtube":{"name":"YouTube","desc":"Displays either popular videos or videos from a specified user.","settings":{"format":"Format","format_options":{"large":"One large","large_2":"One large, two small","large_4":"One large, four small","four":"Four small","six":"Six small"},"from":"Show Videos From","from_help":"This must be an <b>exact</b> username as shown in the URL of the page when you're viewing their profile.\n<br /><br />\nThis value never includes spaces.","from_placeholder":"Leave blank to show Top Videos","open":"Open search results in"},"search":"Search YouTube","num_views":"views"},"quotes":{"name":"Quotes","desc":"Displays a quote picked either every time you load the page or once daily.","settings":{"source":"Source","method":"Load new quotes","method_options":{"daily":"Once daily","random":"Every time I load the page"}},"unknown_author":"Unknown"},"html":{"name":"HTML","desc":"Displays completely custom HTML in an iframe.","settings":{"html":"HTML","js":"JavaScript","height":"Widget Height","refresh":"Refresh interval, secs"}},"sitelink":{"name":"Site Link","desc":"Displays a link, optionally with a title and thumbnail","settings":{"link":"Link URL","link_placeholder":"https://www.google.com/","image":"Image URL","image_placeholder":"https://www.example.com/image.png","image_help":"Please upload your image to any image sharing service such as <a href=\"https://postimg.cc/\" target=\"_blank\">PostImage</a>, <a href=\"https://imgur.com/\" target=\"_blank\">imgur</a>, <a href=\"https://imgbb.com/\" target=\"_blank\">Imgbb</a> or share an image on file hostings like Google Drive or DropBox. Then copy the URL ending with an extension (i.e. .jpg, .gif or .png) and paste it into the field.","color":"Image Background Color","style":"Image Style","style_fill":"Fill","style_center":"Center","target":{"title":"Target","default":"Default","same":"The same","new":"New tab"}}},"stats":{"name":"System Statistics","desc":"Keep an eye on your system with realtime statistics","memory":"Memory","battery":"Battery","usage":"usage","in_use":"in use","remaining":"remaining","charged":"Fully Charged","idle":"Idle","charging":"Charging","discharging":"Discharging"},"search":{"name":"Search","desc":"Embeds a search box in your page for easy access","settings":{"placeholder":"Search Field Placeholder","search_url":"Search URL","param":"Query Parameter","param_placeholder":"The parameter where the query goes, i.e. \"q\""},"default_placeholder":"Search Google"},"pushbullet":{"name":"Pushbullet","desc":"Keep track of notifications from your phone and other devices","no_pushes":"No pushes found","sign_in":"Sign in","no_key":"It doesn't look like you're signed in to Pushbullet.  Sign in now to connect this widget."},"linkedin":{"name":"LinkedIn","desc":"Displays your LinkedIn home stream"},"directions":{"name":"Directions","desc":"Get directions to and from nearly anywhere right from your homepage","driving":"Driving","transit":"Public Transit","walking":"Walking","cycling":"Cycling","from":"Enter a starting point","to":"Enter a destination","loading":"Loading directions, please wait...","error":"Something went wrong while trying to load the directions you requested.","error2":"Please check the start and destination addresses you entered.","open_in_maps":"Open in Google Maps","via":"via"},"pocket":{"name":"Pocket","desc":"Display a list of your saved articles, videos, and web pages from Pocket","settings":{"links_shown":"Number of links shown","open":"Open links","open_pocket":"In Pocket","open_original":"At their original URL"},"by":"By","no_links":"No links found","grant_access":"Grant access","no_key":"You'll need to give ProductivityTab access to your Pocket account before it can load your links."}},"themes":{"title":"Themes","all":"All","custom":"Custom","create":"Create a theme","url_or_upload":"or","upload_image":"Upload an image","edit_btn":"Edit","delete":"Delete","use":"Use","preview":"Preview","author":"By","images":"%s images","resolution":"Resolution","categories":"Categories","cached":"This theme has been cached and is available offline","random":"This theme displays a random image every time you load the page","random_daily":"This theme displays an image picked randomly every day","sunrise_sunset":"This theme displays an image based on the time of day","feed":"This theme displays an image selected daily from an external feed","video":"This theme displays a live video","pro_only":"This theme is only available to Pro users. Buy Pro in the settings.","delete_confirm":"Are you really sure you would like to delete this theme?\r\nThis action is irreversible; the entire theme will be permanently lost.","delete_error":"An error occurred while trying to delete the theme.  Please try again later.","feed_fetching":"Please wait, fetching feed...","feed_error":"Something went wrong while trying to fetch the feed.  Please try again later.","caching":"Please wait, caching theme...","cache_status":"%s of %s images cached","cache_error":"An error occurred while trying to cache the theme.  Please try again later","bginfo":{"view":"View","source":"Source","unknown":"Unknown","download":"Download","pro_only":"Only Pro users can download background images and videos"},"edit":{"title":"Edit Theme","create_title":"Create Theme","name":"Theme Name","default_name":"New Theme","name_placeholder":"Enter a theme name","image":"Image URL","image_placeholder":"Enter a background image URL","image_help":"Uploaded images <b>cannot be synced</b> between computers.<br /><br />If this is important to you, please upload your image to a service such as <a href=\"https://imgur.com/\" target=\"_blank\">imgur</a>. Then copy the URL ending with an extension (i.e. .jpg) and paste it into the field on the left.","color":"Fallback Color","color_placeholder":"Enter any color name","position":"Position","position_options":{"center":"Center","top_left":"Top Left","top_center":"Top Center","top_right":"Top Right","bottom_left":"Bottom Left","bottom_center":"Bottom Center","bottom_right":"Bottom Right"},"scaling":"Scaling","scaling_options":{"auto":"Auto","width":"Full Width","height":"Full Height","none":"No Scaling (preview may be inaccurate)"},"repeat":"Image Repeat","repeat_options":{"none":"No Repeat","horizontal":"Repeat Horizontally","vertical":"Repeat Vertically","both":"Repeat Both"},"attach":"Attach Image To","attach_tab":"The tab","attach_window":"The window","preview":"Preview","save":"Save & Close","cache_error":"An error occurred while trying to cache the image you provided, please double-check the URL.","upload_error":"An error occurred while trying to upload the file you provided, please make sure that it's a reasonable size and an image."}}},"es":{"lang_code":"es","language":"Inglés","extName":"ProductivityTab — Custom Homepage Dashboard","newtabName":"ProductivityTab — Custom New Tab Dashboard","extDescription":"A remarkably customizable personal homepage featuring 50+ widgets, breathtaking backgrounds and much more.","newtabDescription":"A customizable personal dashboard on your new tab page featuring 50+ widgets, breathtaking backgrounds and much more.","defaults":{"tab":"Inicio","me":"Yo"},"remove_widget":"Quitar","hide_banner":"Hide this banner","hide_ad":{"content":"Hey! We're not crazy about ads either, but we're only able to make ProductivityTab available and continue developing features for our free users (that's you!) by showing ads. If you'd like to support ProductivityTab directly and get rid of ads for free, we would really appreciate if you upgraded to our pro version","upgrade":"Upgrade","hide":"Hide ads"},"alert":{"default_button":"Ignorar","confirm_title":"¿Está seguro de que quiere hacer esto?","confirm_continue":"Continuar","confirm_cancel":"Cancelar"},"onboarding":{"modal":{"tagline":"All the sites and apps you use, in one place","wrong_extension":"Want ProductivityTab on your new tab page instead?","wrong_extension_newtab":"Want ProductivityTab on your home page instead?","wrong_extension_action":"Clica aquí","about":"ProductivityTab's all about tabs and widgets","about_desc":"Tabs are pages filled with widgets - blocks that show things like the weather, news, and your email. You can customize most widgets and add as many as you want.","terms":"By checking, you agree to ProductivityTab's <a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\">Terms</a> and <a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\">Privacy Policy</a>","sign_in":"Sign in with your Google account","sign_in_desc":"Sign in with your Google account before getting started to securely save your changes online.","sign_in_desc2":"You can stay signed out if you want, but your page won't be saved online and you won't be able to access it from other computers.","sign_in_button":"Sign in with Google","have_account":"It looks like you already have an account!","have_account_desc":"All your tabs and widgets are ready to use!","get_started":"Let's get started!","get_started_desc":"You're good to go! Let's get your page set up."},"widgets":{"configure":"Let's configure a widget.","configure_desc":"Click the wrench to open a widget's <b>settings</b>.","configure_skip":"Skip Tutorial","settings":"Replace <b>Link URL</b> with your favorite site, then press <b>Save</b>.","move":"You can <b>reposition</b> widgets by clicking and dragging the three dots highlighted here.","remove":"To <b>delete</b>, simply click the red trash bin icon.","done":"Got it"},"settings":{"intro":"Now let’s add a new widget. This highlighted button is where you can access the Widget Menu.","instructions":"Click the new widget button on to open the widget menu!","skip":"Pasar","tooltips":{"settings":"Cambiar el aspecto y el funcionamiento de ProductivityTab","widgets":"Añadir nuevos widgets - puedes tener tantos como quieras","editing":"Show or hide the editing buttons on widgets","links":"This is a list of links, add sites you use often in the settings","tabs":"These are your tabs. You can add more in the settings","support":"Send us a message or leave a review here"},"finished":"That's it!","finished_next":"Choose an option from the menu (try starting with <b>Widgets</b>) and set your page up!","finished_contact":"Use the support link if you need any help and we'll get back to you ASAP."}},"storage":{"signin":"Sign in with Google now to securely save and sync your configuration","signin_btn":"Acceder","signin_dismiss":"Ignorar","signin_confirm":{"title":"Keep local data?","desc":"Would you like to keep your local data, and replace the configuration in your account with it, or replace this computer's configuration with the one already in your account?","keep_account":"Use account","keep_local":"Keep local"},"signout_confirm":"Signing out will erase your local backups","pastdue":"Your subscription is past due","pastdue_desc":"Please update your billing information in the settings"},"toolbar":{"placeholder":"Escribe aquí","placeholder_ok":"Escribe aquí, o di \"OK, Google\"","suggestions":{"url_subtext":"Visit URL","capture_notice":"ProductivityTab handles searches you normally make from the Omnibox. You can disable this at any time from the settings"},"apps":{"search":"Buscar","youtube":"YouTube","maps":"Maps","play":"Play","news":"News","gmail":"Gmail","drive":"Disco","calendar":"Calendario","more":"Más"}},"menu":{"settings":"Ajustes","widgets":"Applicaciones","editing":"Edición","editing_enabled":"Habilitado","editing_disabled":"Deshabilitado","plus":"Google Plus","tabs":"Pestañas","footer":{"support":"Soporte","feedback":"Commentarios","review":"Críticas","terms":"Terms","privacy":"Privacy","by":"Por Avi Kohn"}},"voice":{"listening":"Escuchando...","searching":"Buscando: %s","missed":"No entendí. <a>Intente Nuevamente</a>"},"settings":{"title":"Ajustes","exit":"Exit settings","saved":"Settings saved","nav":{"visual":"Visual","visual_sections":{"background":"Background","layout":"Diseño","theme":"App theme","ad_placement":"Ad placement"},"toolbar":"Toolbar","toolbar_sections":{"style":"Style","search":"Buscar","links":"Links"},"tabs":"Pestañas","widgets":"Applicaciones","ads":"Ads","pro":"Pro","accounts":"Account","misc":"Miscellaneous","advanced":"Advanced","advanced_sections":{"backups":"Backup and restore","css":"Custom CSS","debug_tools":"Debug tools"},"support":"Help and support","suggest":"Suggest a feature"},"visual":{"background":{"title":"Background","desc":"This is the image or set of images shown as a background to your tabs","current":"Current background","custom":"Personlizado","unnamed":"Theme %s","select":"Select a theme","or":"o","url_placeholder":"Enter an image URL"},"layout":{"title":"Diseño","desc":"Here you can adjust the type and number of columns in each tab","columns":"Columns","grid":"Grid","columns_number":"Number of columns","column_width":"Column width","column_width_fixed":"Fixed","column_width_fluid":"Fluid","column_warning":{"column_to_grid":"Changing to a grid-based layout will move all of your widgets to the top left corner.","grid_to_column":"Changing to a column-based layout will move all of your widgets to the first column."}},"theme":{"title":"App theme","desc":"The app theme controls the style of ProductivityTab itself and all widgets","preview":"Avance","light":"Light (default)","dark":"Oscuro","transparent":"Transparent","transparent_darker":"Transparent (darker)"}},"toolbar":{"style":{"title":"Style","desc":"This controls the style of the toolbar.  It can either appear normally or as an out of the way button","normal":"Normal","button":"Button"},"search":{"title":"Buscar","desc":"These settings control how the search box and voice search function","engine":"Search engine","engines_default":"Default","engines_custom":"Personlizado","engines_custom_desc":"Enter a URL that queries should be sent to, with <b>%s</b> where the query should go.","omnibox_capture":"Handle searches normally made in the Omnibox","voice":"Enable voice search","ok_google":"Enable \"OK Google\" hotword detection","search_tab":"Open search results in a new tab"},"links":{"title":"Links","desc":"These are the items shown at the right of the toolbar","apps":"Apps menu","custom":"Custom links","custom_note1":"Maximum of 3 allowed","custom_note2":"users get 8","custom_name_placeholder":"Link text","custom_url_placeholder":"Link URL, i.e. https://www.google.com/"}},"misc":{"link_tab":"Open links in a new tab by default"},"tabs":{"create_new":"Create new","make_default":"Make default","desc1":"Tabs are pages inside ProductivityTab. Each tab has its own set of widgets that is completely separate from every other tab.","desc2":"You can switch between tabs by clicking the buttons that appear at the left and right of the screen when you move your mouse over a tab or by using the arrow keys on your keyboard.","name_placeholder":"Enter a tab name","delete_confirm":"This action is irreversible. All data from all widgets in the tab will be permanently lost."},"accounts":{"status":{"title":"Status","signed_in":"You are currently <b>signed in</b> as %s (%s).","reset_account":"Reset account","sign_out":"Sign out","signed_out":"You are <b>not currently signed in</b>. Sign in with your Google account now to securely store and sync your configuration.","sign_in":"Sign in with Google"},"reset_confirm_desc":"This will erase all local and synced data, there is no backup and no way to undo this.","reset_confirm_desc2":"You will lose your entire current configuration on all computers connected to this account."},"advanced":{"backups":{"title":"Backup and restore","desc":"Backups are complete copies of all your tabs, settings, and widgets. They're automatically created when you first open ProductivityTab each day.","desc2":"Use the buttons below to roll ProductivityTab back to a particular date or download one of your backups.","backup":"Backup now","upload":"Restore from file","download":"Download","restore":"Restore","download_name":"ProductivityTab Backup","restore_confirm":"This will overwrite all local and synced data. You will lose your entire current configuration on all computers under this account.","restore_error":"An error occurred while trying to parse the provided data, please try again later."},"css":{"title":"Custom CSS","desc":"You can use CSS (<a href=\"https://developer.mozilla.org/en-US/docs/Web/CSS\" target=\"blank\">definition</a>) to customize almost any part of ProductivityTab.","placeholder":"Enter up to 1000 characters of CSS here"},"debug_tools":{"title":"Debug tools","desc":"<b>WARNING:</b> These tools can erase your entire configuration in a single click. Only use them if your developer instructs you to.","open":"Open tools"}},"widgets":{"desc1":"Widgets have their own settings and can't be customized here.","desc2":"To edit a widget's settings, follow these steps:","steps1":"Move your mouse over any widget","steps2":"Click the wrench icon that appears at the top right of the widget. If none appears then the widget doesn't have any settings that can be customized.","steps3":"Edit any of the settings shown in the dialog that's displayed","steps4":"Click Save to save your changes, or any part of the background to discard of them"},"pro":{"promo":{"monthly_price":"$4.99 per month","yearly_price":"or $29.99 per year","upgrade_btn":"Upgrade Now","business":"Interested in buying Pro for your business or school?","business_contact":"Contact us","themes":"Tema","themes_desc":"See more of your backgrounds with dark and transparent themes","bgs":"Live backgrounds","bgs_desc":"Bring your page to life with 20 live high-definition backgrounds","widgets":"Maximizable widgets","widgets_desc":"Take ProductivityTab to another level with maximizable widgets","more_header":"And more","stocks":"Realtime stocks with extended and historical information","rss":"Support for multiple RSS feeds per widget","sports":"General and league-specific sports news","tabbed_widgets":"Tabbed news and RSS widgets","bg_downloads":"Downloadable backgrounds","weather":"Hourly weather forecasts up to 10 days out","toolbar":"More toolbar links","ads":"A completely ad-free experience","support":"Prioritized support and suggestions","buy_pro":"Buy Pro"},"checkout":{"title":"Checkout","updating_title":"Update plan","payment_options":"Pay","pay_monthly":"Monthly ($4.99)","pay_yearly":"Yearly ($29.99)","cancel":"Cancelar","update":"Update","subscribe":"Subscribe","braintree_notice":"Payments securely processed by Braintree.","monthly_notice":"By subscribing, you authorize ProductivityTab to charge you $4.99 every month until you cancel your subscription.","yearly_notice":"By subscribing, you authorize ProductivityTab to charge you $29.99 every year until you cancel your subscription.","update_notice":"Although billing cycle changes take effect immediately, you won't be charged until your current cycle ends.","thank_you":"Thank you for buying ProductivityTab Pro!","thank_you2":"ProductivityTab will reload in a few seconds and you'll be all set!","error":"Something went wrong while trying to process your payment.","error2":"Please try again later or email us at support@ichro.me","signin":"Acceder","signin_desc":"You need to sign in before buying Pro so we can make sure it's you","signin_btn":"Acceder"},"plan":{"title":"Plan","desc":"You are currently subscribed to ProductivityTab Pro (%s)","types":{"monthly":"Monthly","yearly":"Yearly","business":"Business","education":"Education","custom":"Personlizado"},"uneditable_desc":"Business, education, and custom plans cannot be updated from within ProductivityTab. Please <a href=\"mailto:support@ichro.me\">contact us</a> to update or cancel your subscription.","status":"Status","status_active":"Active","status_trial":"Trial","status_pastdue":"Past due","subscription_date":"Subscription date","paid_through":"Paid through","next_bill":"Next bill","next_bill_value":"$%s on %s","update_plan":"Update plan","update_billing":"Update billing","cancel":"Cancel subscription","cancel_notice":"Your subscription will be canceled immediately","cancel_notice2":"If you would like a refund, please contact us at support@ichro.me"}},"ads":{"text1":"ProductivityTab displays a few small ads to pay for server, support and development costs. With these ads, we can afford to offer iChrome free to everyone.","text2":"Here you can choose where those ads are shown, or buy ad-free to permanently remove them.","text3":"Ad-free is a one-time purchase that permanently removes ads from ProductivityTab wherever you're signed in. You can also upgrade to Pro for extra features in addition to an ad-free experience.","upgrade_btn":"Upgrade to ad-free","already_upgraded":"It looks like you've already upgraded to ad-free","signin":"Acceder","signin_desc":"Sign in before upgrading so we can link your purchase to your account","signin_btn":"Acceder","thank_you":"Thank you for upgrading to ad-free!","placement":{"title":"Ad placement","left":"In the leftmost column","right":"In the rightmost column","top":"Above the tab","bottom":"Floating at the bottom"}}},"store":{"installation":"Instalación","description":"Descripción","preview":"Avance","instructions":"Arrastrar y soltar cualquier tamaño en tu página de inicio"},"widgets":{"sizes":{"tiny":"Minúsculo","small":"Pequeño","medium":"Mediano","large":"Grande","variable":"Variable"},"settings":{"title":"Configuración de Widget","save":"Guardar","size":"Tamaño del widget"},"minimize":"Minimize","maximize":"Maximize","delete_confirm":"¿Estás seguro de que desea eliminar este widget? Esta acción es irreversible; todos los datos de este widget se perderán permanentemente.","permissions_request":{"title":"Access required","button":"Grant Access","desc":"This widget needs extra permissions before it can be used. Grant them using the button below."},"error":{"explanation":"Something went wrong while we were trying to display this widget.","advice":"Try reinstalling the widget or reloading the page. Contact us if you see this message often.","support":"Soporte","refresh":"Refresh"},"auth":{"message":"You'll need to give this widget access to your account before you can use it.","button":"Grant Access"},"shared":{"settings":{"title":"Título de widget","title_placeholder":"Introduzca el título de un widget o deje en blanco para ocultar","height":"Altura de Widget","open_options":{"current":"La pestaña actual","blank":"Una nueva pestaña"},"footer_link":"Enlace de pie de página","footer_link_options":{"show":"Mostrar","hide":"Ocultar"},"account":"ID de Cuenta","account_help":"Si usted firmó en múltiples cuentas, este es el \"authuser =\" valor.\n<br /><br />\nPor ejemplo, si está firmado en dos cuentas, jsmith1@gmail.com y jsmith2@gmail.com, el valor \"authuser\" para jsmith2@gmail.com interesaría 1 puesto que es la segunda cuenta (contando desde cero), que está firmado.","account_placeholder":"Su \"authuser =\" valor","on":"Activado","off":"Desactivado"}},"apps":{"name":"Aplicaciones","desc":"Muestra tus aplicaciones Google Chrome instalados actualmente.","settings":{"format":"Formato widget","format_options":{"tiles":"Cuadrillas","list":"Lista"},"display":"Mostrar","display_options":{"all":"Todas las aplicaciones","enabled":"Sólo habilita aplicaciones"},"sort":"Organizar","sort_options":{"id":"ID","alphabetically":"Por orden alfabético","offline":"Línea habilitada","available":"Disponibilidad"},"open":"Aplicaciones abiertas en"},"store_app":"Tienda"},"bookmarks":{"name":"Marcadores","desc":"Muestra había seleccionada y marcadores y otros enlaces personalizados.","settings":{"title_placeholder":"Introduzca el título de un widget","layout":"Diseño","layout_options":{"single":"Sola columna","double":"De doble columna"},"open":"Abrir marcadores en"},"edit":{"dialog_title":"Editar favoritos","title":"Marcador de título","title_placeholder":"Google","url":"Bookmark URL","url_placeholder":"https://www.google.com/","save":"Guardar"},"new_caption":"Nuevo","new_bookmark":"Marcador","new_folder":"Carpeta","drop_link":"Caída de enlace aquí"},"chrome_bookmarks":{"name":"Marcadores","desc":"Muestra tus marcadores de Chrome, opcionalmente de una carpeta específica.","settings":{"title_placeholder":"Introduzca el título de un widget","from":"Mostrar marcadores de","open":"Abrir marcadores en"}},"calc":{"name":"Calculadora","desc":"Muestra una calculadora con soporte para los operadores básicos.","error":"¡ Error!","infinity":"Infinito","mismatch":"Paréntesis no coincidentes"},"calendar":{"name":"Calendario","desc":"Muestra eventos de uno o más de sus calendarios de Google.","settings":{"calendar":"Calendario","show":"Mostrar eventos de","show_options":{"all":"Todo el tiempo","today":"Hoy solamente"}},"title":"Agenda","calendar":"Calendario","noevents":"No events found in the near future, it looks like your schedule's clear!"},"clock":{"name":"Reloj","desc":"Offers alarm, time, timer, and stopwatch functionality.","settings":{"timezone":"Zona horaria","timezone_local":"Local","format":"Formato de reloj","format_options":{"ampm":"AM/PM - Digital","24hour":"24 horas - Digital","analog":"12 horas - analógico","ampmseconds":"AM/PM - Digital, No segundos","24hourseconds":"24 horas - Digital, No segundos"},"sound":"Sonido de Alerta"},"title":"Reloj","alarm":"Alarma","clock":"Reloj","timer":"Temporizador","stopwatch":"Cronómetro","set":"Establecer","unset":"Anular","dismiss":"Ignorar","enable_audio":"Activar el sonido"},"facebook":{"name":"Facebook","desc":"Incrusta Facebook en un widget"},"feedly":{"name":"Feedly","desc":"Muestra los artículos de tu cuenta Feedly en un formato configurable.","settings":{"source":"Mostrar artículos de","source_feeds":"Entradas","show":"Mostrar","show_options":{"all":"Todos los artículos","unread":"Sólo los artículos no leídos"},"layout":"Diseño","layout_options":{"titles":"Títulos solamente","magazine":"Revista","cards":"Tarjetas","cards_columns":"Tarjetas (dos columnas)"},"mark":"Marca un artículo como Lee cuando me","mark_options":{"scroll":"Desplazarse más allá o haga clic en él","click":"Simplemente haga clic en él"},"sort":"Orden de clasificación","sort_options":{"newest":"Nuevos Primero","oldest":"Antiguos Primero"}},"all":"Todos","saved":"Salvado para más tarde","uncategorized":"Sin clasificar","author":"por","go_to_feedly":"Ir a Feedly"},"notes":{"name":"Notas","desc":"Inserta una nota simple, editable.","settings":{"color":"Note el Color","color_options":{"yellow":"Amarillo","orange":"Naranja","red":"Rojo","blue":"Azul","green":"Verde","white":"Blanco"},"font":"Cara de letra","fontsize":"Tamaño de letra"}},"now":{"name":"Google Now","desc":"Muestra las tarjetas a partir de ahora Google incluyendo estado de vuelo y seguimiento de paquetes.","authorize":"Usted necesitará dar permiso ProductivityTab para ver tus cartas de Google ahora antes de que algo va a aparecer aquí.","authorize_btn":"Autorizar","caught_up":"Todo atrapado, nada aquí.","no_title":"Sin título"},"plus":{"name":"Google +","desc":"Incrusta Google Plus en un widget"},"notifications":{"name":"Notificaciones de Google","desc":"Muestra tus notificaciones de Google de servicios tales como Google +"},"reddit":{"name":"Reddit","desc":"Muestra los elementos principales en Reddit para cualquier subreddit dado.","settings":{"subreddit":"Subreddit","subreddit_help":"Introduzca cualquier subreddit por la parte más allá de <b>/r/</b> cuando en Reddit.\n<br /><br />\nPor ejemplo, la Tecnología es: <a href=\"https://www.reddit.com/r/technology\">https://www.reddit.com/r/technology</a>, por lo tanto, es necesario introducir <b>tecnología</b>","subreddit_placeholder":"Introduzca un subreddit para mostrar enlaces de. (es decir, tecnología)","sort":"Orden de clasificación","sort_options":{"hot":"Popular","top":"De Los Mejores Temas","new":"Nuevo","gilded":"Dorado","rising":"Levantamiento","controversial":"Polémico"},"links":"Links de","click":"Cuando hago clic en un enlace mostrarme","click_options":{"link":"El enlace","comments":"Los comentarios"}},"more":"Más"},"tasks":{"name":"tareas","desc":"Muestra una lista de tareas de una de sus tareas de Google editable aparecen.","title":"tareas","settings":{"list":"Lista"},"task_title":"Título","due_date":"fecha de vencimiento","notes":"Notas","add":"Añadir Artículo","delete_task":"Borrar tarea","move_up":"Subir","move_down":"Abajo","done":"Hecho","due_today":"Vencen hoy","overdue":"Atrasado","authorize":"Usted necesitará seleccionar una lista de sus tareas de Google mediante la configuración antes de que nada puede ser mostrado aquí."},"twitter":{"name":"Twitter","desc":"Muestra tweets de su corriente de la casa o una lista especificada.","settings":{"source":"Mostrar Tweets de","show":"Tweets que se muestra"},"authorize":"Usted necesitará autorizar ProductivityTab primero","authorize_msg":"Usted necesitará dar permiso ProductivityTab para ver tweets desde tu cuenta antes de que algo va a aparecer aquí.","authorize_btn":"Autorizar","no_tweets":"No parece haber ningún tweets aquí...","home":"Inicio","mentions":"Menciones","retweets":"Retweets de mí","lists":"Listas","more":"Más","reply":"Responder","retweet":"Retweetear","favorite":"Favorito"},"wolfram":{"name":"Wolfram|Alpha","desc":"Inserta un pequeño Wolfram|Buscador de alfa."},"youtube":{"name":"YouTube","desc":"Muestra vídeos populares o vídeos de un usuario específico.","settings":{"format":"Formato","format_options":{"large":"Uno grande","large_2":"Uno grande, dos pequeñas","large_4":"Uno grande, cuatro pequeños","four":"Cuatro pequeños","six":"Seis pequeñas"},"from":"Mostrar Videos de","from_help":"Este debe ser un nombre de usuario <b>exactamente</b> como se muestra en la dirección URL de la página cuando estás viendo su perfil.\n<br /><br />\neste valor no incluye espacios.","from_placeholder":"Deje en blanco para mostrar Videos Top","open":"Resultados de búsqueda abierta"},"search":"Buscar YouTube","num_views":"Vistas"},"quotes":{"name":"Comillas","desc":"Muestra una cotización elegida cada vez que se carga la página o una vez al día.","settings":{"source":"Fuente","method":"Carga nuevas frases","method_options":{"daily":"Una vez al día","random":"Cada vez cargue la página"}},"unknown_author":"Desconocido"},"html":{"name":"HTML","desc":"Muestra totalmente personalizado HTML en un iframe.","settings":{"html":"HTML","js":"JavaScript","height":"Altura de Widget"}},"sitelink":{"name":"Site Link","desc":"Displays a link, optionally with a title and thumbnail","settings":{"link":"URL del Enlace","link_placeholder":"https://www.google.com/","image":"URL de la imagen","image_placeholder":"https://www.example.com/image.png","color":"Color de fondo del imagen","style":"Estilo de Imagen","style_fill":"Llenar","style_center":"Centro"}},"stats":{"name":"Estadísticas del Sistema","desc":"Monitorear su sistema con estadísticas en tiempo real","memory":"Memoria","battery":"Batería","usage":"uso","in_use":"en uso","remaining":"restante","charged":"Carga completa","idle":"Inactivo","charging":"Cargando","discharging":"Descargando"},"search":{"name":"Buscar","desc":"Incrustar un cuadro de búsqueda en su página para facilitar el acceso","settings":{"placeholder":"Search Field Placeholder","search_url":"URL de búsqueda","param":"Parámetro de consulta","param_placeholder":"The parameter where the query goes, i.e. \"q\""},"default_placeholder":"Buscar en Google"},"pushbullet":{"name":"Pushbullet","desc":"Keep track of notifications from your phone and other devices","no_pushes":"No se han encontrado pushes","sign_in":"Acceder","no_key":"It doesn't look like you're signed in to Pushbullet.  Sign in now to connect this widget."},"linkedin":{"name":"LinkedIn","desc":"Displays your LinkedIn home stream"},"directions":{"name":"Direcciones","desc":"Get directions to and from nearly anywhere right from your homepage","driving":"Conducción","transit":"Transporte público","walking":"Andando","cycling":"Ciclismo","from":"Introduzca un punto de partida","to":"Introduzca un destino","loading":"Cargando direcciones, por favor espere...","error":"Algo salió mal mientras trataba de cargar las direcciones solicitadas.","error2":"Por favor verifique las direcciones de inicio y destino que ha ingresado.","open_in_maps":"Abrir en Google Maps","via":"mediante"},"pocket":{"name":"Pocket","desc":"Ver una lista sus artículos, videos y páginas guardados en Pocket","settings":{"links_shown":"Número de enlaces mostrados","open":"Abrir enlaces","open_pocket":"En Pocket","open_original":"En su URL original"},"by":"por","no_links":"No se han encontrado enlaces","grant_access":"Otorgar acceso","no_key":"Necesitará otorgar acceso a su cuenta de Pocket para que ProductivityTab pueda cargar sus enlaces."}},"themes":{"title":"Tema","all":"Todos","custom":"Personlizado","create":"Crear un tema","url_or_upload":"o","upload_image":"Subir una imagen","edit_btn":"Editar","delete":"Eliminar","use":"Usar","preview":"Previsualizar","author":"por","images":"%s imágenes","resolution":"Resolución","categories":"Categorías","cached":"Este tema ha sido almacenados en caché y está disponible sin conexión","random":"Este tema muestra una imagen al azar cada vez que se carga la página","random_daily":"Este tema muestra una imagen escogida al azar cada día","sunrise_sunset":"Este tema muestra una imagen basada en la hora del día","feed":"Este tema muestra una imagen seleccionada diario de alimentación externo","video":"This theme displays a live video","pro_only":"This theme is only available to Pro users. Buy Pro in the settings.","delete_confirm":"¿Estás seguro de que desea eliminar este tema? Esta acción es irreversible; el tema entero se perderá permanentemente.","delete_error":"Se ha producido un error al intentar eliminar el tema.  Inténtalo de nuevo más tarde.","feed_fetching":"Por favor espere, obteniendo datos...","feed_error":"Algo salió mal al intentar descargar los datos. Inténtalo de nuevo más tarde.","caching":"Por favor espere, almacenamiento en caché de tema...","cache_status":"%s de %s imágenes en caché","cache_error":"Se ha producido un error al intentar eliminar el tema.  Inténtalo de nuevo más tarde","bginfo":{"view":"View","source":"Fuente","unknown":"Desconocido","download":"Download","pro_only":"Only Pro users can download background images and videos"},"edit":{"title":"Editar Tema","create_title":"Crear Tema","name":"Nombre de Tema","default_name":"Nuevo Tema","name_placeholder":"Introduzca nombre de Tema","image":"URL de la imagen","image_placeholder":"Introduzca una URL de la imagen de fondo","image_help":"La subida de imágenes <b>no puede ser sincronizada</b> entre ordenadores. <br /> <br /> Si esto es importante para usted, por favor, sube tu imagen a un servicio como <a href=\"https://imgur.com/\" target=\"_blank\"> imgur</a>. Luego copie y pegue la dirección URL terminando con una extensión (por ejemplo, .jpg) y péguelo en el campo de la izquierda.","color":"Color de Suplencia","color_placeholder":"Introduzca el nombre de un color","position":"Posición","position_options":{"center":"Centro","top_left":"Arriba a la izquierda","top_center":"Arriba al centro","top_right":"Arriba a la derecha","bottom_left":"Abajo a la Izquierda","bottom_center":"Abajo al centro","bottom_right":"Abajo a la Derecha"},"scaling":"Redimensionamiento","scaling_options":{"auto":"Automático","width":"Anchura completa","height":"De altura completa","none":"No hay escalamiento (vista previa puede ser inexacta)"},"repeat":"Repetición de la imagen","repeat_options":{"none":"Sin repetición","horizontal":"Repetir horizontalmente","vertical":"Repita verticalmente","both":"Repetir horizontal y verticalmente"},"attach":"Adjuntar imagen","attach_tab":"La Pestaña","attach_window":"La ventana","preview":"Avance","save":"Guardar y Cerrar","cache_error":"Se ha producido un error al intentar almacenar en caché la imagen proporcionado, por favor verifique la dirección URL.","upload_error":"Se ha producido un error al intentar cargar el archivo proporcionado, por favor, asegúrese de que es un tamaño razonable y una imagen."}}},"fr":{"lang_code":"fr","language":"Français","extName":"ProductivityTab — Custom Homepage Dashboard","newtabName":"ProductivityTab — Custom New Tab Dashboard","extDescription":"A remarkably customizable personal homepage featuring 50+ widgets, breathtaking backgrounds and much more.","newtabDescription":"A customizable personal dashboard on your new tab page featuring 50+ widgets, breathtaking backgrounds and much more.","defaults":{"tab":"Accueil","me":"Moi"},"remove_widget":"Supprimer","hide_banner":"Masquer cette bannière","hide_ad":{"content":"Hey! We're not crazy about ads either, but we're only able to make ProductivityTab available and continue developing features for our free users (that's you!) by showing ads. If you'd like to support ProductivityTab directly and get rid of ads for free, we would really appreciate if you upgraded to our pro version","upgrade":"Mettre à jour","hide":"Cacher les annonces"},"alert":{"default_button":"Abandonner","confirm_title":"Êtes-vous sur de vouloir faire ça ?","confirm_continue":"Continuer","confirm_cancel":"Annuler"},"onboarding":{"modal":{"tagline":"Tous les sites web et applications que vous utilisez, en un seul endroit","wrong_extension":"Voulez-vous définir ProductivityTab comme page de nouvel onglet par défaut ?","wrong_extension_newtab":"Voulez-vous définir ProductivityTab comme page d'accueil ?","wrong_extension_action":"Cliquez ici","about":"Tout à propos des onglets et des widgets d'ProductivityTab","about_desc":"Les onglets sont des pages contenant des widgets - des blocs qui montrent des informations comme la météo, les actualités ou votre boîte mail. Vous pouvez personnaliser la plupart des widgets et en ajouter autant que vous voulez.","terms":"En continuant, vous acceptez <a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\">les conditions d'utilisation</a> d'ProductivityTab et <a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\">la Politique de confidentialité</a>","sign_in":"Connectez-vous avec votre compte Google","sign_in_desc":"Connectez-vous avec votre compte Google avant de commencer pour sauvegarder vos changements en ligne.","sign_in_desc2":"Vous pouvez rester déconnecté si vous voulez, mais votre page ne sera pas sauvegardée en ligne et vous ne pourrez pas y accéder à partir d'un autre ordinateur.","sign_in_button":"Connectez-vous avec Google","have_account":"Il semblerait que vous ayiez déjà un compte !","have_account_desc":"Tous vos onglets et les widgets sont prêts à être utilisés !","get_started":"Commençons !","get_started_desc":"Vous êtes prêts à commencer ! Configurons votre page."},"widgets":{"configure":"Configurons un widget.","configure_desc":"Click the wrench to open a widget's <b>settings</b>.","configure_skip":"Skip Tutorial","settings":"Replace <b>Link URL</b> with your favorite site, then press <b>Save</b>.","move":"You can <b>reposition</b> widgets by clicking and dragging the three dots highlighted here.","remove":"To <b>delete</b>, simply click the red trash bin icon.","done":"Compris"},"settings":{"intro":"Now let’s add a new widget. This highlighted button is where you can access the Widget Menu.","instructions":"Click the new widget button on to open the widget menu!","skip":"Passer","tooltips":{"settings":"Modifiez l'apparence et le fonctionnement d'ProductivityTab","widgets":"Ajoutez de nouveaux widgets - vous pouvez en avoir autant que vous voulez","editing":"Affichez ou cachez les boutons d'édition sur les widgets","links":"Voici une liste de liens, ajoutez des sites que vous utilisez souvent dans les paramètres","tabs":"Ce sont vos onglets. Vous pouvez en ajouter d'autres dans les paramètres","support":"Envoyez-nous un message ou laissez un commentaire ici"},"finished":"C'est tout!","finished_next":"Choisissez une option depuis le menu (essayez en commençant avec <b>Widgets</b>) et configurez votre page !","finished_contact":"Utilisez le lien de support si vous avez besoin d'aide et nous allons revenir vers vous le plus tôt possible."}},"storage":{"signin":"Connectez-vous maintenant avec Google pour sauvegarder et synchroniser votre configuration","signin_btn":"Connectez vous","signin_dismiss":"Abandonner","signin_confirm":{"title":"Conserver les données locales ?","desc":"Souhaitez-vous conserver vos données locales et remplacer la configuration de votre compte avec celle-ci, ou remplacer la configuration de l'ordinateur avec celle déjà sur votre compte ?","keep_account":"Utiliser un compte","keep_local":"Garder en local"},"signout_confirm":"Vous déconnecter effacera vos sauvegardes locales","pastdue":"Votre abonnement est expiré","pastdue_desc":"Mettez à jour vos informations de facturation dans les paramètres"},"toolbar":{"placeholder":"Entrez ce que vous cherchez","placeholder_ok":"Entrez ce que vous cherchez ou dites \"OK,Google\"","suggestions":{"url_subtext":"Voir l'URL","capture_notice":"ProductivityTab gère les recherches que vous effectuez normalement à partir de l’Omnibox. Vous pouvez désactiver celà à tout moment depuis les paramètres"},"apps":{"search":"Rechercher","youtube":"YouTube","maps":"Maps","play":"Play","news":"News","gmail":"Gmail","drive":"Drive","calendar":"Calendrier","more":"Plus"}},"menu":{"settings":"Paramètres","widgets":"Widgets","editing":"Editer","editing_enabled":"Activé","editing_disabled":"Desactivé","plus":"Google Plus","tabs":"Onglets","footer":{"support":"Support","feedback":"Commentaires","review":"Avis","terms":"Termes & Conditions","privacy":"Politique de confidentialité","by":"Par Avi Kohn"}},"voice":{"listening":"A l'écoute...","searching":"Recherche : %s","missed":"Je n'ai pas compris. <a>Réessayer</a>"},"settings":{"title":"Paramètres","exit":"Paramètres de déconnexion","saved":"Paramètres sauvegardés","nav":{"visual":"Affichage","visual_sections":{"background":"Fond d'écran","layout":"Mode d'affichage","theme":"Thème de l'application","ad_placement":"Placement d’annonces"},"toolbar":"Barre d’outils","toolbar_sections":{"style":"Style","search":"Rechercher","links":"Liens"},"tabs":"Onglets","widgets":"Widgets","ads":"Annonces","pro":"Pro","accounts":"Compte","misc":"Divers","advanced":"Options avancées","advanced_sections":{"backups":"Sauvegarde et restauration","css":"CSS personnalisé","debug_tools":"Outils de débogage"},"support":"Aide et support","suggest":"Suggérer une fonctionnalité"},"visual":{"background":{"title":"Fond d'écran","desc":"Il s'agit de l'image ou un ensemble d'images présentées comme une toile de fond à vos onglets","current":"Fond d'écran actuel","custom":"Personalisé","unnamed":"Thème %s","select":"Sélectionner un thème","or":"ou","url_placeholder":"Coller l'URL d'une image"},"layout":{"title":"Mode d'affichage","desc":"Ici vous pouvez régler le type et le nombre de colonnes dans chaque onglet","columns":"Colonnes","grid":"Grille","columns_number":"Nombre de colonnes","column_width":"Largeur de colonne","column_width_fixed":"Fixe","column_width_fluid":"Fluide","column_warning":{"column_to_grid":"Changer pour une disposition en grille déplacera tous vos widgets dans le coin en haut à gauche.","grid_to_column":"Changer pour une disposition en colonne déplacera tous vos widgets dans la première colonne."}},"theme":{"title":"Thème de l'application","desc":"Le thème de l'application contrôle le style d'ProductivityTab et de tous les widgets","preview":"Aperçu ","light":"Clair (par défaut)","dark":"sombre","transparent":"Transparent","transparent_darker":"Transparent (plus sombre)"}},"toolbar":{"style":{"title":"Style","desc":"Ceci contrôle le style de la barre d'outils. Elle peut soit apparaître normalement, soit légèrement vers le bas","normal":"Normal","button":"Bouton"},"search":{"title":"Rechercher","desc":"Ces paramètres contrôlent comment la barre de recherche et la recherche vocale fonctionnent","engine":"Moteur de recherche","engines_default":"Par défaut","engines_custom":"Personalisé","engines_custom_desc":"Entrez une URL à laquelle les requêtes doivent être envoyées, avec <b>%s</b> à l'endroit de la requête.","omnibox_capture":"Gérer les recherches effectuées normalement dans l’Omnibox","voice":"Activer la recherche vocal","ok_google":"Activer le mot clé \"OK Google\" pour la detection vocal","search_tab":"Ouvrir les résultats de la recherche dans un nouvel onglet"},"links":{"title":"Liens","desc":"Ce sont les éléments affichés à droite de la barre d'outils","apps":"Menu d'applications","custom":"Liens personnalisés","custom_note1":"Maximum de 3 permis","custom_note2":"les utilisateurs en obtiennent 8","custom_name_placeholder":"Texte du lien","custom_url_placeholder":"URL de lien (Exemple : https://www.google.com/)"}},"misc":{"link_tab":"Ouvrir le lien dans un nouvel onglet par défaut"},"tabs":{"create_new":"Nouveau","make_default":"Définir par défaut","desc1":"Les onglets sont des pages à l'intérieur d'ProductivityTab. Chaque onglet possède son propre ensemble de widgets qui est complètement séparé de chaque autre onglet.","desc2":"Vous pouvez basculer entre les onglets en cliquant sur les boutons qui apparaissent à gauche et à droite de l'écran lorsque vous déplacez votre souris sur un onglet ou en utilisant les flèches de votre clavier.","name_placeholder":"Entrez un nom d'onglet","delete_confirm":"Cette action est irréversible. Toutes les données de tous les widgets dans l'onglet seront définitivement perdues."},"accounts":{"status":{"title":"État","signed_in":"Vous êtes actuellement <b>connecté</b> comme %s (%s).","reset_account":"Réinitialiser le compte","sign_out":"Déconnexion","signed_out":"Vous êtes <b>actuellement non connecté</b>. Connectez-vous avec votre compte Google pour sauvegarder et synchroniser votre configuration.","sign_in":"Connectez-vous avec Google"},"reset_confirm_desc":"Ceci effacera toutes les données locales et synchronisées, il n'y a pas de sauvegarde et aucun moyen d'annuler cette action.","reset_confirm_desc2":"Vous perdrez l'ensemble de la configuration actuelle sur tous les ordinateurs connectés à ce compte."},"advanced":{"backups":{"title":"Sauvegarder et restaurer","desc":"Les sauvegardes sont des copies complètes de tous vos onglets, vos paramètres et vos widgets.Elles sont créés quotidiennement lorsque vous ouvrez ProductivityTab.","desc2":"Utilisez les boutons ci-dessous pour restaurer ProductivityTab à une date précise ou télécharger une de vos sauvegardes.","backup":"Sauvegarder maintenant","upload":"Restaurer à partir d'un fichier","download":"Télécharger","restore":"Restaurer","download_name":"Sauvegarde ProductivityTab","restore_confirm":"Ceci écrasera toutes les données locales et synchronisées. Vous perdrez l'ensemble votre configuration actuelle sur tous les ordinateurs connectés à ce compte.","restore_error":"Une erreur s'est produite en essayant d'interpréter les données fournies, Veuillez réessayer ultérieurement."},"css":{"title":"CSS personnalisé","desc":"Vous pouvez utiliser le CSS (<a href=\"https://developer.mozilla.org/en-US/docs/Web/CSS\" target=\"blank\"> définition</a>) pour personnaliser presque n'importe quoi d'ProductivityTab.","placeholder":"Entrez jusqu'à 1000 caractères de CSS ici"},"debug_tools":{"title":"Outils de débogage","desc":"<b>Avertissement :</b> Ces outils peuvent effacer l'ensemble de votre configuration en un seul clic. Utilisez-les seulement si le développeur vous l'indique.","open":"Outils sous licence ibre"}},"widgets":{"desc1":"Les widgets ont leurs propres paramètres et ne peuvent pas être personnalisés ici.","desc2":"Pour modifier les paramètres du widget, procédez comme suit :","steps1":"Déplacez votre souris sur n'importe quel widget","steps2":"Cliquez sur l'icône de clé qui apparaît en haut à droite du widget. Si rien n'apparaît alors le widget n'a aucun paramètre personnalisable.","steps3":"Modifier les paramètres indiqués dans la boîte de dialogue qui s'affiche","steps4":"Cliquez sur Sauvegarder pour enregistrer vos modifications, ou n'importe quelle partie de l'arrière-plan pour les effacer"},"pro":{"promo":{"monthly_price":"4.99$ par mois","yearly_price":"ou 29.99$ par an","upgrade_btn":"Mettre à niveau maintenant","business":"Intéressé à acheter la version Pro pour votre entreprise ou votre école ?","business_contact":"Contactez nous","themes":"Thèmes","themes_desc":"Voir plus de fonds avec des thèmes foncés et transparents","bgs":"Arrière-plans intéractifs","bgs_desc":"Donner vie à votre page avec 20 fonds haute-définition en direct","widgets":"Agrandir les Widgets","widgets_desc":"Rendez ProductivityTab plus confortable avec les widgets agrandis","more_header":"Et plus encore","stocks":"Bourse en direct avec historique des cours et informations complètes","rss":"Prise en charge de plusieurs flux RSS par widget","sports":"News sportives générales ou locales","tabbed_widgets":"Nouvelles en onglets et widgets RSS","bg_downloads":"Fonds d'écran téléchargeables","weather":"Prévisions météo heure par heure jusqu'à 10 jours","toolbar":"Autres liens de la barre d'outils","ads":"Une expérience complètement sans publicité","support":"Suggestions et support prioritaire","buy_pro":"Acheter la version pro"},"checkout":{"title":"Sortie","updating_title":"Plan de mise à jour","payment_options":"Payer","pay_monthly":"Mensuel (4.99$)","pay_yearly":"Annuel (29.99$)","cancel":"Annuler","update":"Actualiser","subscribe":"S'abonner","braintree_notice":"Paiements traités en toute sécurité par Braintree.","monthly_notice":"En vous inscrivant, vous autorisez ProductivityTab à vous facturer 4.99 $ chaque mois jusqu'à ce que vous annuliez votre abonnement.","yearly_notice":"En vous inscrivant, vous autorisez ProductivityTab à vous payer 29.99 $ chaque année jusqu'à ce que vous annuliez votre abonnement.","update_notice":"Bien que le cycle de facturation prenne effet immédiatement, vous ne serez pas débité d'ici la fin de votre cycle actuel.","thank_you":"Merci d'avoir acheté ProductivityTab Pro !","thank_you2":"ProductivityTab va se recharger dans quelques secondes et vos réglages seront pris en compte !","error":"Une erreur s'est produite pendant le traitement de votre paiement.","error2":"Veuillez réessayer ultérieurement ou nous écrire à support@ichro.me","signin":"Se connecter","signin_desc":"Vous devez vous authentifier avant d'acheter Pro afin de nous assurer de votre identité","signin_btn":"Se connecter"},"plan":{"title":"Plan","desc":"Vous êtes actuellement abonnés à ProductivityTab Pro (%s)","types":{"monthly":"Mensuel","yearly":"Annuellement","business":"Économie","education":"Éducation","custom":"Personalisé"},"uneditable_desc":"Les plans d'affaires, d'éducation et personnalisés ne peuvent être mis à jours depuis ProductivityTab. Veuillez <a href=\"mailto:support@ichro.me\">nous contacter</a> pour mettre à jour ou annuler votre abonnement.","status":"État","status_active":"Actif","status_trial":"Démo","status_pastdue":"En souffrance","subscription_date":"Date de souscription","paid_through":"Payé par","next_bill":"Prochaine facture","next_bill_value":"$%s sur %s","update_plan":"Plan de mise à jour","update_billing":"Mise à jour de la facturation","cancel":"Annuler l'abonnement","cancel_notice":"Votre abonnement sera immédiatement annulée","cancel_notice2":"Si vous souhaitez un remboursement, veuillez nous contacter à support@ichro.me"}},"ads":{"text1":"ProductivityTab affiche quelques petites annonces pour payer les frais de développement, de serveur et de soutien. Avec ces annonces, nous pouvons nous permettre d’offrir ProductivityTab gratuit pour tout le monde.","text2":"Ici, vous pouvez choisir où ces annonces sont affichées, ou acheter sans publicité pour les supprimer définitivement.","text3":"Sans publicité, est un achat ponctuel qui supprime définitivement les annonces d’ProductivityTab partout où vous êtes connecté. Vous pouvez également mettre à niveau vers Pro pour des fonctionnalités supplémentaires en plus une expérience sans publicité.","upgrade_btn":"Mise à niveau pour enlever les publicité","already_upgraded":"On dirait que vous avez déjà mis à niveau vers sans publicité","signin":"Se connecter","signin_desc":"Connectez-vous avant la mise à niveau de sorte que nous pouvons relier votre achat sur votre compte","signin_btn":"Se connecter","thank_you":"Je vous remercie pour la mise à niveau vers sans publicité !","placement":{"title":"Placement d’annonces","left":"Dans la colonne de gauche","right":"Dans la colonne de droite","top":"Au-dessus de l’onglet","bottom":"Flottant au bas"}}},"store":{"installation":"Installation","description":"Description ","preview":"Aperçu ","instructions":"Cliquer et déplacer toute les tailles sur votre page d'accueil"},"widgets":{"sizes":{"tiny":"Très petit","small":"Petit","medium":"Moyen","large":"Grand","variable":"Variable"},"settings":{"title":"Paramètres du widget","save":"Enregistrer","size":"Taille du Widget"},"minimize":"Minimiser","maximize":"Agrandir","delete_confirm":"Etes vous vraiment sur de supprimer ce widget?\nCet action est irréversible; toutes les données de ce widget seront effacés de façon permanentes.","permissions_request":{"title":"Accès requis","button":"Autoriser l'accès","desc":"Ce widget nécessite des autorisations supplémentaires pour fonctionner. Accordez-les en utilisant le bouton ci-dessous."},"error":{"explanation":"Une erreur s'est produite lors de l'affichage de ce widget.","advice":"Essayez de réinstaller le widget ou rechargez la page. Contactez-nous si ce message s'affiche souvent.","support":"Support","refresh":"Rafraichir"},"auth":{"message":"Vous devrez donner à ce widget l'accès à votre compte avant utilisation.","button":"Autoriser l'accès"},"shared":{"settings":{"title":"Nom du widget","title_placeholder":"Entrer un nom au widget ou le laisser blanc pour le cacher","height":"Hauteur du widget","open_options":{"current":"L'onglet actuel","blank":"Nouvel onglet"},"footer_link":"Lien en pied de page","footer_link_options":{"show":"Montrer","hide":"Cacher"},"account":"ID du compte","account_help":"","account_placeholder":"Vous \"authuser=\" value","on":"On","off":"Off"}},"apps":{"name":"Applications","desc":"Affiche les applications Chrome actuellement installées.","settings":{"format":"Format du widget","format_options":{"tiles":"Mosaîques","list":"Listes"},"display":"Afficher","display_options":{"all":"Toutes les applications","enabled":"Applications activées seulement"},"sort":"Trier","sort_options":{"id":"ID","alphabetically":"Par ordre alphabétique","offline":"Hors-Ligne Activé","available":"Disponibilité"},"open":"Ouvrir les applications avec"},"store_app":"Magasin"},"bookmarks":{"name":"Marque-pages","desc":"Affiche les marque-pages sélectionnés et personnalisés ainsi que d'autres liens.","settings":{"title_placeholder":"Entrez le titre du widget","layout":"Mode d'affichage","layout_options":{"single":"Une colonne","double":"Deux colonnes"},"open":"Ouvrir marque-pages avec"},"edit":{"dialog_title":"Modifier le marque-page","title":"Titre du marque-page","title_placeholder":"Google","url":"URL du marque-page","url_placeholder":"https://www.google.com/","save":"Enregistrer"},"new_caption":"Nouveau","new_bookmark":"Marque-page","new_folder":"Dossier","drop_link":"Déposer le lien ici"},"chrome_bookmarks":{"name":"Marque-pages","desc":"Affiche vos signets Chrome, éventuellement à partir d'un dossier spécifique.","settings":{"title_placeholder":"Entrez le titre du widget","from":"Afficher les signets de","open":"Ouvrir favori dans"}},"calc":{"name":"Calculatrice","desc":"Affiche une calculatrice pouvant effectuer des opérations simples.","error":"Erreur!","infinity":"Infini","mismatch":"Parenthèses non appariées"},"calendar":{"name":"Calendrier","desc":"Affiche les événements à venir d'un ou plusieurs de vos calendriers Google.","settings":{"calendar":"Calendrier","show":"Montrer les événements de","show_options":{"all":"tous les temps","today":"aujourd'hui seulement"}},"title":"Agenda","calendar":"Calendrier","noevents":"Aucun événement n'a été trouvé dans un futur proche."},"clock":{"name":"Horloge","desc":"Offre les fonctionnalités alarme, heure, minuteur et chronomètre.","settings":{"timezone":"Fuseau horaire","timezone_local":"Mon appareil","format":"Format de l'heure ","format_options":{"ampm":"AM/PM - Digitale","24hour":"24 Heures - Digitale","analog":"12 Heures - Analogique","ampmseconds":"AM/PM - Digitale, Sans Secondes","24hourseconds":"24 Heures - Digitale, Sans Secondes"},"sound":"Alerte sonore"},"title":"Horloge","alarm":"Alarmes","clock":"Horloge","timer":"Minuteur","stopwatch":"Chronomètre","set":"Appliquer","unset":"Annuler","dismiss":"Abandonner","enable_audio":"Activer le son"},"facebook":{"name":"Facebook","desc":"Intègre Facebook dans un widget"},"feedly":{"name":"Feedly","desc":"Afficher un article depuis un compte Feedly dans un format configurable.","settings":{"source":"Montrer les articles","source_feeds":"Flux","show":"Voir","show_options":{"all":"Tous les articles","unread":"Seulement les articles non-lus"},"layout":"Mode d'affichage","layout_options":{"titles":"Titres seulement","magazine":"Magazine","cards":"Cartes","cards_columns":"Cartes (deux colonnes)"},"mark":"Marquer un article comme lus quand je","mark_options":{"scroll":"Faites défiler au-delà de ça ou cliquez ça","click":"Il suffit de cliquer dessus"},"sort":"Le classement","sort_options":{"newest":"Plus récent en premier","oldest":"Plus ancien en premier"}},"all":"Tous","saved":"Sauvegardé pour plus tard","uncategorized":"Sans catégorie","author":"par","go_to_feedly":"Aller à Feedly"},"notes":{"name":"Notes","desc":"Insérez une note simple et modifiable.","settings":{"color":"Couleur de la note","color_options":{"yellow":"Jaune","orange":"Orange","red":"Rouge","blue":"Blue","green":"Vert","white":"Blanc"},"font":"Polices de caractères","fontsize":"Taille de la Police"}},"now":{"name":"Google Now","desc":"Affiche les cartes depuis Google Now, ceci inclus le statut de votre vol ou de vos colis.","authorize":"Vous devez autoriser ProductivityTab à accéder à vos cartes Google Now avant que quoi que ce soit soit affiché ici.","authorize_btn":"Autoriser","caught_up":"Tout a été récupéré, il n'y a plus rien ici.","no_title":"Pas de titre"},"plus":{"name":"Google+","desc":"Intègre Google Plus dans un widget"},"notifications":{"name":"Notifications Google","desc":"Affiche vos notifications Google à partir de services tel que Google+"},"reddit":{"name":"Reddit","desc":"Affiche les liens populaires de Reddit pour tout subreddit donné.","settings":{"subreddit":"Subreddit","subreddit_help":"Entrez le nom de n'importe que subreddit après le <b>/r/</b>\n<br /><br />\nExemple : Pour le subreddit technologie est à : <a href=\"https://www.reddit.com/r/technology\">https://www.reddit.com/r/technology</a>, donc vous devez entrer <b>technology</b>","subreddit_placeholder":"Entrez un subreddit ici pour afficher les liens de celui-ci (Exemple : technology)","sort":"Le classement","sort_options":{"hot":"Populaire","top":"Populaire","new":"Nouveau","gilded":"Doré","rising":"croissant","controversial":"Controversé"},"links":"Nombre de liens","click":"Quand je cliques sur un lien montrez moi","click_options":{"link":"Le lien","comments":"Commentaires"}},"more":"Plus"},"tasks":{"name":"tâches","desc":"Affiche une liste modifiable de tâches à partir d'un de vos listes de Google Tasks.","title":"Tâches","settings":{"list":"Liste"},"task_title":"Titre","due_date":"date d'échéance","notes":"Notes","add":"Ajouter un élément","delete_task":"effacez la tâche","move_up":"déplacer vers le haut","move_down":"descendre","done":"fini","due_today":"en raison aujourd'hui","overdue":"en retard","authorize":"Vous aurez besoin de sélectionner une liste de votre Google Tasks via les paramètres avant tout peut être affiché ici."},"twitter":{"name":"Twitter","desc":"Affiche les tweets comme affiché sur votre accueil Twitter ou depuis une liste spécifiée.","settings":{"source":"Afficher les Tweets de","show":"Tweets montrés"},"authorize":"Vous aurez tout d'abord besoin d'autoriser ProductivityTab","authorize_msg":"Vous devez donner ProductivityTab la permission d'accéder à votre compte Twitter avant que ce ne soit affiché ici.","authorize_btn":"Autoriser","no_tweets":"Il ne semble pas y avoir de tweets ici...","home":"Accueil","mentions":"Mentions","retweets":"Mes Retweets","lists":"Listes","more":"Plus","reply":"Répondre","retweet":"Retweet","favorite":"Favoris"},"wolfram":{"name":"Wolfram Alpha","desc":"Insère une zone de recherche Wolfram|Alpha."},"youtube":{"name":"YouTube","desc":"Affiche soit les vidéos populaires soit les vidéos d'un utilisateur spécifié.","settings":{"format":"Format","format_options":{"large":"Une grande","large_2":"Une grande, deux petites","large_4":"Une grande, quatre petites","four":"Quatre petites","six":"Six petites"},"from":"Afficher videos depuis","from_help":"Ce doit être le nom d'utilisateur <b>exactement</b> comme indiqué dans l'URL de la page lorsque vous consultez leur profil. <br /> <br /> Cette valeur n'inclut jamais d'espaces.","from_placeholder":"Laissez vide pour montrer les vidéos populaires","open":"Ouvrir les résultats de la recherche dans "},"search":"Recherche YouTube","num_views":"vues"},"quotes":{"name":"citations","desc":"Affiche une citation cueillis soit à chaque fois que vous chargez la page ou une fois par jour.","settings":{"source":"Source","method":"Charger les nouvelles citations","method_options":{"daily":"Une fois par jour","random":"Chaque fois que je charge la page"}},"unknown_author":"Inconnu"},"html":{"name":"HTML","desc":"HTML personnalisée s'affiche dans un iframe.","settings":{"html":"HTML","js":"JavaScript","height":"Hauteur du Widget"}},"sitelink":{"name":"Lien du site","desc":"Affiche un lien, éventuellement avec un titre et une vignette","settings":{"link":"Lien URL","link_placeholder":"https://www.google.com/","image":"URL de l'image","image_placeholder":"http://www.exemple.fr/image.png","color":"Couleur d'arrière-plan de la page","style":"Style d'images","style_fill":"Remplir","style_center":"Centre"}},"stats":{"name":"Statistiques du système ","desc":"Gardez un œil sur votre système avec des statistiques en temps réel","memory":"RAM","battery":"Batterie","usage":"Utilité","in_use":"en cours d'utilisation","remaining":"restant","charged":"Charge complète","idle":"Inactif","charging":"Chargement en cours","discharging":"Déchargement"},"search":{"name":"Rechercher","desc":"Incorporer une boîte de recherche dans votre page pour un accès facile","settings":{"placeholder":"Texte par défaut du champ de recherche","search_url":"URL de recherche","param":"Paramètre de requête","param_placeholder":"Le paramètre où la requête va, par exemple « q »"},"default_placeholder":"Recherche Google"},"pushbullet":{"name":"Pushbullet","desc":"Assurer le suivi des notifications à partir de votre téléphone et autres appareils","no_pushes":"Aucune notification Pushbulette trouvée","sign_in":"Se connecter","no_key":"Il ne ressemble pas vous êtes connecté à Pushbullet.  Connectez-vous maintenant pour connecter ce widget."},"linkedin":{"name":"LinkedIn","desc":"Affiche votre flux LinkedIn"},"directions":{"name":"Itinéraires","desc":"Obtenez des itinéraires vers et depuis n'importe quelle destination depuis votre page d'accueil","driving":"En voiture","transit":"Transports en commun","walking":"À pied","cycling":"A vélo","from":"Insérez un point de départ","to":"Entrez une destination","loading":"Calcul d'itinéraire en cours, veuillez patienter...","error":"Quelque chose n'as pas marché lors du chargement des indications que vous avez demandé.","error2":"Veuillez vérifier les adresses de départ et de destination que vous avez entré.","open_in_maps":"Ouvrir dans Google Maps","via":"via"},"pocket":{"name":"Pocket","desc":"Affiche une liste de vos articles, vidéos et pages web enregistré depuis Pocket","settings":{"links_shown":"Nombre de liens affichés","open":"Ouvrir les liens","open_pocket":"Dans la poche","open_original":"À leur URL d'origine"},"by":"par","no_links":"Aucun lien trouvé","grant_access":"Accorder l'accès","no_key":"Vous devrez donner à ProductivityTab un accès à votre compte Pocket avant de charger vos liens."}},"themes":{"title":"Thèmes","all":"Tous","custom":"Personalisé","create":"Créer un thème","url_or_upload":"ou","upload_image":"Ajouter une image","edit_btn":"Modifier","delete":"Supprimer","use":"Utiliser","preview":"Aperçu ","author":"par","images":"%s images","resolution":"Résolution","categories":"Catégories","cached":"Ce thème à été mis en cache et est disponible en ligne","random":"Ce thème affiche une image aléatoire à chaque fois que vous chargez la page","random_daily":"Ce thème affiche une image aléatoire chaque jour","sunrise_sunset":"Ce thème affiche une image en fonction de l'heure","feed":"Ce thème affiche une image sélectionner chaque jour depuis une source externe","video":"Ce thème affiche une vidéo en direct","pro_only":"Ce thème n'est accessible qu'aux utilisateurs de la version Pro. Pour l'acheter, consultez les paramètres.","delete_confirm":"Etes vous vraiment sur de vouloir supprimer ce thème?\nCet action est irréversible; le thème sera perdu pour toujours.","delete_error":"Une erreur est survenue lors de la suppression du thème, veuillez réessayer dans quelques minutes.","feed_fetching":"Attendez s'il vous plait, la source est en cours d'acheminement","feed_error":"Une erreur est survenue lors de l'acheminement, veuillez réessayer dans quelques minutes.","caching":"Patientez s'il vous plait, le thème est en cours de sauvegarde...","cache_status":"%s de %s images mises en cache","cache_error":"Une erreur est survenue lors de la sauvegarde du thème, veuillez réessayer dans quelques minutes","bginfo":{"view":"Vue","source":"Source","unknown":"Inconnu","download":"Télécharger","pro_only":"Seuls les utilisateurs de la version Pro peuvent télécharger des fonds d'écran et des vidéos"},"edit":{"title":"Editer un thème","create_title":"Créer un thème","name":"Nom du Thème","default_name":"Nouveau Theme","name_placeholder":"Entrer le nom du thème","image":"URL de l'image","image_placeholder":"Entrer l'URL d'une image qui sera utilisé comme fond d'écran","image_help":"Votre image n'a pas pu êtres envoyée de votre ordinateur.\n<br /><br />\nSi vous tenez à avoir cette image, vous pouvez l'envoyé depuis le site <a href=\"https://imgur.com/\" target=\"_blank\">imgur</a>.\nPuis copiez l'url que ce site vous fournira, mais faite attention que l'url ce finisse par une extension d'image de type (i.e. .jpg), puis collez la dans le champ de gauche.","color":"Couleur d'arrière-plan","color_placeholder":"Entrez une couleur","position":"Position","position_options":{"center":"Centre","top_left":"En haut à gauche","top_center":"Centrer en Haut","top_right":"En haut à droite","bottom_left":"En bas à gauche","bottom_center":"Centrer en Bas","bottom_right":"En bas à droite"},"scaling":"Mise à l'échelle","scaling_options":{"auto":"Auto","width":"Pleine largeur","height":"Pleine hauteur","none":"Pas de mise à l'échelle (L'aperçu peut être inexact)"},"repeat":"Mosaïque ","repeat_options":{"none":"Pas de répétition","horizontal":"Répéter horizontalement","vertical":"Répéter verticalement","both":"Répéter des deux façons"},"attach":"Joindre l'image à","attach_tab":"L'onglet","attach_window":"La fênetre","preview":"Aperçu ","save":"Enregistrer & Fermer","cache_error":"Une erreur est survenue lors de la mise en cache de l'image, s'il vous plait vérifiez l'URL de votre image.","upload_error":"Une erreur est survenue lors de l'envoi de votre image, veuillez vérifier que votre fichier est bien une image et a une taille raisonnable."}}},"he":{"lang_code":"he","language":"עִבְרִית","extName":"ProductivityTab — Custom Homepage Dashboard","newtabName":"ProductivityTab — Custom New Tab Dashboard","extDescription":"A remarkably customizable personal homepage featuring 50+ widgets, breathtaking backgrounds and much more.","newtabDescription":"A customizable personal dashboard on your new tab page featuring 50+ widgets, breathtaking backgrounds and much more.","defaults":{"tab":"Home","me":"Me"},"remove_widget":"Remove","hide_banner":"Hide this banner","hide_ad":{"content":"Hey! We're not crazy about ads either, but we're only able to make ProductivityTab available and continue developing features for our free users (that's you!) by showing ads. If you'd like to support ProductivityTab directly and get rid of ads for free, we would really appreciate if you upgraded to our pro version","upgrade":"Upgrade","hide":"Hide ads"},"alert":{"default_button":"Dismiss","confirm_title":"Are you sure you want to do this?","confirm_continue":"Continue","confirm_cancel":"Cancel"},"onboarding":{"modal":{"tagline":"All the sites and apps you use, in one place","wrong_extension":"Want ProductivityTab on your new tab page instead?","wrong_extension_newtab":"Want ProductivityTab on your home page instead?","wrong_extension_action":"Click here","about":"ProductivityTab's all about tabs and widgets","about_desc":"Tabs are pages filled with widgets - blocks that show things like the weather, news, and your email. You can customize most widgets and add as many as you want.","terms":"By checking, you agree to ProductivityTab's <a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\">Terms</a> and <a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\">Privacy Policy</a>","sign_in":"Sign in with your Google account","sign_in_desc":"Sign in with your Google account before getting started to securely save your changes online.","sign_in_desc2":"You can stay signed out if you want, but your page won't be saved online and you won't be able to access it from other computers.","sign_in_button":"Sign in with Google","have_account":"It looks like you already have an account!","have_account_desc":"All your tabs and widgets are ready to use!","get_started":"Let's get started!","get_started_desc":"You're good to go! Let's get your page set up."},"widgets":{"configure":"Let's configure a widget.","configure_desc":"Click the wrench to open a widget's <b>settings</b>.","configure_skip":"Skip Tutorial","settings":"Replace <b>Link URL</b> with your favorite site, then press <b>Save</b>.","move":"You can <b>reposition</b> widgets by clicking and dragging the three dots highlighted here.","remove":"To <b>delete</b>, simply click the red trash bin icon.","done":"Got it"},"settings":{"intro":"Now let’s add a new widget. This highlighted button is where you can access the Widget Menu.","instructions":"Click the new widget button on to open the widget menu!","skip":"Skip","tooltips":{"settings":"Change the way ProductivityTab looks and works","widgets":"Add new widgets - you can have as many as you want","editing":"Show or hide the editing buttons on widgets","links":"This is a list of links, add sites you use often in the settings","tabs":"These are your tabs. You can add more in the settings","support":"Send us a message or leave a review here"},"finished":"That's it!","finished_next":"Choose an option from the menu (try starting with <b>Widgets</b>) and set your page up!","finished_contact":"Use the support link if you need any help and we'll get back to you ASAP."}},"storage":{"signin":"Sign in with Google now to securely save and sync your configuration","signin_btn":"Sign in","signin_dismiss":"Dismiss","signin_confirm":{"title":"Keep local data?","desc":"Would you like to keep your local data, and replace the configuration in your account with it, or replace this computer's configuration with the one already in your account?","keep_account":"Use account","keep_local":"Keep local"},"signout_confirm":"Signing out will erase your local backups","pastdue":"Your subscription is past due","pastdue_desc":"Please update your billing information in the settings"},"toolbar":{"placeholder":"Search the web","placeholder_ok":"Enter your terms or say \"OK, Google\"","suggestions":{"url_subtext":"Visit URL","capture_notice":"ProductivityTab handles searches you normally make from the Omnibox. You can disable this at any time from the settings"},"apps":{"search":"Search","youtube":"YouTube","maps":"Maps","play":"Play","news":"News","gmail":"Gmail","drive":"Drive","calendar":"Calendar","more":"More"}},"menu":{"settings":"Settings","widgets":"Widgets","editing":"Editing","editing_enabled":"Enabled","editing_disabled":"Disabled","plus":"Google Plus","tabs":"Tabs","footer":{"support":"Support","feedback":"Feedback","review":"Review","terms":"Terms","privacy":"Privacy","by":"By Avi Kohn"}},"voice":{"listening":"Listening...","searching":"Searching for: %s","missed":"Didn't get that. <a>Try Again</a>"},"settings":{"title":"Settings","exit":"Exit settings","saved":"Settings saved","nav":{"visual":"Visual","visual_sections":{"background":"Background","layout":"Layout","theme":"App theme","ad_placement":"Ad placement"},"toolbar":"Toolbar","toolbar_sections":{"style":"Style","search":"Search","links":"Links"},"tabs":"Tabs","widgets":"Widgets","ads":"Ads","pro":"Pro","accounts":"Account","misc":"Miscellaneous","advanced":"Advanced","advanced_sections":{"backups":"Backup and restore","css":"Custom CSS","debug_tools":"Debug tools"},"support":"Help and support","suggest":"Suggest a feature"},"visual":{"background":{"title":"Background","desc":"This is the image or set of images shown as a background to your tabs","current":"Current background","custom":"Custom","unnamed":"Theme %s","select":"Select a theme","or":"or","url_placeholder":"Enter an image URL"},"layout":{"title":"Layout","desc":"Here you can adjust the type and number of columns in each tab","columns":"Columns","grid":"Grid","columns_number":"Number of columns","column_width":"Column width","column_width_fixed":"Fixed","column_width_fluid":"Fluid","column_warning":{"column_to_grid":"Changing to a grid-based layout will move all of your widgets to the top left corner.","grid_to_column":"Changing to a column-based layout will move all of your widgets to the first column."}},"theme":{"title":"App theme","desc":"The app theme controls the style of ProductivityTab itself and all widgets","preview":"Preview","light":"Light (default)","dark":"Dark","transparent":"Transparent","transparent_darker":"Transparent (darker)"}},"toolbar":{"style":{"title":"Style","desc":"This controls the style of the toolbar.  It can either appear normally or as an out of the way button","normal":"Normal","button":"Button"},"search":{"title":"Search","desc":"These settings control how the search box and voice search function","engine":"Search engine","engines_default":"Default","engines_custom":"Custom","engines_custom_desc":"Enter a URL that queries should be sent to, with <b>%s</b> where the query should go.","omnibox_capture":"Handle searches normally made in the Omnibox","voice":"Enable voice search","ok_google":"Enable \"OK Google\" hotword detection","search_tab":"Open search results in a new tab"},"links":{"title":"Links","desc":"These are the items shown at the right of the toolbar","apps":"Apps menu","custom":"Custom links","custom_note1":"Maximum of 3 allowed","custom_note2":"users get 8","custom_name_placeholder":"Link text","custom_url_placeholder":"Link URL, i.e. https://www.google.com/"}},"misc":{"link_tab":"Open links in a new tab by default"},"tabs":{"create_new":"Create new","make_default":"Make default","desc1":"Tabs are pages inside ProductivityTab. Each tab has its own set of widgets that is completely separate from every other tab.","desc2":"You can switch between tabs by clicking the buttons that appear at the left and right of the screen when you move your mouse over a tab or by using the arrow keys on your keyboard.","name_placeholder":"Enter a tab name","delete_confirm":"This action is irreversible. All data from all widgets in the tab will be permanently lost."},"accounts":{"status":{"title":"Status","signed_in":"You are currently <b>signed in</b> as %s (%s).","reset_account":"Reset account","sign_out":"Sign out","signed_out":"You are <b>not currently signed in</b>. Sign in with your Google account now to securely store and sync your configuration.","sign_in":"Sign in with Google"},"reset_confirm_desc":"This will erase all local and synced data, there is no backup and no way to undo this.","reset_confirm_desc2":"You will lose your entire current configuration on all computers connected to this account."},"advanced":{"backups":{"title":"Backup and restore","desc":"Backups are complete copies of all your tabs, settings, and widgets. They're automatically created when you first open ProductivityTab each day.","desc2":"Use the buttons below to roll ProductivityTab back to a particular date or download one of your backups.","backup":"Backup now","upload":"Restore from file","download":"Download","restore":"Restore","download_name":"ProductivityTab Backup","restore_confirm":"This will overwrite all local and synced data. You will lose your entire current configuration on all computers under this account.","restore_error":"An error occurred while trying to parse the provided data, please try again later."},"css":{"title":"Custom CSS","desc":"You can use CSS (<a href=\"https://developer.mozilla.org/en-US/docs/Web/CSS\" target=\"blank\">definition</a>) to customize almost any part of ProductivityTab.","placeholder":"Enter up to 1000 characters of CSS here"},"debug_tools":{"title":"Debug tools","desc":"<b>WARNING:</b> These tools can erase your entire configuration in a single click. Only use them if your developer instructs you to.","open":"Open tools"}},"widgets":{"desc1":"Widgets have their own settings and can't be customized here.","desc2":"To edit a widget's settings, follow these steps:","steps1":"Move your mouse over any widget","steps2":"Click the wrench icon that appears at the top right of the widget. If none appears then the widget doesn't have any settings that can be customized.","steps3":"Edit any of the settings shown in the dialog that's displayed","steps4":"Click Save to save your changes, or any part of the background to discard of them"},"pro":{"promo":{"monthly_price":"$4.99 per month","yearly_price":"or $29.99 per year","upgrade_btn":"Upgrade Now","business":"Interested in buying Pro for your business or school?","business_contact":"Contact us","themes":"Themes","themes_desc":"See more of your backgrounds with dark and transparent themes","bgs":"Live backgrounds","bgs_desc":"Bring your page to life with 20 live high-definition backgrounds","widgets":"Maximizable widgets","widgets_desc":"Take ProductivityTab to another level with maximizable widgets","more_header":"And more","stocks":"Realtime stocks with extended and historical information","rss":"Support for multiple RSS feeds per widget","sports":"General and league-specific sports news","tabbed_widgets":"Tabbed news and RSS widgets","bg_downloads":"Downloadable backgrounds","weather":"Hourly weather forecasts up to 10 days out","toolbar":"More toolbar links","ads":"A completely ad-free experience","support":"Prioritized support and suggestions","buy_pro":"Buy Pro"},"checkout":{"title":"Checkout","updating_title":"Update plan","payment_options":"Pay","pay_monthly":"Monthly ($4.99)","pay_yearly":"Yearly ($29.99)","cancel":"Cancel","update":"Update","subscribe":"Subscribe","braintree_notice":"Payments securely processed by Braintree.","monthly_notice":"By subscribing, you authorize ProductivityTab to charge you $4.99 every month until you cancel your subscription.","yearly_notice":"By subscribing, you authorize ProductivityTab to charge you $29.99 every year until you cancel your subscription.","update_notice":"Although billing cycle changes take effect immediately, you won't be charged until your current cycle ends.","thank_you":"Thank you for buying ProductivityTab Pro!","thank_you2":"ProductivityTab will reload in a few seconds and you'll be all set!","error":"Something went wrong while trying to process your payment.","error2":"Please try again later or email us at support@ichro.me","signin":"Sign in","signin_desc":"You need to sign in before buying Pro so we can make sure it's you","signin_btn":"Sign in"},"plan":{"title":"Plan","desc":"You are currently subscribed to ProductivityTab Pro (%s)","types":{"monthly":"Monthly","yearly":"Yearly","business":"Business","education":"Education","custom":"Custom"},"uneditable_desc":"Business, education, and custom plans cannot be updated from within ProductivityTab. Please <a href=\"mailto:support@ichro.me\">contact us</a> to update or cancel your subscription.","status":"Status","status_active":"Active","status_trial":"Trial","status_pastdue":"Past due","subscription_date":"Subscription date","paid_through":"Paid through","next_bill":"Next bill","next_bill_value":"$%s on %s","update_plan":"Update plan","update_billing":"Update billing","cancel":"Cancel subscription","cancel_notice":"Your subscription will be canceled immediately","cancel_notice2":"If you would like a refund, please contact us at support@ichro.me"}},"ads":{"text1":"ProductivityTab displays a few small ads to pay for server, support and development costs. With these ads, we can afford to offer ProductivityTab free to everyone.","text2":"Here you can choose where those ads are shown, or buy ad-free to permanently remove them.","text3":"Ad-free is a one-time purchase that permanently removes ads from ProductivityTab wherever you're signed in. You can also upgrade to Pro for extra features in addition to an ad-free experience.","upgrade_btn":"Upgrade to ad-free","already_upgraded":"It looks like you've already upgraded to ad-free","signin":"Sign in","signin_desc":"Sign in before upgrading so we can link your purchase to your account","signin_btn":"Sign in","thank_you":"Thank you for upgrading to ad-free!","placement":{"title":"Ad placement","left":"In the leftmost column","right":"In the rightmost column","top":"Above the tab","bottom":"Floating at the bottom"}}},"store":{"installation":"Installation","description":"Description","preview":"Preview","instructions":"Drag and drop any size onto your homepage"},"widgets":{"sizes":{"tiny":"Tiny","small":"Small","medium":"Medium","large":"Large","variable":"Variable"},"settings":{"title":"Widget Settings","save":"Save","size":"Widget Size"},"minimize":"Minimize","maximize":"Maximize","delete_confirm":"Are you really sure you want to delete this widget?\r\nThis action is irreversible; all data from this widget will be permanently lost.","permissions_request":{"title":"Access required","button":"Grant Access","desc":"This widget needs extra permissions before it can be used. Grant them using the button below."},"error":{"explanation":"Something went wrong while we were trying to display this widget.","advice":"Try reinstalling the widget or reloading the page. Contact us if you see this message often.","support":"Support","refresh":"Refresh"},"auth":{"message":"You'll need to give this widget access to your account before you can use it.","button":"Grant Access"},"shared":{"settings":{"title":"Widget Title","title_placeholder":"Enter a widget title or leave blank to hide","height":"Widget Height","open_options":{"current":"The current tab","blank":"A new tab"},"footer_link":"Footer Link","footer_link_options":{"show":"Show","hide":"Hide"},"account":"Account ID","account_help":"If you're signed into multiple accounts, this is the \"authuser=\" value.\n<br /><br />\nFor example, if you're signed into two accounts, jsmith1@gmail.com and jsmith2@gmail.com, the \"authuser\" value for jsmith2@gmail.com would be 1 since it's the second account (counting from zero) that you're signed into.","account_placeholder":"Your \"authuser=\" value","on":"On","off":"Off"}},"apps":{"name":"Apps","desc":"Displays your currently installed Google Chrome applications.","settings":{"format":"Widget Format","format_options":{"tiles":"Tiles","list":"List"},"display":"Show","display_options":{"all":"All apps","enabled":"Only enabled apps"},"sort":"Sort","sort_options":{"id":"ID","alphabetically":"Alphabetically","offline":"Offline Enabled","available":"Availability"},"open":"Open apps in"},"store_app":"Store"},"bookmarks":{"name":"Bookmarks","desc":"Displays selected and customized bookmarks, and other links.","settings":{"title_placeholder":"Enter a widget title","layout":"Layout","layout_options":{"single":"Single column","double":"Double column"},"open":"Open bookmarks in"},"edit":{"dialog_title":"Edit Bookmark","title":"Bookmark Title","title_placeholder":"Google","url":"Bookmark URL","url_placeholder":"https://www.google.com/","save":"Save"},"new_caption":"New","new_bookmark":"Bookmark","new_folder":"Folder","drop_link":"Drop link here"},"chrome_bookmarks":{"name":"Bookmarks","desc":"Displays your Chrome bookmarks, optionally from a specific folder.","settings":{"title_placeholder":"Enter a widget title","from":"Show bookmarks from","open":"Open bookmarks in"}},"calc":{"name":"Calculator","desc":"Displays a calculator with support for basic operators.","error":"Error!","infinity":"Infinity","mismatch":"Mismatched parentheses"},"calendar":{"name":"Calendar","desc":"Displays upcoming events from one or more of your Google calendars.","settings":{"calendar":"Calendar","show":"Show events from","show_options":{"all":"All time (up to 40 events)","today":"Today only"}},"title":"Agenda","calendar":"Calendar","noevents":"No events found in the near future, it looks like your schedule's clear!"},"clock":{"name":"Clock","desc":"Offers alarm, time, timer, and stopwatch functionality.","settings":{"timezone":"Time Zone","timezone_local":"Local","format":"Clock Format","format_options":{"ampm":"AM/PM - Digital","24hour":"24 Hour - Digital","analog":"12 Hour - Analog","ampmseconds":"AM/PM - Digital, No Seconds","24hourseconds":"24 Hour - Digital, No Seconds"},"sound":"Alert Sound"},"title":"Clock","alarm":"Alarm","clock":"Clock","timer":"Timer","stopwatch":"Stopwatch","set":"Set","unset":"Unset","dismiss":"Dismiss","enable_audio":"Enable audio"},"facebook":{"name":"Facebook","desc":"Embeds Facebook in a widget"},"feedly":{"name":"Feedly","desc":"Displays articles from your Feedly account in a configurable format.","settings":{"source":"Show articles from","source_feeds":"Feeds","show":"Show","show_options":{"all":"All articles","unread":"Only unread articles"},"layout":"Layout","layout_options":{"titles":"Titles only","magazine":"Magazine","cards":"Cards","cards_columns":"Cards (two columns)"},"mark":"Mark an article as read when I","mark_options":{"scroll":"Scroll past it or click it","click":"Just click it"},"sort":"Sort Order","sort_options":{"newest":"Newest first","oldest":"Oldest first"}},"all":"All","saved":"Saved for later","uncategorized":"Uncategorized","author":"by","go_to_feedly":"Go To Feedly"},"notes":{"name":"Notes","desc":"Inserts a simple, editable, note.","settings":{"color":"Note Color","color_options":{"yellow":"Yellow","orange":"Orange","red":"Red","blue":"Blue","green":"Green","white":"White"},"font":"Font Face","fontsize":"Font Size"}},"now":{"name":"Google Now","desc":"Displays cards from Google Now including flight status and package tracking.","authorize":"You'll need to give ProductivityTab permission to view your Google Now cards before anything will show up here.","authorize_btn":"Authorize","caught_up":"All caught up, nothing here.","no_title":"No Title"},"plus":{"name":"Google+","desc":"Embeds Google Plus in a widget"},"notifications":{"name":"Google Notifications","desc":"Displays your Google Notifications from services such as Google+"},"reddit":{"name":"Reddit","desc":"Displays the top items on Reddit for any given subreddit.","settings":{"subreddit":"Subreddit","subreddit_help":"Enter any subreddit by the part past <b>/r/</b> when on Reddit.\n<br /><br />\nFor example, Technology is at: <a href=\"https://www.reddit.com/r/technology\">https://www.reddit.com/r/technology</a>, therefore you would enter <b>technology</b>","subreddit_placeholder":"Enter a subreddit to show links from. (i.e. technology)","sort":"Sort Order","sort_options":{"hot":"Hot","top":"Top","new":"New","gilded":"Gilded","rising":"Rising","controversial":"Controversial"},"links":"Links Shown","click":"When I click a link show me","click_options":{"link":"The link","comments":"The comments"}},"more":"More"},"tasks":{"name":"Tasks","desc":"Displays an editable list of tasks from one of your Google Tasks lists.","title":"Tasks","settings":{"list":"List"},"task_title":"Title","due_date":"Due date","notes":"Notes","add":"Add Item","delete_task":"Delete Task","move_up":"Move Up","move_down":"Move Down","done":"Done","due_today":"Due today","overdue":"Overdue","authorize":"You'll need to select a list from your Google Tasks via the settings before anything can be displayed here."},"twitter":{"name":"Twitter","desc":"Displays tweets from your home stream or a specified list.","settings":{"source":"Show Tweets from","show":"Tweets Shown"},"authorize":"You'll need to authorize ProductivityTab first","authorize_msg":"You'll need to give ProductivityTab permission to view tweets from your account before anything will show up here.","authorize_btn":"Authorize","no_tweets":"There don't seem to be any tweets here...","home":"Home","mentions":"Mentions","retweets":"Retweets of me","lists":"Lists","more":"More","reply":"Reply","retweet":"Retweet","favorite":"Favorite"},"wolfram":{"name":"Wolfram|Alpha","desc":"Inserts a small Wolfram|Alpha search box."},"youtube":{"name":"YouTube","desc":"Displays either popular videos or videos from a specified user.","settings":{"format":"Format","format_options":{"large":"One large","large_2":"One large, two small","large_4":"One large, four small","four":"Four small","six":"Six small"},"from":"Show Videos From","from_help":"This must be an <b>exact</b> username as shown in the URL of the page when you're viewing their profile.\n<br /><br />\nThis value never includes spaces.","from_placeholder":"Leave blank to show Top Videos","open":"Open search results in"},"search":"Search YouTube","num_views":"views"},"quotes":{"name":"Quotes","desc":"Displays a quote picked either every time you load the page or once daily.","settings":{"source":"Source","method":"Load new quotes","method_options":{"daily":"Once daily","random":"Every time I load the page"}},"unknown_author":"Unknown"},"html":{"name":"HTML","desc":"Displays completely custom HTML in an iframe.","settings":{"html":"HTML","js":"JavaScript","height":"Widget Height"}},"sitelink":{"name":"Site Link","desc":"Displays a link, optionally with a title and thumbnail","settings":{"link":"Link URL","link_placeholder":"https://www.google.com/","image":"Image URL","image_placeholder":"https://www.example.com/image.png","color":"Image Background Color","style":"Image Style","style_fill":"Fill","style_center":"Center"}},"stats":{"name":"System Statistics","desc":"Keep an eye on your system with realtime statistics","memory":"Memory","battery":"Battery","usage":"usage","in_use":"in use","remaining":"remaining","charged":"Fully Charged","idle":"Idle","charging":"Charging","discharging":"Discharging"},"search":{"name":"Search","desc":"Embeds a search box in your page for easy access","settings":{"placeholder":"Search Field Placeholder","search_url":"Search URL","param":"Query Parameter","param_placeholder":"The parameter where the query goes, i.e. \"q\""},"default_placeholder":"Search Google"},"pushbullet":{"name":"Pushbullet","desc":"Keep track of notifications from your phone and other devices","no_pushes":"No pushes found","sign_in":"Sign in","no_key":"It doesn't look like you're signed in to Pushbullet.  Sign in now to connect this widget."},"linkedin":{"name":"LinkedIn","desc":"Displays your LinkedIn home stream"},"directions":{"name":"Directions","desc":"Get directions to and from nearly anywhere right from your homepage","driving":"Driving","transit":"Public Transit","walking":"Walking","cycling":"Cycling","from":"Enter a starting point","to":"Enter a destination","loading":"Loading directions, please wait...","error":"Something went wrong while trying to load the directions you requested.","error2":"Please check the start and destination addresses you entered.","open_in_maps":"Open in Google Maps","via":"via"},"pocket":{"name":"Pocket","desc":"Display a list of your saved articles, videos, and web pages from Pocket","settings":{"links_shown":"Number of links shown","open":"Open links","open_pocket":"In Pocket","open_original":"At their original URL"},"by":"By","no_links":"No links found","grant_access":"Grant access","no_key":"You'll need to give ProductivityTab access to your Pocket account before it can load your links."}},"themes":{"title":"Themes","all":"All","custom":"Custom","create":"Create a theme","url_or_upload":"or","upload_image":"Upload an image","edit_btn":"Edit","delete":"Delete","use":"Use","preview":"Preview","author":"By","images":"%s images","resolution":"Resolution","categories":"Categories","cached":"This theme has been cached and is available offline","random":"This theme displays a random image every time you load the page","random_daily":"This theme displays an image picked randomly every day","sunrise_sunset":"This theme displays an image based on the time of day","feed":"This theme displays an image selected daily from an external feed","video":"This theme displays a live video","pro_only":"This theme is only available to Pro users. Buy Pro in the settings.","delete_confirm":"Are you really sure you would like to delete this theme?\r\nThis action is irreversible; the entire theme will be permanently lost.","delete_error":"An error occurred while trying to delete the theme.  Please try again later.","feed_fetching":"Please wait, fetching feed...","feed_error":"Something went wrong while trying to fetch the feed.  Please try again later.","caching":"Please wait, caching theme...","cache_status":"%s of %s images cached","cache_error":"An error occurred while trying to cache the theme.  Please try again later","bginfo":{"view":"View","source":"Source","unknown":"Unknown","download":"Download","pro_only":"Only Pro users can download background images and videos"},"edit":{"title":"Edit Theme","create_title":"Create Theme","name":"Theme Name","default_name":"New Theme","name_placeholder":"Enter a theme name","image":"Image URL","image_placeholder":"Enter a background image URL","image_help":"Uploaded images <b>cannot be synced</b> between computers.<br /><br />If this is important to you, please upload your image to a service such as <a href=\"https://imgur.com/\" target=\"_blank\">imgur</a>. Then copy the URL ending with an extension (i.e. .jpg) and paste it into the field on the left.","color":"Fallback Color","color_placeholder":"Enter any color name","position":"Position","position_options":{"center":"Center","top_left":"Top Left","top_center":"Top Center","top_right":"Top Right","bottom_left":"Bottom Left","bottom_center":"Bottom Center","bottom_right":"Bottom Right"},"scaling":"Scaling","scaling_options":{"auto":"Auto","width":"Full Width","height":"Full Height","none":"No Scaling (preview may be inaccurate)"},"repeat":"Image Repeat","repeat_options":{"none":"No Repeat","horizontal":"Repeat Horizontally","vertical":"Repeat Vertically","both":"Repeat Both"},"attach":"Attach Image To","attach_tab":"The tab","attach_window":"The window","preview":"Preview","save":"Save & Close","cache_error":"An error occurred while trying to cache the image you provided, please double-check the URL.","upload_error":"An error occurred while trying to upload the file you provided, please make sure that it's a reasonable size and an image."}}},"hi":{"lang_code":"hi","language":"हिन्दी","extName":"ProductivityTab — Custom Homepage Dashboard","newtabName":"ProductivityTab — Custom New Tab Dashboard","extDescription":"A remarkably customizable personal homepage featuring 50+ widgets, breathtaking backgrounds and much more.","newtabDescription":"A customizable personal dashboard on your new tab page featuring 50+ widgets, breathtaking backgrounds and much more.","defaults":{"tab":"घऱ","me":"मैं"},"remove_widget":"हटाना","hide_banner":"Hide this banner","hide_ad":{"content":"Hey! We're not crazy about ads either, but we're only able to make ProductivityTab available and continue developing features for our free users (that's you!) by showing ads. If you'd like to support ProductivityTab directly and get rid of ads for free, we would really appreciate if you upgraded to our pro version","upgrade":"Upgrade","hide":"Hide ads"},"alert":{"default_button":"Dismiss","confirm_title":"Are you sure you want to do this?","confirm_continue":"Continue","confirm_cancel":"Cancel"},"onboarding":{"modal":{"tagline":"All the sites and apps you use, in one place","wrong_extension":"Want ProductivityTab on your new tab page instead?","wrong_extension_newtab":"Want ProductivityTab on your home page instead?","wrong_extension_action":"Click here","about":"ProductivityTab's all about tabs and widgets","about_desc":"Tabs are pages filled with widgets - blocks that show things like the weather, news, and your email. You can customize most widgets and add as many as you want.","terms":"By checking, you agree to ProductivityTab's <a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\">Terms</a> and <a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\">Privacy Policy</a>","sign_in":"Sign in with your Google account","sign_in_desc":"Sign in with your Google account before getting started to securely save your changes online.","sign_in_desc2":"You can stay signed out if you want, but your page won't be saved online and you won't be able to access it from other computers.","sign_in_button":"Sign in with Google","have_account":"It looks like you already have an account!","have_account_desc":"All your tabs and widgets are ready to use!","get_started":"Let's get started!","get_started_desc":"You're good to go! Let's get your page set up."},"widgets":{"configure":"Let's configure a widget.","configure_desc":"Click the wrench to open a widget's <b>settings</b>.","configure_skip":"Skip Tutorial","settings":"Replace <b>Link URL</b> with your favorite site, then press <b>Save</b>.","move":"You can <b>reposition</b> widgets by clicking and dragging the three dots highlighted here.","remove":"To <b>delete</b>, simply click the red trash bin icon.","done":"Got it"},"settings":{"intro":"Now let’s add a new widget. This highlighted button is where you can access the Widget Menu.","instructions":"Click the new widget button on to open the widget menu!","skip":"Skip","tooltips":{"settings":"Change the way ProductivityTab looks and works","widgets":"Add new widgets - you can have as many as you want","editing":"Show or hide the editing buttons on widgets","links":"This is a list of links, add sites you use often in the settings","tabs":"These are your tabs. You can add more in the settings","support":"Send us a message or leave a review here"},"finished":"That's it!","finished_next":"Choose an option from the menu (try starting with <b>Widgets</b>) and set your page up!","finished_contact":"Use the support link if you need any help and we'll get back to you ASAP."}},"storage":{"signin":"Sign in with Google now to securely save and sync your configuration","signin_btn":"Sign in","signin_dismiss":"Dismiss","signin_confirm":{"title":"Keep local data?","desc":"Would you like to keep your local data, and replace the configuration in your account with it, or replace this computer's configuration with the one already in your account?","keep_account":"Use account","keep_local":"Keep local"},"signout_confirm":"Signing out will erase your local backups","pastdue":"Your subscription is past due","pastdue_desc":"Please update your billing information in the settings"},"toolbar":{"placeholder":"अपने शब्द दर्ज करें","placeholder_ok":"अपने शब्द दर्ज करें या \"OK, Google\" कहें","suggestions":{"url_subtext":"Visit URL","capture_notice":"ProductivityTab handles searches you normally make from the Omnibox. You can disable this at any time from the settings"},"apps":{"search":"खोज","youtube":"यूट्यूब","maps":"नक्शे","play":"खेलें","news":"समाचार","gmail":"जीमेल","drive":"ड्राइव","calendar":"कैलेंडर","more":"अन्य कार्यकलाप"}},"menu":{"settings":"सेटिंग्स","widgets":"विजेट्स","editing":"संपादन","editing_enabled":"औन","editing_disabled":"औफ","plus":"गूगल प्लस","tabs":"टैब्स","footer":{"support":"सहायता","feedback":"सूझाव?","review":"समीक्षा","terms":"Terms","privacy":"Privacy","by":"अवी कोन द्वारा"}},"voice":{"listening":"सुन रहा हूं...","searching":"खोजा जा रहा है: %s","missed":"समझ नही पाया। <a>दुबारा प्रयास करें</a>"},"settings":{"title":"सेटिंग्स","exit":"Exit settings","saved":"Settings saved","nav":{"visual":"Visual","visual_sections":{"background":"Background","layout":"लेआउट","theme":"App theme","ad_placement":"Ad placement"},"toolbar":"Toolbar","toolbar_sections":{"style":"Style","search":"खोज","links":"Links"},"tabs":"टैब्स","widgets":"विजेट्स","ads":"Ads","pro":"Pro","accounts":"Account","misc":"Miscellaneous","advanced":"Advanced","advanced_sections":{"backups":"Backup and restore","css":"Custom CSS","debug_tools":"Debug tools"},"support":"Help and support","suggest":"Suggest a feature"},"visual":{"background":{"title":"Background","desc":"This is the image or set of images shown as a background to your tabs","current":"Current background","custom":"अनुकूल","unnamed":"Theme %s","select":"Select a theme","or":"या","url_placeholder":"Enter an image URL"},"layout":{"title":"लेआउट","desc":"Here you can adjust the type and number of columns in each tab","columns":"Columns","grid":"Grid","columns_number":"Number of columns","column_width":"Column width","column_width_fixed":"Fixed","column_width_fluid":"Fluid","column_warning":{"column_to_grid":"Changing to a grid-based layout will move all of your widgets to the top left corner.","grid_to_column":"Changing to a column-based layout will move all of your widgets to the first column."}},"theme":{"title":"App theme","desc":"The app theme controls the style of ProductivityTab itself and all widgets","preview":"पूर्वावलोकन","light":"Light (default)","dark":"Dark","transparent":"Transparent","transparent_darker":"Transparent (darker)"}},"toolbar":{"style":{"title":"Style","desc":"This controls the style of the toolbar.  It can either appear normally or as an out of the way button","normal":"Normal","button":"Button"},"search":{"title":"खोज","desc":"These settings control how the search box and voice search function","engine":"Search engine","engines_default":"Default","engines_custom":"अनुकूल","engines_custom_desc":"Enter a URL that queries should be sent to, with <b>%s</b> where the query should go.","omnibox_capture":"Handle searches normally made in the Omnibox","voice":"Enable voice search","ok_google":"Enable \"OK Google\" hotword detection","search_tab":"Open search results in a new tab"},"links":{"title":"Links","desc":"These are the items shown at the right of the toolbar","apps":"Apps menu","custom":"Custom links","custom_note1":"Maximum of 3 allowed","custom_note2":"users get 8","custom_name_placeholder":"Link text","custom_url_placeholder":"Link URL, i.e. https://www.google.com/"}},"misc":{"link_tab":"Open links in a new tab by default"},"tabs":{"create_new":"Create new","make_default":"Make default","desc1":"Tabs are pages inside ProductivityTab. Each tab has its own set of widgets that is completely separate from every other tab.","desc2":"You can switch between tabs by clicking the buttons that appear at the left and right of the screen when you move your mouse over a tab or by using the arrow keys on your keyboard.","name_placeholder":"Enter a tab name","delete_confirm":"This action is irreversible. All data from all widgets in the tab will be permanently lost."},"accounts":{"status":{"title":"Status","signed_in":"You are currently <b>signed in</b> as %s (%s).","reset_account":"Reset account","sign_out":"Sign out","signed_out":"You are <b>not currently signed in</b>. Sign in with your Google account now to securely store and sync your configuration.","sign_in":"Sign in with Google"},"reset_confirm_desc":"This will erase all local and synced data, there is no backup and no way to undo this.","reset_confirm_desc2":"You will lose your entire current configuration on all computers connected to this account."},"advanced":{"backups":{"title":"Backup and restore","desc":"Backups are complete copies of all your tabs, settings, and widgets. They're automatically created when you first open ProductivityTab each day.","desc2":"Use the buttons below to roll ProductivityTab back to a particular date or download one of your backups.","backup":"Backup now","upload":"Restore from file","download":"Download","restore":"Restore","download_name":"ProductivityTab Backup","restore_confirm":"This will overwrite all local and synced data. You will lose your entire current configuration on all computers under this account.","restore_error":"An error occurred while trying to parse the provided data, please try again later."},"css":{"title":"Custom CSS","desc":"You can use CSS (<a href=\"https://developer.mozilla.org/en-US/docs/Web/CSS\" target=\"blank\">definition</a>) to customize almost any part of ProductivityTab.","placeholder":"Enter up to 1000 characters of CSS here"},"debug_tools":{"title":"Debug tools","desc":"<b>WARNING:</b> These tools can erase your entire configuration in a single click. Only use them if your developer instructs you to.","open":"Open tools"}},"widgets":{"desc1":"Widgets have their own settings and can't be customized here.","desc2":"To edit a widget's settings, follow these steps:","steps1":"Move your mouse over any widget","steps2":"Click the wrench icon that appears at the top right of the widget. If none appears then the widget doesn't have any settings that can be customized.","steps3":"Edit any of the settings shown in the dialog that's displayed","steps4":"Click Save to save your changes, or any part of the background to discard of them"},"pro":{"promo":{"monthly_price":"$4.99 per month","yearly_price":"or $29.99 per year","upgrade_btn":"Upgrade Now","business":"Interested in buying Pro for your business or school?","business_contact":"Contact us","themes":"थीम्स","themes_desc":"See more of your backgrounds with dark and transparent themes","bgs":"Live backgrounds","bgs_desc":"Bring your page to life with 20 live high-definition backgrounds","widgets":"Maximizable widgets","widgets_desc":"Take ProductivityTab to another level with maximizable widgets","more_header":"And more","stocks":"Realtime stocks with extended and historical information","rss":"Support for multiple RSS feeds per widget","sports":"General and league-specific sports news","tabbed_widgets":"Tabbed news and RSS widgets","bg_downloads":"Downloadable backgrounds","weather":"Hourly weather forecasts up to 10 days out","toolbar":"More toolbar links","ads":"A completely ad-free experience","support":"Prioritized support and suggestions","buy_pro":"Buy Pro"},"checkout":{"title":"Checkout","updating_title":"Update plan","payment_options":"Pay","pay_monthly":"Monthly ($4.99)","pay_yearly":"Yearly ($29.99)","cancel":"Cancel","update":"Update","subscribe":"Subscribe","braintree_notice":"Payments securely processed by Braintree.","monthly_notice":"By subscribing, you authorize ProductivityTab to charge you $4.99 every month until you cancel your subscription.","yearly_notice":"By subscribing, you authorize ProductivityTab to charge you $29.99 every year until you cancel your subscription.","update_notice":"Although billing cycle changes take effect immediately, you won't be charged until your current cycle ends.","thank_you":"Thank you for buying ProductivityTab Pro!","thank_you2":"ProductivityTab will reload in a few seconds and you'll be all set!","error":"Something went wrong while trying to process your payment.","error2":"Please try again later or email us at support@ichro.me","signin":"Sign in","signin_desc":"You need to sign in before buying Pro so we can make sure it's you","signin_btn":"Sign in"},"plan":{"title":"Plan","desc":"You are currently subscribed to ProductivityTab Pro (%s)","types":{"monthly":"Monthly","yearly":"Yearly","business":"Business","education":"Education","custom":"अनुकूल"},"uneditable_desc":"Business, education, and custom plans cannot be updated from within ProductivityTab. Please <a href=\"mailto:support@ichro.me\">contact us</a> to update or cancel your subscription.","status":"Status","status_active":"Active","status_trial":"Trial","status_pastdue":"Past due","subscription_date":"Subscription date","paid_through":"Paid through","next_bill":"Next bill","next_bill_value":"$%s on %s","update_plan":"Update plan","update_billing":"Update billing","cancel":"Cancel subscription","cancel_notice":"Your subscription will be canceled immediately","cancel_notice2":"If you would like a refund, please contact us at support@ichro.me"}},"ads":{"text1":"ProductivityTab displays a few small ads to pay for server, support and development costs. With these ads, we can afford to offer ProductivityTab free to everyone.","text2":"Here you can choose where those ads are shown, or buy ad-free to permanently remove them.","text3":"Ad-free is a one-time purchase that permanently removes ads from ProductivityTab wherever you're signed in. You can also upgrade to Pro for extra features in addition to an ad-free experience.","upgrade_btn":"Upgrade to ad-free","already_upgraded":"It looks like you've already upgraded to ad-free","signin":"Sign in","signin_desc":"Sign in before upgrading so we can link your purchase to your account","signin_btn":"Sign in","thank_you":"Thank you for upgrading to ad-free!","placement":{"title":"Ad placement","left":"In the leftmost column","right":"In the rightmost column","top":"Above the tab","bottom":"Floating at the bottom"}}},"store":{"installation":"Installation","description":"वर्णन","preview":"पूर्वावलोकन","instructions":"Drag and drop any size onto your homepage"},"widgets":{"sizes":{"tiny":"बहुत छोटा","small":"छोटा","medium":"मध्यम","large":"बड़ा","variable":"Variable"},"settings":{"title":"Widget Settings","save":"सेव करें","size":"Widget Size"},"minimize":"Minimize","maximize":"Maximize","delete_confirm":"Are you really sure you want to delete this widget?\r\nThis action is irreversible; all data from this widget will be permanently lost.","permissions_request":{"title":"Access required","button":"Grant Access","desc":"This widget needs extra permissions before it can be used. Grant them using the button below."},"error":{"explanation":"Something went wrong while we were trying to display this widget.","advice":"Try reinstalling the widget or reloading the page. Contact us if you see this message often.","support":"सहायता","refresh":"Refresh"},"auth":{"message":"You'll need to give this widget access to your account before you can use it.","button":"Grant Access"},"shared":{"settings":{"title":"Widget Title","title_placeholder":"Enter a widget title or leave blank to hide","height":"Widget Height","open_options":{"current":"The current tab","blank":"एक नया टैब"},"footer_link":"Footer Link","footer_link_options":{"show":"दिखाएँ","hide":"छिपाएँ"},"account":"Account ID","account_help":"If you're signed into multiple accounts, this is the \"authuser=\" value.\n<br /><br />\nFor example, if you're signed into two accounts, jsmith1@gmail.com and jsmith2@gmail.com, the \"authuser\" value for jsmith2@gmail.com would be 1 since it's the second account (counting from zero) that you're signed into.","account_placeholder":"Your \"authuser=\" value","on":"ऑन","off":"ऑफ"}},"apps":{"name":"Apps","desc":"Displays your currently installed Google Chrome applications.","settings":{"format":"Widget Format","format_options":{"tiles":"टाइलें","list":"सूची"},"display":"दिखाएँ","display_options":{"all":"All apps","enabled":"Only enabled apps"},"sort":"Sort","sort_options":{"id":"ID","alphabetically":"Alphabetically","offline":"Offline Enabled","available":"उपलब्धता"},"open":"में खोलें apps"},"store_app":"Store"},"bookmarks":{"name":"Bookmarks","desc":"Displays selected and customized bookmarks, and other links.","settings":{"title_placeholder":"Enter a widget title","layout":"लेआउट","layout_options":{"single":"Single column","double":"Double column"},"open":"Open bookmarks in"},"edit":{"dialog_title":"Edit Bookmark","title":"Bookmark Title","title_placeholder":"Google","url":"Bookmark URL","url_placeholder":"https://www.google.com/","save":"सेव करें"},"new_caption":"New","new_bookmark":"Bookmark","new_folder":"Folder","drop_link":"Drop link here"},"chrome_bookmarks":{"name":"Bookmarks","desc":"Displays your Chrome bookmarks, optionally from a specific folder.","settings":{"title_placeholder":"Enter a widget title","from":"Show bookmarks from","open":"Open bookmarks in"}},"calc":{"name":"Calculator","desc":"Displays a calculator with support for basic operators.","error":"Error!","infinity":"Infinity","mismatch":"Mismatched parentheses"},"calendar":{"name":"कैलेंडर","desc":"Displays upcoming events from one or more of your Google calendars.","settings":{"calendar":"कैलेंडर","show":"Show events from","show_options":{"all":"All time","today":"Today only"}},"title":"Agenda","calendar":"कैलेंडर","noevents":"No events found in the near future, it looks like your schedule's clear!"},"clock":{"name":"Clock","desc":"Offers alarm, time, timer, and stopwatch functionality.","settings":{"timezone":"Time Zone","timezone_local":"Local","format":"Clock Format","format_options":{"ampm":"AM/PM - Digital","24hour":"24 Hour - Digital","analog":"12 Hour - Analog","ampmseconds":"AM/PM - Digital, No Seconds","24hourseconds":"24 Hour - Digital, No Seconds"},"sound":"Alert Sound"},"title":"Clock","alarm":"Alarm","clock":"Clock","timer":"Timer","stopwatch":"Stopwatch","set":"Set","unset":"Unset","dismiss":"Dismiss","enable_audio":"Enable audio"},"facebook":{"name":"Facebook","desc":"Embeds Facebook in a widget"},"feedly":{"name":"Feedly","desc":"Displays articles from your Feedly account in a configurable format.","settings":{"source":"Show articles from","source_feeds":"Feeds","show":"दिखाएँ","show_options":{"all":"All articles","unread":"Only unread articles"},"layout":"लेआउट","layout_options":{"titles":"Titles only","magazine":"Magazine","cards":"Cards","cards_columns":"Cards (two columns)"},"mark":"Mark an article as read when I","mark_options":{"scroll":"Scroll past it or click it","click":"Just click it"},"sort":"Sort Order","sort_options":{"newest":"Newest first","oldest":"Oldest first"}},"all":"सभी","saved":"Saved for later","uncategorized":"Uncategorized","author":"by","go_to_feedly":"Go To Feedly"},"notes":{"name":"Notes","desc":"Inserts a simple, editable, note.","settings":{"color":"Note Color","color_options":{"yellow":"Yellow","orange":"Orange","red":"Red","blue":"Blue","green":"Green","white":"White"},"font":"Font Face","fontsize":"Font Size"}},"now":{"name":"Google Now","desc":"Displays cards from Google Now including flight status and package tracking.","authorize":"You'll need to give ProductivityTab permission to view your Google Now cards before anything will show up here.","authorize_btn":"Authorize","caught_up":"All caught up, nothing here.","no_title":"No Title"},"plus":{"name":"Google+","desc":"Embeds Google Plus in a widget"},"notifications":{"name":"Google Notifications","desc":"Displays your Google Notifications from services such as Google+"},"reddit":{"name":"Reddit","desc":"Displays the top items on Reddit for any given subreddit.","settings":{"subreddit":"Subreddit","subreddit_help":"Enter any subreddit by the part past <b>/r/</b> when on Reddit.\n<br /><br />\nFor example, Technology is at: <a href=\"https://www.reddit.com/r/technology\">https://www.reddit.com/r/technology</a>, therefore you would enter <b>technology</b>","subreddit_placeholder":"Enter a subreddit to show links from. (i.e. technology)","sort":"Sort Order","sort_options":{"hot":"Hot","top":"Top","new":"New","gilded":"Gilded","rising":"Rising","controversial":"Controversial"},"links":"Links Shown","click":"When I click a link show me","click_options":{"link":"The link","comments":"The comments"}},"more":"अन्य कार्यकलाप"},"tasks":{"name":"Tasks","desc":"Displays an editable list of tasks from one of your Google Tasks lists.","title":"Tasks","settings":{"list":"सूची"},"task_title":"Title","due_date":"Due date","notes":"Notes","add":"Add Item","delete_task":"Delete Task","move_up":"Move Up","move_down":"Move Down","done":"Done","due_today":"Due today","overdue":"Overdue","authorize":"You'll need to select a list from your Google Tasks via the settings before anything can be displayed here."},"twitter":{"name":"ट्विटर","desc":"Displays tweets from your home stream or a specified list.","settings":{"source":"Show Tweets from","show":"Tweets Shown"},"authorize":"You'll need to authorize ProductivityTab first","authorize_msg":"You'll need to give ProductivityTab permission to view tweets from your account before anything will show up here.","authorize_btn":"Authorize","no_tweets":"There don't seem to be any tweets here...","home":"घऱ","mentions":"Mentions","retweets":"Retweets of me","lists":"Lists","more":"अन्य कार्यकलाप","reply":"Reply","retweet":"Retweet","favorite":"Favorite"},"wolfram":{"name":"Wolfram|Alpha","desc":"Inserts a small Wolfram|Alpha search box."},"youtube":{"name":"यूट्यूब","desc":"Displays either popular videos or videos from a specified user.","settings":{"format":"Format","format_options":{"large":"One large","large_2":"One large, two small","large_4":"One large, four small","four":"Four small","six":"Six small"},"from":"Show Videos From","from_help":"This must be an <b>exact</b> username as shown in the URL of the page when you're viewing their profile.\n<br /><br />\nThis value never includes spaces.","from_placeholder":"Leave blank to show Top Videos","open":"Open search results in"},"search":"Search YouTube","num_views":"views"},"quotes":{"name":"Quotes","desc":"Displays a quote picked either every time you load the page or once daily.","settings":{"source":"Source","method":"Load new quotes","method_options":{"daily":"Once daily","random":"Every time I load the page"}},"unknown_author":"Unknown"},"html":{"name":"HTML","desc":"Displays completely custom HTML in an iframe.","settings":{"html":"HTML","js":"JavaScript","height":"Widget Height"}},"sitelink":{"name":"Site Link","desc":"Displays a link, optionally with a title and thumbnail","settings":{"link":"Link URL","link_placeholder":"https://www.google.com/","image":"छवि URL","image_placeholder":"https://www.example.com/image.png","color":"Image Background Color","style":"Image Style","style_fill":"Fill","style_center":"मध्य"}},"stats":{"name":"System Statistics","desc":"Keep an eye on your system with realtime statistics","memory":"Memory","battery":"Battery","usage":"usage","in_use":"in use","remaining":"remaining","charged":"Fully Charged","idle":"Idle","charging":"Charging","discharging":"Discharging"},"search":{"name":"खोज","desc":"Embeds a search box in your page for easy access","settings":{"placeholder":"Search Field Placeholder","search_url":"खोजें यूआरएल","param":"Query Parameter","param_placeholder":"The parameter where the query goes, i.e. \"q\""},"default_placeholder":"Search Google"},"pushbullet":{"name":"Pushbullet","desc":"Keep track of notifications from your phone and other devices","no_pushes":"No pushes found","sign_in":"Sign in","no_key":"It doesn't look like you're signed in to Pushbullet.  Sign in now to connect this widget."},"linkedin":{"name":"LinkedIn","desc":"Displays your LinkedIn home stream"},"directions":{"name":"Directions","desc":"Get directions to and from nearly anywhere right from your homepage","driving":"Driving","transit":"Public Transit","walking":"Walking","cycling":"Cycling","from":"Enter a starting point","to":"Enter a destination","loading":"Loading directions, please wait...","error":"Something went wrong while trying to load the directions you requested.","error2":"Please check the start and destination addresses you entered.","open_in_maps":"Open in Google Maps","via":"via"},"pocket":{"name":"Pocket","desc":"Display a list of your saved articles, videos, and web pages from Pocket","settings":{"links_shown":"Number of links shown","open":"Open links","open_pocket":"In Pocket","open_original":"At their original URL"},"by":"द्वारा","no_links":"No links found","grant_access":"Grant access","no_key":"You'll need to give ProductivityTab access to your Pocket account before it can load your links."}},"themes":{"title":"थीम्स","all":"सभी","custom":"अनुकूल","create":"एक थीम बनाएँ","url_or_upload":"या","upload_image":"छवि अपलोड","edit_btn":"संपादित","delete":"मिटाए","use":"उपयोग","preview":"पूर्वावलोकन","author":"द्वारा","images":"%s छवियाँ","resolution":"रेज़ोल्यूशन","categories":"श्रेणियाँ","cached":"This theme has been cached and is available offline","random":"This theme displays a random image every time you load the page","random_daily":"This theme displays an image picked randomly every day","sunrise_sunset":"This theme displays an image based on the time of day","feed":"This theme displays an image selected daily from an external feed","video":"This theme displays a live video","pro_only":"This theme is only available to Pro users. Buy Pro in the settings.","delete_confirm":"Are you really sure you would like to delete this theme?\r\nThis action is irreversible; the entire theme will be permanently lost.","delete_error":"An error occurred while trying to delete the theme.  Please try again later.","feed_fetching":"कृपया प्रतीक्षा करें, फ़ीड लाया जा रहा है...","feed_error":"Something went wrong while trying to fetch the feed.  Please try again later.","caching":"Please wait, caching theme...","cache_status":"%s %s छवियों कैश्ड हुइ हैं","cache_error":"An error occurred while trying to cache the theme.  Please try again later","bginfo":{"view":"View","source":"Source","unknown":"Unknown","download":"Download","pro_only":"Only Pro users can download background images and videos"},"edit":{"title":"थीम संपादित करें","create_title":"थीम बनाएँ","name":"थीम का नाम","default_name":"नई थीम","name_placeholder":"थीम का नाम दर्ज करें","image":"छवि URL","image_placeholder":"एक पृष्ठभूमि छवि का URL दर्ज करें","image_help":"Uploaded images <b>cannot be synced</b> between computers.<br /><br />If this is important to you, please upload your image to a service such as <a href=\"https://imgur.com/\" target=\"_blank\">imgur</a>. Then copy the URL ending with an extension (i.e. .jpg) and paste it into the field on the left.","color":"फ़ॉलबैक रंग","color_placeholder":"किसी भी रंग का नाम दर्ज करें","position":"पोजीशन (स्थान)","position_options":{"center":"मध्य","top_left":"ऊपर-बाएं","top_center":"ऊपर-मध्य","top_right":"ऊपर-दाएँ","bottom_left":"नीचे-बाएं","bottom_center":"नीचे-मध्य","bottom_right":"नीचे-दाएँ"},"scaling":"स्केलिंग","scaling_options":{"auto":"ऑटो","width":"पूरी चौड़ाई","height":"पूरी ऊँचाई","none":"No Scaling (preview may be inaccurate)"},"repeat":"छवि दोहराएँ","repeat_options":{"none":"नहीं दोहराने","horizontal":"Repeat Horizontally","vertical":"Repeat Vertically","both":"Repeat Both"},"attach":"Attach Image To","attach_tab":"टैब","attach_window":"खिड़की","preview":"पूर्वावलोकन","save":"सेव & बंद","cache_error":"An error occurred while trying to cache the image you provided, please double-check the URL.","upload_error":"An error occurred while trying to upload the file you provided, please make sure that it's a reasonable size and an image."}}},"hr":{"lang_code":"hr","language":"Hrvatski","extName":"ProductivityTab — Custom Homepage Dashboard","newtabName":"ProductivityTab — Custom New Tab Dashboard","extDescription":"A remarkably customizable personal homepage featuring 50+ widgets, breathtaking backgrounds and much more.","newtabDescription":"A customizable personal dashboard on your new tab page featuring 50+ widgets, breathtaking backgrounds and much more.","defaults":{"tab":"Početna","me":"Ja"},"remove_widget":"Ukloni","hide_banner":"Sakrij reklamu","hide_ad":{"content":"Hey! We're not crazy about ads either, but we're only able to make ProductivityTab available and continue developing features for our free users (that's you!) by showing ads. If you'd like to support ProductivityTab directly and get rid of ads for free, we would really appreciate if you upgraded to our pro version","upgrade":"Nadogradi","hide":"Sakrij reklame"},"alert":{"default_button":"Odbaci","confirm_title":"Jeste li sigurni da želite to napraviti?","confirm_continue":"Nastavi","confirm_cancel":"Poništi"},"onboarding":{"modal":{"tagline":"Sve web-stranice i aplikacije koje koristite, na jednom mjestu","wrong_extension":"Želite li ProductivityTab na novom tabu?","wrong_extension_newtab":"Želite li ProductivityTab na početnoj stranici?","wrong_extension_action":"Kliknite ovdje","about":"U ProductivityTab-u sve je u karticama i widgetima","about_desc":"Kartice su stranice pune widgeta - blokova koji pokazuju vrijeme, vijesti i e-poštu. Možete dodati widgeta koliko kod želite, a većinu ih možete prilagođavati.","terms":"Nastavkom se slažete sa ProductivityTab <a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\"> Uvjetima</a> i <a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\"> Pravilima o privatnosti</a>","sign_in":"Prijavi se pomoću Google računa","sign_in_desc":"Prijavi se pomoću Google računa prije početka da bi sigurno pohranili tvoje promjene online.","sign_in_desc2":"Možeš ostati odjavljen ako želiš, ali tvoja stranica neće biti spremljena online i nećeš joj moći pristupiti s drugih računala.","sign_in_button":"Prijavi se sa Googleom","have_account":"Izgleda da već imate korisnički račun!","have_account_desc":"Sve vaše kartice i widgeti su spremni za korištenje!","get_started":"Započnimo!","get_started_desc":"Možemo početi! Postavimo tvoju stranicu."},"widgets":{"configure":"Podesi widget.","configure_desc":"Click the wrench to open a widget's <b>settings</b>.","configure_skip":"Skip Tutorial","settings":"Replace <b>Link URL</b> with your favorite site, then press <b>Save</b>.","move":"You can <b>reposition</b> widgets by clicking and dragging the three dots highlighted here.","remove":"To <b>delete</b>, simply click the red trash bin icon.","done":"Shvaćam"},"settings":{"intro":"Now let’s add a new widget. This highlighted button is where you can access the Widget Menu.","instructions":"Click the new widget button on to open the widget menu!","skip":"Preskoči","tooltips":{"settings":"Izmjeni kako ProductivityTab izgleda i radi","widgets":"Dodaj novi widget - možete ih imati koliko god želite","editing":"Prikaži ili sakri gumbove za uređivanje widgeta","links":"Ovo je popis linkova, u postavkama dodajte stranice koje često posjećujete","tabs":"Ovu su vaše kartice. Možete dodati nove u postavkama","support":"Ovdje nam možeš poslati poruku ili ostaviti recenziju"},"finished":"To je sve!","finished_next":"Odaberi opciju iz izbornika (za početak, pokušaj s <b>widgetima</b>) i postavi svoju stranicu!","finished_contact":"Koristi link za podršku ako ti treba pomoć i javit ćemo vam se što prije."}},"storage":{"signin":"Prijavi se s Googleom da bi mogli sigurno pohraniti i sinkronizirati tvoju konfiguraciju","signin_btn":"Prijavi se","signin_dismiss":"Odbaci","signin_confirm":{"title":"Zadrži lokalne podatke?","desc":"Želiš li zadržati lokalne podatke i zamijeniti konfiguraciju tvoga računa s lokalnom konfiguracijom ili da tvoju lokalnu konfiguraciju zamijenimo s konfiguracijom tvog računa u oblacima?","keep_account":"Koristi račun","keep_local":"Zadrži lokalno"},"signout_confirm":"Odjava će izbrisati vaše lokalne podatke","pastdue":"Pretplata je istekla","pastdue_desc":"Molimo obnovite informacije o naplati u postavkama"},"toolbar":{"placeholder":"Unesi pojmove","placeholder_ok":"Unesi pojmove ili reci \"OK, Google\"","suggestions":{"url_subtext":"Otvori URL","capture_notice":"ProductivityTab preuzima pretraživanja iz Chrome omniboxa. Moguće je to onemogućiti u postavkama"},"apps":{"search":"Pretraživanje","youtube":"YouTube","maps":"Karte","play":"Play","news":"Vijesti","gmail":"Gmail","drive":"Disk","calendar":"Kalendar","more":"Više"}},"menu":{"settings":"Postavke","widgets":"Widgeti","editing":"Uređivanje","editing_enabled":"Omogućeno","editing_disabled":"Omogući","plus":"Google Plus","tabs":"Kartice","footer":{"support":"Podrška","feedback":"Povratne informacije","review":"Recenzija","terms":"Uvjeti","privacy":"Privatnost","by":"Napravio Avi Kohn"}},"voice":{"listening":"Slušanje...","searching":"Tražim: %s","missed":"Nismo razumjeli. <a>Pokušajte ponovo</a>"},"settings":{"title":"Postavke","exit":"Napusti postavke","saved":"Postavke spremljene","nav":{"visual":"Vizualni ugođaj","visual_sections":{"background":"Pozadina","layout":"Raspored","theme":"Tema aplikacije","ad_placement":"Mjesto reklama"},"toolbar":"Alatna traka","toolbar_sections":{"style":"Stil","search":"Pretraživanje","links":"Linkovi"},"tabs":"Kartice","widgets":"Widgeti","ads":"Reklame","pro":"Pro","accounts":"Račun","misc":"Ostalo","advanced":"Napredno","advanced_sections":{"backups":"Sigurnosno kopiranje i vraćanje podataka","css":"Osobni CSS","debug_tools":"Alati za debug"},"support":"Pomoć i podrška","suggest":"Predloži funkciju"},"visual":{"background":{"title":"Pozadina","desc":"Ovo je slika ili skup slika koji se prikazuje kao pozadina tvojih kartica","current":"Trenutna pozadina","custom":"Prilagođena","unnamed":"Tema %s","select":"Odaberi temu","or":"ili","url_placeholder":"Unesi URL slike"},"layout":{"title":"Raspored","desc":"Ovdje možeš podesiti broj i tip stupaca u svakoj kartici","columns":"Stupci","grid":"Rešetka","columns_number":"Broj stupaca","column_width":"Širina stupca","column_width_fixed":"Fiksna","column_width_fluid":"Promjenjiva","column_warning":{"column_to_grid":"Promjena na rešetku će sve tvoje widgete pomaknuti u gornji lijevi kut.","grid_to_column":"Promjena na stupce će sve tvoje widgete pomaknuti u prvi supac."}},"theme":{"title":"Tema aplikacije","desc":"Tema aplikacije određuje stil ProductivityTab-a i widgeta","preview":"Pregled","light":"Svijetla (zadano)","dark":"Tamna","transparent":"Prozirna","transparent_darker":"Prozirna (tamnije)"}},"toolbar":{"style":{"title":"Stil","desc":"Ovo kontrolira stil prikaza alata. Može biti u obliku trake ili gumba","normal":"Traka","button":"Gumb"},"search":{"title":"Pretraživanje","desc":"Ove postavke kontroliraju rad pretraživanja i glasovnog pretraživanja","engine":"Pretražitelj","engines_default":"Zadan","engines_custom":"Prilagođen","engines_custom_desc":"Unesi URL koji ima <b>%s</b> tamo gdje treba ići pojam pretraživanja.","omnibox_capture":"Preuzmi pretraživanja iz Chrome omniboxa","voice":"Omogući glasovno pretraživanje","ok_google":"Omogući \"OK Google\" detekciju","search_tab":"Otvori rezultate pretraživanja u novoj kartici"},"links":{"title":"Linkovi","desc":"Ovo su stavke na desnoj strani trake","apps":"Aplikacije","custom":"Prilagođeni linkovi","custom_note1":"Najviše 3","custom_note2":"korisnici mogu 8","custom_name_placeholder":"Tekst linka","custom_url_placeholder":"URL linka, npr. https://www.google.com/"}},"misc":{"link_tab":"Otvaraj linkove u novoj kartici po zadanom"},"tabs":{"create_new":"Napravi novu","make_default":"Postavi kao početnu","desc1":"Kartice su stranice unutar ProductivityTab-a. Svaka kartica ima svoj vlastiti set widgeta koji je u potpunosti odvojen od svake druge kartice.","desc2":"Možeš se prebacivati između kartica klikom na gumbe koji se pojavljuju lijevo i desno kada miš pomakneš na karticu ili se možeš prebacivati pomoću strelica na tipkovnici.","name_placeholder":"Unesi naziv kartice","delete_confirm":"Ova akcija je nepovratna. Svi podaci widgeta u ovoj kartici bit će trajno izgubljeni."},"accounts":{"status":{"title":"Status","signed_in":"Trenutno si <b>prijavljen</b> kao %s (%s).","reset_account":"Resetiranje računa","sign_out":"Odjavi se","signed_out":"Trenutno <b>nisi prijavljen</b>. Prijavi se s Google računom sada da bi mogli sigurno pohraniti i sinkronizirati tvoju konfiguraciju.","sign_in":"Prijavi se sa Googleom"},"reset_confirm_desc":"Ovo će izbrisati sve lokalne i sinkronizirane podatke, ne postoji način za povratak.","reset_confirm_desc2":"Izgubit ćeš svu trenutnu konfiguraciju na svim računalima koja su spojena na ovaj račun."},"advanced":{"backups":{"title":"Sigurnosno kopiranje i vraćanje podataka","desc":"Sigurnosne kopije su potpune kopije tvojih kartica, postavka i widgeta. Automatski se stvaraju svaki dan kada otvoriš ProductivityTab.","desc2":"Pomoću gumba ispod možeš vratiti podatke ProductivityTab-a iz prošlosti ili možeš skinuti te podatke.","backup":"Izradi sigurnosnu kopiju sada","upload":"Povrati podatke iz datoteke","download":"Preuzmi","restore":"Povrati podatke","download_name":"ProductivityTab sigurnosna kopija","restore_confirm":"Ovo će prepisati sve lokalne i sinkronizirane podatke. Izgubit ćeš trenutnu konfiguraciju na svim kompjuterima s ovim računom.","restore_error":"Došlo je do pogreške prilikom analiziranja podataka, pokušaj ponovo kasnije."},"css":{"title":"Osobni CSS","desc":"Možeš koristiti CSS (<a href=\"https://developer.mozilla.org/en-US/docs/Web/CSS\" target=\"blank\">definicija</a>) za prilagođavanje gotovo svakog dijela ProductivityTab-a.","placeholder":"Unesi najviše 1000 znakova CSS-a ovdje"},"debug_tools":{"title":"Alati za debug","desc":"<b>UPOZORENJE:</b> Ovi alati mogu izbrisati sve podatke u jednom kliku. Koristite ih samo ako vas developer upućuje.","open":"Otvori alate"}},"widgets":{"desc1":"Widgeti imaju svoje vlastite postavke koje se ne mogu podešavati odavde.","desc2":"Da bi promijenio postavke widgeta, slijedi ove korake:","steps1":"Pomakni miš na bilo koji widget","steps2":"Klikni na alatni ključ koji se pojavljuje gore desno u widgetu. Ako se ne prikazuje to znači da widget nema postavka.","steps3":"Promijeni bilo koju postavku u okviru koji je prikazan","steps4":"Klikni Spremi za spremanje promjena ili klikni na pozadinu za otkazivanje"},"pro":{"promo":{"monthly_price":"$4.99 mjesečno","yearly_price":"ili $29.99 godišnje","upgrade_btn":"Nadogradi sada","business":"Zainteresirani ste za kupnju Pro verzije za posao ili školu?","business_contact":"Kontaktirajte nas","themes":"Teme","themes_desc":"Bolje vidi svoju pozadinu uz tamne i prozirne teme","bgs":"Aktivne pozadine","bgs_desc":"Oživi svoju stranicu sa 20 aktivnih HD pozadina","widgets":"Proširi widgete","widgets_desc":"Nadogradi ProductivityTab na novu razinu uz proširene widgete","more_header":"I više","stocks":"Dionice u stvarnom vremenu uz proširene i povijesne podatke","rss":"Podrška za više RSS feed-ova po widgetu","sports":"Općenite ili specifične za ligu informacije o sportu","tabbed_widgets":"Prošireni widgeti za vijesti i RSS","bg_downloads":"Pozadine koje se mogu preuzeti","weather":"Prognoza po satu za 10 dana unaprijed","toolbar":"Više linkova na traci","ads":"Potpuno iskustvo bez reklama","support":"Prioritizirana podrška i prijedlozi","buy_pro":"Kupi Pro"},"checkout":{"title":"Kupnja","updating_title":"Plan","payment_options":"Plati","pay_monthly":"Mjesečno ($4.99)","pay_yearly":"Godišnje ($29.99)","cancel":"Poništi","update":"Obnovi","subscribe":"Pretplati se","braintree_notice":"Uplate sigurno obrađuje Braintree.","monthly_notice":"Ako se pretplatite, ovlašćujete ProductivityTab da vam naplati $4.99 svaki mjesec sve dok ne otkažete pretplatu.","yearly_notice":"Ako se pretplatite, ovlašćujete ProductivityTab da vam naplati $29.99 svaki mjesec sve dok ne otkažete pretplatu.","update_notice":"Iako se ciklus naplate promijeni odmah, ne će vam biti naplaćeno dok trenutni ciklus ne završi.","thank_you":"Hvala ti na kupnji ProductivityTab Pro verzije!","thank_you2":"ProductivityTab će se osvježiti za nekoliko sekunda i sve će biti spremno!","error":"Nešto je pošlo po zlu prilikom procesiranja vaše uplate.","error2":"Molimo pokušajte kasnije ili nam pošaljite mail na support@ichro.me","signin":"Prijavi se","signin_desc":"Trebaš se prijaviti prije kupnje Pro verzije da bi bili sigurni da si to ti","signin_btn":"Prijavi se"},"plan":{"title":"Plan","desc":"Trenutačno si pretplaćen na ProductivityTab Pro (%s)","types":{"monthly":"Mjesečni","yearly":"Godišnji","business":"Poslovni","education":"Obrazovni","custom":"Prilagođen"},"uneditable_desc":"Poslovni, obrazovni i prilagođeni planovi ne mogu se ažurirati iz ProductivityTab-a. Molimo <a href=\"mailto:support@ichro.me\">kontaktirajte nas</a> za ažuriranje ili otkazivanje pretplate.","status":"Status","status_active":"Aktivan","status_trial":"Trial","status_pastdue":"Datum dospijeća","subscription_date":"Datum pretplate","paid_through":"Plaćeno do","next_bill":"Sljedeći račun","next_bill_value":"$%s na datum %s","update_plan":"Plan","update_billing":"Ažuriraj naplatu","cancel":"Otkaži pretplatu","cancel_notice":"Vaša pretplata će biti otkazana odmah","cancel_notice2":"Ako želiš povrat novca, molimo kontaktiraj nas na support@ichro.me"}},"ads":{"text1":"ProductivityTab prikazuje nekoliko malih reklama kako bi serveri mogli biti plaćeni kao i daljni razvoj aplikacije. S ovim reklamama ProductivityTab može biti besplatan svakome.","text2":"Ovdje možeš odabrati mjesto prikazivanja reklama ili kupiti nadogradnju na Iskustvo bez oglasa.","text3":"Iskustvo bez oglasa je jednokratna kupnja koja trajno uklanja reklame iz ProductivityTab-a gdjegod si prijavljen. Također možeš nadograditi na Pro koji uz trajno uklanjanje reklama nudi još dodatne mogućnosti.","upgrade_btn":"Nadogradi na Iskustvo bez oglasa","already_upgraded":"Već ste nadograđeni na Iskustvo bez oglasa","signin":"Prijavi se","signin_desc":"Prijavi se prije nadogradnje tako da kupnja bude povezana s tvojim računom","signin_btn":"Prijavi se","thank_you":"Hvala vam na nadogradnji na Iskustvo bez oglasa!","placement":{"title":"Mjesto reklama","left":"U prvom stupcu","right":"U posljednjem stupcu","top":"Iznad kartice","bottom":"Na dnu zaslona"}}},"store":{"installation":"Instalacija","description":"Opis","preview":"Pregled","instructions":"Povuci i ispusti bilo koju veličinu na stranicu"},"widgets":{"sizes":{"tiny":"Sićušan","small":"Malen","medium":"Srednji","large":"Velik","variable":"Varijacijski"},"settings":{"title":"Postavke widgeta","save":"Spremi","size":"Veličine widgeta"},"minimize":"Minimiziraj","maximize":"Maksimiziraj","delete_confirm":"Jesi li siguran da želiš izbrisati taj widget?\nOva odluka je nepovratna; svi podaci widgeta bit će trajno izgubljeni.","permissions_request":{"title":"Pristup potreban","button":"Odobri pristup","desc":"Ovaj widget treba dodatne dozvole prije nego što se može koristiti. Ispuni ih koristeći gumb ispod."},"error":{"explanation":"Nešto je pošlo po zlu dok smo pokušavali prikazati ovaj widget.","advice":"Pokušaj ponovo instalirati widget ili ponovo učitati stranicu. Kontaktirajte nas ako često vidite ovu poruku.","support":"Podrška","refresh":"Osvježi"},"auth":{"message":"Morat ćete ovom widgetu dati pristup vašem računu prije no što će te ga moći koristiti.","button":"Odobri pristup"},"shared":{"settings":{"title":"Naslov widgeta","title_placeholder":"Unesi naslov widgeta ili ostavi prazno za skrivanje","height":"Visina widgeta","open_options":{"current":"Trenutna kartica","blank":"Nova kartica"},"footer_link":"Link podnožja","footer_link_options":{"show":"Prikaži","hide":"Sakrij"},"account":"ID računa","account_help":"Ako si prijavljen sa više računa, ovo je tvoja \"authuser=\" vrijednost.\n<br /><br />\nNpr. ako si prijavljen s dva računa, ihorvat1@gmail.com i ihorvat2@gmail.com, vrijednost \"authuser=\" za ihorvat2@gmail.com jest 1 zbog toga što je to drugi račun kojim si prijavljen (računajući od nule).","account_placeholder":"Tvoja \"authuser=\" vrijednost","on":"Uključeno","off":"Isključeno"}},"apps":{"name":"Aplikacije","desc":"Prikazuje trenutno instalirane Google Chrome aplikacije.","settings":{"format":"Format widgeta","format_options":{"tiles":"Pločice","list":"Lista"},"display":"Prikaži","display_options":{"all":"Sve aplikacije","enabled":"Samo omogućene aplikacije"},"sort":"Sortiranje","sort_options":{"id":"ID","alphabetically":"Abecednim redom","offline":"Dostupno izvanmrežno","available":"Dostupnost"},"open":"Otvori aplikacije u"},"store_app":"Trgovina"},"bookmarks":{"name":"Oznake","desc":"Prikazuje odabrane i prilagođene oznake te ostale linkove.","settings":{"title_placeholder":"Upiši naziv widgeta","layout":"Raspored","layout_options":{"single":"Jedan stupac","double":"Dva stupca"},"open":"Otvori oznake u"},"edit":{"dialog_title":"Uredi oznaku","title":"Naslov oznake","title_placeholder":"Google","url":"URL oznake","url_placeholder":"https://www.google.com/","save":"Spremi"},"new_caption":"Novi","new_bookmark":"Oznaka","new_folder":"Mapa","drop_link":"Ovdje ispusti link"},"chrome_bookmarks":{"name":"Oznake","desc":"Prikazuje Chrome oznake s mogučnošću prikazivanja posebne mape.","settings":{"title_placeholder":"Upiši naziv widgeta","from":"Prikaži oznake iz","open":"Otvori oznake u"}},"calc":{"name":"Računalo","desc":"Prikazuje kalkulator sa podrškom za osnovne operatore.","error":"Pogreška!","infinity":"Bez kraja","mismatch":"Problem sa zagradama"},"calendar":{"name":"Kalendar","desc":"Prikazuje nadolazeće događaje iz Google Kalendara.","settings":{"calendar":"Kalendar","show":"Prikaži događaje od","show_options":{"all":"Svo vrijeme","today":"Samo danas"}},"title":"Agenda","calendar":"Kalendar","noevents":"Nema događaja u bližoj budućnosti, izgleda da je tvoj raspored prazan!"},"clock":{"name":"Sat","desc":"Nudi alarm, trenutno vrijeme, brojač i štopericu.","settings":{"timezone":"Vremenska zona","timezone_local":"Lokalna","format":"Format sata","format_options":{"ampm":"AM/PM - Digitalni","24hour":"24 sata - Digitalni","analog":"12 sati - Analogni","ampmseconds":"AM/PM - Digitalni, bez sekunda","24hourseconds":"24 sata - Digitalni, bez sekunda"},"sound":"Zvuk upozorenja"},"title":"Sat","alarm":"Alarm","clock":"Sat","timer":"Vremenski brojač","stopwatch":"Štoperica","set":"Postavi","unset":"Odustani","dismiss":"Odbaci","enable_audio":"Omogući zvuk"},"facebook":{"name":"Facebook","desc":"Ugrađuje Facebook u widgetu"},"feedly":{"name":"Feedly","desc":"Prikazuje članke sa tvog Feedly računa u obliku koji se može konfigurirati.","settings":{"source":"Prikazuj članke od","source_feeds":"Feedovi","show":"Prikaži","show_options":{"all":"Svi članci","unread":"Samo nepročitani članci"},"layout":"Raspored","layout_options":{"titles":"Samo naslovi","magazine":"Magazin","cards":"Kartice","cards_columns":"Kartice (dva stupca)"},"mark":"Označi članak kao pročitan kada","mark_options":{"scroll":"Prođi to ili klikni to","click":"Samo klikni"},"sort":"Redoslijed sortiranja","sort_options":{"newest":"Prvo najnovije","oldest":"Prvo najstarije"}},"all":"Sve","saved":"Spremljeno za kasnije","uncategorized":"Nekategorizirano","author":"napisao","go_to_feedly":"Idi na Feedly"},"notes":{"name":"Bilješke","desc":"Umeće jednostavnu bilješku koja se može uređivati.","settings":{"color":"Boja bilješke","color_options":{"yellow":"Žuto","orange":"Narančasto","red":"Crveno","blue":"Plavo","green":"Zeleno","white":"Bijelo"},"font":"Font","fontsize":"Veličina fonta"}},"now":{"name":"Google Now","desc":"Prikazuje kartice sa Google Now-a, uključujući stanje letova i praćenje paketa.","authorize":"ProductivityTab-u morate dati dozvolu za prikaz Google Now kartica da bi se ovdje nešto prikazivalo.","authorize_btn":"Autoriziraj","caught_up":"Sada sve znate.","no_title":"Bez naslova"},"plus":{"name":"Google+","desc":"Ugrađuje Google Plus u widgetu"},"notifications":{"name":"Google obavijesti","desc":"Prikazuje Google obavijesti od usluga kao što je Google+"},"reddit":{"name":"Reddit","desc":"Prikazuje najpopularnije stavke na Reddit-u za bilo koji zadani subreddit.","settings":{"subreddit":"Subreddit","subreddit_help":"Unesi subreddit kao dio nakon <b>/r/</b>.\n<br /><br />\nNa primjer, \"Technology\" je: <a href=\"https://www.reddit.com/r/technology\">https://www.reddit.com/r/technology</a>, dakle, unio bi <b>technology</b>","subreddit_placeholder":"Unesi subreddit (npr. technology)","sort":"Redoslijed sortiranja","sort_options":{"hot":"U trendu","top":"Popularno","new":"Novi","gilded":"Pozlaćeni","rising":"Rastuće","controversial":"Kontroverzno"},"links":"Prikazani linkovi","click":"Kada kliknem link pokaži","click_options":{"link":"Link","comments":"Komentari"}},"more":"Više"},"tasks":{"name":"Zadaci","desc":"Prikazuje listu zadataka sa Google Zadataka.","title":"Zadaci","settings":{"list":"Lista"},"task_title":"Naslov","due_date":"Krajnji dan","notes":"Bilješke","add":"Dodaj stavku","delete_task":"Izbriši zadatak","move_up":"Pomakni gore","move_down":"Pomakni dolje","done":"Završeno","due_today":"Do danas","overdue":"Prekoračen rok","authorize":"Morat ćeš odabrati listu iz Google Zadataka putem postavka prije nego što išta može biti prikazano ovdje."},"twitter":{"name":"Twitter","desc":"Prikazuje tweetove sa tvog streama ili posebne liste.","settings":{"source":"Pokaži tweetove od","show":"Tweetovi prikazani"},"authorize":"Prvo ćete morati autorizirati ProductivityTab","authorize_msg":"Morat ćeš dati ProductivityTab-u dozvolu za prikaz tweetova sa tvog računa da bi se prikazali ovdje.","authorize_btn":"Autoriziraj","no_tweets":"Izgleda da ovdje nema tweetova...","home":"Početna","mentions":"Spominjanja","retweets":"Retweetovi mene","lists":"Liste","more":"Više","reply":"Odgovori","retweet":"Retweet","favorite":"Favoriti"},"wolfram":{"name":"Wolfram|Alpha","desc":"Umeće malo Wolfram|Alpha pretraživanje."},"youtube":{"name":"YouTube","desc":"Prikazuje ili popularne videozapise ili videozapise od određenog korisnika.","settings":{"format":"Format","format_options":{"large":"Jedna velika","large_2":"Jedna velika, dvije male","large_4":"Jedna velika, četiri male","four":"Četiri male","six":"Šest malih"},"from":"Pokaži videozapise od","from_help":"Ovo mora biti <b>točno</b> korisničko ime koje je prikazano u URL-u stranice kada je prikazan taj račun.\n<br /><br />\nNikad ne uključuje razmake.","from_placeholder":"Ostavite prazno za prikaz najpopularnijih videozapisa","open":"Otvori rezultate pretraživanja u"},"search":"Pretraži YouTube","num_views":"pog."},"quotes":{"name":"Citati","desc":"Prikazuje novi citat jedanput dnevno ili prilikom svakog učitavanja stranice.","settings":{"source":"Izvor","method":"Učitaj nove citate","method_options":{"daily":"Jedanput dnevno","random":"Svaki put kad učitam stranicu"}},"unknown_author":"Nepoznati autor"},"html":{"name":"HTML","desc":"Prikazuje potpuno prilagođeni HTML u pametnom okviru.","settings":{"html":"HTML","js":"JavaScript","height":"Visina widgeta"}},"sitelink":{"name":"Link stranice","desc":"Prikazuje link, po želji s nazivom i sličicom","settings":{"link":"URL linka","link_placeholder":"https://www.google.com/","image":"URL slike","image_placeholder":"https://www.example.com/image.png","color":"Boja pozadinske slike","style":"Stil slike","style_fill":"Popuni","style_center":"Sredina"}},"stats":{"name":"Statistike sustava","desc":"Prati svoj sustav sa statistikama u stvarnom vremenu","memory":"RAM","battery":"Baterija","usage":"korištenje","in_use":"u uporabi","remaining":"preostaje","charged":"Napunjeno","idle":"Mirovanje","charging":"Punjenje","discharging":"Pražnjenje"},"search":{"name":"Pretraživaje","desc":"Ugrađuje pretraživanje za laki pristup","settings":{"placeholder":"Naziv polja za pretraživanje","search_url":"URL za pretraživanje","param":"Parametar upita","param_placeholder":"Parametar gdje upit odlazi, npr. \"q\""},"default_placeholder":"Pretraži Google"},"pushbullet":{"name":"Pushbullet","desc":"Prati obavijesti sa mobitela i drugih uređaja","no_pushes":"Nema pusheva","sign_in":"Prijavi se","no_key":"Izgleda da nisi prijavljen u Pushbullet.  Prijavi se sada."},"linkedin":{"name":"LinkedIn","desc":"Prikazuje tvoj LinkedIn stream"},"directions":{"name":"Upute","desc":"Upute od i do gotovo svakog mjesta na svijetu","driving":"Vožnja","transit":"Javni prijevoz","walking":"Pješice","cycling":"Biciklom","from":"Početna točka","to":"Krajnja točka","loading":"Učitavanje uputa, molimo pričekajte...","error":"Nešto je pošlo po zlu prilikom učitavanja uputa koje si tražio.","error2":"Molimo provjeri ispravnost početne i krajnje točke.","open_in_maps":"Otvori u Google Kartama","via":"putem"},"pocket":{"name":"Pocket","desc":"Prikazuje listu spremljenih članaka, videozapisa i web-stranica sa Pocket-a","settings":{"links_shown":"Broj prikazanih linkova","open":"Otvori linkove","open_pocket":"U Pocket-u","open_original":"Na originalnom URL-u"},"by":"Autor","no_links":"Nema linkova","grant_access":"Odobri pristup","no_key":"Morat ćeš dati ProductivityTab-u pristup svom Pocket računu da bi se ovdje prikazali linkovi."}},"themes":{"title":"Teme","all":"Sve","custom":"Prilagođena","create":"Stvori temu","url_or_upload":"ili","upload_image":"Uploadaj sliku","edit_btn":"Uredi","delete":"Izbriši","use":"Koristi","preview":"Pregled","author":"Autor","images":"%s slika","resolution":"Rezolucija","categories":"Kategorije","cached":"Ova tema je pohranjena u međuspremniku te je dostupna izvan mreže","random":"Ova tema prikazuje nasumičnu sliku prilikom svakog osvježenja stranice","random_daily":"Ova tema prikazuje nasumičnu sliku svaki dan","sunrise_sunset":"Ova tema prikazuje različitu sliku prema dobu dana","feed":"Ova tema prikazuje novu sliku svaki dan iz vanjskih izvora","video":"Ova tema prikazuje aktivan videozapis","pro_only":"Ova tema je dostupna isključivo Pro korisnicima. Kupi Pro u postavkama.","delete_confirm":"Jesi li zaista siguran da želiš izbrisati ovu temu?\nOva akcija je nepovratna; cijela tema bit će potpuno izgubljena.","delete_error":"Dogodila se pogreška prilikom brisanja teme. Pokušaj ponovo kasnije.","feed_fetching":"Molimo pričekajte, prikupljanje feed-a...","feed_error":"Nešto je pošlo po zlu prilikom skupljanja feed-a. Pokušaj ponovo kasnije.","caching":"Molimo pričekajte, pohranjivanje teme...","cache_status":"%s od %s slika pohranjeno","cache_error":"Došlo je do pogreške prilikom pohranjivanja teme.  Pokušaj ponovo kasnije","bginfo":{"view":"Prikaz","source":"Izvor","unknown":"Nepoznato","download":"Preuzmi","pro_only":"Samo Pro korisnici mogu preuzeti pozadinske slike i videozapise"},"edit":{"title":"Uredi temu","create_title":"Napravi temu","name":"Naziv teme","default_name":"Nova tema","name_placeholder":"Unesi naziv teme","image":"URL slike","image_placeholder":"Unesi URL slike pozadine","image_help":"Postavljene slike <b>nije moguće sinkronizirati</b> između kompjutera.<br /><br />Molimo uploadaj slike na servis kao na primjer <a href=\"https://imgur.com/\" target=\"_blank\">imgur</a>. Zatim kopiraj URL slike (najčešće .jpg) i zalijepi ga na polje lijevo.","color":"Pozadinska boja","color_placeholder":"Unesi naziv bilo koje boje","position":"Pozicija","position_options":{"center":"Sredina","top_left":"Gore lijevo","top_center":"Gore u sredini","top_right":"Gore desno","bottom_left":"Dolje lijevo","bottom_center":"Dolje u sredini","bottom_right":"Dolje desno"},"scaling":"Skaliranje","scaling_options":{"auto":"Automatsko","width":"Puna širina","height":"Puna visina","none":"Bez skaliranja (pregled je možda neprecizan)"},"repeat":"Ponavljanje slike","repeat_options":{"none":"Bez ponavljanja","horizontal":"Ponavljanje vodoravno","vertical":"Ponavljanje okomito","both":"Ponavljanje u oba smjera"},"attach":"Postavi sliku na","attach_tab":"Karticu","attach_window":"Prozor","preview":"Pregled","save":"Spremi i Zatvori","cache_error":"Došlo je do pogreške prilikom pohranjivanja slike koju si unio, molimo provjeri URL.","upload_error":"Došlo je do pogreške prilikom uploadanja datoteke koju si unio, molimo da provjeriš je li slika prihvatljive veličine."}}},"id":{"lang_code":"id","language":"Bahasa Indonesia","extName":"ProductivityTab — Custom Homepage Dashboard","newtabName":"ProductivityTab — Custom New Tab Dashboard","extDescription":"A remarkably customizable personal homepage featuring 50+ widgets, breathtaking backgrounds and much more.","newtabDescription":"A customizable personal dashboard on your new tab page featuring 50+ widgets, breathtaking backgrounds and much more.","defaults":{"tab":"Beranda","me":"Saya"},"remove_widget":"Hapus","hide_banner":"Hide this banner","hide_ad":{"content":"Hey! We're not crazy about ads either, but we're only able to make ProductivityTab available and continue developing features for our free users (that's you!) by showing ads. If you'd like to support ProductivityTab directly and get rid of ads for free, we would really appreciate if you upgraded to our pro version","upgrade":"Upgrade","hide":"Hide ads"},"alert":{"default_button":"Hentikan","confirm_title":"Apakah Anda yakin akan melakukan ini?","confirm_continue":"Teruskan","confirm_cancel":"Batalkan"},"onboarding":{"modal":{"tagline":"Semua situs dan aplikasi yang Anda gunakan, dalam satu tempat","wrong_extension":"Want ProductivityTab on your new tab page instead?","wrong_extension_newtab":"Want ProductivityTab on your home page instead?","wrong_extension_action":"Click here","about":"ProductivityTab's all about tabs and widgets","about_desc":"Tabs are pages filled with widgets - blocks that show things like the weather, news, and your email. You can customize most widgets and add as many as you want.","terms":"By checking, you agree to ProductivityTab's <a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\">Terms</a> and <a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\">Privacy Policy</a>","sign_in":"Sign in with your Google account","sign_in_desc":"Sign in with your Google account before getting started to securely save your changes online.","sign_in_desc2":"You can stay signed out if you want, but your page won't be saved online and you won't be able to access it from other computers.","sign_in_button":"Sign in with Google","have_account":"It looks like you already have an account!","have_account_desc":"All your tabs and widgets are ready to use!","get_started":"Let's get started!","get_started_desc":"You're good to go! Let's get your page set up."},"widgets":{"configure":"Let's configure a widget.","configure_desc":"Click the wrench to open a widget's <b>settings</b>.","configure_skip":"Skip Tutorial","settings":"Replace <b>Link URL</b> with your favorite site, then press <b>Save</b>.","move":"You can <b>reposition</b> widgets by clicking and dragging the three dots highlighted here.","remove":"To <b>delete</b>, simply click the red trash bin icon.","done":"Got it"},"settings":{"intro":"Now let’s add a new widget. This highlighted button is where you can access the Widget Menu.","instructions":"Click the new widget button on to open the widget menu!","skip":"Skip","tooltips":{"settings":"Change the way ProductivityTab looks and works","widgets":"Add new widgets - you can have as many as you want","editing":"Show or hide the editing buttons on widgets","links":"This is a list of links, add sites you use often in the settings","tabs":"These are your tabs. You can add more in the settings","support":"Send us a message or leave a review here"},"finished":"That's it!","finished_next":"Choose an option from the menu (try starting with <b>Widgets</b>) and set your page up!","finished_contact":"Use the support link if you need any help and we'll get back to you ASAP."}},"storage":{"signin":"Sign in with Google now to securely save and sync your configuration","signin_btn":"Sign in","signin_dismiss":"Dismiss","signin_confirm":{"title":"Keep local data?","desc":"Would you like to keep your local data, and replace the configuration in your account with it, or replace this computer's configuration with the one already in your account?","keep_account":"Use account","keep_local":"Keep local"},"signout_confirm":"Signing out will erase your local backups","pastdue":"Your subscription is past due","pastdue_desc":"Please update your billing information in the settings"},"toolbar":{"placeholder":"Search the web","placeholder_ok":"Enter your terms or say \"OK, Google\"","suggestions":{"url_subtext":"Visit URL","capture_notice":"ProductivityTab handles searches you normally make from the Omnibox. You can disable this at any time from the settings"},"apps":{"search":"Search","youtube":"YouTube","maps":"Maps","play":"Play","news":"News","gmail":"Gmail","drive":"Drive","calendar":"Calendar","more":"More"}},"menu":{"settings":"Settings","widgets":"Widgets","editing":"Editing","editing_enabled":"Enabled","editing_disabled":"Disabled","plus":"Google Plus","tabs":"Tabs","footer":{"support":"Support","feedback":"Feedback","review":"Review","terms":"Terms","privacy":"Privacy","by":"By Avi Kohn"}},"voice":{"listening":"Listening...","searching":"Searching for: %s","missed":"Didn't get that. <a>Try Again</a>"},"settings":{"title":"Settings","exit":"Exit settings","saved":"Settings saved","nav":{"visual":"Visual","visual_sections":{"background":"Background","layout":"Layout","theme":"App theme","ad_placement":"Ad placement"},"toolbar":"Toolbar","toolbar_sections":{"style":"Style","search":"Search","links":"Links"},"tabs":"Tabs","widgets":"Widgets","ads":"Ads","pro":"Pro","accounts":"Account","misc":"Miscellaneous","advanced":"Advanced","advanced_sections":{"backups":"Backup and restore","css":"Custom CSS","debug_tools":"Debug tools"},"support":"Help and support","suggest":"Suggest a feature"},"visual":{"background":{"title":"Background","desc":"This is the image or set of images shown as a background to your tabs","current":"Current background","custom":"Custom","unnamed":"Theme %s","select":"Select a theme","or":"or","url_placeholder":"Enter an image URL"},"layout":{"title":"Layout","desc":"Here you can adjust the type and number of columns in each tab","columns":"Columns","grid":"Grid","columns_number":"Number of columns","column_width":"Column width","column_width_fixed":"Fixed","column_width_fluid":"Fluid","column_warning":{"column_to_grid":"Changing to a grid-based layout will move all of your widgets to the top left corner.","grid_to_column":"Changing to a column-based layout will move all of your widgets to the first column."}},"theme":{"title":"App theme","desc":"The app theme controls the style of ProductivityTab itself and all widgets","preview":"Preview","light":"Light (default)","dark":"Dark","transparent":"Transparent","transparent_darker":"Transparent (darker)"}},"toolbar":{"style":{"title":"Style","desc":"This controls the style of the toolbar.  It can either appear normally or as an out of the way button","normal":"Normal","button":"Button"},"search":{"title":"Search","desc":"These settings control how the search box and voice search function","engine":"Search engine","engines_default":"Default","engines_custom":"Custom","engines_custom_desc":"Enter a URL that queries should be sent to, with <b>%s</b> where the query should go.","omnibox_capture":"Handle searches normally made in the Omnibox","voice":"Enable voice search","ok_google":"Enable \"OK Google\" hotword detection","search_tab":"Open search results in a new tab"},"links":{"title":"Links","desc":"These are the items shown at the right of the toolbar","apps":"Apps menu","custom":"Custom links","custom_note1":"Maximum of 3 allowed","custom_note2":"users get 8","custom_name_placeholder":"Link text","custom_url_placeholder":"Link URL, i.e. https://www.google.com/"}},"misc":{"link_tab":"Open links in a new tab by default"},"tabs":{"create_new":"Create new","make_default":"Make default","desc1":"Tabs are pages inside ProductivityTab. Each tab has its own set of widgets that is completely separate from every other tab.","desc2":"You can switch between tabs by clicking the buttons that appear at the left and right of the screen when you move your mouse over a tab or by using the arrow keys on your keyboard.","name_placeholder":"Enter a tab name","delete_confirm":"This action is irreversible. All data from all widgets in the tab will be permanently lost."},"accounts":{"status":{"title":"Status","signed_in":"You are currently <b>signed in</b> as %s (%s).","reset_account":"Reset account","sign_out":"Sign out","signed_out":"You are <b>not currently signed in</b>. Sign in with your Google account now to securely store and sync your configuration.","sign_in":"Sign in with Google"},"reset_confirm_desc":"This will erase all local and synced data, there is no backup and no way to undo this.","reset_confirm_desc2":"You will lose your entire current configuration on all computers connected to this account."},"advanced":{"backups":{"title":"Backup and restore","desc":"Backups are complete copies of all your tabs, settings, and widgets. They're automatically created when you first open ProductivityTab each day.","desc2":"Use the buttons below to roll ProductivityTab back to a particular date or download one of your backups.","backup":"Backup now","upload":"Restore from file","download":"Download","restore":"Restore","download_name":"ProductivityTab Backup","restore_confirm":"This will overwrite all local and synced data. You will lose your entire current configuration on all computers under this account.","restore_error":"An error occurred while trying to parse the provided data, please try again later."},"css":{"title":"Custom CSS","desc":"You can use CSS (<a href=\"https://developer.mozilla.org/en-US/docs/Web/CSS\" target=\"blank\">definition</a>) to customize almost any part of ProductivityTab.","placeholder":"Enter up to 1000 characters of CSS here"},"debug_tools":{"title":"Debug tools","desc":"<b>WARNING:</b> These tools can erase your entire configuration in a single click. Only use them if your developer instructs you to.","open":"Open tools"}},"widgets":{"desc1":"Widgets have their own settings and can't be customized here.","desc2":"To edit a widget's settings, follow these steps:","steps1":"Move your mouse over any widget","steps2":"Click the wrench icon that appears at the top right of the widget. If none appears then the widget doesn't have any settings that can be customized.","steps3":"Edit any of the settings shown in the dialog that's displayed","steps4":"Click Save to save your changes, or any part of the background to discard of them"},"pro":{"promo":{"monthly_price":"$4.99 per month","yearly_price":"or $29.99 per year","upgrade_btn":"Upgrade Now","business":"Interested in buying Pro for your business or school?","business_contact":"Contact us","themes":"Themes","themes_desc":"See more of your backgrounds with dark and transparent themes","bgs":"Live backgrounds","bgs_desc":"Bring your page to life with 20 live high-definition backgrounds","widgets":"Maximizable widgets","widgets_desc":"Take ProductivityTab to another level with maximizable widgets","more_header":"And more","stocks":"Realtime stocks with extended and historical information","rss":"Support for multiple RSS feeds per widget","sports":"General and league-specific sports news","tabbed_widgets":"Tabbed news and RSS widgets","bg_downloads":"Downloadable backgrounds","weather":"Hourly weather forecasts up to 10 days out","toolbar":"More toolbar links","ads":"A completely ad-free experience","support":"Prioritized support and suggestions","buy_pro":"Buy Pro"},"checkout":{"title":"Checkout","updating_title":"Update plan","payment_options":"Pay","pay_monthly":"Monthly ($4.99)","pay_yearly":"Yearly ($29.99)","cancel":"Batalkan","update":"Update","subscribe":"Subscribe","braintree_notice":"Payments securely processed by Braintree.","monthly_notice":"By subscribing, you authorize ProductivityTab to charge you $4.99 every month until you cancel your subscription.","yearly_notice":"By subscribing, you authorize ProductivityTab to charge you $29.99 every year until you cancel your subscription.","update_notice":"Although billing cycle changes take effect immediately, you won't be charged until your current cycle ends.","thank_you":"Thank you for buying ProductivityTab Pro!","thank_you2":"ProductivityTab will reload in a few seconds and you'll be all set!","error":"Something went wrong while trying to process your payment.","error2":"Please try again later or email us at support@ichro.me","signin":"Sign in","signin_desc":"You need to sign in before buying Pro so we can make sure it's you","signin_btn":"Sign in"},"plan":{"title":"Plan","desc":"You are currently subscribed to ProductivityTab Pro (%s)","types":{"monthly":"Monthly","yearly":"Yearly","business":"Business","education":"Education","custom":"Custom"},"uneditable_desc":"Business, education, and custom plans cannot be updated from within ProductivityTab. Please <a href=\"mailto:support@ichro.me\">contact us</a> to update or cancel your subscription.","status":"Status","status_active":"Active","status_trial":"Trial","status_pastdue":"Past due","subscription_date":"Subscription date","paid_through":"Paid through","next_bill":"Next bill","next_bill_value":"$%s on %s","update_plan":"Update plan","update_billing":"Update billing","cancel":"Cancel subscription","cancel_notice":"Your subscription will be canceled immediately","cancel_notice2":"If you would like a refund, please contact us at support@ichro.me"}},"ads":{"text1":"ProductivityTab displays a few small ads to pay for server, support and development costs. With these ads, we can afford to offer ProductivityTab free to everyone.","text2":"Here you can choose where those ads are shown, or buy ad-free to permanently remove them.","text3":"Ad-free is a one-time purchase that permanently removes ads from ProductivityTab wherever you're signed in. You can also upgrade to Pro for extra features in addition to an ad-free experience.","upgrade_btn":"Upgrade to ad-free","already_upgraded":"It looks like you've already upgraded to ad-free","signin":"Sign in","signin_desc":"Sign in before upgrading so we can link your purchase to your account","signin_btn":"Sign in","thank_you":"Thank you for upgrading to ad-free!","placement":{"title":"Ad placement","left":"In the leftmost column","right":"In the rightmost column","top":"Above the tab","bottom":"Floating at the bottom"}}},"store":{"installation":"Installation","description":"Description","preview":"Preview","instructions":"Drag and drop any size onto your homepage"},"widgets":{"sizes":{"tiny":"Tiny","small":"Small","medium":"Medium","large":"Large","variable":"Variable"},"settings":{"title":"Widget Settings","save":"Save","size":"Widget Size"},"minimize":"Minimize","maximize":"Maximize","delete_confirm":"Are you really sure you want to delete this widget?\r\nThis action is irreversible; all data from this widget will be permanently lost.","permissions_request":{"title":"Access required","button":"Grant Access","desc":"This widget needs extra permissions before it can be used. Grant them using the button below."},"error":{"explanation":"Something went wrong while we were trying to display this widget.","advice":"Try reinstalling the widget or reloading the page. Contact us if you see this message often.","support":"Support","refresh":"Refresh"},"auth":{"message":"You'll need to give this widget access to your account before you can use it.","button":"Grant Access"},"shared":{"settings":{"title":"Widget Title","title_placeholder":"Enter a widget title or leave blank to hide","height":"Widget Height","open_options":{"current":"The current tab","blank":"A new tab"},"footer_link":"Footer Link","footer_link_options":{"show":"Show","hide":"Hide"},"account":"Account ID","account_help":"If you're signed into multiple accounts, this is the \"authuser=\" value.\n<br /><br />\nFor example, if you're signed into two accounts, jsmith1@gmail.com and jsmith2@gmail.com, the \"authuser\" value for jsmith2@gmail.com would be 1 since it's the second account (counting from zero) that you're signed into.","account_placeholder":"Your \"authuser=\" value","on":"On","off":"Off"}},"apps":{"name":"Apps","desc":"Displays your currently installed Google Chrome applications.","settings":{"format":"Widget Format","format_options":{"tiles":"Tiles","list":"List"},"display":"Show","display_options":{"all":"All apps","enabled":"Only enabled apps"},"sort":"Sort","sort_options":{"id":"ID","alphabetically":"Alphabetically","offline":"Offline Enabled","available":"Availability"},"open":"Open apps in"},"store_app":"Store"},"bookmarks":{"name":"Bookmarks","desc":"Displays selected and customized bookmarks, and other links.","settings":{"title_placeholder":"Enter a widget title","layout":"Layout","layout_options":{"single":"Single column","double":"Double column"},"open":"Open bookmarks in"},"edit":{"dialog_title":"Edit Bookmark","title":"Bookmark Title","title_placeholder":"Google","url":"Bookmark URL","url_placeholder":"https://www.google.com/","save":"Save"},"new_caption":"New","new_bookmark":"Bookmark","new_folder":"Folder","drop_link":"Drop link here"},"chrome_bookmarks":{"name":"Bookmarks","desc":"Displays your Chrome bookmarks, optionally from a specific folder.","settings":{"title_placeholder":"Enter a widget title","from":"Show bookmarks from","open":"Open bookmarks in"}},"calc":{"name":"Calculator","desc":"Displays a calculator with support for basic operators.","error":"Error!","infinity":"Infinity","mismatch":"Mismatched parentheses"},"calendar":{"name":"Calendar","desc":"Displays upcoming events from one or more of your Google calendars.","settings":{"calendar":"Calendar","show":"Show events from","show_options":{"all":"All time","today":"Today only"}},"title":"Agenda","calendar":"Calendar","noevents":"No events found in the near future, it looks like your schedule's clear!"},"clock":{"name":"Clock","desc":"Offers alarm, time, timer, and stopwatch functionality.","settings":{"timezone":"Time Zone","timezone_local":"Local","format":"Clock Format","format_options":{"ampm":"AM/PM - Digital","24hour":"24 Hour - Digital","analog":"12 Hour - Analog","ampmseconds":"AM/PM - Digital, No Seconds","24hourseconds":"24 Hour - Digital, No Seconds"},"sound":"Alert Sound"},"title":"Clock","alarm":"Alarm","clock":"Clock","timer":"Timer","stopwatch":"Stopwatch","set":"Set","unset":"Unset","dismiss":"Dismiss","enable_audio":"Enable audio"},"facebook":{"name":"Facebook","desc":"Embeds Facebook in a widget"},"feedly":{"name":"Feedly","desc":"Displays articles from your Feedly account in a configurable format.","settings":{"source":"Show articles from","source_feeds":"Feeds","show":"Show","show_options":{"all":"All articles","unread":"Only unread articles"},"layout":"Layout","layout_options":{"titles":"Titles only","magazine":"Magazine","cards":"Cards","cards_columns":"Cards (two columns)"},"mark":"Mark an article as read when I","mark_options":{"scroll":"Scroll past it or click it","click":"Just click it"},"sort":"Sort Order","sort_options":{"newest":"Newest first","oldest":"Oldest first"}},"all":"All","saved":"Saved for later","uncategorized":"Uncategorized","author":"by","go_to_feedly":"Go To Feedly"},"notes":{"name":"Notes","desc":"Inserts a simple, editable, note.","settings":{"color":"Note Color","color_options":{"yellow":"Yellow","orange":"Orange","red":"Red","blue":"Blue","green":"Green","white":"White"},"font":"Font Face","fontsize":"Font Size"}},"now":{"name":"Google Now","desc":"Displays cards from Google Now including flight status and package tracking.","authorize":"You'll need to give ProductivityTab permission to view your Google Now cards before anything will show up here.","authorize_btn":"Authorize","caught_up":"All caught up, nothing here.","no_title":"No Title"},"plus":{"name":"Google+","desc":"Embeds Google Plus in a widget"},"notifications":{"name":"Google Notifications","desc":"Displays your Google Notifications from services such as Google+"},"reddit":{"name":"Reddit","desc":"Displays the top items on Reddit for any given subreddit.","settings":{"subreddit":"Subreddit","subreddit_help":"Enter any subreddit by the part past <b>/r/</b> when on Reddit.\n<br /><br />\nFor example, Technology is at: <a href=\"https://www.reddit.com/r/technology\">https://www.reddit.com/r/technology</a>, therefore you would enter <b>technology</b>","subreddit_placeholder":"Enter a subreddit to show links from. (i.e. technology)","sort":"Sort Order","sort_options":{"hot":"Hot","top":"Top","new":"New","gilded":"Gilded","rising":"Rising","controversial":"Controversial"},"links":"Links Shown","click":"When I click a link show me","click_options":{"link":"The link","comments":"The comments"}},"more":"More"},"tasks":{"name":"Tasks","desc":"Displays an editable list of tasks from one of your Google Tasks lists.","title":"Tasks","settings":{"list":"List"},"task_title":"Title","due_date":"Due date","notes":"Notes","add":"Add Item","delete_task":"Delete Task","move_up":"Move Up","move_down":"Move Down","done":"Done","due_today":"Due today","overdue":"Overdue","authorize":"You'll need to select a list from your Google Tasks via the settings before anything can be displayed here."},"twitter":{"name":"Twitter","desc":"Displays tweets from your home stream or a specified list.","settings":{"source":"Show Tweets from","show":"Tweets Shown"},"authorize":"You'll need to authorize ProductivityTab first","authorize_msg":"You'll need to give ProductivityTab permission to view tweets from your account before anything will show up here.","authorize_btn":"Authorize","no_tweets":"There don't seem to be any tweets here...","home":"Beranda","mentions":"Mentions","retweets":"Retweets of me","lists":"Lists","more":"More","reply":"Reply","retweet":"Retweet","favorite":"Favorite"},"wolfram":{"name":"Wolfram|Alpha","desc":"Inserts a small Wolfram|Alpha search box."},"youtube":{"name":"YouTube","desc":"Displays either popular videos or videos from a specified user.","settings":{"format":"Format","format_options":{"large":"One large","large_2":"One large, two small","large_4":"One large, four small","four":"Four small","six":"Six small"},"from":"Show Videos From","from_help":"This must be an <b>exact</b> username as shown in the URL of the page when you're viewing their profile.\n<br /><br />\nThis value never includes spaces.","from_placeholder":"Leave blank to show Top Videos","open":"Open search results in"},"search":"Search YouTube","num_views":"views"},"quotes":{"name":"Quotes","desc":"Displays a quote picked either every time you load the page or once daily.","settings":{"source":"Source","method":"Load new quotes","method_options":{"daily":"Once daily","random":"Every time I load the page"}},"unknown_author":"Unknown"},"html":{"name":"HTML","desc":"Displays completely custom HTML in an iframe.","settings":{"html":"HTML","js":"JavaScript","height":"Widget Height"}},"sitelink":{"name":"Site Link","desc":"Displays a link, optionally with a title and thumbnail","settings":{"link":"Link URL","link_placeholder":"https://www.google.com/","image":"Image URL","image_placeholder":"https://www.example.com/image.png","color":"Image Background Color","style":"Image Style","style_fill":"Fill","style_center":"Center"}},"stats":{"name":"System Statistics","desc":"Keep an eye on your system with realtime statistics","memory":"Memory","battery":"Battery","usage":"usage","in_use":"in use","remaining":"remaining","charged":"Fully Charged","idle":"Idle","charging":"Charging","discharging":"Discharging"},"search":{"name":"Search","desc":"Embeds a search box in your page for easy access","settings":{"placeholder":"Search Field Placeholder","search_url":"Search URL","param":"Query Parameter","param_placeholder":"The parameter where the query goes, i.e. \"q\""},"default_placeholder":"Search Google"},"pushbullet":{"name":"Pushbullet","desc":"Keep track of notifications from your phone and other devices","no_pushes":"No pushes found","sign_in":"Sign in","no_key":"It doesn't look like you're signed in to Pushbullet.  Sign in now to connect this widget."},"linkedin":{"name":"LinkedIn","desc":"Displays your LinkedIn home stream"},"directions":{"name":"Directions","desc":"Get directions to and from nearly anywhere right from your homepage","driving":"Driving","transit":"Public Transit","walking":"Walking","cycling":"Cycling","from":"Enter a starting point","to":"Enter a destination","loading":"Loading directions, please wait...","error":"Something went wrong while trying to load the directions you requested.","error2":"Please check the start and destination addresses you entered.","open_in_maps":"Open in Google Maps","via":"via"},"pocket":{"name":"Pocket","desc":"Display a list of your saved articles, videos, and web pages from Pocket","settings":{"links_shown":"Number of links shown","open":"Open links","open_pocket":"In Pocket","open_original":"At their original URL"},"by":"By","no_links":"No links found","grant_access":"Grant access","no_key":"You'll need to give ProductivityTab access to your Pocket account before it can load your links."}},"themes":{"title":"Themes","all":"All","custom":"Custom","create":"Create a theme","url_or_upload":"or","upload_image":"Upload an image","edit_btn":"Edit","delete":"Delete","use":"Use","preview":"Preview","author":"By","images":"%s images","resolution":"Resolution","categories":"Categories","cached":"This theme has been cached and is available offline","random":"This theme displays a random image every time you load the page","random_daily":"This theme displays an image picked randomly every day","sunrise_sunset":"This theme displays an image based on the time of day","feed":"This theme displays an image selected daily from an external feed","video":"This theme displays a live video","pro_only":"This theme is only available to Pro users. Buy Pro in the settings.","delete_confirm":"Are you really sure you would like to delete this theme?\r\nThis action is irreversible; the entire theme will be permanently lost.","delete_error":"An error occurred while trying to delete the theme.  Please try again later.","feed_fetching":"Please wait, fetching feed...","feed_error":"Something went wrong while trying to fetch the feed.  Please try again later.","caching":"Please wait, caching theme...","cache_status":"%s of %s images cached","cache_error":"An error occurred while trying to cache the theme.  Please try again later","bginfo":{"view":"View","source":"Source","unknown":"Unknown","download":"Download","pro_only":"Only Pro users can download background images and videos"},"edit":{"title":"Edit Theme","create_title":"Create Theme","name":"Theme Name","default_name":"New Theme","name_placeholder":"Enter a theme name","image":"Image URL","image_placeholder":"Enter a background image URL","image_help":"Uploaded images <b>cannot be synced</b> between computers.<br /><br />If this is important to you, please upload your image to a service such as <a href=\"https://imgur.com/\" target=\"_blank\">imgur</a>. Then copy the URL ending with an extension (i.e. .jpg) and paste it into the field on the left.","color":"Fallback Color","color_placeholder":"Enter any color name","position":"Position","position_options":{"center":"Center","top_left":"Top Left","top_center":"Top Center","top_right":"Top Right","bottom_left":"Bottom Left","bottom_center":"Bottom Center","bottom_right":"Bottom Right"},"scaling":"Scaling","scaling_options":{"auto":"Auto","width":"Full Width","height":"Full Height","none":"No Scaling (preview may be inaccurate)"},"repeat":"Image Repeat","repeat_options":{"none":"No Repeat","horizontal":"Repeat Horizontally","vertical":"Repeat Vertically","both":"Repeat Both"},"attach":"Attach Image To","attach_tab":"The tab","attach_window":"The window","preview":"Preview","save":"Save & Close","cache_error":"An error occurred while trying to cache the image you provided, please double-check the URL.","upload_error":"An error occurred while trying to upload the file you provided, please make sure that it's a reasonable size and an image."}}},"it":{"lang_code":"it","language":"Italiano","extName":"ProductivityTab — Custom Homepage Dashboard","newtabName":"ProductivityTab — Custom New Tab Dashboard","extDescription":"A remarkably customizable personal homepage featuring 50+ widgets, breathtaking backgrounds and much more.","newtabDescription":"A customizable personal dashboard on your new tab page featuring 50+ widgets, breathtaking backgrounds and much more.","defaults":{"tab":"Home","me":"Io"},"remove_widget":"Rimuovi","hide_banner":"Hide this banner","hide_ad":{"content":"Hey! We're not crazy about ads either, but we're only able to make ProductivityTab available and continue developing features for our free users (that's you!) by showing ads. If you'd like to support ProductivityTab directly and get rid of ads for free, we would really appreciate if you upgraded to our pro version","upgrade":"Upgrade","hide":"Hide ads"},"alert":{"default_button":"Scarta","confirm_title":"Sei sicuro di voler proseguire?","confirm_continue":"Continua","confirm_cancel":"Annulla"},"onboarding":{"modal":{"tagline":"Tutti i siti e le applicazioni che utilizzi, in un unico posto","wrong_extension":"Vuoi che ProductivityTab sostituisca la tua nuova scheda?","wrong_extension_newtab":"Vuoi che ProductivityTab diventi la tua home page?","wrong_extension_action":"Clicca qui","about":"ProductivityTab è fatto di tab e widget","about_desc":"I Tab (o Schede) sono pagine contenenti widget - riquadri che mostrano cose come il meteo, le news e le tue email. Puoi personalizzare la maggior parte dei widget e aggiungerne quanti ne vuoi.","terms":"Procedendo, accetti le<a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\">condizioni</a> e i<a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\">termini sulla privacy</a>","sign_in":"Registrati con il tuo account Google","sign_in_desc":"Accedi con il tuo account Google prima di cominciare per salvare in sicurezza le modifiche online.","sign_in_desc2":"Puoi non essere loggato se vuoi, ma la pagina non verrá salvata online e tu non avrai la possibilitá di accedervi da altri computer.","sign_in_button":"Accedi con Google","have_account":"Sembra che tu abbia già un account!","have_account_desc":"Tutte le schede e i widget sono pronti all'uso!","get_started":"Iniziamo!","get_started_desc":"Sei pronto per iniziare! Impostiamo la tua pagina."},"widgets":{"configure":"Configuriamo un widget.","configure_desc":"Click the wrench to open a widget's <b>settings</b>.","configure_skip":"Skip Tutorial","settings":"Replace <b>Link URL</b> with your favorite site, then press <b>Save</b>.","move":"You can <b>reposition</b> widgets by clicking and dragging the three dots highlighted here.","remove":"To <b>delete</b>, simply click the red trash bin icon.","done":"Ok"},"settings":{"intro":"Now let’s add a new widget. This highlighted button is where you can access the Widget Menu.","instructions":"Click the new widget button on to open the widget menu!","skip":"Salta","tooltips":{"settings":"Modificare l'aspetto e le funzioni di ProductivityTab","widgets":"Aggiungere nuovi widget - se ne possono avere quanti ne vuoi","editing":"Mostrare o nascondere i pulsanti di modifica sui widget","links":"Questo è un elenco di link, aggiungi i siti che si utilizzi spesso nelle impostazioni","tabs":"Queste sono le schede. È possibile aggiungerne più nelle impostazioni","support":"Inviaci un messaggio o lascia una recensione qui"},"finished":"Questo è tutto!","finished_next":"Scegli un'opzione dal menu (prova a partire con i <b>widget</b>) e imposta la tua pagina!","finished_contact":"Utilizzare il link di supporto se hai bisogno di aiuto e ti risponderemo al più presto."}},"storage":{"signin":"Accedi ora con Google per salvare e sincronizzare in modo sicuro la configurazione","signin_btn":"Accedi","signin_dismiss":"Scarta","signin_confirm":{"title":"Memorizza dati in locale (sul tuo Computer)?","desc":"Vuoi conservare i dati in locale e sostituire la configurazione nel tuo account con esso o sostituire la configurazione di questo computer con quello già presente nel tuo account?","keep_account":"Utilizza l'account","keep_local":"Salva in locale"},"signout_confirm":"L'accettazione cancellerà i backup locali","pastdue":"La tua iscrizione è scaduta","pastdue_desc":"Si prega di aggiornare i dati di fatturazione nelle impostazioni"},"toolbar":{"placeholder":"Inserisci i termini della tua ricerca","placeholder_ok":"Inserisci i termini della tua ricerca o pronuncia \"OK, Google\"","suggestions":{"url_subtext":"Visit URL","capture_notice":"ProductivityTab handles searches you normally make from the Omnibox. You can disable this at any time from the settings"},"apps":{"search":"Cerca","youtube":"YouTube","maps":"Maps","play":"Play","news":"Notizie","gmail":"Gmail","drive":"Drive","calendar":"Calendario","more":"Altro"}},"menu":{"settings":"Impostazioni","widgets":"Widgets","editing":"Modifiche","editing_enabled":"Attive","editing_disabled":"Disattivate","plus":"Google Plus","tabs":"Schede","footer":{"support":"Supporta","feedback":"Opinioni","review":"Recensisci","terms":"Condizioni del servizio","privacy":"Informativa sulla Privacy","by":"Di Avi Kohn"}},"voice":{"listening":"In ascolto...","searching":"cercando per: %s","missed":"Non ho capito. <a>Prova ancora</a>"},"settings":{"title":"Impostazioni","exit":"Esci dalle impostazioni","saved":"Impostazioni salvate","nav":{"visual":"Visualizzazione","visual_sections":{"background":"Sfondo","layout":"Aspetto","theme":"Tema dell'Applicazione","ad_placement":"Ad placement"},"toolbar":"Barra degli strumenti","toolbar_sections":{"style":"Stile","search":"Cerca","links":"Collegamenti"},"tabs":"Schede","widgets":"Widgets","ads":"Ads","pro":"Pro","accounts":"Profilo","misc":"Varie","advanced":"Avanzate","advanced_sections":{"backups":"Backup e ripristino","css":"Personalizza CSS","debug_tools":"Strumenti di debug"},"support":"Aiuto e supporto","suggest":"Suggerisci una funzione"},"visual":{"background":{"title":"Sfondo","desc":"Questa è l'immagine o il set di immagini mostrate come sfondo per le tue schede","current":"Sfondo in uso","custom":"personalizzato","unnamed":"Tema %s","select":"Seleziona un Tema","or":"o","url_placeholder":"Inserisci l'URL di un'immagine"},"layout":{"title":"Aspetto","desc":"Qui è possibile regolare il tipo e il numero di colonne in ogni scheda","columns":"Colonne","grid":"Griglia","columns_number":"Numero di colonne","column_width":"Larghezza della colonna","column_width_fixed":"Misura Fissa","column_width_fluid":"Misura variabile","column_warning":{"column_to_grid":"Modificando un layout basato su griglia sposterà tutti i widget nell'angolo superiore sinistro.","grid_to_column":"Modificando un layout basato su colonne sposterà tutti i widget nell'angolo superiore sinistro."}},"theme":{"title":"Tema dell'Applicazione","desc":"L'Applicazione del Tema controlla lo stile dello stesso ProductivityTab e di tutti i widgets","preview":"Anteprima","light":"Chiaro (impostazione predefinita)","dark":"Scuro","transparent":"Trasparente","transparent_darker":"Trasparente (più scuro)"}},"toolbar":{"style":{"title":"Stile","desc":"Questo controlla lo stile della barra degli strumenti. Può apparire o normalmente o come un pulsante","normal":"Normale","button":"Pulsante"},"search":{"title":"Cerca","desc":"Queste impostazioni controllano il motore di ricerca e la voce funzione di ricerca","engine":"Motori di Ricerca","engines_default":"Default","engines_custom":"personalizzato","engines_custom_desc":"Immettere un URL che devono essere inviate, con <b>%s</b> dove dovrebbe andare la query.","omnibox_capture":"Handle searches normally made in the Omnibox","voice":"Attivare la ricerca vocale","ok_google":"Attiva il rilevamento della frase chiave \"OK Google\"","search_tab":"Apri i risultati della ricerca in una nuova scheda"},"links":{"title":"Link","desc":"Questi sono gli elementi mostrati a destra della barra degli strumenti","apps":"Menu delle app","custom":"Link personalizzati","custom_note1":"Massimo di 3 ammessi","custom_note2":"gli utenti ottengono 8","custom_name_placeholder":"Testo del link","custom_url_placeholder":"URL del link, es: https://www.google.com/"}},"misc":{"link_tab":"Apre i link in una nuova scheda per Default"},"tabs":{"create_new":"Crea nuova","make_default":"Rendilo predefinito","desc1":"Le schede sono pagine all'interno di ProductivityTab. Ogni scheda ha il suo insieme di widget che è totalmente separato rispetto da ogni altra scheda.","desc2":"È possibile cambiare scheda cliccando i pulsanti che appaiono a sinistra e destra dello schermo quando muovi il mouse sopra una scheda, oppure tramite i tasti freccia sulla tastiera.","name_placeholder":"Inserire nome scheda","delete_confirm":"Quest'azione è irreversibile. Tutti i dati dei widgets nella scheda saranno persi definitivamente."},"accounts":{"status":{"title":"Stato","signed_in":"Hai effettuato l'<b>accesso</b> come %s (%s).","reset_account":"Ripristino account","sign_out":"Esci","signed_out":"Al momento <b>non hai effettuato l'accesso</b>. Accedi con il tuo account Google per salvare e sincronizzare la tua configurazione.","sign_in":"Accedi con Google"},"reset_confirm_desc":"Questo cancellerà tutti i tuoi dati locali e sincronizzati, non c'è alcun backup e non potrai tornare indietro.","reset_confirm_desc2":"Perderai tutta la tua configurazione corrente su tutti i computer collegati a questo account."},"advanced":{"backups":{"title":"Backup e ripristino","desc":"I backup sono copie complete di tutte le tue schede, impostazioni e widget. Sono creati automaticamente ogni giorno quando apri ProductivityTab la prima volta.","desc2":"Usa i pulsanti qui sotto per riportare ProductivityTab ad una data precisa o scarica uno dei tuoi backup.","backup":"Esegui il backup ora","upload":"Ripristina da un file","download":"Download","restore":"Ripristina","download_name":"Backup ProductivityTab","restore_confirm":"Questo sovrascriverà tutti i dati locali e sincronizzati. Perderai la tua intera configurazione corrente su tutti i computer con questo account.","restore_error":"Si è verificato un errore durante il tentativo di analizzare i dati forniti, si prega di riprovare più tardi."},"css":{"title":"Personalizza CSS","desc":"Puoi usare i CSS (<a href=\"https://developer.mozilla.org/en-US/docs/Web/CSS\" target=\"blank\">definizione</a>) per personalizzare quasi tutte le parti di ProductivityTab.","placeholder":"Inserire fino a 1000 caratteri CSS qui"},"debug_tools":{"title":"Strumenti di debug","desc":"<b>ATTENZIONE:</b>Questi strumenti possono eliminare completamente la tua configurazione in un singolo click. Utilizzali soltanto se guidato dal tuo sviluppatore.","open":"Aprire gli strumenti"}},"widgets":{"desc1":"I widget hanno le proprie impostazioni e non possono essere personalizzati qui.","desc2":"Per modificare le impostazioni di un widget, seguire i seguenti passi:","steps1":"Muovi il mouse su un qualsiasi widget","steps2":"Fare click sull'icona a forma di chiave inglese che appare nella parte superiore destra del widget. Se non appare nessuna icona il widget non dispone di impostazioni che possono essere personalizzate.","steps3":"Modificare le impostazioni visualizzate nella finestra di dialogo","steps4":"Clicca Salva per salvare le modifiche, o in qualunque parte dello sfondo per annullarle"},"pro":{"promo":{"monthly_price":"4.99$ al mese","yearly_price":"o 29.99$ all'anno","upgrade_btn":"Esegui ora l'upgrade","business":"Siete interessati all'acquisto della versione Pro per il lavoro o la scuola?","business_contact":"Contattaci","themes":"Temi","themes_desc":"Ammira gli sfondi con i temi scuri e trasparenti","bgs":"Sfondi live","bgs_desc":"Dai vita alla tua pagina con 20 sfondi in alta definizione","widgets":"Windget massimizabile","widgets_desc":"Porta ProductivityTab ad un altro livello con i Windgets massimizzabili","more_header":"E altro ancora","stocks":"Azioni di mercato in tempo reale con informazioni storiche estese","rss":"Supporto per più feed RSS per widget","sports":"Notizie generali e notizie del campionato selezionato","tabbed_widgets":"Schede per i widget di News e RSS","bg_downloads":"Sfondi scaricabili","weather":"Previsioni meteo orarie fino a 10 giorni","toolbar":"Altri link per la barra degli strumenti","ads":"A completely ad-free experience","support":"Priorità per supporto e suggerimenti","buy_pro":"Acquista la versione Pro"},"checkout":{"title":"Cassa","updating_title":"Piani di aggiornamento","payment_options":"Effettua il pagamento","pay_monthly":"Mensile (4.99$)","pay_yearly":"Annuale (29.99$)","cancel":"Annulla","update":"Aggiorna","subscribe":"Iscriviti","braintree_notice":"I pagamenti sono elaborati in modo sicuro da Braintree.","monthly_notice":"Mediante la sottoscrizione, si autorizza ProductivityTab a farti pagare 4.99 dollari ogni mese fino a quando non si annulla la sottoscrizione.","yearly_notice":"Mediante la sottoscrizione, si autorizza ProductivityTab a farti pagare 29.99 dollari ogni anno fino a quando non si annulla la sottoscrizione.","update_notice":"Anche se i cambiamenti al ciclo di fatturazione sono immediati, non ti sarà addebitato niente fino alla fine del ciclo corrente.","thank_you":"Grazie per aver acquistato ProductivityTab Pro!","thank_you2":"ProductivityTab ricaricherà in pochi secondi e sarà tutto impostato!","error":"Qualcosa è andato storto durante il tentativo di elaborare il pagamento.","error2":"Si prega di riprovare più tardi o scrivere a support@ichro.me","signin":"Accedi","signin_desc":"È necessario accedere prima dell'acquisto della versione Pro in modo da assicurarci che sei tu","signin_btn":"Accedi"},"plan":{"title":"Piano","desc":"Sei attualmente iscritto ad ProductivityTab Pro (%s)","types":{"monthly":"Mensilmente","yearly":"Annualmente","business":"Affari","education":"Educazione","custom":"personalizzato"},"uneditable_desc":"Business, education e piani personalizzati non possono essere aggiornati all'interno di ProductivityTab. Si prega di <a href=\"mailto:support@ichro.me\"> contattarci</a> per aggiornare o cancellare la tua iscrizione.","status":"Stato","status_active":"Attivo","status_trial":"Versione di prova","status_pastdue":"Scaduto","subscription_date":"Data di sottoscrizione","paid_through":"Pagato il","next_bill":"Prossimo pagamento","next_bill_value":"$%s il %s","update_plan":"Piano di aggiornamento","update_billing":"Aggiornare la fatturazione","cancel":"Annulla sottoscrizione","cancel_notice":"L'abbonamento verrà annullato immediatamente","cancel_notice2":"Se desideri un rimborso, ti preghiamo di contattarci a support@ichro.me"}},"ads":{"text1":"ProductivityTab displays a few small ads to pay for server, support and development costs. With these ads, we can afford to offer ProductivityTab free to everyone.","text2":"Here you can choose where those ads are shown, or buy ad-free to permanently remove them.","text3":"Ad-free is a one-time purchase that permanently removes ads from ProductivityTab wherever you're signed in. You can also upgrade to Pro for extra features in addition to an ad-free experience.","upgrade_btn":"Upgrade to ad-free","already_upgraded":"It looks like you've already upgraded to ad-free","signin":"Registrati","signin_desc":"Sign in before upgrading so we can link your purchase to your account","signin_btn":"Registrati","thank_you":"Thank you for upgrading to ad-free!","placement":{"title":"Ad placement","left":"In the leftmost column","right":"In the rightmost column","top":"Above the tab","bottom":"Floating at the bottom"}}},"store":{"installation":"Installazione","description":"Descrizione","preview":"Anteprima","instructions":"Trascina la dimensione voluta per il widget sulla tua homepage"},"widgets":{"sizes":{"tiny":"Minuscolo","small":"Piccolo","medium":"Medio","large":"Grande","variable":"Variabile"},"settings":{"title":"Impostazioni widget","save":"Salva","size":"Dimensione widget"},"minimize":"Riduci","maximize":"Ingrandisci","delete_confirm":"Sei sicuro di voler eliminare questo widget?\nQuesta azione non è reversibile; tutti i dati del widget saranno persi in modo permanete.","permissions_request":{"title":"È necessario l'accesso","button":"Concedi l'accesso","desc":"Questo widget ha bisogno di autorizzazioni aggiuntive prima di poter essere utilizzato. Concederle utilizzando il pulsante qui sotto."},"error":{"explanation":"Qualcosa è andato storto mentre stavamo cercando di visualizzare questo widget.","advice":"Provare a reinstallare il widget o ricaricare la pagina. Contattaci se vedete questo messaggio spesso.","support":"Supporta","refresh":"Ricarica"},"auth":{"message":"È necessario concedere l'accesso di widget al tuo account prima di utilizzarlo.","button":"Concedi l'accesso"},"shared":{"settings":{"title":"Titolo del Widget","title_placeholder":"Immetti un nome per il widget o lascialo bianco per nascondere","height":"Altezza del widget","open_options":{"current":"La scheda corrente","blank":"Una nuova scheda"},"footer_link":"Link a piè di pagina","footer_link_options":{"show":"Mostra","hide":"Nascondi"},"account":"Account ID","account_help":"Se sei connesso con più account, questo è il valore di \"authuser=\".\n<br /><br />\nPer esempio, se sei connesso con due account,  jsmith1@gmail.com  e jsmith2@gmail.com, il valore di \"authuser\" per jsmith2@gmail.com sarà 1 dato che è il secondo account (occorre contare partendo da zero) in cui sei connesso.","account_placeholder":"Il tuo valore per \"authuser=\"","on":"On","off":"Off"}},"apps":{"name":"Apps","desc":"Consente di visualizzare le applicazioni di Google Chrome attualmente installate.","settings":{"format":"Formato widget","format_options":{"tiles":"Piastrelle","list":"Lista"},"display":"Mostra","display_options":{"all":"Tutte le apps","enabled":"Solo le apps attivate"},"sort":"Ordinamento","sort_options":{"id":"ID","alphabetically":"Alfabeticamente","offline":"Offline abilitato","available":"Disponibilità"},"open":"Applicazioni aperte in"},"store_app":"Store"},"bookmarks":{"name":"Preferiti","desc":"Visualizza segnalibri selezionati e personalizzati, e altri link.","settings":{"title_placeholder":"Inserisci un titolo del widget","layout":"Aspetto","layout_options":{"single":"Colonna Singola","double":"Colonna Doppia"},"open":"Apri preferiti in"},"edit":{"dialog_title":"Modifica Preferito","title":"Titolo Segnalibro","title_placeholder":"Google","url":"URL Segnalibro","url_placeholder":"https://www.google.com/","save":"Salva"},"new_caption":"Nuovo","new_bookmark":"Segnalibro","new_folder":"Cartella","drop_link":"Trascina il link qui"},"chrome_bookmarks":{"name":"Preferiti","desc":"Visualizza i preferiti di Chrome, facoltativamente da una cartella specifica.","settings":{"title_placeholder":"Inserisci un titolo del widget","from":"Mostra i preferiti da","open":"Apri preferiti in"}},"calc":{"name":"Calcolatrice","desc":"Consente di visualizzare una calcolatrice con il supporto per gli operatori di base.","error":"Errore!","infinity":"Infinito","mismatch":"Parentesi non corrispondenti"},"calendar":{"name":"Calendar","desc":"Visualizza gli eventi imminenti da uno o più dei vostri calendari di Google.","settings":{"calendar":"Calendar","show":"Mostra gli eventi da","show_options":{"all":"Tutto il tempo","today":"Solo oggi"}},"title":"Agenda","calendar":"Calendario","noevents":"Nessun appuntamento in programma, sembra che tu sia libero!"},"clock":{"name":"Orologio","desc":"Offre funzionalità come sveglia, orologio, timer e cronometro.","settings":{"timezone":"Fuso orario","timezone_local":"Locale","format":"Formato orologio","format_options":{"ampm":"AM/PM - digitale","24hour":"24 ore - digitale","analog":"12 ore - analogico","ampmseconds":"AM/PM - digitale, senza secondi","24hourseconds":"24 ore - digitale, senza secondi"},"sound":"Suono di avviso"},"title":"Orologio","alarm":"Avviso","clock":"Orologio","timer":"Timer","stopwatch":"Cronometro","set":"Set","unset":"Non impostato","dismiss":"Togli","enable_audio":"Attiva audio"},"facebook":{"name":"Facebook","desc":"Incorpora Facebook in un widget"},"feedly":{"name":"Feedly","desc":"Visualizza articoli dal tuo account Feedly in un formato configurabile.","settings":{"source":"Visualizza articoli di","source_feeds":"Feeds","show":"Mostra","show_options":{"all":"Tutti gli articoli","unread":"Solo gli articoli non letti"},"layout":"Aspetto","layout_options":{"titles":"Solo titoli","magazine":"Rivista","cards":"Carte","cards_columns":"Carte (due colonne)"},"mark":"Contrassegnare un articolo come letto quando io","mark_options":{"scroll":"Scorri oltre o cliccalo","click":"Cliccalo solamente"},"sort":"Ordinamento","sort_options":{"newest":"Prima i più recenti","oldest":"Prima i più vecchi"}},"all":"Tutti","saved":"salvati per dopo","uncategorized":"Senza categoria","author":"di","go_to_feedly":"Vai a Feedly"},"notes":{"name":"note","desc":"Inserisce una semplice, modificabile, nota.","settings":{"color":"Colore della nota","color_options":{"yellow":"Giallo","orange":"Arancione","red":"Rosso","blue":"Blu","green":"Verde","white":"Bianco"},"font":"Stile font","fontsize":"Dimensione carattere"}},"now":{"name":"Google Now","desc":"Visualizza le schede di Google Now, tra cui lo stato dei voli e il tracciamento dei pacchi.","authorize":"Avrete bisogno di dare ProductivityTab il permesso di visualizzare le schede di Google Now prima che venga visualizzata qui qualsiasi cosa.","authorize_btn":"Autorizza","caught_up":"Hai visto tutto, niente qui.","no_title":"Senza titolo"},"plus":{"name":"Google+","desc":"Incorpora Google Plus in un widget"},"notifications":{"name":"Google Notifications","desc":"Mostra le notifiche di Google da servizi come Google+"},"reddit":{"name":"Reddit","desc":"Mostra i migliori elementi di Reddit per ogni subreddit dato.","settings":{"subreddit":"Subreddit","subreddit_help":"Inserire un subreddit inserendo soltanto la parte dell'URL di quel subreddit a partire da <b>/r/</b>.\n<br /><br />\nPer esempio, Technology si trova su: <a href=\"https://www.reddit.com/r/technology\">https://www.reddit.com/r/technology</a>, quindi va inserito soltanto <b>technology</b>","subreddit_placeholder":"Inserisci un subreddit di per poter vedere i links. (es: technology)","sort":"Ordinamento","sort_options":{"hot":"Hot","top":"Top","new":"Nuovo","gilded":"Dorato","rising":"In evidenza","controversial":"Controverso"},"links":"Links mostrati","click":"Quando faccio clic su un collegamento Mostrami","click_options":{"link":"Il link","comments":"I commenti"}},"more":"Altro"},"tasks":{"name":"Attività","desc":"Mostra una lista modificabile di attività da una delle tue liste Google Task.","title":"Attività","settings":{"list":"Lista"},"task_title":"Titolo","due_date":"Data di scadenza","notes":"note","add":"Aggiungi elemento","delete_task":"Elimina attività","move_up":"Sposta in alto","move_down":"Sposta in basso","done":"Fatto","due_today":"Scade oggi","overdue":"Scaduto","authorize":"Per far visualizzare qualcosa qui, devi prima selezionare una lista da Google Task nelle impostazioni."},"twitter":{"name":"Twitter","desc":"Mostra i tweet della tua timeline o da una lista specificata.","settings":{"source":"Mostra i tweet da","show":"Tweet mostrati"},"authorize":"Devi prima autorizzare ProductivityTab","authorize_msg":"È necessario dare il permesso ad ProductivityTab per accedere ai tuoi tweet per visualizzare i tuoi tweet qui.","authorize_btn":"Autorizza","no_tweets":"Non sembrano esserci tweet qui...","home":"Home","mentions":"Menzioni","retweets":"I miei retweet","lists":"Liste","more":"Altro","reply":"Rispondi","retweet":"Ritwitta","favorite":"Preferito"},"wolfram":{"name":"Wolfram|Alpha","desc":"Inserisce un piccolo modulo per cercare su Wolfram|Alpha."},"youtube":{"name":"YouTube","desc":"Mostra video popolari o di un utente specifico.","settings":{"format":"Formato","format_options":{"large":"Uno grande","large_2":"Uno grande, due piccoli","large_4":"Uno grande, quattro piccoli","four":"Quattro piccoli","six":"Sei piccoli"},"from":"Mostra video da","from_help":"Questo deve essere il nome <b>utente esatto</b> come mostrato nel URL della pagina in cui visualizzi il tuo profilo su YouTube.\n<br /><br />\nQuesto valore non include mai spazzi.","from_placeholder":"Lascia vuoto per mostrare i video popolari","open":"Apri risultati in"},"search":"Cerca su YouTube","num_views":"Visualizzazioni"},"quotes":{"name":"Citazioni","desc":"Mostra una citazione selezionata ogni volta che apri la pagina o una volta al giorno.","settings":{"source":"Fonte","method":"Carica nuove citazioni","method_options":{"daily":"Una volta al giorno","random":"Ogni volta che carico la pagina"}},"unknown_author":"Sconosciuto"},"html":{"name":"HTML","desc":"Mostra dell'HTML personalizzabile all'interno di un iframe.","settings":{"html":"HTML","js":"JavaScript","height":"Altezza del widget"}},"sitelink":{"name":"Collegamento al sito","desc":"Mostra un link, facoltativamente con un titolo e una miniatura","settings":{"link":"URL Link","link_placeholder":"https://www.google.com/","image":"URL dell'immagine","image_placeholder":"https://www.example.com/image.png","color":"Colore di sfondo dell'immagine","style":"Stile dell'immagine","style_fill":"Riempi","style_center":"Al centro"}},"stats":{"name":"Statistiche del sistema","desc":"Tenete d'occhio il vostro sistema con statistiche in tempo reale","memory":"Memoria","battery":"Batteria","usage":"utilizzo","in_use":"in uso","remaining":"rimanenti","charged":"Ricarica completa","idle":"Inattivo","charging":"In Carica","discharging":"In scarica"},"search":{"name":"Cerca","desc":"Incorporate una casella di ricerca nella pagina per un accesso facile","settings":{"placeholder":"Campo di ricerca","search_url":"URL di ricerca","param":"Parametro della query","param_placeholder":"Il parametro dove va inserita la Query, cioè \"q\""},"default_placeholder":"Cerca su Google"},"pushbullet":{"name":"Pushbullet","desc":"Tenete traccia delle notifiche dal vostro cellulare e altri dispositivi","no_pushes":"Nessuna notifica trovata","sign_in":"Registrati","no_key":"Non sembra che tu sia iscritto a Pushbullet.  Accedi ora per collegare questo widget."},"linkedin":{"name":"LinkedIn","desc":"Visualizza la tua bacheca di Linkedin"},"directions":{"name":"Indicazioni","desc":"Ricevi indicazioni stradali per andare in qualunque posto da praticamente ovunque\n direttamente nella homepage","driving":"In auto","transit":"Transito pubblico","walking":"A piedi","cycling":"Bicicletta","from":"Inserire un punto di partenza","to":"Inserisci una destinazione","loading":"Caricando le indicazioni, attendere prego...","error":"Qualcosa è andato storto durante il tentativo di caricare le indicazioni che avete richiesto.","error2":"Per favore controlla gli indirizzi di partenza e destinazione che hai inserito.","open_in_maps":"Apri in Google Maps","via":"via"},"pocket":{"name":"Tasca","desc":"Mostra una lista dei tuoi video, articoli e pagine web salvati","settings":{"links_shown":"Numero di link visualizzati","open":"Apri links","open_pocket":"Nella tasca","open_original":"Al loro URL originale"},"by":"di","no_links":"Nessun link trovato","grant_access":"Concedi accesso","no_key":"Dovete dare l'accesso ad ProductivityTab al vostro account Pocket prima di poter caricare il vostro link."}},"themes":{"title":"Temi","all":"Tutti","custom":"personalizzato","create":"Crea un tema","url_or_upload":"o","upload_image":"Carica un immagine","edit_btn":"Modifica","delete":"Cancella","use":"Usa","preview":"Anteprima","author":"di","images":"%s imagini","resolution":"Risoluzione","categories":"Categorie","cached":"Questo tema è stato memorizzato nella cache ed è disponibile anche offline","random":"Questo tema mostra un immagine casuale ogni volta che carichi la pagina","random_daily":"Questo tema mostra un immagine scelta casualmente ogni giorno","sunrise_sunset":"Questo tema mostra un immagine basata sul ora del giorno","feed":"Questo tema mostra un immagine scelta giornalmente da un feed esterno","video":"Questo tema mostra un video live","pro_only":"Questo tema è disponibile solo per utenti Pro. Acquista la versione Pro nelle impostazioni.","delete_confirm":"Sei sicuro di voler eliminare questo tema?\nQuesta azione non è reversibile; Il tema sarà perso in modo permanente.","delete_error":"Si è verificato un errore durante l'eliminazione del tema. Riprova più tardi.","feed_fetching":"Attendere prego, caricando il feed...","feed_error":"Qualcosa è andato storto durante il tentativo di recuperare il feed.  Riprova più tardi.","caching":"Memorizzazione del tema nella cache, attendere...","cache_status":"%s di %s memorizzato nella cache","cache_error":"Si è verificato un errore mentre si tentava la memorizzazione del tema nella cache, riprova più tardi","bginfo":{"view":"Vista","source":"Fonte","unknown":"Sconosciuto","download":"Download","pro_only":"Solo gli utenti Pro possono scaricare video e immagini di sfondo"},"edit":{"title":"Modifica tema","create_title":"Crea tema","name":"Nome del tema","default_name":"Nuovo tema","name_placeholder":"Inserisci il nome di un tema","image":"URL dell'immagine","image_placeholder":"Inserire l'URL dell'immagine di sfondo","image_help":"Le immagini caricate <b>non possono essere sincronizzate</b> tra computer.<br /><br />Se per te questo è importate, si consiglia di caricare la tua immagine su un servizio di hosting immagini tipo <a href=\"https://imgur.com/\" target=\"_blank\">imgur</a>. Dopo di che copia l'URL che finisce con un estensione (es: .jpg) ed incollalo nel campo a sinistra.","color":"Colore di riserva","color_placeholder":"Inserisci il nome di colore","position":"Posizione","position_options":{"center":"Al centro","top_left":"In alto a sinistra","top_center":"In alto al centro","top_right":"In alto a destra","bottom_left":"In basso a sinistra","bottom_center":"In basso al centro","bottom_right":"In basso a destra"},"scaling":"Ridimensiona","scaling_options":{"auto":"Automatico","width":"Larghezza massima","height":"Altezza massima","none":"Nessun ridimensionamento (l'anteprima può essere imprecisa)"},"repeat":"Ripeti imagine","repeat_options":{"none":"Non ripetere","horizontal":"Ripeti orizzontalmente","vertical":"Ripeti verticalmente","both":"Ripeti entrambi"},"attach":"Ancora immagine alla","attach_tab":"Scheda","attach_window":"Finestra","preview":"Anteprima","save":"Salva e chiudi","cache_error":"Si è verificato un errore durante la memorizzazione nella cache dell'immagine che hai fornito, ricontrolla l'URL.","upload_error":"Si è verificato un errore cercando di fare l'upload dell'immagine che hai fornito, si prega di controllare che l'immagine sia consona e di dimensioni ragionevoli."}}},"ja":{"lang_code":"ja","language":"日本語","extName":"ProductivityTab — Custom Homepage Dashboard","newtabName":"ProductivityTab — Custom New Tab Dashboard","extDescription":"A remarkably customizable personal homepage featuring 50+ widgets, breathtaking backgrounds and much more.","newtabDescription":"A customizable personal dashboard on your new tab page featuring 50+ widgets, breathtaking backgrounds and much more.","defaults":{"tab":"ホーム","me":"自分"},"remove_widget":"削除","hide_banner":"Hide this banner","hide_ad":{"content":"Hey! We're not crazy about ads either, but we're only able to make ProductivityTab available and continue developing features for our free users (that's you!) by showing ads. If you'd like to support ProductivityTab directly and get rid of ads for free, we would really appreciate if you upgraded to our pro version","upgrade":"アップグレード","hide":"広告を非表示"},"alert":{"default_button":"閉じる","confirm_title":"これを行ってもよろしいですか？","confirm_continue":"続ける","confirm_cancel":"キャンセル"},"onboarding":{"modal":{"tagline":"よく使うサイトとアプリをまとめます","wrong_extension":"新しいタブに ProductivityTab を表示させたいですか？","wrong_extension_newtab":"ホームページを ProductivityTab に設定しますか？","wrong_extension_action":"ここをクリック","about":"ProductivityTab のタブとウィジェットについて","about_desc":"タブには、ウィジェット（天気やニュース、メールなど）を追加することができます。ほとんどのウィジェットをカスタマイズ可能で、必要なだけ追加することができます。","terms":"ProductivityTab を利用することにより、<a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\">利用規約</a> と <a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\">プライバシーポリシー</a> に同意したものとみなされます。","sign_in":"Google アカウントでログイン","sign_in_desc":"オンラインでの変更を安全に保存するために、Google アカウントでログインしてください。","sign_in_desc2":"ログインせずに使用することも可能ですが、その場合、ウィジェットの配置などがオンラインに保存されず、別のコンピューターと共有することができません。","sign_in_button":"Google でログイン","have_account":"すでにアカウントをお持ちのようです。","have_account_desc":"タブとウィジェットを使用する準備ができました！","get_started":"さあ、始めましょう！","get_started_desc":"次に、ページの設定を行いましょう。"},"widgets":{"configure":"ウィジェットを設定してみましょう。","configure_desc":"Click the wrench to open a widget's <b>settings</b>.","configure_skip":"Skip Tutorial","settings":"Replace <b>Link URL</b> with your favorite site, then press <b>Save</b>.","move":"You can <b>reposition</b> widgets by clicking and dragging the three dots highlighted here.","remove":"To <b>delete</b>, simply click the red trash bin icon.","done":"OK"},"settings":{"intro":"Now let’s add a new widget. This highlighted button is where you can access the Widget Menu.","instructions":"Click the new widget button on to open the widget menu!","skip":"スキップ","tooltips":{"settings":"ProductivityTab の外観と動作を変更","widgets":"新規ウィジェットを追加 - 必要なだけ追加することができます","editing":"ウィジェットの編集ボタンを表示/非表示","links":"リンク一覧 - 設定でよく利用するサイトを追加できます","tabs":"タブ - 設定で追加できます","support":"お問い合わせ/レビュー"},"finished":"以上です！","finished_next":"<b>ウィジェット</b> をクリックして、ウィジェットを配置しましょう！","finished_contact":"ヘルプが必要な場合はサポートをご利用ください。迅速にご連絡いたします。"}},"storage":{"signin":"Google にログインすると、設定を安全に保存および同期できます。","signin_btn":"ログイン","signin_dismiss":"閉じる","signin_confirm":{"title":"ローカルデータを保持しますか？","desc":"ローカルデータを保持してアカウント内のデータを置き換えますか？またはアカウント内のデータでローカルデータを置き換えますか？","keep_account":"アカウントを使用","keep_local":"ローカルを保持"},"signout_confirm":"ログアウトするとローカルのバックアップが削除されます。","pastdue":"定期購入の期限が過ぎています","pastdue_desc":"設定からお支払い情報を更新してください"},"toolbar":{"placeholder":"キーワードを入力","placeholder_ok":"キーワードを入力するか、\"OK, Google\" と言ってください","suggestions":{"url_subtext":"URL を参照","capture_notice":"ProductivityTab handles searches you normally make from the Omnibox. You can disable this at any time from the settings"},"apps":{"search":"検索","youtube":"YouTube","maps":"マップ","play":"Play","news":"ニュース","gmail":"Gmail","drive":"ドライブ","calendar":"カレンダー","more":"もっと見る"}},"menu":{"settings":"設定","widgets":"ウィジェット","editing":"編集モード","editing_enabled":"有効","editing_disabled":"無効","plus":"Google+","tabs":"タブ","footer":{"support":"サポート","feedback":"フィードバック","review":"レビュー","terms":"利用規約","privacy":"プライバシー","by":"By Avi Kohn"}},"voice":{"listening":"お話しください","searching":"検索: %s","missed":"聞き取れませんでした。<a>再試行</a>"},"settings":{"title":"設定","exit":"設定を終了","saved":"設定が保存されました","nav":{"visual":"外観","visual_sections":{"background":"背景","layout":"レイアウト","theme":"アプリのテーマ","ad_placement":"Ad placement"},"toolbar":"ツールバー","toolbar_sections":{"style":"スタイル","search":"検索","links":"リンク"},"tabs":"タブ","widgets":"ウィジェット","ads":"広告","pro":"Pro","accounts":"アカウント","misc":"その他","advanced":"高度な設定","advanced_sections":{"backups":"バックアップと復元","css":"カスタム CSS","debug_tools":"デバッグツール"},"support":"ヘルプとサポート","suggest":"機能を提案"},"visual":{"background":{"title":"背景","desc":"ProductivityTab のタブの背景として表示される画像です","current":"現在の背景画像","custom":"カスタム","unnamed":"テーマ %s","select":"テーマを選択","or":"または","url_placeholder":"画像の URL を入力"},"layout":{"title":"レイアウト","desc":"ウィジェットの表示方法を変更できます","columns":"列表示","grid":"グリッド表示","columns_number":"列の数","column_width":"列の幅","column_width_fixed":"固定","column_width_fluid":"可変","column_warning":{"column_to_grid":"レイアウトをグリッドに変更すると、すべてのウィジェットが左上に移動されます。","grid_to_column":"レイアウトを列に変更すると、すべてのウィジェットが最初の列に移動されます。"}},"theme":{"title":"アプリのテーマ","desc":"ProductivityTab とウィジェットの外観を変更できます","preview":"プレビュー","light":"明るい (デフォルト)","dark":"ダーク","transparent":"透明","transparent_darker":"半透明 (ダーク)"}},"toolbar":{"style":{"title":"スタイル","desc":"ツールバーのスタイルを設定できます。通常表示もしくは小さなボタン表示を選択できます。","normal":"標準","button":"ボタン"},"search":{"title":"検索","desc":"検索ボックスと音声検索の設定を変更できます","engine":"検索エンジン","engines_default":"デフォルト","engines_custom":"カスタム","engines_custom_desc":"クエリを <b>%s</b> にして URL を入力","omnibox_capture":"Handle searches normally made in the Omnibox","voice":"音声検索を有効にする","ok_google":"ホットワード ”OK Google\" の検出を有効にする","search_tab":"検索結果を新しいタブで開く"},"links":{"title":"リンク","desc":"右上にあるツールバーに表示される項目です","apps":"アプリメニュー","custom":"カスタムリンク","custom_note1":"最大3個","custom_note2":"ユーザーは最大8個","custom_name_placeholder":"リンクテキスト","custom_url_placeholder":"リンクURL（例: https://www.google.co.jp/）"}},"misc":{"link_tab":"リンクを新しいタブで開く"},"tabs":{"create_new":"新規作成","make_default":"デフォルトに設定","desc1":"タブは ProductivityTab 内のページです。それぞれのタブごとにウィジェットを配置することができます。","desc2":"画面の左右にマウスを移動すると表示されるボタンをクリックするか、キーボードの矢印キーを使用してタブを切り替えることができます。","name_placeholder":"タブ名を入力","delete_confirm":"このタブを削除してよろしいですか？\nこの操作を元に戻すことはできません。タブ内のすべてのウィジェットが消去されます。"},"accounts":{"status":{"title":"ステータス","signed_in":"現在、%s (%s) として<b>ログイン中</b>です。","reset_account":"アカウントをリセット","sign_out":"ログアウト","signed_out":"<b>現在、ログインしていません。</b>Google アカウントでログインし、安全に設定を保存および同期してください。","sign_in":"Google でログイン"},"reset_confirm_desc":"アカウントをリセットすると、ローカルおよび同期されたデータ、バックアップがすべて削除されます。この操作を元に戻すことはできません。","reset_confirm_desc2":"このアカウントに関連付けられたすべてのコンピューターからも、すべての設定とデータが消去されます。"},"advanced":{"backups":{"title":"バックアップと復元","desc":"すべてのタブ、設定、ウィジェットのデータがバックアップされます。これは毎日、最初に ProductivityTab を開いた時に自動的に実行されます。","desc2":"下のボタンを使って、特定の日付に戻ったり、バックアップデータをダウンロードしたりできます。","backup":"今すぐバックアップ","upload":"ファイルから復元","download":"ダウンロード","restore":"復元","download_name":"ProductivityTab バックアップ","restore_confirm":"このアカウントでログインしているすべてのコンピューターの ProductivityTab データおよび同期されたデータが上書きされます。","restore_error":"データの解析中にエラーが発生しました。後でもう一度やり直してください。"},"css":{"title":"カスタム CSS","desc":"<a href=\"https://developer.mozilla.org/en-US/docs/Web/CSS\"target=\"blank\">CSS</a> を使用すると、ProductivityTab のほとんどをカスタマイズできます。","placeholder":"CSS をここに入力（最大1000文字）"},"debug_tools":{"title":"デバッグツール","desc":"<b>警告:</b> これらのツールは、設定を1クリックで消去することができます。指示があった場合にのみ使用してください。","open":"ツールを開く"}},"widgets":{"desc1":"ウィジェットの設定はここからは変更できません。","desc2":"ウィジェットの設定を変更するには以下の手順に従ってください。","steps1":"設定を変更したいウィジェットの上にマウスを移動します。","steps2":"ウィジェットの右上に表示されるレンチのアイコンをクリックします。そのウィジェットに設定できる項目がない場合、アイコンは表示されません。","steps3":"表示されたダイアログボックスでウィジェットの設定を変更します。","steps4":"保存をクリックして設定を保存します。設定をキャンセルするには、背景をクリックします。"},"pro":{"promo":{"monthly_price":"月額 $4.99","yearly_price":"または年額 $29.99","upgrade_btn":"今すぐアップグレード","business":"ビジネスや教育目的で Pro 版を購入することに興味をお持ちの場合は","business_contact":"ご連絡ください","themes":"テーマ","themes_desc":"半透明やダークテーマを使用すれば、お気に入りの背景画像がもっとよく見えるようになります","bgs":"動く背景画像","bgs_desc":"20種の高解像度画像を使って、あなたのページに命を吹き込みましょう！","widgets":"ウィジェットの最大化","widgets_desc":"最大化できるウィジェットと共に、ProductivityTabは新しいレベルに引き上げられます。","more_header":"その他の機能","stocks":"チャートやリアルタイムの詳細な株価情報","rss":"複数の RSS フィードをサポート","sports":"スポーツ全般および指定したリーグのニュース","tabbed_widgets":"タブ付きのニュースや RSS ウィジェット","bg_downloads":"ダウンロード可能な背景画像","weather":"1時間ごとの天気予報を10日後まで表示","toolbar":"より多くのツールバーリンク","ads":"A completely ad-free experience","support":"優先サポート/ご提案","buy_pro":"Pro を購入"},"checkout":{"title":"購入","updating_title":"プランを更新","payment_options":"お支払い","pay_monthly":"毎月 ($4.99)","pay_yearly":"毎年 ($29.99)","cancel":"キャンセル","update":"更新","subscribe":"定期購入","braintree_notice":"お支払いは Braintree によって安全に処理されます。","monthly_notice":"定期購入を停止するまで、毎月 $4.99 を請求します。","yearly_notice":"定期購入を停止するまで、毎年 $29.99 を請求します。","update_notice":"定期支払いの変更の反映はすぐに行われますが、現在の支払い期間終了まで請求されません。","thank_you":"ProductivityTab Pro をご購入いただきありがとうございます！","thank_you2":"ProductivityTab Pro はすぐにご利用いただけるようになります！","error":"お支払いの処理中に問題が発生しました。","error2":"後でもう一度やり直してください。問題が解決しない場合は、support@ichro.me までお問い合わせください。","signin":"ログイン","signin_desc":"Pro を購入する前にログインする必要があります。","signin_btn":"ログイン"},"plan":{"title":"プラン","desc":"ProductivityTab Pro (%s) に加入契約済みです","types":{"monthly":"毎月","yearly":"毎年","business":"ビジネス","education":"教育","custom":"カスタム"},"uneditable_desc":"ビジネス、教育、およびカスタムのプランは、ProductivityTab 内からは更新できません。更新または解約するには、<a href=\"mailto:support@ichro.me\">サポート</a> へお問い合わせください。","status":"ステータス","status_active":"有効","status_trial":"試用版","status_pastdue":"期限切れ","subscription_date":"契約日","paid_through":"有効期限","next_bill":"次回のお支払い日","next_bill_value":"金額: $%s, 日付: %s","update_plan":"プランを更新","update_billing":"お支払い情報を更新","cancel":"定期購入を解約","cancel_notice":"定期購入はすぐに停止されます","cancel_notice2":"返金が必要な場合は、support@ichro.me にお問い合わせください"}},"ads":{"text1":"ProductivityTab displays a few small ads to pay for server, support and development costs. With these ads, we can afford to offer ProductivityTab free to everyone.","text2":"Here you can choose where those ads are shown, or buy ad-free to permanently remove them.","text3":"Ad-free is a one-time purchase that permanently removes ads from ProductivityTab wherever you're signed in. You can also upgrade to Pro for extra features in addition to an ad-free experience.","upgrade_btn":"広告なしバージョンにアップグレード","already_upgraded":"It looks like you've already upgraded to ad-free","signin":"ログイン","signin_desc":"Sign in before upgrading so we can link your purchase to your account","signin_btn":"ログイン","thank_you":"広告なしバージョンにアップグレードしていただきありがとうございます ！","placement":{"title":"Ad placement","left":"In the leftmost column","right":"In the rightmost column","top":"タブの上","bottom":"Floating at the bottom"}}},"store":{"installation":"配置","description":"説明","preview":"プレビュー","instructions":"ドラッグ&ドロップで配置"},"widgets":{"sizes":{"tiny":"最小","small":"小","medium":"標準","large":"大","variable":"可変"},"settings":{"title":"ウィジェットの設定","save":"保存","size":"ウィジェットのサイズ"},"minimize":"最小化","maximize":"最大化","delete_confirm":"このウィジェットを削除してもよろしいですか？\nこの操作を元に戻すことはできません。ウィジェット内のすべてのデータが削除されます。","permissions_request":{"title":"アクセス権限が必要です","button":"アクセスを許可","desc":"このウィジェットは追加のアクセス許可が必要です。下のボタンを押すことで許可することができます。"},"error":{"explanation":"ウィジェットの表示に失敗しました。","advice":"ウィジェットを再配置するかページを再読み込みしてください。このメッセージが頻繁に表示される場合、サポートへご連絡ください。","support":"サポート","refresh":"再読み込み"},"auth":{"message":"このウィジェットを使用するには、アカウントへのアクセスを許可する必要があります。","button":"アクセスを許可"},"shared":{"settings":{"title":"ウィジェットのタイトル","title_placeholder":"ウィジェットのタイトルを入力（空白にすると非表示）","height":"ウィジェットの高さ","open_options":{"current":"現在のタブ","blank":"新しいタブ"},"footer_link":"フッターのリンク","footer_link_options":{"show":"表示","hide":"非表示"},"account":"アカウント ID","account_help":"複数のアカウントにログインしている場合、これが \"authuser=\" の値になります。\n<br /><br />\n例えば、tanaka1@gmail.com と tanaka2@gmail.com という2個のアカウントにログインしている場合、tanaka2@gmail.com は2つ目のアカウントになるので、\"authuser\" の値は0から数えるため1になります。","account_placeholder":"\"authuser=\" の値","on":"ON","off":"OFF"}},"apps":{"name":"アプリ","desc":"現在インストールされている Google Chrome のアプリケーションを表示します。","settings":{"format":"ウィジェットの表示方法","format_options":{"tiles":"タイル","list":"一覧"},"display":"表示","display_options":{"all":"すべてのアプリ","enabled":"有効なアプリのみ"},"sort":"並べ替え","sort_options":{"id":"ID","alphabetically":"アルファベット順","offline":"オフラインで利用可能","available":"利用可能"},"open":"アプリの開き方"},"store_app":"ストア"},"bookmarks":{"name":"ブックマーク","desc":"選択したブックマークやカスタムリンクを表示します。","settings":{"title_placeholder":"ウィジェットのタイトルを入力","layout":"レイアウト","layout_options":{"single":"1列","double":"2列"},"open":"ブックマークの開き方"},"edit":{"dialog_title":"ブックマークを編集","title":"ブックマークのタイトル","title_placeholder":"Google","url":"ブックマークの URL","url_placeholder":"https://www.google.co.jp/","save":"保存"},"new_caption":"新着","new_bookmark":"ブックマーク","new_folder":"フォルダ","drop_link":"ここにリンクをドロップ"},"chrome_bookmarks":{"name":"ブックマーク","desc":"Chrome のブックマークおよび指定フォルダ内のブックマークを表示します。","settings":{"title_placeholder":"ウィジェットのタイトルを入力","from":"表示するブックマーク","open":"ブックマークの開き方"}},"calc":{"name":"電卓","desc":"基本的な計算をすることのできる電卓を表示します。","error":"エラーが発生しました","infinity":"無限","mismatch":"かっこが一致しません"},"calendar":{"name":"カレンダー","desc":"Google カレンダーから今後の予定を表示します。","settings":{"calendar":"カレンダー","show":"表示する予定の期間","show_options":{"all":"すべて","today":"今日のみ"}},"title":"予定","calendar":"カレンダー","noevents":"近日中の予定はなく、スケジュールは空いています。"},"clock":{"name":"時計","desc":"アラーム、時計、タイマー、ストップウォッチ機能を使うことができます。","settings":{"timezone":"タイムゾーン","timezone_local":"ローカル","format":"時刻の表示方法","format_options":{"ampm":"AM/PM - デジタル","24hour":"24時間制 - デジタル","analog":"12時間制 - アナログ","ampmseconds":"AM/PM - デジタル, 秒表示なし","24hourseconds":"24時間制 - デジタル, 秒表示なし"},"sound":"アラーム音"},"title":"時計","alarm":"アラーム","clock":"時計","timer":"タイマー","stopwatch":"ストップウォッチ","set":"セット","unset":"キャンセル","dismiss":"閉じる","enable_audio":"通知音を有効にする"},"facebook":{"name":"Facebook","desc":"Facebook をウィジェットに埋め込みます。"},"feedly":{"name":"Feedly","desc":"Feedly アカウントからの記事を設定した形式で表示します。","settings":{"source":"表示する記事","source_feeds":"フィード","show":"表示","show_options":{"all":"すべての記事","unread":"未読の記事のみ"},"layout":"レイアウト","layout_options":{"titles":"タイトルのみ","magazine":"マガジン","cards":"カード","cards_columns":"カード (2列)"},"mark":"既読にするタイミング","mark_options":{"scroll":"クリックまたはスクロールして通り過ぎたとき","click":"クリックしたときのみ"},"sort":"並べ替え順序","sort_options":{"newest":"新着順","oldest":"古い順"}},"all":"すべて","saved":"あとで読む","uncategorized":"未分類","author":"著者:","go_to_feedly":"Feedly に移動"},"notes":{"name":"メモ","desc":"シンプルで、編集可能なメモを挿入します。","settings":{"color":"メモの色","color_options":{"yellow":"イエロー","orange":"オレンジ","red":"レッド","blue":"ブルー","green":"グリーン","white":"ホワイト"},"font":"フォントの種類","fontsize":"文字サイズ"}},"now":{"name":"Google Now","desc":"フライト情報や荷物の追跡などの Google Now カードを表示します。","authorize":"Google Now のカードを表示するためには、ProductivityTab に許可を与える必要があります。","authorize_btn":"許可","caught_up":"カードはありません","no_title":"タイトルなし"},"plus":{"name":"Google+","desc":"Google+ のウィジェットを埋め込みます。"},"notifications":{"name":"Google からの通知","desc":"Google+ などの Google サービスからの通知を表示します。"},"reddit":{"name":"Reddit","desc":"Reddit 上の指定した subreddit の投稿を表示します。","settings":{"subreddit":"Subreddit","subreddit_help":"Reddit の URL の <b>/r/</b> の後にある subreddit を入力してください。\n<br /><br />\n例えば Technology の場合、<a href=\"https://www.reddit.com/r/technology\">https://www.reddit.com/r/technology</a> の<b>technology</b> を入力します。","subreddit_placeholder":"表示させたい subreddit を入力 (例: technology)","sort":"並べ替え順序","sort_options":{"hot":"注目","top":"トップ","new":"新着","gilded":"ゴールド","rising":"上昇中","controversial":"論争中"},"links":"表示するリンクの数","click":"リンクをクリックしたときに開く","click_options":{"link":"リンク","comments":"コメント"}},"more":"もっと表示"},"tasks":{"name":"タスク","desc":"編集可能な Google タスクのリストを表示します。","title":"タスク","settings":{"list":"一覧"},"task_title":"タイトル","due_date":"期限","notes":"メモ","add":"項目を追加","delete_task":"タスクを削除","move_up":"上へ移動","move_down":"下へ移動","done":"完了","due_today":"今日中","overdue":"期限切れ","authorize":"タスクを表示するには、設定で Google タスクのリストを選択する必要があります。"},"twitter":{"name":"Twitter","desc":"Twitter のホームや指定したリストからのツイートを表示します。","settings":{"source":"表示するツイート","show":"表示するツイートの数"},"authorize":"まず ProductivityTab を許可する必要があります","authorize_msg":"あなたの Twitter アカウントからツイートを表示するためには、ProductivityTab に許可を与える必要があります。","authorize_btn":"許可","no_tweets":"ツイートがありません","home":"ホーム","mentions":"@ツイート","retweets":"リツイート","lists":"リスト","more":"もっと表示","reply":"返信","retweet":"リツイート","favorite":"お気に入り"},"wolfram":{"name":"Wolfram|Alpha","desc":"Wolfram|Alpha の小さな検索ボックスを挿入します。"},"youtube":{"name":"YouTube","desc":"人気のある動画や指定したユーザーの動画を表示します。","settings":{"format":"表示方法","format_options":{"large":"1個のみ大きく表示","large_2":"1個大きく、2個小さく表示","large_4":"1個大きく、4個小さく表示","four":"4個小さく表示","six":"6個小さく表示"},"from":"表示する動画","from_help":"ユーザーの URL にあるユーザー名を <b>正確に</b> 設定する必要があります。\n<br /><br />\nこの値にスペースが含まれることはありません。","from_placeholder":"空白のままでトップの動画を表示","open":"検索結果の表示"},"search":"YouTube で検索","num_views":"回再生"},"quotes":{"name":"格言","desc":"選りすぐりの格言を1日1回またはページを読み込むたびに表示します。","settings":{"source":"引用元","method":"格言の更新頻度","method_options":{"daily":"1日1回","random":"ページを読み込むごと"}},"unknown_author":"不明"},"html":{"name":"HTML","desc":"iframe 内にカスタム HTML を表示します。","settings":{"html":"HTML","js":"JavaScript","height":"ウィジェットの高さ"}},"sitelink":{"name":"サイトのリンク","desc":"リンクをタイトルやサムネイルとともに表示します。","settings":{"link":"リンク先の URL","link_placeholder":"https://www.google.co.jp/","image":"画像 URL","image_placeholder":"https://www.example.com/image.png","color":"画像の背景色","style":"画像のスタイル","style_fill":"埋める","style_center":"中央揃え"}},"stats":{"name":"システムの統計情報","desc":"リアルタイムのシステム統計情報をいつでも確認することができます。","memory":"メモリ","battery":"バッテリー","usage":"使用中","in_use":"使用中","remaining":" ","charged":"充電完了","idle":"待機中","charging":"充電中","discharging":"放電中"},"search":{"name":"検索","desc":"シンプルな検索ボックスを埋め込みます。","settings":{"placeholder":"検索フィールドのプレースホルダー","search_url":"検索エンジンの URL","param":"クエリのパラメータ","param_placeholder":"クエリを送信するパラメータを入力（例：\"q\"）"},"default_placeholder":"Google で検索"},"pushbullet":{"name":"Pushbullet","desc":"携帯電話など他のデバイスからの通知を表示します。","no_pushes":"プッシュがありません","sign_in":"ログイン","no_key":"Pushbullet にログインしていません。通知を受け取るためにログインしてください。"},"linkedin":{"name":"LinkedIn","desc":"LinkedIn のホームを表示します。"},"directions":{"name":"経路","desc":"目的地までの経路を簡単に検索することができます。","driving":"車","transit":"公共機関","walking":"徒歩","cycling":"自転車","from":"出発地を入力","to":"目的地を入力","loading":"経路を読み込み中です...","error":"経路の読み込みに失敗しました。","error2":"出発地および目的地の住所を確認してください。","open_in_maps":"Google マップで開く","via":"経由"},"pocket":{"name":"Pocket","desc":"Pocket に保存した記事、ビデオ、および Web ページの一覧を表示します。","settings":{"links_shown":"表示するリンクの数","open":"リンクの開き方","open_pocket":"Pocket 内","open_original":"オリジナルの URL"},"by":"By","no_links":"リンクはありません。","grant_access":"アクセスを許可","no_key":"Pocket からリンクを読み込むために、ProductivityTab にアクセス権限を与える必要があります。"}},"themes":{"title":"テーマ","all":"すべて","custom":"カスタム","create":"テーマを作成","url_or_upload":"または","upload_image":"アップロード","edit_btn":"編集","delete":"削除","use":"使用","preview":"プレビュー","author":"By","images":"%s 個の画像","resolution":"解像度","categories":"カテゴリ","cached":"このテーマはキャッシュされ、オフラインで使用可能です","random":"このテーマはページを読み込むたびにランダムな画像を表示します","random_daily":"このテーマは毎日ランダムな画像を表示します","sunrise_sunset":"このテーマは時間によって選ばれた画像を表示します。","feed":"このテーマは毎日外部フィードから選ばれた画像を表示します","video":"このテーマは動画を表示します","pro_only":"このテーマは Pro 版ユーザーのみ利用できます。設定からご購入ください。","delete_confirm":"このテーマを削除してもよろしいですか？\nこの操作を元に戻すことはできません。テーマは完全に削除されます。","delete_error":"テーマを削除中にエラーが発生しました。後でもう一度やり直してください。","feed_fetching":"フィードを取得中です。しばらくお待ちください。","feed_error":"フィードの取得に失敗しました。後でもう一度やり直してください。","caching":"テーマをキャッシュ中です。しばらくお待ちください。","cache_status":"画像のキャッシュ中: %s/%s","cache_error":"テーマをキャッシュ中にエラーが発生しました。後でもう一度やり直してください。","bginfo":{"view":"表示","source":"引用元","unknown":"不明","download":"ダウンロード","pro_only":"Pro 版ユーザーのみが背景画像や動画をダウンロードできます"},"edit":{"title":"テーマを編集","create_title":"テーマを作成","name":"テーマ名","default_name":"新しいテーマ","name_placeholder":"テーマ名を入力","image":"背景画像の URL","image_placeholder":"画像の URL を入力","image_help":"アップロードされた画像は <b>同期ができません</b>。<br /><br />背景画像の同期が必要な場合は、<a href=\"https://imgur.com/\" target=\"_blank\">imgur</a> などのサービスへ画像をアップロードしてから、左のフィールドに .jpg などの拡張子で終わる URL を入力してください。","color":"背景色","color_placeholder":"色の名前を入力","position":"位置","position_options":{"center":"中央揃え","top_left":"左上","top_center":"中央上","top_right":"右上","bottom_left":"左下","bottom_center":"中央下","bottom_right":"右下"},"scaling":"拡大/縮小","scaling_options":{"auto":"自動","width":"最大幅","height":"最大高","none":"拡大/縮小しない (プレビューが不正確な可能性あり)"},"repeat":"背景画像をタイル表示","repeat_options":{"none":"繰り返さない","horizontal":"水平方向に繰り返し","vertical":"垂直方向に繰り返し","both":"両方向に繰り返し"},"attach":"画像の表示場所","attach_tab":"タブ","attach_window":"ウィンドウ","preview":"プレビュー","save":"保存して閉じる","cache_error":"画像の読み込み中にエラーが発生しました。URL が正しいことをご確認ください。","upload_error":"ファイルのアップロード中にエラーが発生しました。ファイルが画像であることと、サイズが適切であることを確認してください。"}}},"nl":{"lang_code":"nl","language":"Nederlands","extName":"ProductivityTab — Custom Homepage Dashboard","newtabName":"ProductivityTab — Custom New Tab Dashboard","extDescription":"A remarkably customizable personal homepage featuring 50+ widgets, breathtaking backgrounds and much more.","newtabDescription":"A customizable personal dashboard on your new tab page featuring 50+ widgets, breathtaking backgrounds and much more.","defaults":{"tab":"Home","me":"Ik"},"remove_widget":"Verwijder","hide_banner":"Hide this banner","hide_ad":{"content":"Hey! We're not crazy about ads either, but we're only able to make ProductivityTab available and continue developing features for our free users (that's you!) by showing ads. If you'd like to support ProductivityTab directly and get rid of ads for free, we would really appreciate if you upgraded to our pro version","upgrade":"Upgrade","hide":"Hide ads"},"alert":{"default_button":"Negeren","confirm_title":"Weet u zeker dat u dit wilt doen?","confirm_continue":"Doorgaan","confirm_cancel":"Annuleren"},"onboarding":{"modal":{"tagline":"Alle sites en apps die je gebruikt op één plek","wrong_extension":"Wilt u ProductivityTab gebruiken als uw nieuw tabblad-pagina?","wrong_extension_newtab":"Wilt u ProductivityTab instellen als uw startpagina?","wrong_extension_action":"Klik hier","about":"Bij ProductivityTab draait alles om tabbladen en widgets","about_desc":"Tabbladen zijn pagina's gevuld met widgets - blokken die zaken zoals het weer, nieuws en uw e-mail tonen. De meeste widgets kunt u aanpassen en u kunt zoveel widgets toevoegen als u wilt.","terms":"Door verder te gaan, gaat u akkoord met de <a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\">voorwaarden</a> en het <a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\">privacybeleid</a> van ProductivityTab","sign_in":"Log in met Google account","sign_in_desc":"Meld u aan met uw Google-account voordat u begint, om uw aanpassingen veilig online op te kunnen slaan.","sign_in_desc2":"U kunt uitgelogd blijven als u wilt, maar uw pagina zal dan niet online opgeslagen worden en zal niet beschikbaar zijn op andere computers.","sign_in_button":"Log in met Google","have_account":"Het lijkt erop dat je al een account hebt!","have_account_desc":"Al uw tabbladen en widgets zijn klaar voor gebruik!","get_started":"Laten we beginnen!","get_started_desc":"Alles is gereed! Laten we uw pagina instellen."},"widgets":{"configure":"Laten we een widget instellen.","configure_desc":"Click the wrench to open a widget's <b>settings</b>.","configure_skip":"Skip Tutorial","settings":"Replace <b>Link URL</b> with your favorite site, then press <b>Save</b>.","move":"You can <b>reposition</b> widgets by clicking and dragging the three dots highlighted here.","remove":"To <b>delete</b>, simply click the red trash bin icon.","done":"Oké, ik snap het"},"settings":{"intro":"Now let’s add a new widget. This highlighted button is where you can access the Widget Menu.","instructions":"Click the new widget button on to open the widget menu!","skip":"Overslaan","tooltips":{"settings":"Het uiterlijk en de functionaliteit van ProductivityTab aanpassen","widgets":"Nieuwe widgets toevoegen - u kunt er zoveel toevoegen als u wilt","editing":"De bewerkingsknoppen op widgets tonen of verbergen","links":"Dit is een lijst met links, voeg in de instellingen sites toe die u regelmatig gebruikt","tabs":"Dit zijn uw tabbladen. U kunt er meer toevoegen bij instellingen","support":"Stuur ons een bericht of laat hier een review achter"},"finished":"Klaar!","finished_next":"Kies een optie uit het menu (probeer bijvoorbeeld <b>Widgets</b>) en stel uw pagina samen!","finished_contact":"Gebruik de supportlink als u hulp nodig heeft. Wij zullen dan zo spoedig mogelijk contact met u opnemen."}},"storage":{"signin":"Log nu in met uw Google-account om uw configuratie veilig op te slaan en te synchroniseren","signin_btn":"Inloggen","signin_dismiss":"Negeer","signin_confirm":{"title":"Lokale gegevens bewaren?","desc":"Wilt u uw lokale gegevens behouden en de configuratie in uw account overschrijven, of wilt u de configuratie van de computer vervangen door de configuratie uit uw account?","keep_account":"Account gebruiken","keep_local":"Lokale gegevens behouden"},"signout_confirm":"Als u zich afmeldt zullen uw lokale back-ups verwijderd worden","pastdue":"Uw abonnement is verlopen","pastdue_desc":"Bewerk uw factuurgegevens in de instellingen"},"toolbar":{"placeholder":"Vul uw zoekopdracht in","placeholder_ok":"Vul uw zoekopdracht in of zeg \"OK, Google\"","suggestions":{"url_subtext":"Visit URL","capture_notice":"ProductivityTab handles searches you normally make from the Omnibox. You can disable this at any time from the settings"},"apps":{"search":"Zoeken","youtube":"YouTube","maps":"Maps","play":"Play","news":"Nieuws","gmail":"Gmail","drive":"Drive","calendar":"Kalender","more":"Meer"}},"menu":{"settings":"Instellingen","widgets":"Widgets","editing":"Bewerken","editing_enabled":"Ingeschakeld","editing_disabled":"Uitgeschakeld","plus":"Google+","tabs":"Tabbladen","footer":{"support":"Help","feedback":"Feedback","review":"Review","terms":"Voorwaarden","privacy":"Privacy","by":"Door Avi Kohn"}},"voice":{"listening":"Luisteren...","searching":"Zoeken naar: %s","missed":"Niet verstaan. <a>Probeer opnieuw</a>"},"settings":{"title":"Instellingen","exit":"Instellingen verlaten","saved":"Instellingen oopgeslagen","nav":{"visual":"Weergave","visual_sections":{"background":"Achtergrond","layout":"Layout","theme":"Thema's","ad_placement":"Ad placement"},"toolbar":"Menubalk","toolbar_sections":{"style":"Stijl","search":"Zoeken","links":"Koppelingen"},"tabs":"Tabbladen","widgets":"Widgets","ads":"Ads","pro":"PRO","accounts":"Account","misc":"Diversen","advanced":"Geavanceerd","advanced_sections":{"backups":"Back-up en herstel","css":"Aangepaste CSS","debug_tools":"Debughulpmiddelen"},"support":"Hulp en ondersteuning","suggest":"Een nieuwe functie voorstellen"},"visual":{"background":{"title":"Achtergrond","desc":"Dit is de afbeelding of set van afbeeldingen die als achtergrond worden weergegeven in uw tabbladen","current":"Huidige achtergrond","custom":"Aangepast","unnamed":"Thema %s","select":"Selecteer een thema","or":"of","url_placeholder":"Voer de URL van een afbeelding in"},"layout":{"title":"Layout","desc":"Hier kunt u het aantal kolommen in elk tabblad aanpassen","columns":"Kolommen","grid":"Raster","columns_number":"Aantal kolommen","column_width":"Kolombreedte","column_width_fixed":"Vast","column_width_fluid":"Flexibel","column_warning":{"column_to_grid":"Overgaan op een raster-gebaseerde lay-out zal al uw widgets verplaatsen naar de linkerbovenhoek.","grid_to_column":"Overgaan op een kolom-gebaseerde lay-out zal al uw widgets verplaatsen naar de eerste kolom."}},"theme":{"title":"App-thema","desc":"Het app-thema bepaalt de stijl van ProductivityTab zelf en alle widgets","preview":"Voorbeeld","light":"Licht (standaard)","dark":"Donker","transparent":"Transparantie","transparent_darker":"Transparant (donkerder)"}},"toolbar":{"style":{"title":"Stijl","desc":"Hiermee wordt de stijl van de werkbalk bepaald. Het kan er normaal uitzien of als een knop die niet in de weg zit","normal":"Standaard","button":"Knop"},"search":{"title":"Zoeken","desc":"Deze instellingen bepalen hoe het zoekvak en de stemzoekfunctie functioneren","engine":"Zoekmachine","engines_default":"Default","engines_custom":"Custom","engines_custom_desc":"Voer een URL in waar de query's naar verzonden moeten worden, met <b>%s</b> waar de query naar moet gaan.","omnibox_capture":"Handle searches normally made in the Omnibox","voice":"Stembediening inschakelen","ok_google":"Schakel \"OK Google\" herkenning in","search_tab":"Open de zoekresultaten in een nieuw tabblad"},"links":{"title":"Koppelingen","desc":"Dit zijn de items aan de rechterkant van de werkbalk","apps":"Apps menu","custom":"Aangepaste links","custom_note1":"Maximaal 3 toegestaan","custom_note2":"gebruikers krijgen 8","custom_name_placeholder":"Koppelingstekst","custom_url_placeholder":"Link URL, bijvoorbeeld: https://www.google.com/"}},"misc":{"link_tab":"Links standaard openen in een nieuw tabblad"},"tabs":{"create_new":"Nieuwe aanmaken","make_default":"Standaard maken","desc1":"Tabbladen zijn pagina's binnen ProductivityTab. Elk tabblad heeft zijn eigen set van widgets die volledig los staat van elke andere tabblad.","desc2":"U kunt schakelen tussen tabbladen door te klikken op de knoppen die aan de linker- en rechterkant van het scherm worden weergegeven wanneer u uw muis over een tabblad beweegt of met behulp van de pijltoetsen op uw toetsenbord.","name_placeholder":"Voer een naam in voor het tabblad","delete_confirm":"Deze actie is onomkeerbaar. Alle gegevens van alle widgets in het tabblad zullen permanent verloren gaan."},"accounts":{"status":{"title":"Status","signed_in":"U bent momenteel <b>ingelogd</b> als %s (%s).","reset_account":"Account resetten","sign_out":"Uitloggen","signed_out":"U bent <b>momenteel niet ingelogd</b>. Meld u nu aan met uw Google-account voor het veilig opslaan en synchroniseren van uw configuratie.","sign_in":"Log in met Google"},"reset_confirm_desc":"Dit zal alle lokale en gesynchroniseerde gegevens verwijderen, er is geen back-up en geen manier om dit ongedaan te maken.","reset_confirm_desc2":"U zult uw gehele huidige configuratie verliezen op alle computers die gekoppeld zijn aan dit account."},"advanced":{"backups":{"title":"Backup maken en terugzetten","desc":"Back-ups zijn volledige kopieën van al uw tabbladen, instellingen en widgets. Ze worden automatisch elke dag gemaakt wanneer u voor het eerst ProductivityTab opent.","desc2":"Gebruik de onderstaande knoppen om ProductivityTab terug te zetten naar een bepaalde datum of om één van uw back-ups te downloaden.","backup":"Nu een back-up maken","upload":"Vanuit bestand terugzetten","download":"Downloaden","restore":"Terugzetten","download_name":"ProductivityTab back-up","restore_confirm":"Dit overschrijft alle lokale en gesynchroniseerde gegevens. U verliest uw gehele huidige configuratie op alle computers die gekoppeld zijn aan dit account.","restore_error":"Er is een fout opgetreden tijdens het verwerken van de verstrekte gegevens, probeer het later opnieuw."},"css":{"title":"Aangepaste CSS","desc":"U kunt CSS (<a href=\"https://developer.mozilla.org/en-US/docs/Web/CSS\" target=\"blank\"> definitie</a>) gebruiken om bijna elk onderdeel van ProductivityTab aan te passen.","placeholder":"Voer hier CSS van maximaal 1000 regels in"},"debug_tools":{"title":"Debughulpmiddelen","desc":"<b>WAARSCHUWING:</b> Deze hulpmiddelen kunnen uw gehele configuratie in een enkele klik wissen. Gebruik ze alleen als uw ontwikkelaar u verzoekt dit te doen.","open":"Open hulpmiddelen"}},"widgets":{"desc1":"Widgets hebben hun eigen instellingen en deze kunnen niet hier aangepast worden.","desc2":"Volg de volgende stappen als u de instellingen van een widget wilt veranderen:","steps1":"Beweeg uw muis over een element","steps2":"Klik op de moersleutelpictogram dat wordt weergegeven aan de bovenkant van de widget. Als er geen pictogram verschijnt heeft de widget geen instellingen die bewerkt kunnen worden.","steps3":"Bewerk één van de instellingen die worden weergegeven in het dialoogvenster dat wordt weergegeven","steps4":"Klik op Opslaan om uw wijzigingen op te slaan, of op elk deel van de achtergrond om ze weg te gooien"},"pro":{"promo":{"monthly_price":"$4.99 per maand","yearly_price":"of $29.99 per jaar","upgrade_btn":"Upgrade nu","business":"Geïnteresseerd in het kopen van Pro voor uw bedrijf of school?","business_contact":"Neem contact met ons op","themes":"Thema's","themes_desc":"Zie meer van uw achtergrond met donkere en transparante thema's","bgs":"Bewegende achtergronden","bgs_desc":"Breng uw pagina tot leven met 20 live HD-achtergronden","widgets":"Maximaliseer widgets","widgets_desc":"Neem ProductivityTab naar een hoger niveau met maximaliseerbare widgets","more_header":"En meer","stocks":"Realtime beursinformatie met uitgebreide en historische informatie","rss":"Ondersteuning voor meerdere RSS-feeds per widget","sports":"Algemeen en kampioenschap-specifiek sportnieuws","tabbed_widgets":"Tabbladen met nieuws en RSS widgets","bg_downloads":"Downloadbare achtergronden","weather":"Weersverwachting per uur tot 10 dagen vooruit","toolbar":"Meer werkbalk links","ads":"A completely ad-free experience","support":"Prioriteeer steun en suggesties","buy_pro":"Koop de volledige versie"},"checkout":{"title":"Uitchecken","updating_title":"Abonnement bijwerken","payment_options":"Betalen","pay_monthly":"Maandelijks ($4.99)","pay_yearly":"Jaarlijks ($29.99)","cancel":"Annuleren","update":"Update","subscribe":"Abonneer","braintree_notice":"Betalingen veilig verwerkt door Braintree.","monthly_notice":"Door u te abonneren, machtigt u ProductivityTab om $4.99 per maand in rekening te brengen totdat u uw abonnement opzegt.","yearly_notice":"Door u te abonneren, machtigt u ProductivityTab om $29.99 per jaar in rekening te brengen totdat u uw abonnement opzegt.","update_notice":"Hoewel de facturering cyclus onmiddellijk gewijzigd wordt, wordt er niets afgeschreven tot de huidige cyclus eindigt.","thank_you":"Dank u voor de aankoop van ProductivityTab Pro!","thank_you2":"ProductivityTab zal binnen enkele seconden opnieuw worden geladen. Daarna bent u klaar!","error":"Er ging iets fout bij het verwerken van uw betaling.","error2":"Probeer het later opnieuw of email ons op support@ichro.me","signin":"Aanmelden","signin_desc":"U moet zich aanmelden voordat u Pro koopt, zodat we zeker zijn dat u het bent","signin_btn":"Aanmelden"},"plan":{"title":"Abonnement","desc":"U bent momenteel geabonneerd op ProductivityTab Pro (%s)","types":{"monthly":"Maandelijks","yearly":"Jaarlijks","business":"Zakelijk","education":"Onderwijs","custom":"Custom"},"uneditable_desc":"Bedrijfsleven, onderwijs, en aangepaste abonnementen kunnen niet worden bijgewerkt binnen ProductivityTab. Gelieve <a href=\"mailto:support@ichro.me\">Neem contact met ons op</a> om uw abonnement bij te werken of te annuleren.","status":"Status","status_active":"Actief","status_trial":"Proefperiode","status_pastdue":"Verlopen","subscription_date":"Abonnementsdatum","paid_through":"Betaald via","next_bill":"Volgende rekening","next_bill_value":"$%s op %s","update_plan":"Plan bijwerken","update_billing":"Facturering bijwerken","cancel":"Abonnement annuleren","cancel_notice":"Uw abonnement zal onmiddellijk worden geannuleerd","cancel_notice2":"Als u graag een restitutie wilt, neem dan gelieve contact met ons op via support@ichro.me"}},"ads":{"text1":"ProductivityTab displays a few small ads to pay for server, support and development costs. With these ads, we can afford to offer ProductivityTab free to everyone.","text2":"Here you can choose where those ads are shown, or buy ad-free to permanently remove them.","text3":"Ad-free is a one-time purchase that permanently removes ads from ProductivityTab wherever you're signed in. You can also upgrade to Pro for extra features in addition to an ad-free experience.","upgrade_btn":"Upgrade to ad-free","already_upgraded":"It looks like you've already upgraded to ad-free","signin":"Aanmelden","signin_desc":"Sign in before upgrading so we can link your purchase to your account","signin_btn":"Aanmelden","thank_you":"Thank you for upgrading to ad-free!","placement":{"title":"Ad placement","left":"In the leftmost column","right":"In the rightmost column","top":"Above the tab","bottom":"Floating at the bottom"}}},"store":{"installation":"Installatie","description":"Beschrijving","preview":"Voorbeeld","instructions":"Sleep elke grote op uw homepage"},"widgets":{"sizes":{"tiny":"Zeer klein","small":"Klein","medium":"Gemiddeld","large":"Groot","variable":"Variabel"},"settings":{"title":"Widget instellingen","save":"Opslaan","size":"Widget afmeting"},"minimize":"Minimaliseren","maximize":"Maximaliseren","delete_confirm":"Ben je echt zeker dat je deze widget wilt verwijderen? Deze actie is onherroepelijk; alle gegevens van deze widget zullen permanent verloren gaan.","permissions_request":{"title":"Toegang vereist","button":"Toegang verlenen","desc":"Deze widget heeft extra machtigingen nodig voordat deze kan worden gebruikt. Verleen toestemming met de knop hieronder."},"error":{"explanation":"Iets ging mis terwijl wij probeerden de widget weer te geven.","advice":"Probeer de widget opnieuw te installeren of de pagina opnieuw te laden. Neem contact op met ons als u dit bericht vaak ziet.","support":"Help","refresh":"Vernieuwen"},"auth":{"message":"U moet deze widget toestemming verlenen tot uw account voordat deze gebruikt kan worden.","button":"Toegang verlenen"},"shared":{"settings":{"title":"Widget titel","title_placeholder":"Voer een titel in of laat leeg om hem te verbergen","height":"Widget hoogte","open_options":{"current":"Het huidige tabblad","blank":"Een nieuw tabblad"},"footer_link":"Voettekst Link","footer_link_options":{"show":"Tonen","hide":"Verbergen"},"account":"Account-ID","account_help":"Als u bij meerdere account bent aangemeld, is dit de \"authuser=\" waarde.\n<br /><br />\nVoorbeeld, als u bij twee accounts bent aangemeld, jsmith1@gmail.com en jsmith2@gmail.com, de \"authuser\" waarde voor jsmith2@gmail.com zou 1 zijn aangezien het het tweede account (beginnend van 0) is waar u bent aangemeld.","account_placeholder":"Uw \"authuser =\" waarde","on":"Aan","off":"Uit"}},"apps":{"name":"Apps","desc":"Laat uw huidige geïnstalleerde Google Chrome applicaties zien.","settings":{"format":"Widget formaat","format_options":{"tiles":"Tegels","list":"Lijst"},"display":"Laat zien","display_options":{"all":"Alle apps","enabled":"Alleen ingeschakelde apps"},"sort":"Sorteren","sort_options":{"id":"ID","alphabetically":"Alfabetisch","offline":"Offline ingeschakeld","available":"Beschikbaarheid"},"open":"Open apps in"},"store_app":"Winkel"},"bookmarks":{"name":"Bladwijzers","desc":"Geselecteerde displays en aangepaste bladwijzers, en andere links.","settings":{"title_placeholder":"Voer een widget titel in","layout":"Layout","layout_options":{"single":"Één kolom","double":"Dubbele kolom"},"open":"Open Bladwijzers in"},"edit":{"dialog_title":"Bladwijzers bijwerken","title":"Bladwijzer titel","title_placeholder":"Google","url":"Bladwijzer URL","url_placeholder":"https://www.google.com/","save":"Opslaan"},"new_caption":"Nieuw","new_bookmark":"Bladwijzer","new_folder":"Map","drop_link":"Link hier neerzetten"},"chrome_bookmarks":{"name":"Bladwijzers","desc":"Laat je Chromen bladwijzers zien,\nzo gewenst van een specifieke map.","settings":{"title_placeholder":"Voer een widget titel in","from":"Laat bladwijzers zien uit","open":"Open Bladwijzers in"}},"calc":{"name":"Rekenmachine","desc":"Laat een rekenmachine zien met ondersteuning voor basisoperatoren.","error":"Fout!","infinity":"Oneindigheid","mismatch":"Onjuiste combinaties van haakjes"},"calendar":{"name":"Agenda","desc":"Toont aanstaande gebeurtenissen uit een of meer van uw Google agenda's.","settings":{"calendar":"Agenda","show":"Laat afspraken zien uit","show_options":{"all":"Alle tijd","today":"Alleen vandaag"}},"title":"Agenda","calendar":"Kalender","noevents":"Geen evenementen gevonden, je zit op schema!"},"clock":{"name":"Klok","desc":"Bied alarm, tijd, timer en stopwatch functionaliteit.","settings":{"timezone":"Tijdzone","timezone_local":"Lokaal","format":"Kloknotatie","format_options":{"ampm":"AM/PM - Digitaal","24hour":"24-uurs - Digitaal","analog":"12-uurs - Analoog","ampmseconds":"AM/PM - Digitaal, geen Seconden","24hourseconds":"24-uurs - Digitaal, geen Seconden"},"sound":"Geluid"},"title":"Klok","alarm":"Wekker","clock":"Klok","timer":"Timer","stopwatch":"Stopwatch","set":"Stel in","unset":"Instelling verwijderen","dismiss":"Negeer","enable_audio":"Schakel geluid in"},"facebook":{"name":"Facebook","desc":"Hiermee sluit u Facebook in in een widget"},"feedly":{"name":"Feedly","desc":"Laat uw Feedly artikelen zien in een configureerbaar formaat.","settings":{"source":"Laat artikelen zien van","source_feeds":"Feeds","show":"Tonen","show_options":{"all":"Alle artikelen","unread":"Alleen ongelezen artikelen"},"layout":"Layout","layout_options":{"titles":"Alleen koppen","magazine":"Tijdschrift","cards":"Kaarten","cards_columns":"Kaarten (twee kolommen)"},"mark":"Markeer een artikel als gelezen wanneer ik","mark_options":{"scroll":"Er voorbij scrol of  erop klik","click":"Gewoon op klikken"},"sort":"Sorteervolgorde","sort_options":{"newest":"Nieuwste eerst","oldest":"Oudste eerst"}},"all":"Alle","saved":"Opgeslagen voor later","uncategorized":"Niet ingedeeld","author":"door","go_to_feedly":"Ga naar Feedly"},"notes":{"name":"Notities","desc":"Voegt een simpele, aanpasbare notitie toe.","settings":{"color":"Notitiekleur","color_options":{"yellow":"Geel","orange":"Oranje","red":"Rood","blue":"Blauw","green":"Groen","white":"Wit"},"font":"Lettertype","fontsize":"Tekstgrootte"}},"now":{"name":"Google Now","desc":"Toon kaarten van Google Now inclusief vluchtstatus en het volgen van pakketten.","authorize":"U zult ProductivityTab toestemming moeten geven om uw Google Now-kaarten te bekijken voordat er iets getoond zal worden.","authorize_btn":"Machtigen","caught_up":"Alles voltooid, hier is niets.","no_title":"Geen titel"},"plus":{"name":"Google+","desc":"Hiermee sluit u Google Plus in in een widget"},"notifications":{"name":"Google notificaties","desc":"Geef uw Google notificaties van services zoals Google+ weer"},"reddit":{"name":"Reddit","desc":"Toont de populairste items op Reddit voor elke opgegeven subreddit.","settings":{"subreddit":"Subreddit","subreddit_help":"Vul een subreddit in dat volgt na <b>/r/</b> op Reddit.\n<br /><br />\n'Technology' is bijvoorbeeld te vinden via: <a href=\"https://www.reddit.com/r/technology\">https://www.reddit.com/r/technology</a>, wat betekent dat u <b>technology</b> invult","subreddit_placeholder":"Geef een subreddit om links ervan te tonen (bijv. technologie)","sort":"Sorteervolgorde","sort_options":{"hot":"Populair","top":"Top","new":"Nieuw","gilded":"Verguld","rising":"Stijgend","controversial":"Controversiële"},"links":"Getoonde links","click":"Laat zien bij het klikken op een link","click_options":{"link":"De link","comments":"De reacties"}},"more":"Meer"},"tasks":{"name":"Taken","desc":"Toont een bewerkbare lijst met taken van een van uw Google Task lijsten.","title":"Taken","settings":{"list":"Lijst"},"task_title":"Titel","due_date":"Vervaldatum","notes":"Notities","add":"Item toevoegen","delete_task":"Verwijder taak","move_up":"Omhoog","move_down":"Omlaag","done":"Klaar","due_today":"Vervalt vandaag","overdue":"Achterstallige","authorize":"U zult een lijst moeten selecteren van uw Google Tasks via instellingen voordat hier iets getoont kan worden."},"twitter":{"name":"Twitter","desc":"Geeft tweets weer van uw tijdlijn of een specifieke lijst.","settings":{"source":"Laat tweets zien van","show":"Tweets weergegeven"},"authorize":"U zult ProductivityTab eerst toestemming moeten geven","authorize_msg":"U zult ProductivityTab eerst toestemming moeten geven om uw tweets te bekijken van uw account voordat er hier iets zal worden weergegeven.","authorize_btn":"Machtigen","no_tweets":"Er schijnen hier geen tweets te zijn...","home":"Home","mentions":"Vermeldingen","retweets":"Mijn retweets","lists":"Lijsten","more":"Meer","reply":"Reageer","retweet":"Retweet","favorite":"Favoriet"},"wolfram":{"name":"Wolfram|Alpha","desc":"Voegt een klein Wolfram|Alpha zoekvak toe."},"youtube":{"name":"YouTube","desc":"Populaire video's of video's van een specifieke gebruiker weergeven.","settings":{"format":"Indeling","format_options":{"large":"Één groot","large_2":"Één groot, twee klein","large_4":"Één groot, vier klein","four":"Vier klein","six":"Zes klein"},"from":"Toon video's van","from_help":"Dit moet een <b>exacte</b> gebruikersnaam zijn zoals weergegeven in de URL van de pagina wanneer u dat profiel bekijkt. <br /><br /> Deze waarde bevat nooit spaties.","from_placeholder":"Laat leeg om de populairste video's te laten zien","open":"Open zoekresultaten in"},"search":"Zoek op YouTube","num_views":"weergaven"},"quotes":{"name":"Citaten","desc":"Geeft een citaat weer van iedere keer dat u de pagina laad of één keer daags.","settings":{"source":"Bron","method":"Nieuwe citaten laden","method_options":{"daily":"Eenmaal dagelijks","random":"Telkens wanneer de pagina wordt geladen"}},"unknown_author":"Onbekend"},"html":{"name":"HTML","desc":"Toont volledig aangepaste HTML-code in een iframe.","settings":{"html":"HTML","js":"JavaScript","height":"Widget hoogte"}},"sitelink":{"name":"Koppeling","desc":"Geeft een link weer, optioneel met een titel en een miniatuurweergave","settings":{"link":"URL","link_placeholder":"https://www.google.com/","image":"Afbeelding-URL","image_placeholder":"https://www.example.com/image.png","color":"Achtergrondkleur","style":"Afbeelding stijl","style_fill":"Vul in","style_center":"Middelpunt"}},"stats":{"name":"Systeem statistieken","desc":"Houd uw systeem in de gaten met realtime statistieken","memory":"Geheugen","battery":"Batterijpercentage","usage":"gebruik","in_use":"in gebruik","remaining":"resterende","charged":"100% opgeladen","idle":"Inactief","charging":"Opladen","discharging":"Ontladen"},"search":{"name":"Zoeken","desc":"Voeg een zoekvak in op uw pagina voor gemakkelijke toegang","settings":{"placeholder":"Plaatsaanduiding voor zoekveld","search_url":"Zoek-URL","param":"Query Parameter","param_placeholder":"De parameter waar de query gaat, dat wil zeggen \"q\""},"default_placeholder":"Zoek met Google"},"pushbullet":{"name":"Pushbullet","desc":"Blijf op de hoogte van notificaties van uw gsm en andere apparaten","no_pushes":"Geen pushberichten gevonden","sign_in":"Aanmelden","no_key":"Het lijkt erop dat u niet bent aangemeld bij Pushbullet.  Log nu in om verbinding te maken met deze widget."},"linkedin":{"name":"LinkedIn","desc":"Geeft uw LinkedIn home stream weer"},"directions":{"name":"Routebeschrijving","desc":"Routebeschrijving naar bijna overal rechtstreeks vanaf uw starpagina","driving":"Onderweg","transit":"Openbaar vervoer","walking":"Wandelen","cycling":"Fietsen","from":"Voer een vertrekpunt in","to":"Voer een bestemming in","loading":"Routebeschrijving laden, moment geduld a.u.b....","error":"Er ging iets fout tijdens het laden van de aanwijzingen die u hebt aangevraagd.","error2":"Controleer het start- en eindpunt en de adressen die u heeft ingevoerd.","open_in_maps":"Open in Google Maps","via":"via"},"pocket":{"name":"Pocket","desc":"Geeft een lijst van uw opgeslagen artikelen, video's en webpagina's van Pocket weer","settings":{"links_shown":"Aantal links weergegeven","open":"Koppelingen openen","open_pocket":"In Pocket","open_original":"Via hun oorspronkelijke URL"},"by":"Door","no_links":"Geen links gevonden","grant_access":"Toegang verlenen","no_key":"U zult ProductivityTab toegang moeten geven tot uw Pocket-account voordat het uw links kan laden."}},"themes":{"title":"Thema's","all":"Alle","custom":"Custom","create":"Een thema maken","url_or_upload":"of","upload_image":"Een afbeelding uploaden","edit_btn":"Bewerken","delete":"Verwijderen","use":"Gebruiken","preview":"Voorbeeld","author":"Door","images":"%s afbeeldingen","resolution":"Resolutie","categories":"Categorieën","cached":"Dit thema is opgeslagen en is nu off-line beschikbaar","random":"Dit thema toont telkens als u de pagina laadt een willekeurige afbeelding","random_daily":"Dit thema toont elke dag een willekeurige afbeelding","sunrise_sunset":"Dit thema toont op basis van de tijd van de dag een afbeelding","feed":"Dit thema toont dagelijks een willekeurige afbeelding uit een externe bron","video":"Dit thema geeft een live video weer","pro_only":"Dit thema is alleen beschikbaar voor Pro-gebruikers. Koop Pro in de instellingen.","delete_confirm":"Weet u zeker dat u dit thema wilt verwijderen? Deze actie is onherroepelijk; het hele thema zal permanent verloren gaan.","delete_error":"Er is een fout opgetreden terwijl u probeerde om het thema te verwijderen.  Probeer het later nog eens.","feed_fetching":"Een moment geduld a.u.b., ophalen van de feed...","feed_error":"Er ging iets fout bij het ophalen van de feed.  Probeer het later nog eens.","caching":"Een moment geduld. caching thema...","cache_status":"%s van %s beelden in de cache opgeslagen","cache_error":"Er is een fout opgetreden terwijl u probeerde om het thema te verwijderen.  Probeer het later nog eens","bginfo":{"view":"Weergave","source":"Bron","unknown":"Onbekend","download":"Downloaden","pro_only":"Alleen Pro-gebruikers kunnen achtergrondafbeelden en -video's downloaden"},"edit":{"title":"Thema bewerken","create_title":"Thema maken","name":"Thema naam","default_name":"Nieuw thema","name_placeholder":"Voer de naam van een thema in","image":"Afbeelding-URL","image_placeholder":"Voer een URL in voor een achtergrondplaatje","image_help":"Afbeeldingen die zijn geüpload <b>kunnen niet worden gesynchroniseerd</b> tussen computers.<br /><br />Als dit belangrijk is voor u, gelieve uw afbeelding te uploaden naar een service zoals <a href=\"https://imgur.com/\" target=\"_blank\">imgur</a>. Kopieer en plak de URL die eindigt met de extentie (bv., .jpg) en plak deze in het veld aan de linkerkant.","color":"Achtergrondkleur","color_placeholder":"Voer een kleurnaam in","position":"Positie","position_options":{"center":"Middelpunt","top_left":"Linksboven","top_center":"Middenboven","top_right":"Rechtsboven","bottom_left":"Linksonder","bottom_center":"Middenonder","bottom_right":"Rechtsonder"},"scaling":"Schalen","scaling_options":{"auto":"Automatisch","width":"Volledige breedte","height":"Volledige hoogte","none":"Niet schalen (preview mogelijk onjuist)"},"repeat":"Afbeelding herhalen","repeat_options":{"none":"Niet herhalen","horizontal":"Herhaal horizontaal","vertical":"Herhaal verticaal","both":"Herhaal beide"},"attach":"Afbeelding toevoegen aan","attach_tab":"Het tabblad","attach_window":"Het venster","preview":"Voorbeeld","save":"Opslaan en sluiten","cache_error":"Er is een error opgetreden tijdens het cachen van uw afbeelding, controleer de URL.","upload_error":"Er is een fout opgetreden tijdens het uploaden van het opgegeven bestand, gelieve ervoor te zorgen dat het een redelijke grootte en afbeelding is."}}},"pl":{"lang_code":"pl","language":"Polski","extName":"ProductivityTab — Custom Homepage Dashboard","newtabName":"ProductivityTab — Custom New Tab Dashboard","extDescription":"A remarkably customizable personal homepage featuring 50+ widgets, breathtaking backgrounds and much more.","newtabDescription":"A customizable personal dashboard on your new tab page featuring 50+ widgets, breathtaking backgrounds and much more.","defaults":{"tab":"Strona głóna","me":"Ja"},"remove_widget":"Usuń","hide_banner":"Ukryj ten baner","hide_ad":{"content":"Hey! We're not crazy about ads either, but we're only able to make ProductivityTab available and continue developing features for our free users (that's you!) by showing ads. If you'd like to support ProductivityTab directly and get rid of ads for free, we would really appreciate if you upgraded to our pro version","upgrade":"Ulepsz","hide":"Ukryj reklamy"},"alert":{"default_button":"Odrzuć","confirm_title":"Czy na pewno chcesz to zrobić?","confirm_continue":"Kontynuuj","confirm_cancel":"Anuluj"},"onboarding":{"modal":{"tagline":"Wszystkie strony i aplikacje których używasz w jednym miejscu","wrong_extension":"Chesz ProductivityTab jako stronę nowej karty?","wrong_extension_newtab":"Chcesz ProductivityTab jako stronę domową?","wrong_extension_action":"Kliknij tutaj","about":"W ProductivityTab'ie wszystko opiera się na kartach i widgetach","about_desc":"Karty to strony wypełnione widgetami - blokami, które pokazuję rzeczy takie jak pogoda, wiadomości i twój e-mail. Możesz skonfigurować większość widgetów i dodać tak dużo jak tylko chcesz.","terms":"Kontynuując zgadzasz się na <a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\">Warunki korzystania z serwisu</a> ProductivityTab. <a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\"> Polityka prywatności</a>","sign_in":"Zaloguj się przy pomocy konta Google","sign_in_desc":"Zaloguj się używając konta Google zanim zaczniesz aby bezpiecznie przechowywać Twoje zmiany online.","sign_in_desc2":"Jeżeli nie chcesz, nie musisz się logować, ale twoja strona nie będzie zapisana online i nie będziesz mieć do niej dostępu z innego komputera.","sign_in_button":"Zaloguj się z Google","have_account":"Wygląda na to, że już masz konto!","have_account_desc":"Wszystkie twoje karty i widgety są gotowe do użycia!","get_started":"Zaczynajmy!","get_started_desc":"Możemy ruszać! Skonfigurujmy twoją stronę."},"widgets":{"configure":"Skonfiguruj swój wigdet.","configure_desc":"Click the wrench to open a widget's <b>settings</b>.","configure_skip":"Skip Tutorial","settings":"Replace <b>Link URL</b> with your favorite site, then press <b>Save</b>.","move":"You can <b>reposition</b> widgets by clicking and dragging the three dots highlighted here.","remove":"To <b>delete</b>, simply click the red trash bin icon.","done":"OK"},"settings":{"intro":"Now let’s add a new widget. This highlighted button is where you can access the Widget Menu.","instructions":"Click the new widget button on to open the widget menu!","skip":"Pomiń","tooltips":{"settings":"Zmień wygląd oraz sposób w jaki działa ProductivityTab","widgets":"Dodaj nowe wigdety - możesz mieć tak dużo jak tylko chcesz","editing":"Pokaż albo ukryj przyciski edycji na widgetach","links":"To jest lista odnośników. dodaj strony których często używasz w ustawieniach","tabs":"To są Twoje karty. Możesz dodać ich więcej w ustawieniach","support":"Wyślij nam wiadomość albo zostaw tutaj swoją recenzję"},"finished":"I już!","finished_next":"Wybierz opcję z menu (spróbuj zacząć od <b>Widgety</b>) i stwórz swój układ strony!","finished_contact":"Użyj odnośnika wsparcia jeśli potrzebujesz pomocy a odpiszemy Ci najszybciej jak to możliwe."}},"storage":{"signin":"Zaloguj się teraz za pomocą konta Google aby bezpiecznie zachowywać i synchronizować swoje ustawienia","signin_btn":"Zaloguj się","signin_dismiss":"Odrzuć","signin_confirm":{"title":"Zachować dane lokalne?","desc":"Czy chcesz zachować swoje dane lokalne i zastąpić ustawienia na swoim koncie, czy zastąpić ustawienia tego komputera tymi które już są na koncie?","keep_account":"Użyj konta","keep_local":"Zachowaj lokalnie"},"signout_confirm":"Wylogowanie spowoduje usunięcie danych lokalnych","pastdue":"Twoja subskrypcja jest nieaktualna","pastdue_desc":"Proszę zaktualizować swoje dane rozliczeniowe w ustawieniach"},"toolbar":{"placeholder":"Wpisz słowa kluczowe","placeholder_ok":"Wpisz słowa kluczowe lub powiedz \"OK, Google\"","suggestions":{"url_subtext":"Odwiedź URL","capture_notice":"ProductivityTab obsługuje wyszukiwania, które normalnie wprowadzasz z omniboksu. Można to wyłączyć w dowolnym momencie w ustawieniach"},"apps":{"search":"Szukaj","youtube":"YouTube","maps":"Mapy","play":"Play","news":"Nowości","gmail":"Gmail","drive":"Drive","calendar":"Kalendarz","more":"Więcej"}},"menu":{"settings":"Ustawienia","widgets":"Widżety","editing":"Edytowanie","editing_enabled":"Aktywne","editing_disabled":"Nieaktywne","plus":"Google+","tabs":"Karty","footer":{"support":"Pomoc","feedback":"Oceń","review":"Opinia","terms":"Warunki","privacy":"Prywatność","by":"Przez Avi Kohn"}},"voice":{"listening":"Słucham...","searching":"Wyszukiwanie: %s","missed":"Nie rozumiem. <a>Spróbuj ponownie</a>"},"settings":{"title":"Ustawienia","exit":"Wyjdź z ustawień","saved":"Ustawienia zapisane","nav":{"visual":"Wygląd","visual_sections":{"background":"Tło","layout":"Układ","theme":"Motyw aplikacji","ad_placement":"Miejsce docelowe reklamy"},"toolbar":"Pasek narzędzi","toolbar_sections":{"style":"Styl","search":"Szukaj","links":"Odnośniki"},"tabs":"Karty","widgets":"Widżety","ads":"Reklamy","pro":"Pro","accounts":"Konto","misc":"Inne","advanced":"Zaawansowane","advanced_sections":{"backups":"Kopia i przywracanie","css":"Niestandardowy CSS","debug_tools":"Narzędzia debugowania"},"support":"Pomoc i wsparcie","suggest":"Zasugeruj funkcjonalność"},"visual":{"background":{"title":"Tło","desc":"To jest obraz lub zbiór obrazów które posłużą jako tło do Twoich kart","current":"Bieżące tło","custom":"Niestandardowy","unnamed":"Motyw %s","select":"Wybierz motyw","or":"lub","url_placeholder":"Wprowadź adres URL obrazu"},"layout":{"title":"Układ","desc":"Tutaj można dostosować typ i liczbę kolumn w każdej karcie","columns":"Kolumny","grid":"Siatka","columns_number":"Liczba kolumn","column_width":"Szerokość kolumny","column_width_fixed":"Stała","column_width_fluid":"Płynna","column_warning":{"column_to_grid":"Zmiana na układ oparty na siatce spowoduje przeniesienie wszystkich twoich widżetów do lewego górnego rogu.","grid_to_column":"Zmiana na układ kolumnowy spowoduje przeniesienie wszystkich twoich widżetów do pierwszej kolumny."}},"theme":{"title":"Motyw aplikacji","desc":"Motyw aplikacji kontroluje styl ProductivityTab i wszystkich widżetów","preview":"Podgląd","light":"Jasny (domyślnie)","dark":"Ciemny","transparent":"Przezroczysty","transparent_darker":"Przezroczysty (ciemniejszy)"}},"toolbar":{"style":{"title":"Styl","desc":"Ta opcja kontroluje styl paska narzędzi. Może pojawiać się normalnie lub jako przycisk","normal":"Domyślny","button":"Przycisk"},"search":{"title":"Szukaj","desc":"Ustawienia te kontrolują, w jaki sposób wyszukiwanie tekstowe i głosowe działają","engine":"Wyszukiwarka","engines_default":"Domyślny","engines_custom":"Niestandardowy","engines_custom_desc":"Jest to adres URL wyszukiwarki który użyje tekstu z pola wyszukiwarki. Umieść <b>%s</b> w miejsce gdzie parametry wyszukiwania mają się znaleźć.","omnibox_capture":"Handle searches normally made in the Omnibox","voice":"Włącz wyszukiwanie głosowe","ok_google":"Włącz detekcje słów \"OK Google\"","search_tab":"Otwórz wyniki wyszukiwania w nowej karcie"},"links":{"title":"Odnośniki","desc":"Są to elementy widoczne po prawej stronie paska narzędzi","apps":"Menu aplikacji","custom":"Linki niestandardowe","custom_note1":"Dozwolone maksymalnie 3","custom_note2":"użytkownicy otrzymują 8","custom_name_placeholder":"Tytuł linku","custom_url_placeholder":"Adres URL linku, przykładowo https://www.google.com/"}},"misc":{"link_tab":"Domyślnie otwieraj linki w nowej karcie"},"tabs":{"create_new":"Stwórz nową","make_default":"Ustaw jako domyślne","desc1":"Karty są stronami wewnątrz ProductivityTab. Każda karta ma swój własny zestaw widżetów, który jest całkowicie oddzielny od pozostałych stron.","desc2":"Możesz przełączać się między kartami poprzez kliknięcie przycisków pojawiających się po prawej i lewej stronie ekranu w czasie ruszania myszką nad karta lub poprzez użycie strzałek na klawiaturze.","name_placeholder":"Podaj nazwę karty","delete_confirm":"Ta akcja jest nieodwracalna. Wszystkie dane z wszystkich widżetów na tej karcie zostaną trwale utracone."},"accounts":{"status":{"title":"Status","signed_in":"Jesteś aktualnie <b>zalogowany/a</b> jako %s (%s).","reset_account":"Zresetuj konto","sign_out":"Wyloguj się","signed_out":"<b>Nie jesteś aktualnie zalogowany</b>. Zaloguj się na swoje konto Google teraz by bezpiecznie przechowywać i synchronizować konfigurację.","sign_in":"Zaloguj się z Google"},"reset_confirm_desc":"Ta akcja usunie wszystkie twoje lokalne i zsynchronizowane dane. Nie istnieje kopia zapasowa i nie ma możliwości cofnięcia tej akcji.","reset_confirm_desc2":"Stracisz swoje wszystkie obecne ustawienia na wszystkich komputerach podłączonych do tego konta."},"advanced":{"backups":{"title":"Kopia i przywracanie","desc":"Kopie zapasowe są kopiami wszystkich twoich kart, ustawień i widgetów. Są one automatycznie tworzone kiedy otwierasz ProductivityTab po raz pierwszy każdego dnia.","desc2":"Użyj przycisków poniżej aby przywrócić ProductivityTab do konkretnej daty lub użyć jednej z twoich kopii zapasowych.","backup":"Utwórz kopię zapasową teraz","upload":"Przywróć z pliku","download":"Pobierz","restore":"Przywróć","download_name":"Kopia zapasowa ProductivityTab","restore_confirm":"Ta akcja spowoduje nadpisanie wszystkich twoich lokalnych i zsynchronizowanych danych. Stracisz wszystkie twoje obecne ustawienia na wszystkich komputerach podłączonych do tego konta.","restore_error":"Wystąpił błąd podczas przetwarzania dostarczonych informacji, prosimy spróbować ponownie później."},"css":{"title":"Niestandardowy CSS","desc":"Możesz użyć kodu CSS (<a href=\"https://developer.mozilla.org/pl/docs/Web/CSS\" target=\"blank\">definicja</a>) do dostosowania prawie każdej części ProductivityTab.","placeholder":"Wprowadź maksymalnie 1000 znaków kodu CSS"},"debug_tools":{"title":"Narzędzia debugowania","desc":"<b>Ostrzeżenie:</b> Narzędzia te mogą usunąć całą konfigurację jednym kliknięciem. Użyj ich tylko jeśli Twój developer tak cię poinstruuje.","open":"Otwórz narzędzia"}},"widgets":{"desc1":"Widgety posiadaj swoje własne ustawienia i nie mogą być tutaj skonfigurowane.","desc2":"Aby edytować ustawienia widgetu, wykonaj następujące kroki:","steps1":"Przesuń kursor myszy nad jakikolwiek widget","steps2":"Kliknij ikonę klucza, który pojawia się w prawym górnym rogu widgetu. Jeśli nie pojawi się ona oznacza to że widget nie ma żadnych ustawień które można dostosowywać.","steps3":"Edytuj ustawienia w oknie które jest wyświetlone","steps4":"Kliknij przycisk Zapisz aby zapisać zmiany lub gdziekolwiek w tło aby je odrzucić"},"pro":{"promo":{"monthly_price":"4.99$ miesięcznie","yearly_price":"lub 29.99$ rocznie","upgrade_btn":"Ulepsz teraz","business":"Zainteresowany kupnem wersji Pro dla Twojej firmy lub szkoły?","business_contact":"Skontaktuj się z nami","themes":"Motywy","themes_desc":"Zobacz więcej teł z ciemnymi lub przezroczystymi motywami","bgs":"Aktywne tła","bgs_desc":"Ożyw swoje strony za pomocą 20 aktywnych teł wysokiej rozdzielczości","widgets":"Zmaksymalizuj widgety","widgets_desc":"Wznieś ProductivityTab na nowy poziom z widgetami z możliwością maksymilizacji","more_header":"I więcej","stocks":"Akcje w czasie rzeczywistym i dane historyczne","rss":"Obsługa wielu kanałów RSS na widżet","sports":"Wiadomości ogólne i specyficzne dla danej ligi sportowej","tabbed_widgets":"Aktualności i kanały RSS w zakładkach","bg_downloads":"Tła do pobrania","weather":"Godzinowa prognoza pogody do 10 dni","toolbar":"Więcej linków w pasku narzędzi","ads":"A completely ad-free experience","support":"Priorytetowa pomoc i sugestie","buy_pro":"Kup wersję Pro"},"checkout":{"title":"Realizuj zamówienie","updating_title":"Aktualizuj plan","payment_options":"Zapłać","pay_monthly":"Miesięcznie ($4.99)","pay_yearly":"Rocznie ($29.99)","cancel":"Anuluj","update":"Uaktualnij","subscribe":"Subskrybuj","braintree_notice":"Płatności bezpiecznie przetwarzane przez Braintree.","monthly_notice":"Zapisując się, zezwalasz by ProductivityTab naliczał $4.99 każdego miesiąca dopóki nie zrezygnujesz z subskrypcji.","yearly_notice":"Zapisując się, zezwalasz by ProductivityTab naliczał $29.99 każdego roku dopóki nie zrezygnujesz z subskrypcji.","update_notice":"Mimo, że zmiany cyklu rozliczeniowego wchodzą w życie natychmiast, nie będziesz obciążony dopóki nie zakończy się aktualny cykl.","thank_you":"Dziękujemy za zakup ProductivityTab Pro!","thank_you2":"ProductivityTab odświeży się w kilka sekund i wszystko będzie gotowe!","error":"Coś poszło nie tak podczas przetwarzania płatności.","error2":"Spróbuj ponownie później lub napisz do nas na support@ichro.me","signin":"Zaloguj się","signin_desc":"Musisz się zalogować przed kupnem planu Pro, dzięki czemu możemy mieć pewność, że to Ty","signin_btn":"Zaloguj się"},"plan":{"title":"Subskrypcja","desc":"Aktualnie subskrybujesz ProductivityTab Pro (%s)","types":{"monthly":"Miesięcznie","yearly":"Rocznie","business":"Biznes","education":"Edukacja","custom":"Niestandardowy"},"uneditable_desc":"Plan Biznes, Edukacja i Niestandardowy nie można zaktualizować z poziomu ProductivityTab. Proszę <a href=\"mailto:support@ichro.me\"> skontaktuj się z nami</a> by dokonać aktualizacji lub rezygnacji z subskrypcji.","status":"Status","status_active":"Aktywny","status_trial":"Wersja próbna","status_pastdue":"Nieaktywne","subscription_date":"Konto aktywne do","paid_through":"Termin płatności","next_bill":"Następna płatność","next_bill_value":"$%s dnia %s","update_plan":"Aktualizuj plan","update_billing":"Aktualizuj dane rozliczeniowe","cancel":"Anuluj subskrypcję","cancel_notice":"Twoja subskrypcja zostanie anulowana natychmiast","cancel_notice2":"Jeśli chcesz zwrotu pieniędzy, napisz do nas na support@ichro.me"}},"ads":{"text1":"ProductivityTab displays a few small ads to pay for server, support and development costs. With these ads, we can afford to offer ProductivityTab free to everyone.","text2":"Here you can choose where those ads are shown, or buy ad-free to permanently remove them.","text3":"Ad-free is a one-time purchase that permanently removes ads from ProductivityTab wherever you're signed in. You can also upgrade to Pro for extra features in addition to an ad-free experience.","upgrade_btn":"Uaktualnij do wersji bez reklam","already_upgraded":"Wygląda na to, że masz już uaktualnione do wersji premium","signin":"Zaloguj się","signin_desc":"Sign in before upgrading so we can link your purchase to your account","signin_btn":"Zaloguj się","thank_you":"Dziękujemy za zakup wersji premium!","placement":{"title":"Miejsce docelowe reklamy","left":"W kolumnie z lewej strony","right":"W kolumnie z prawej strony","top":"Powyżej zakładki","bottom":"Pływające na dole"}}},"store":{"installation":"Instalacja","description":"Opis","preview":"Podgląd","instructions":"Przeciągnij i upuść na stronę główną w dowolnej wielkości"},"widgets":{"sizes":{"tiny":"Malutki","small":"Mały","medium":"Średni","large":"Duży","variable":"Zmienna"},"settings":{"title":"Ustawienia widżetu","save":"Zapisz","size":"Rozmiar widżetu"},"minimize":"Minimalizuj","maximize":"Maksymalizuj","delete_confirm":"Czy naprawdę chcesz usunąć ten widżet? Spowoduje to usunięcie wszystkich danych z tego widżetu. Ta akcja jest nieodwracalna.","permissions_request":{"title":"Wymagany dostęp","button":"Przyznaj dostęp","desc":"Ten widget potrzebuje dodatkowych uprawnień, zanim będzie można go używać. Przyznaj je za pomocą przycisku poniżej."},"error":{"explanation":"Coś poszło nie tak gdy chcieliśmy wyświetlić widżet.","advice":"Spróbuj ponownie zainstalować widżet lub odśwież stronę. Skontaktuj się z nami jeśli problem nie ustępuje.","support":"Pomoc","refresh":"Odśwież"},"auth":{"message":"Musisz przyznać uprawnienia temu widżetowi do swojego konta przed skorzystaniem z niego.","button":"Przyznaj dostęp"},"shared":{"settings":{"title":"Tytuł widżetu","title_placeholder":"Wprowadź tytuł widżetu lub pozostaw puste pole aby ukryć","height":"Wysokość widżetu","open_options":{"current":"Bieżącej karcie","blank":"Nowej karcie"},"footer_link":"Link w stopce","footer_link_options":{"show":"Pokaż","hide":"Ukryj"},"account":"ID Klienta","account_help":"Jeśli posiadasz wiele kont, to jest to wartość \"authuser=\".\n<br /><br />\nNa przykład, gdy zalogujesz się na dwa konta, example1@gmail.com i example2@gmail.com, wartość \"authuser\" dla example2@gmail.com wynosi 1, ponieważ to drugie konto na którym jesteś zalogowany/zalogowana dla \"authuser\" przyjmuje wartość 0 (liczyć od 0 należy).","account_placeholder":"Twoja wartość \"authuser=\"","on":"Włącz","off":"Wyłącz"}},"apps":{"name":"Aplikacje","desc":"Wyświetla aktualnie zainstalowane aplikacje w Google Chrome.","settings":{"format":"Styl widżetu","format_options":{"tiles":"Kafelki","list":"Lista"},"display":"Pokaż","display_options":{"all":"Wszystkie aplikacje","enabled":"Tylko włączone aplikacje"},"sort":"Sortowanie","sort_options":{"id":"ID","alphabetically":"Alfabetycznie","offline":"Włączono w trybie offline","available":"Dostępność"},"open":"Włącz aplikację w"},"store_app":"Sklep"},"bookmarks":{"name":"Zakładki","desc":"Wyświetl zaznaczone i dostosowane zakładki, a także inne linki.","settings":{"title_placeholder":"Wprowadź tytuł widżetu","layout":"Układ","layout_options":{"single":"Pojedyncza kolumna","double":"Podwójna kolumna"},"open":"Otwórz zakładki w"},"edit":{"dialog_title":"Edytuj zakładkę","title":"Tytuł zakładki","title_placeholder":"Google","url":"Adres URL zakładki","url_placeholder":"https://www.google.com/","save":"Zapisz"},"new_caption":"Nowy","new_bookmark":"Zakładka","new_folder":"Nowy folder","drop_link":"Upuść link tutaj"},"chrome_bookmarks":{"name":"Zakładki","desc":"Wyświetla zakładki Chrome, opcjonalnie z określonego folderu.","settings":{"title_placeholder":"Wprowadź tytuł widżetu","from":"Pokaż zakładki z","open":"Otwórz zakładki w"}},"calc":{"name":"Kalkulator","desc":"Wyświetla kalkulator z obsługą podstawowych operatorów.","error":"Wystąpił błąd!","infinity":"Nieskończoność","mismatch":"Niedopasowane nawiasy"},"calendar":{"name":"Kalendarz","desc":"Wyświetla nadchodzące zdarzenia z jednego lub więcej kalendarzy Google.","settings":{"calendar":"Kalendarz","show":"Pokaż wydarzenia z","show_options":{"all":"Cały czas","today":"Dziś tylko"}},"title":"Agenda","calendar":"Kalendarz","noevents":"Nie znaleziono zdarzeń w najbliższej przyszłości. Najwyraźniej masz pusty harmonogram!"},"clock":{"name":"Zegar","desc":"Posiada funkcję alarmu, zegara, minutnika i stopera.","settings":{"timezone":"Strefa czasowa","timezone_local":"Lokalny","format":"Format zegara","format_options":{"ampm":"AM/PM - cyfrowy","24hour":"24 godzinny - cyfrowy","analog":"12 godzinny - analogowy","ampmseconds":"AM/PM - cyfrowy, bez sekund","24hourseconds":"24 godzinny - cyfrowy, bez sekund"},"sound":"Dźwięk alarmu"},"title":"Zegar","alarm":"Alarm","clock":"Zegar","timer":"Minutnik","stopwatch":"Stoper","set":"Ustaw","unset":"Anuluj ustawienie","dismiss":"Odrzuć","enable_audio":"Włącz dźwięk"},"facebook":{"name":"Facebook","desc":"Osadza Facebook w widget'cie"},"feedly":{"name":"Feedly","desc":"Wyświetla teksty z Twojego konta Feedly w konfigurowalnym formacie.","settings":{"source":"Pokaż artykuły z","source_feeds":"Kanały RSS","show":"Pokaż","show_options":{"all":"Wszystkie artykuły","unread":"Tylko nieprzeczytane wiadomości"},"layout":"Układ","layout_options":{"titles":"Tylko tytuły","magazine":"Magazyn","cards":"Karty","cards_columns":"Karty (dwie kolumny)"},"mark":"Zaznacz artykuł jako przeczytany gdy","mark_options":{"scroll":"Przewiniesz dalej lub klikniesz na niego","click":"Klikniesz na niego"},"sort":"Kolejność sortowania","sort_options":{"newest":"Najmłodsze","oldest":"Najstarsze"}},"all":"Wszystko","saved":"Zapisane na później","uncategorized":"Bez kategorii","author":"przez","go_to_feedly":"Przejdź do Feedly"},"notes":{"name":"Notatki","desc":"Wstawia prostą, edytowalną, notatkę.","settings":{"color":"Kolor notatki","color_options":{"yellow":"Żółty","orange":"Pomarańczowy","red":"Czerwony","blue":"Niebieski","green":"Zielony","white":"Biały"},"font":"Krój czcionki","fontsize":"Wielkość czcionki"}},"now":{"name":"Google Now","desc":"Wyświetla karty z Google Now wraz ze statusem lotu i śledzeniem pakietów.","authorize":"Musisz nadać ProductivityTab uprawnienia do wyświetlania karty Google Now, zanim cokolwiek pojawi się tutaj.","authorize_btn":"Przyznaj uprawnienia","caught_up":"Nic tu nie ma, wszystko na czasie.","no_title":"Bez tytułu"},"plus":{"name":"Google+","desc":"Osadza Google Plus w widżecie"},"notifications":{"name":"Powiadomienia Google","desc":"Wyświetla Powiadomienia Google z usług takich jak Google+"},"reddit":{"name":"Reddit","desc":"Wyświetla najpopularniejsze elementy na Reddit dla dowolnego danego subreddita.","settings":{"subreddit":"Subreddit","subreddit_help":"Enter any subreddit by the part past <b>/r/</b> when on Reddit.\n<br /><br />\nFor example, Technology is at: <a href=\"https://www.reddit.com/r/technology\">https://www.reddit.com/r/technology</a>, therefore you would enter <b>technology</b>","subreddit_placeholder":"Wprowadź subreddit aby wyświetlić łącza (np. Technologia)","sort":"Kolejność sortowania","sort_options":{"hot":"Gorący","top":"Góra","new":"Nowy","gilded":"Pozłocone","rising":"Wschodzące","controversial":"Kontrowersyjne"},"links":"Ilość linków","click":"Gdy kliknę link pokaż mi","click_options":{"link":"Link","comments":"Komentarze"}},"more":"Więcej"},"tasks":{"name":"Zadania","desc":"Wyświetla edytowalną listę zadań spośród jednego z Twych zadań Google Tasks.","title":"Zadania","settings":{"list":"Lista"},"task_title":"Tytuł","due_date":"Termin realizacji","notes":"Notatki","add":"Dodaj element","delete_task":"Usuń zadanie","move_up":"Przesuń w górę","move_down":"Przenieś w dół","done":"Wykonano","due_today":"Dzisiaj","overdue":"Zaległe","authorize":"Musisz wybrać listę zadań Google za pomocą ustawień nim cokolwiek będzie mogło być tutaj wyświetlane."},"twitter":{"name":"Twitter","desc":"Wyświetla tweety z Twojego strumienia lub ze wskazanej listy.","settings":{"source":"Pokazuj tweety z","show":"Wyświetlane Tweety"},"authorize":"Musisz wcześniej udzielić ProductivityTab uprawnień","authorize_msg":"Musisz udzielić ProductivityTab uprawnień do oglądania tweetów na Twoim koncie zanim cokolwiek się tu pokaże.","authorize_btn":"Przyznaj uprawnienia","no_tweets":"Wydaje się, że nie ma tu żadnych tweetów...","home":"Strona głóna","mentions":"Wzmianki","retweets":"Retweety moich wiadomości","lists":"Listy","more":"Więcej","reply":"Odpowiedź","retweet":"Retweet","favorite":"Ulubione"},"wolfram":{"name":"Wolfram | Alpha","desc":"Dodaje małe okno wyszukiwania Wolfram|Alpha."},"youtube":{"name":"YouTube","desc":"Wyświetla popularne filmy lub filmy zadanego użytkownika.","settings":{"format":"Format","format_options":{"large":"Jeden duży","large_2":"Jeden duży, dwa małe","large_4":"Jeden duży, cztery małe","four":"Cztery małe","six":"Sześć małych"},"from":"Pokaż Filmy Użytkownika","from_help":"Tu musi być wpisana <b>dokładna</b> nazwa użytkownika, taka jak występuje w URL strony kiedy oglądasz profil użytkownika.\n<br /><br />\nNazwa użytkownika nigdy nie zawiera spacji.","from_placeholder":"Pozostaw puste żeby pokazywać najpopularniejsze filmy","open":"Otwórzy wyniki wyszukiwania w"},"search":"Wyszukaj na YouTube","num_views":"obejrzeń"},"quotes":{"name":"Cytaty","desc":"Wyświetla wybrany cytat albo za każdym razem gdy ładujesz stronę lub raz dziennie.","settings":{"source":"Źródło","method":"Załaduj nowe cytaty","method_options":{"daily":"Raz dziennie","random":"Za każdym razem gdy ładuję stronę"}},"unknown_author":"Nieznane"},"html":{"name":"HTML","desc":"Wyświetla zdefiniowany przez użytkownika kod HTML wewnątrz ramki.","settings":{"html":"HTML","js":"JavaScript","height":"Wysokość widżetu"}},"sitelink":{"name":"Odnośnik","desc":"Wyświetla odnośnik, opcjonalnie z tytułem i miniaturką strony","settings":{"link":"URL odnośnika","link_placeholder":"https://www.google.com/","image":"Adres URL obrazu","image_placeholder":"https://www.example.com/image.png","color":"Kolor tła","style":"Styl obrazu","style_fill":"Wypełnij","style_center":"Środek"}},"stats":{"name":"Statystyki Systemowe","desc":"Monitoruj system przez statystyki wyświetlane w czasie rzeczywistym","memory":"Pamięć","battery":"Bateria","usage":"użycie","in_use":"w użyciu","remaining":"pozostało","charged":"Naładowana","idle":"W stanie spoczynku","charging":"Ładowanie","discharging":"Rozładowywanie"},"search":{"name":"Szukaj","desc":"Łatwy dostęp do okna wyszukiwania przez Twoją stronę","settings":{"placeholder":"Podpowiedź Pola Wyszukiwania","search_url":"Adres URL wyszukiwania","param":"Nazwa Parametru Wyszukiwania","param_placeholder":"Nazwa parametru w którym przekazuje się wyszukiwane zapytanie, np. \"q\""},"default_placeholder":"Wyszukiwarka Google"},"pushbullet":{"name":"Pushbullet","desc":"Otrzymuj powiadomienia z telefonu oraz innych urządzeń","no_pushes":"Brak nowych komunikatów","sign_in":"Zaloguj się","no_key":"Wygląda na to, że nie jesteś zarejestrowany w Pushbullet. Zarejestruj się aby podłączyć ten widżet."},"linkedin":{"name":"LinkedIn","desc":"Wyświetla Twój strumień powiadomień z LinkedIn"},"directions":{"name":"Wyznacz trasę","desc":"Wyznacz trasę z/do niemal dowolnego miejsca, bezpośrednio na swojej stronie domowej","driving":"Samochód","transit":"Transport publiczny","walking":"Pieszo","cycling":"Rower","from":"Miejsce początkowe","to":"Miejsce docelowe","loading":"Wyznaczam trasę, proszę czekać...","error":"Coś poszło nie tak przy próbie wyznaczania zadanej trasy.","error2":"Sprawdź wprowadzone adresy początkowy i docelowy.","open_in_maps":"Otwórz w Mapach Google","via":"przez"},"pocket":{"name":"Pocket","desc":"Wyświetla listę zapisanych artykułów, filmów i stron z serwisu Pocket","settings":{"links_shown":"Liczba wyświetlanych odnośników","open":"Otwórz odnośniki","open_pocket":"W serwisie Pocket","open_original":"W przeglądarce"},"by":"Przez","no_links":"Brak zapisanych odnośników","grant_access":"Przyznaj uprawnienia","no_key":"Musisz przyznać ProductivityTab uprawnienia do Twojego konta Pocket zanim będzie w stanie załadować listę odnośników."}},"themes":{"title":"Motywy","all":"Wszystko","custom":"Niestandardowy","create":"Stwórz motyw","url_or_upload":"lub","upload_image":"Prześlij obraz","edit_btn":"Edytuj","delete":"Usuń","use":"Użyj","preview":"Podgląd","author":"Przez","images":"%s obraz","resolution":"Rozdzielczość","categories":"Kategorie","cached":"Ten motyw jest zbuforowany i jest dostępny offline","random":"Ten motyw wyświetla losowy obraz przy każdym wczytaniu strony","random_daily":"Ten motyw wyświetla losowy obraz każdego dnia","sunrise_sunset":"Ten motyw wyświetla obraz w oparciu o porę dnia","feed":"Ten motyw wyświetla na ten dzień obraz z zewnętrznego źródła","video":"Temat ten wyświetla obraz wideo na żywo","pro_only":"Ten temat dostępny jest tylko dla Pro użytkownika. Zakup plan Pro w ustawieniach.","delete_confirm":"Czy na pewno chcesz usunąć ten motyw? Spowoduje to całkowite usunięcie tego motywu. Ta akcja jest nieodwracalna, cały motyw zostanie trwale utracony.","delete_error":"Wystąpił błąd podczas usuwania motyw. Spróbuj ponownie później.","feed_fetching":"Proszę czekać, pobieranie z źródła obrazów...","feed_error":"Coś poszło nie tak podczas pobierania z źródła obrazów. Spróbuj ponownie później.","caching":"Proszę czekać, buforowanie motywu...","cache_status":"%s z %s obrazów zbuforowanych","cache_error":"Wystąpił błąd podczas buforowania tematu. Spróbuj ponownie później","bginfo":{"view":"Podgląd","source":"Źródło","unknown":"Nieznane","download":"Pobierz","pro_only":"Tylko Pro użytkownicy mogą pobrać obrazy tła i video"},"edit":{"title":"Edytuj motyw","create_title":"Stwórz motyw","name":"Nazwa motywu","default_name":"Nowy motyw","name_placeholder":"Wprowadź nazwę motywu","image":"Adres URL obrazu","image_placeholder":"Wprowadź adres URL obrazu tła","image_help":"Przesłane obrazy <b>nie mogą być zsynchronizowane</b> pomiędzy komputerami.<br /><br />Jeśli jest to dla Ciebie ważne, proszę przesłać obrazy do usług takich jak <a href=\"https://imgur.com/\" target=\"_blank\">imgur</a>. Następnie skopiuj i wklej adres URL kończącego się z rozszerzeniem (np. jpg) i wklej go w polu po lewej stronie.","color":"Kolor awaryjny","color_placeholder":"Wprowadź nazwę koloru","position":"Pozycja","position_options":{"center":"Środek","top_left":"Lewy górny","top_center":"Środkowy górny","top_right":"Prawy górny","bottom_left":"Dolny lewy","bottom_center":"Środkowy dolny","bottom_right":"Prawy dolny"},"scaling":"Skalowanie","scaling_options":{"auto":"Automatyczny","width":"Pełna szerokość","height":"Pełna wysokość","none":"Brak skalowania (podgląd może być niepoprawny)"},"repeat":"Powtórz obraz","repeat_options":{"none":"Nie powtarzaj obrazu","horizontal":"Powtórz poziomo","vertical":"Powtórz pionowo","both":"Powtórz pionowo i poziomo"},"attach":"Dołącz obraz do","attach_tab":"Karty","attach_window":"Okna","preview":"Podgląd","save":"Zapisz i zamknij","cache_error":"Wystąpił błąd podczas próby zbuforowania obrazu które dostarczyłeś, proszę sprawdzić ponownie adres URL.","upload_error":"Wystąpił błąd podczas przesyłania pliku który dostarczyłeś, proszę upewnić się, że jest to rozsądny rozmiar obrazu."}}},"pt-PT":{"lang_code":"pt-PT","language":"Português","extName":"ProductivityTab — Custom Homepage Dashboard","newtabName":"ProductivityTab — Custom New Tab Dashboard","extDescription":"A remarkably customizable personal homepage featuring 50+ widgets, breathtaking backgrounds and much more.","newtabDescription":"A customizable personal dashboard on your new tab page featuring 50+ widgets, breathtaking backgrounds and much more.","defaults":{"tab":"Casa","me":"Eu"},"remove_widget":"Remover","hide_banner":"Hide this banner","hide_ad":{"content":"Hey! We're not crazy about ads either, but we're only able to make ProductivityTab available and continue developing features for our free users (that's you!) by showing ads. If you'd like to support ProductivityTab directly and get rid of ads for free, we would really appreciate if you upgraded to our pro version","upgrade":"Upgrade","hide":"Hide ads"},"alert":{"default_button":"dispensar","confirm_title":"Tem a certeza que quer fazer isto?","confirm_continue":"Continuar","confirm_cancel":"Cancelar"},"onboarding":{"modal":{"tagline":"Todos os seus sites e aplicações em um só lugar","wrong_extension":"Gostaria de utilizar ProductivityTab como sua nova aba?","wrong_extension_newtab":"Gostaria que ProductivityTab fosse a sua página inicial?","wrong_extension_action":"Clique aqui","about":"ProductivityTab é construido á base de abas e mini aplicações.","about_desc":"Abas são preenchidas com mini aplicações em blocos. Por exemplo, a mini aplicação de Meteorologia fica num bloco e em um outro noticias do dia, seus emails etc. Os blocos com as mini aplicações podem ser personalizados da forma que desejar.","terms":"Ao prosseguir, aceita que está de acordo com os <a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\">Termos</a>e com a<a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\">Politica de privacidade\"</a> do ProductivityTab","sign_in":"Inscreva-se com a sua conta do Google","sign_in_desc":"Entre com sua conta do Google antes de começar a gravar as suas alterações de forma segura on-line.","sign_in_desc2":"You can stay signed out if you want, but your page won't be saved online and you won't be able to access it from other computers.","sign_in_button":"Inicie sessão com o Google","have_account":"Parece que você já tem uma conta!","have_account_desc":"Todos os seus separadores e widgets estão prontos a usar!","get_started":"Vamos começar!","get_started_desc":"Está pronto a começar! Vamos preparar a sua página."},"widgets":{"configure":"Vamos configurar um widget.","configure_desc":"Click the wrench to open a widget's <b>settings</b>.","configure_skip":"Skip Tutorial","settings":"Replace <b>Link URL</b> with your favorite site, then press <b>Save</b>.","move":"You can <b>reposition</b> widgets by clicking and dragging the three dots highlighted here.","remove":"To <b>delete</b>, simply click the red trash bin icon.","done":"Compreendi"},"settings":{"intro":"Now let’s add a new widget. This highlighted button is where you can access the Widget Menu.","instructions":"Click the new widget button on to open the widget menu!","skip":"Saltar","tooltips":{"settings":"Change the way ProductivityTab looks and works","widgets":"Add new widgets - you can have as many as you want","editing":"Show or hide the editing buttons on widgets","links":"This is a list of links, add sites you use often in the settings","tabs":"These are your tabs. You can add more in the settings","support":"Send us a message or leave a review here"},"finished":"Está pronto!","finished_next":"Choose an option from the menu (try starting with <b>Widgets</b>) and set your page up!","finished_contact":"Use the support link if you need any help and we'll get back to you ASAP."}},"storage":{"signin":"Sign in with Google now to securely save and sync your configuration","signin_btn":"Inicie sessão","signin_dismiss":"Dismiss","signin_confirm":{"title":"Manter dados locais?","desc":"Would you like to keep your local data, and replace the configuration in your account with it, or replace this computer's configuration with the one already in your account?","keep_account":"Usar a conta","keep_local":"Keep local"},"signout_confirm":"Terminar sessão irá apagar os seus backups locais","pastdue":"A sua subscrição expirou","pastdue_desc":"Por favor, atualize a sua informação de faturação nas configurações"},"toolbar":{"placeholder":"Digite seus termos","placeholder_ok":"Digite seus termos ou diga \"OK, Google\"","suggestions":{"url_subtext":"Visit URL","capture_notice":"ProductivityTab handles searches you normally make from the Omnibox. You can disable this at any time from the settings"},"apps":{"search":"Pesquisar","youtube":"YouTube","maps":"Maps","play":"Play","news":"Noticias","gmail":"Gmail","drive":"Drive","calendar":"Calendario","more":"Mais"}},"menu":{"settings":"Opções","widgets":"Widgets","editing":"Editar","editing_enabled":"Ativada","editing_disabled":"Desativada","plus":"Google Plus","tabs":"Separadores","footer":{"support":"Ajuda","feedback":"Opiniões","review":"Review","terms":"Condições","privacy":"Privacidade","by":"Por Avi Kohn"}},"voice":{"listening":"A ouvir...","searching":"À procura de: %s","missed":"Não entendi. <a>Tente de novo</a>"},"settings":{"title":"Opções","exit":"Sair das configurações","saved":"Definições guardadas","nav":{"visual":"Visualização","visual_sections":{"background":"Imagem de fundo","layout":"Estrutura","theme":"Tema da aplicação","ad_placement":"Ad placement"},"toolbar":"Barra de Ferramentas","toolbar_sections":{"style":"Style","search":"Pesquisar","links":"Links"},"tabs":"Separadores","widgets":"Widgets","ads":"Ads","pro":"Pro","accounts":"Account","misc":"Miscellaneous","advanced":"Advanced","advanced_sections":{"backups":"Backup and restore","css":"Custom CSS","debug_tools":"Debug tools"},"support":"Help and support","suggest":"Suggest a feature"},"visual":{"background":{"title":"Imagem de fundo","desc":"This is the image or set of images shown as a background to your tabs","current":"Current background","custom":"Personalizado","unnamed":"Theme %s","select":"Select a theme","or":"Ou","url_placeholder":"Enter an image URL"},"layout":{"title":"Estrutura","desc":"Here you can adjust the type and number of columns in each tab","columns":"Columns","grid":"Grid","columns_number":"Number of columns","column_width":"Column width","column_width_fixed":"Fixed","column_width_fluid":"Fluid","column_warning":{"column_to_grid":"Changing to a grid-based layout will move all of your widgets to the top left corner.","grid_to_column":"Changing to a column-based layout will move all of your widgets to the first column."}},"theme":{"title":"Tema da aplicação","desc":"The app theme controls the style of ProductivityTab itself and all widgets","preview":"Pré visualização","light":"Light (default)","dark":"Escuro","transparent":"Transparent","transparent_darker":"Transparente (mais escuro)"}},"toolbar":{"style":{"title":"Estilo","desc":"Isto controla o estilo da barra de ferramentas.  Ela pode aparecer normalmente ou como um botão oculto","normal":"Normal","button":"Botão"},"search":{"title":"Pesquisar","desc":"Estas configurações controlam o funcionamento da caixa de pesquisa e função de busca por voz","engine":"Motor de busca","engines_default":"Default","engines_custom":"Personalizado","engines_custom_desc":"Enter a URL that queries should be sent to, with <b>%s</b> where the query should go.","omnibox_capture":"Handle searches normally made in the Omnibox","voice":"Ativar a pesquisa por voz","ok_google":"Ativar a detecção do hotword \"Ok, Google\"","search_tab":"Abrir resultados de busca em novo separador"},"links":{"title":"Ligações","desc":"Estes são os itens mostrados na parte direita da barra de ferramentas","apps":"Menu de aplicações","custom":"Ligações personalizadas","custom_note1":"Máximo de 3 permitidos","custom_note2":"users get 8","custom_name_placeholder":"Texto da ligação","custom_url_placeholder":"URL da ligação, por ex: https://www.google.com/"}},"misc":{"link_tab":"Abrir ligações num novo separador por defeito"},"tabs":{"create_new":"Criar Novo","make_default":"Predefinir","desc1":"Tabs are pages inside ProductivityTab. Each tab has its own set of widgets that is completely separate from every other tab.","desc2":"You can switch between tabs by clicking the buttons that appear at the left and right of the screen when you move your mouse over a tab or by using the arrow keys on your keyboard.","name_placeholder":"Digite um nome de separador","delete_confirm":"Esta ação é irreversível. Todos os dados de todos os widgets serão permanentemente perdidos."},"accounts":{"status":{"title":"Estado","signed_in":"Está actualmente <b>ligado</b> como %s (%s).","reset_account":"Redefinir a conta","sign_out":"Terminar Sessão","signed_out":"You are <b>not currently signed in</b>. Sign in with your Google account now to securely store and sync your configuration.","sign_in":"Iniciar sessão com o Google"},"reset_confirm_desc":"This will erase all local and synced data, there is no backup and no way to undo this.","reset_confirm_desc2":"You will lose your entire current configuration on all computers connected to this account."},"advanced":{"backups":{"title":"Cópia de segurança e restauro","desc":"Cópias de segurança são cópias completas de todos os seus separadores, configurações e widgets. São criadas automaticamente quando você abre o ProductivityTab pela primeira vez em cada dia.","desc2":"Use os botões abaixo para restaurar o ProductivityTab para uma data específica ou transfira uma das suas cópias de segurança.","backup":"Criar Cópia de Segurança agora","upload":"Restaurar a partir de ficheiro","download":"Transferir","restore":"Restaurar","download_name":"Cópia de Segurança do ProductivityTab","restore_confirm":"Isto irá escrever por cima de todos os dados sincronizados e locais. Você vai perder toda a sua configuração atual em todos os computadores nesta conta.","restore_error":"Ocorreu um erro ao tentar analisar os dados fornecidos. Por favor, tente novamente mais tarde."},"css":{"title":"CSS Personalizado","desc":"You can use CSS (<a href=\"https://developer.mozilla.org/en-US/docs/Web/CSS\" target=\"blank\">definition</a>) to customize almost any part of ProductivityTab.","placeholder":"Digite até 1000 caracteres da CSS aqui"},"debug_tools":{"title":"Ferramentas de depuração","desc":"<b>WARNING:</b> These tools can erase your entire configuration in a single click. Only use them if your developer instructs you to.","open":"Open tools"}},"widgets":{"desc1":"Widgets have their own settings and can't be customized here.","desc2":"To edit a widget's settings, follow these steps:","steps1":"Move your mouse over any widget","steps2":"Click the wrench icon that appears at the top right of the widget. If none appears then the widget doesn't have any settings that can be customized.","steps3":"Edit any of the settings shown in the dialog that's displayed","steps4":"Click Save to save your changes, or any part of the background to discard of them"},"pro":{"promo":{"monthly_price":"$4.99 per month","yearly_price":"or $29.99 per year","upgrade_btn":"Upgrade Now","business":"Interested in buying Pro for your business or school?","business_contact":"Contact us","themes":"Temas","themes_desc":"See more of your backgrounds with dark and transparent themes","bgs":"Live backgrounds","bgs_desc":"Bring your page to life with 20 live high-definition backgrounds","widgets":"Maximizable widgets","widgets_desc":"Take ProductivityTab to another level with maximizable widgets","more_header":"And more","stocks":"Realtime stocks with extended and historical information","rss":"Support for multiple RSS feeds per widget","sports":"General and league-specific sports news","tabbed_widgets":"Tabbed news and RSS widgets","bg_downloads":"Downloadable backgrounds","weather":"Hourly weather forecasts up to 10 days out","toolbar":"More toolbar links","ads":"A completely ad-free experience","support":"Prioritized support and suggestions","buy_pro":"Buy Pro"},"checkout":{"title":"Checkout","updating_title":"Update plan","payment_options":"Pay","pay_monthly":"Monthly ($4.99)","pay_yearly":"Yearly ($29.99)","cancel":"Cancelar","update":"Update","subscribe":"Subscribe","braintree_notice":"Payments securely processed by Braintree.","monthly_notice":"By subscribing, you authorize ProductivityTab to charge you $4.99 every month until you cancel your subscription.","yearly_notice":"By subscribing, you authorize ProductivityTab to charge you $29.99 every year until you cancel your subscription.","update_notice":"Although billing cycle changes take effect immediately, you won't be charged until your current cycle ends.","thank_you":"Thank you for buying ProductivityTab Pro!","thank_you2":"ProductivityTab will reload in a few seconds and you'll be all set!","error":"Something went wrong while trying to process your payment.","error2":"Please try again later or email us at support@ichro.me","signin":"Sign in","signin_desc":"You need to sign in before buying Pro so we can make sure it's you","signin_btn":"Sign in"},"plan":{"title":"Plan","desc":"You are currently subscribed to ProductivityTab Pro (%s)","types":{"monthly":"Monthly","yearly":"Yearly","business":"Business","education":"Education","custom":"Personalizado"},"uneditable_desc":"Business, education, and custom plans cannot be updated from within ProductivityTab. Please <a href=\"mailto:support@ichro.me\">contact us</a> to update or cancel your subscription.","status":"Estado","status_active":"Active","status_trial":"Trial","status_pastdue":"Past due","subscription_date":"Subscription date","paid_through":"Paid through","next_bill":"Next bill","next_bill_value":"$%s on %s","update_plan":"Update plan","update_billing":"Update billing","cancel":"Cancel subscription","cancel_notice":"Your subscription will be canceled immediately","cancel_notice2":"If you would like a refund, please contact us at support@ichro.me"}},"ads":{"text1":"ProductivityTab displays a few small ads to pay for server, support and development costs. With these ads, we can afford to offer ProductivityTab free to everyone.","text2":"Here you can choose where those ads are shown, or buy ad-free to permanently remove them.","text3":"Ad-free is a one-time purchase that permanently removes ads from ProductivityTab wherever you're signed in. You can also upgrade to Pro for extra features in addition to an ad-free experience.","upgrade_btn":"Upgrade to ad-free","already_upgraded":"It looks like you've already upgraded to ad-free","signin":"Sign in","signin_desc":"Sign in before upgrading so we can link your purchase to your account","signin_btn":"Sign in","thank_you":"Thank you for upgrading to ad-free!","placement":{"title":"Ad placement","left":"In the leftmost column","right":"In the rightmost column","top":"Above the tab","bottom":"Floating at the bottom"}}},"store":{"installation":"Instalação","description":"Descrição","preview":"Pré visualização","instructions":"Arraste e solte qualquer tamanho para seu homepage"},"widgets":{"sizes":{"tiny":"Minúsculo","small":"Pequeno","medium":"Médio","large":"Grande","variable":"Variável"},"settings":{"title":"Configurações do widget","save":"Gravar","size":"Tamanho do widget"},"minimize":"Minimize","maximize":"Maximize","delete_confirm":"Tem certeza que deseja excluir este widget? Esta ação é irreversível; todos os dados deste widget serão permanentemente perdidos.","permissions_request":{"title":"Access required","button":"Grant Access","desc":"This widget needs extra permissions before it can be used. Grant them using the button below."},"error":{"explanation":"Something went wrong while we were trying to display this widget.","advice":"Try reinstalling the widget or reloading the page. Contact us if you see this message often.","support":"Ajuda","refresh":"Refresh"},"auth":{"message":"You'll need to give this widget access to your account before you can use it.","button":"Grant Access"},"shared":{"settings":{"title":"Título do Widget","title_placeholder":"Insira um widget de título ou deixar em branco para ocultar","height":"Altura do widget","open_options":{"current":"Separador atual","blank":"Novo separador"},"footer_link":"Link do rodapé","footer_link_options":{"show":"Mostrar","hide":"Esconder"},"account":"ID da conta","account_help":"Se você estiver conectado em várias contas, este é o \"authuser =\" valor. <br /> <br /> \nPor exemplo, se você estiver conectado em duas contas, jsmith1@gmail.com e jsmith2@gmail.com, o valor \"authuser\" para jsmith2@gmail.com seria uma vez que é a segunda conta (contando a partir de zero) que está assinado em.\n","account_placeholder":"Seu \"authuser =\" valor","on":"Ligado","off":"Desligado"}},"apps":{"name":"Aplicações","desc":"Exibe seus aplicativos instalados do Google Chrome.","settings":{"format":"Formato do widget","format_options":{"tiles":"Telhas","list":"Lista"},"display":"Mostrar","display_options":{"all":"Todas as aplicações","enabled":"Somente aplicações ativadas"},"sort":"Ordenar","sort_options":{"id":"ID","alphabetically":"Em ordem alfabética","offline":"Offline habilitado","available":"Disponibilidade"},"open":"Aplicações abertas em"},"store_app":"Loja"},"bookmarks":{"name":"Favoritos","desc":"Displays selecionados e favoritos personalizados, e outros links.","settings":{"title_placeholder":"Insira um widget de título","layout":"Estrutura","layout_options":{"single":"Coluna única","double":"Coluna dupla"},"open":"Favoritos  abertos em"},"edit":{"dialog_title":"Editar favoritos","title":"Favoritos Título","title_placeholder":"Google","url":"URL do favorito","url_placeholder":"https://www.google.com","save":"Gravar"},"new_caption":"Novo","new_bookmark":"Favorito","new_folder":"Pasta","drop_link":"Salvar"},"chrome_bookmarks":{"name":"Favoritos","desc":"Displays your Chrome bookmarks, optionally from a specific folder.","settings":{"title_placeholder":"Insira um widget de título","from":"Show bookmarks from","open":"Favoritos  abertos em"}},"calc":{"name":"Calculadora","desc":"Exibe uma calculadora com suporte para operadores básicos.","error":"ERRO!","infinity":"Infinito","mismatch":"Parênteses não correspondentes"},"calendar":{"name":"Calendario","desc":"Exibe os próximos eventos de um ou mais dos seus calendários do Google.","settings":{"calendar":"Calendario","show":"Show events from","show_options":{"all":"All time","today":"Today only"}},"title":"Agenda","calendar":"Calendario","noevents":"No events found in the near future, it looks like your schedule's clear!"},"clock":{"name":"Relógio","desc":"Offers alarm, time, timer, and stopwatch functionality.","settings":{"timezone":"Fuso horário","timezone_local":"Local","format":"Formato de relógio","format_options":{"ampm":"AM / PM - Digital","24hour":"24 horas - Digital","analog":"12 horas - Analógico","ampmseconds":"AM / PM - Digital, não há Segundos","24hourseconds":"24 horas - Digital, não há Segundos"},"sound":"Alert Sound"},"title":"Relógio","alarm":"Alarm","clock":"Relógio","timer":"Timer","stopwatch":"Stopwatch","set":"Set","unset":"Unset","dismiss":"Dismiss","enable_audio":"Enable audio"},"facebook":{"name":"FACEBOOK","desc":"Incorpora o Facebook em um widget"},"feedly":{"name":"Feedly","desc":"Exibe artigos de sua conta Feedly em um formato configurável.","settings":{"source":"Mostrar artigos de","source_feeds":"Feeds","show":"Mostrar","show_options":{"all":"Todos os artigos","unread":"Somente os artigos não-lidos"},"layout":"Estrutura","layout_options":{"titles":"Títulos apenas","magazine":"Revista","cards":"Cartões","cards_columns":"Cartões (duas colunas)"},"mark":"Marcar um artigo como lido quando eu","mark_options":{"scroll":"Rolar após isso ou clique nele","click":"Basta clicar nela"},"sort":"Ordem de classificação","sort_options":{"newest":"Recentes primeiro","oldest":"Antigos primeiro"}},"all":"Tudo\n","saved":"Salvo para mais tarde","uncategorized":"Não categorizado","author":"por","go_to_feedly":"Ir para Feedly"},"notes":{"name":"Notas","desc":"Insere uma simples e editável nota.","settings":{"color":"Cor da Nota","color_options":{"yellow":"Amarelo","orange":"Laranja","red":"Vermelho","blue":"Azul","green":"Verde","white":"Branco"},"font":"Fonte","fontsize":"Tamanho da fonte"}},"now":{"name":"Google Now","desc":"Exibir cartões do Google Now incluindo situações de vôos e rastreio de encomendas.","authorize":"Você precisará dar ao ProductivityTab permissão para ver seus cartões do Google Now antes que algo apareça aqui.","authorize_btn":"Autorizar","caught_up":"Todos apanhados, nada aqui.","no_title":"Sem titulo"},"plus":{"name":"Google+","desc":"Incorpora Google Plus em um Widget"},"notifications":{"name":"Google Notifications","desc":"Displays your Google Notifications from services such as Google+"},"reddit":{"name":"Reddit","desc":"Apresenta os principais itens da Reddit para qualquer subreddit.","settings":{"subreddit":"Subreddit","subreddit_help":"Digite qualquer subreddit pela parte passado <b> / r / </ b> quando no Reddit. <br /> <br /> \nPor exemplo, a tecnologia está em: <a href = \"https://www.reddit.com / r / tecnologia \"> https://www.reddit.com/r/technology </a> , portanto, você deve digitar <b> tecnologia </ b>\n","subreddit_placeholder":"Digite um subreddit para mostrar links de. (Ou seja, a tecnologia)","sort":"Ordem de classificação","sort_options":{"hot":"Quente","top":"Topo","new":"Novo","gilded":"Dourado","rising":"Ascendente","controversial":"Controverso"},"links":"Links mostrados","click":"Quando eu clicar em um link me mostrar","click_options":{"link":"O link","comments":"Os comentários"}},"more":"Mais"},"tasks":{"name":"Tasks","desc":"Displays an editable list of tasks from one of your Google Tasks lists.","title":"Tasks","settings":{"list":"Lista"},"task_title":"Title","due_date":"Due date","notes":"Notas","add":"Adicionar item","delete_task":"Delete Task","move_up":"Move Up","move_down":"Move Down","done":"Done","due_today":"Due today","overdue":"Overdue","authorize":"You'll need to select a list from your Google Tasks via the settings before anything can be displayed here."},"twitter":{"name":"Twitter","desc":"Exibe os tweets do seu fluxo de casa ou de uma lista especificada.","settings":{"source":"Mostrar Tweets de","show":"Tweets mostrados"},"authorize":"Você precisará autorizar ProductivityTab primeiro","authorize_msg":"Você precisará dar ProductivityTab permissão para ver os tweets de sua conta, antes que alguma coisa vai aparecer aqui.","authorize_btn":"Autorizar","no_tweets":"Não parece haver qualquer tweets aqui...","home":"Casa","mentions":"Menções","retweets":"Retweets de mim","lists":"Listas","more":"Mais","reply":"Responder","retweet":"Retweet","favorite":"Favorito"},"wolfram":{"name":"Wolfram|Alpha","desc":"Insere um pequeno Wolfram |Caixa de pesquisa alfa."},"youtube":{"name":"YouTube","desc":"Exibe tanto vídeos populares ou vídeos de um usuário especificado.","settings":{"format":"Formato","format_options":{"large":"Uma grande","large_2":"Um grande, duas pequenas","large_4":"Um grande, quatro pequenas","four":"Quatro pequena","six":"Seis pequeno"},"from":"Mostrar vídeos de","from_help":"Este deve ser um <b> exatamente </ b> nome de usuário, como mostra a URL da página quando você está vendo seu perfil. <br /> <br /> \nEsse valor nunca inclui espaços.\n","from_placeholder":"Deixe em branco para mostrar Melhores Vídeos","open":"Resultados da pesquisa em"},"search":"Pesquisa YouTube","num_views":"Vistas"},"quotes":{"name":"Quotes","desc":"Displays a quote picked either every time you load the page or once daily.","settings":{"source":"Source","method":"Load new quotes","method_options":{"daily":"Once daily","random":"Every time I load the page"}},"unknown_author":"Desconhecido"},"html":{"name":"HTML","desc":"Displays completely custom HTML in an iframe.","settings":{"html":"HTML","js":"JavaScript","height":"Altura do widget"}},"sitelink":{"name":"Site Link","desc":"Displays a link, optionally with a title and thumbnail","settings":{"link":"Link URL","link_placeholder":"https://www.google.com","image":"URL da imagem","image_placeholder":"https://www.example.com/image.png","color":"Image Background Color","style":"Image Style","style_fill":"Fill","style_center":"Centro"}},"stats":{"name":"System Statistics","desc":"Keep an eye on your system with realtime statistics","memory":"Memory","battery":"Battery","usage":"usage","in_use":"in use","remaining":"remaining","charged":"Fully Charged","idle":"Idle","charging":"Charging","discharging":"Discharging"},"search":{"name":"Pesquisar","desc":"Embeds a search box in your page for easy access","settings":{"placeholder":"Search Field Placeholder","search_url":"Procurar por URL","param":"Query Parameter","param_placeholder":"The parameter where the query goes, i.e. \"q\""},"default_placeholder":"Search Google"},"pushbullet":{"name":"Pushbullet","desc":"Keep track of notifications from your phone and other devices","no_pushes":"No pushes found","sign_in":"Sign in","no_key":"It doesn't look like you're signed in to Pushbullet.  Sign in now to connect this widget."},"linkedin":{"name":"LinkedIn","desc":"Displays your LinkedIn home stream"},"directions":{"name":"Directions","desc":"Get directions to and from nearly anywhere right from your homepage","driving":"Condução","transit":"Transporte público","walking":"A pé","cycling":"Cycling","from":"Enter a starting point","to":"Enter a destination","loading":"Loading directions, please wait...","error":"Something went wrong while trying to load the directions you requested.","error2":"Please check the start and destination addresses you entered.","open_in_maps":"Open in Google Maps","via":"via"},"pocket":{"name":"Pocket","desc":"Display a list of your saved articles, videos, and web pages from Pocket","settings":{"links_shown":"Number of links shown","open":"Open links","open_pocket":"In Pocket","open_original":"At their original URL"},"by":"por","no_links":"No links found","grant_access":"Grant access","no_key":"You'll need to give ProductivityTab access to your Pocket account before it can load your links."}},"themes":{"title":"Temas","all":"Tudo\n","custom":"Personalizado","create":"Criar um tema","url_or_upload":"Ou","upload_image":"Carregar uma imagem","edit_btn":"Editar","delete":"Apagar","use":"Utilizar","preview":"Pré visualização","author":"por","images":"%s imagens","resolution":"Resolução","categories":"Categorias","cached":"Este tema foi armazenado em cache e está disponível offline","random":"Este tema exibe uma imagem aleatória cada vez que você carregar a página","random_daily":"Este tema exibe uma imagem escolhida aleatoriamente, todos os dias","sunrise_sunset":"Este tema exibe uma imagem com base na hora do dia","feed":"Este tema apresenta uma imagem selecionada diária de uma alimentação externa","video":"This theme displays a live video","pro_only":"This theme is only available to Pro users. Buy Pro in the settings.","delete_confirm":"Você tem certeza que quer excluir este tema?\nEsta ação é irreversível; o tema completo será perdido permanentemente.","delete_error":"Ocorreu um erro ao tentar excluir o tema.  Por favor, tente novamente mais tarde.","feed_fetching":"Aguarde, buscando feed ...","feed_error":"Algo correu mal ao tentar buscar o feed. Por favor, tente novamente mais tarde.","caching":"Aguarde, carregando o tema ...","cache_status":"%s de %s imagens em cache","cache_error":"Ocorreu um erro ao tentar armazenar em cache o tema. Por favor, tente novamente mais tarde","bginfo":{"view":"View","source":"Source","unknown":"Desconhecido","download":"Transferir","pro_only":"Only Pro users can download background images and videos"},"edit":{"title":"Editar tema","create_title":"Criar tema","name":"Nome do tema","default_name":"Novo tema","name_placeholder":"Digite um nome de tema","image":"URL da imagem","image_placeholder":"Digite a URL para uma imagem de plano de fundo","image_help":"Imagens carregadas <b>não pode ser sincronizado</b> entre computadores. <br /> <br /> Se isso é importante para você, por favor enviar sua imagem para um serviço como o <a href=\"https://imgur.com/\" target=\"_blank\">imgur</a>. Depois copie e cole o URL terminando com uma extensão (ou seja, .jpg) e cole-o no campo do lado esquerdo.","color":"Cor de Fundo","color_placeholder":"Introduza o nome da cor","position":"Posição","position_options":{"center":"Centro","top_left":"Superior esquerdo","top_center":"Superior ao Centro","top_right":"Superior direito","bottom_left":"Inferior esquerdo","bottom_center":"Inferior central","bottom_right":"Inferior direito"},"scaling":"Dimensionamento","scaling_options":{"auto":"Automático","width":"Largura total","height":"Altura total","none":"Sem dimensionamento (visualização pode ser imprecisa)"},"repeat":"Repetição de imagem","repeat_options":{"none":"Não repetir","horizontal":"Repetir horizontalmente","vertical":"Repetir verticalmente","both":"Repetir ambos"},"attach":"Anexar imagem para","attach_tab":"No separador","attach_window":"A janela","preview":"Pré visualização","save":"Salvar & Fechar","cache_error":"Ocorreu um erro ao tentar armazenar em cache a imagem que você forneceu, por favor, verifique novamente a URL.","upload_error":"Ocorreu um erro ao tentar carregar o arquivo que você forneceu, por favor certifique-se que é um tamanho razoável e uma imagem."}}},"ru":{"lang_code":"ru","language":"Русский","extName":"ProductivityTab — Custom Homepage Dashboard","newtabName":"ProductivityTab — Custom New Tab Dashboard","extDescription":"A remarkably customizable personal homepage featuring 50+ widgets, breathtaking backgrounds and much more.","newtabDescription":"A customizable personal dashboard on your new tab page featuring 50+ widgets, breathtaking backgrounds and much more.","defaults":{"tab":"Главная","me":"Я"},"remove_widget":"Удалить","hide_banner":"Спрятать этот баннер","hide_ad":{"content":"Hey! We're not crazy about ads either, but we're only able to make ProductivityTab available and continue developing features for our free users (that's you!) by showing ads. If you'd like to support ProductivityTab directly and get rid of ads for free, we would really appreciate if you upgraded to our pro version","upgrade":"Обновить","hide":"Скрыть рекламу"},"alert":{"default_button":"Отклонить","confirm_title":"Вы уверены что хотите это сделать?","confirm_continue":"Продолжить","confirm_cancel":"Oтменить"},"onboarding":{"modal":{"tagline":"Все Ваши сайты и приложения в одном месте","wrong_extension":"Использовать ProductivityTab на новой вкладке?","wrong_extension_newtab":"Использовать ProductivityTab как домашнюю страницу?","wrong_extension_action":"Нажмите здесь","about":"ProductivityTab - это вкладки и виджеты","about_desc":"Вкладки - это страницы с виджетами; блоками, которые показывают такую информацию, как погода, новости и электронную почту. Вы можете настроить под себя большинство виджетов и добавить их столько, сколько хотите.","terms":"Продолжая, Вы соглашаетесь с <a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\">Условиями использования</a> и <a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\">Политикой конфиденциальности</a>","sign_in":"Войти используя учётную запись Google","sign_in_desc":"Войдите с помощью вашего Google аккаунта перед началом работы для безопасного сохранения изменений.","sign_in_desc2":"Вы можете не использовать аккаунт для входа, если хотите, но тогда Ваша страница не будет сохранена онлайн, и Вы не сможете получить к ней доступ с других компьютеров.","sign_in_button":"Войти с помощью Google","have_account":"Похоже, у Вас уже есть аккаунт!","have_account_desc":"Все ваши вкладки и виджеты готовы к использованию!","get_started":"Давайте начнём!","get_started_desc":"Всё готово! Давайте приступим к настройке Вашей страницы."},"widgets":{"configure":"Давайте настроим виджет.","configure_desc":"Нажмите значок гаечного ключа, чтобы открыть <b>Параметры</b> виджета.","configure_skip":"Пропустить Обучение","settings":"Replace <b>Link URL</b> with your favorite site, then press <b>Save</b>.","move":"You can <b>reposition</b> widgets by clicking and dragging the three dots highlighted here.","remove":"To <b>delete</b>, simply click the red trash bin icon.","done":"Ок"},"settings":{"intro":"Now let’s add a new widget. This highlighted button is where you can access the Widget Menu.","instructions":"Click the new widget button on to open the widget menu!","skip":"Пропустить","tooltips":{"settings":"Изменить вид и работу ProductivityTab","widgets":"Добавить новых виджетов вы можете столько, сколько захотите","editing":"Показать или скрыть кнопки редактирования на виджетах","links":"Это список ссылок, добавить сайты, которые вы используете часто в настройках","tabs":"Это ваши вкладки. Вы можете добавить больше в настройках","support":"Отправьте нам сообщение или оставьте отзыв здесь"},"finished":"Вот и всё!","finished_next":"Выберите вариант из меню (попробуйте начать с <b>Виджетов</b>) и настройте вашу страницу!","finished_contact":"Используйте ссылку службы поддержки, если вам нужна помощь, и мы ответим вам как можно скорее."}},"storage":{"signin":"Войдите при помощи Google, чтобы надежно сохранить и синхронизировать ваши настройки","signin_btn":"Войти","signin_dismiss":"Отклонить","signin_confirm":{"title":"Сохранять данные на моём компьютере?","desc":"Вы хотите сохранить свои локальные данные и заменить ими конфигурацию в своей учетной записи или заменить конфигурацию этого компьютера данными, которые уже находятся в вашей учетной записи?","keep_account":"Сохранить учетную запись","keep_local":"Использовать локальное хранилище"},"signout_confirm":"Выход из аккаунта удалит все локальные резервные копии","pastdue":"Ваша подписка просрочена","pastdue_desc":"Пожалуйста, обновите свою платежную информацию в настройках"},"toolbar":{"placeholder":"Введите запрос","placeholder_ok":"Введите запрос, или скажите \"ОК, Google\"","suggestions":{"url_subtext":"Открыть URL","capture_notice":"ProductivityTab обрабатывает ваши поисковые запросы из Omnibox. Это можно отключить в настройках в любое время"},"apps":{"search":"Поиск","youtube":"YouTube","maps":"Карты","play":"Воспроизвести","news":"Новости","gmail":"Gmail","drive":"Диск","calendar":"Календарь","more":"Ещё"}},"menu":{"settings":"Настройки","widgets":"Виджеты","editing":"Редактирование","editing_enabled":"Включено","editing_disabled":"Отключено","plus":"Google Plus","tabs":"Вкладки","footer":{"support":"Поддержка","feedback":"Обратная связь","review":"Отзыв","terms":"Условия","privacy":"Приватность","by":"От Avi Kohn"}},"voice":{"listening":"Слушаю...","searching":"Ищем: %s","missed":"Непонятно. <a>Повтори</a>"},"settings":{"title":"Настройки","exit":"Назад","saved":"Настройки сохранены","nav":{"visual":"Внешний вид","visual_sections":{"background":"Фоновое изображение","layout":"Раскладка","theme":"Тема приложения","ad_placement":"Расположение рекламы"},"toolbar":"Панель инструментов","toolbar_sections":{"style":"Стиль","search":"Поиск","links":"Ссылки"},"tabs":"Вкладки","widgets":"Виджеты","ads":"Реклама","pro":"Pro","accounts":"Учетная запись","misc":"Прочее","advanced":"Расширенные параметры","advanced_sections":{"backups":"Резервное копирование и восстановление","css":"Пользовательские стили","debug_tools":"Инструменты отладки"},"support":"Справка и поддержка","suggest":"Предложить идею"},"visual":{"background":{"title":"Фоновое изображение","desc":"Это изображение или набор изображений, которые используются как фон для вкладок","current":"Текущий фон","custom":"Свои","unnamed":"Тема %s","select":"Выбрать тему","or":"или","url_placeholder":"Введите URL-адрес изображения"},"layout":{"title":"Раскладка","desc":"Здесь вы можете настроить тип и количество столбцов в каждой вкладке","columns":"Столбцы","grid":"Сетка","columns_number":"Количество столбцов","column_width":"Ширина столбца","column_width_fixed":"Фиксированная","column_width_fluid":"Динамическая","column_warning":{"column_to_grid":"Изменение на раскладку с использованием сетки переместит все ваши виджеты в верхний левый угол.","grid_to_column":"Изменение на раскладку с использованием столбцов переместит все ваши виджеты в первый столбец."}},"theme":{"title":"Тема приложения","desc":"Тема приложения контролирует стиль ProductivityTab и стиль виджетов","preview":"Предпросмотр","light":"Светлая (по умолчанию)","dark":"Темный","transparent":"Прозрачная","transparent_darker":"Прозрачная (темнее)"}},"toolbar":{"style":{"title":"Стиль","desc":"Изменяет отображение панели. Панель может отображаться всегда, либо только при клике по соответствующей кнопке","normal":"Обычный","button":"Кнопочный"},"search":{"title":"Поиск","desc":"Эти параметры определяют то, как будет работать поле поиска и функции голосового поиска","engine":"Поисковая система","engines_default":"По умолчанию","engines_custom":"Свои","engines_custom_desc":"Введите URL, на который будут отправлены запросы, с <0>%s</0>, где находится текст запроса.","omnibox_capture":"Обрабатывать поисковые запросы в Omnibox","voice":"Включить голосовой поиск","ok_google":"Включить распознавание фразы \"OK Google\"","search_tab":"Открывать результаты поиска в новой вкладке"},"links":{"title":"Ссылки","desc":"Это элементы, отображаемые в правой части панели инструментов","apps":"Меню приложений","custom":"Настраиваемые ссылки","custom_note1":"Доступно максимум 3","custom_note2":"пользователи получат 8","custom_name_placeholder":"Текст ссылки","custom_url_placeholder":"Адрес, напр. https://www.google.com/"}},"misc":{"link_tab":"Открывать ссылки в новой вкладке по умолчанию"},"tabs":{"create_new":"Создать новую","make_default":"Сделать главной","desc1":"Вкладки являются страницами внутри ProductivityTab. Каждая вкладка имеет свой собственный набор виджетов, который полностью отделен от другой вкладки.","desc2":"Вы можете переключаться между вкладками, нажимая на кнопки, которые появляются в левой и правой части экрана при перемещении мыши по вкладке или с помощью клавиш со стрелками на клавиатуре.","name_placeholder":"Введите имя вкладки","delete_confirm":"Это действие необратимо. Все данные из всех виджетов в вкладке будут безвозвратно удалены."},"accounts":{"status":{"title":"Состояние","signed_in":"Вы <b>представились</b> как %s (%s).","reset_account":"Сброс учетной записи","sign_out":"Выход","signed_out":"Вы <b>не авторизованы</b>. Авторизуйтесь через аккаунт Google, чтобы надежно сохранить и синхронизировать Ваши настройки.","sign_in":"Войти при помощи Google"},"reset_confirm_desc":"Это сотрет все локальные и синхронизированные данные, У вас нет резервной копии и будет невозможно вернуть все обратно.","reset_confirm_desc2":"Вы потеряете всю текущую конфигурацию на всех компьютерах, подключенных к этой учетной записи."},"advanced":{"backups":{"title":"Резервное копирование и восстановление","desc":"Резервные копии - это полные копии ваших вкладок, настроек и виджетов. Они создаются автоматически каждый день, когда вы в первый раз открываете ProductivityTab.","desc2":"Используйте кнопки ниже, чтобы вернуть ProductivityTab в любое из предыдущих состояние или для загрузки одной из ваших резервных копий.","backup":"Сделать резервную копию","upload":"Восстановить из файла","download":"Скачать","restore":"Восстановить","download_name":"Резервная копия iCrome","restore_confirm":"Это перезапишет все ваши данные, в том числе синхронизированные. Вы потеряете данную конфигурацию на всех компьютерах синхронизированных с этим аккаунтом.","restore_error":"Произошла ошибка при обработке предоставленных данных, повторите попытку позже."},"css":{"title":"Пользовательские стили","desc":"Вы можете использовать CSS (<a href=\"https://developer.mozilla.org/en-US/docs/Web/CSS\" target=\"blank\">что это?</a>) чтобы настроить практически любую часть ProductivityTab.","placeholder":"Напишите CSS-код здесь (до 1000 символов)"},"debug_tools":{"title":"Инструменты отладки","desc":"<b>ВНИМАНИЕ:</b> Эти инструменты могут стереть все Вашу настройки в один клик. Используйте их только если Ваш разработчик попросил об этом.","open":"Открыть инструменты"}},"widgets":{"desc1":"Виджеты имеют свои собственные параметры и не могут быть настроены здесь.","desc2":"Чтобы изменить настройки виджета, выполните следующие действия:","steps1":"Наведите курсор мыши на любой виджет","steps2":"Нажмите на значок гаечного ключа, который появляется в верхней правой части виджета. Если ничего не появляется, значит виджет не имеет параметров, которые могут быть настроены.","steps3":"Измените любой из параметров в отображаемом диалоговом окне","steps4":"Нажмите кнопку Сохранить, чтобы сохранить изменения, или на любой части фона, чтобы отказаться от них"},"pro":{"promo":{"monthly_price":"$4.99 в месяц","yearly_price":"или $29.99 в год","upgrade_btn":"Улучшить сейчас","business":"Заинтересованы в покупке версии Pro для вашей компании или учебного заведения?","business_contact":"Обратная связь","themes":"Темы","themes_desc":"Посмотрите больше ваших фонов с темными и прозрачные темами","bgs":"Живые обои","bgs_desc":"Оживите вашу страницу с 20 живыми заставками высокого разрешения","widgets":"Полноэкранные виджеты","widgets_desc":"Выведите ProductivityTab на новый уровень, с полноэкранными виджетами","more_header":"И многое другое","stocks":"Котировки в режиме реального времени с расширенной информацией","rss":"Поддержка нескольких RSS лент на виджете","sports":"Мировые и спортивные новости","tabbed_widgets":"Вкладки новостей и RSS виджеты","bg_downloads":"Загружаемые обои","weather":"Почасовой прогноз погоды до 10 дней","toolbar":"Больше ссылок в панели инструментов","ads":"Полностью без рекламы","support":"Приоритетная поддержка и предложения","buy_pro":"Обновиться до Pro версии"},"checkout":{"title":"Оформление заказа","updating_title":"Обновить тариф","payment_options":"Оплатить","pay_monthly":"Ежемесячно ($4.99)","pay_yearly":"В год ($29.99)","cancel":"Oтменить","update":"Обновить","subscribe":"Подписаться","braintree_notice":"Платёж успешно обработан в Braintree.","monthly_notice":"Подписываясь, вы потверждаете ежемесячную оплату в размере 4.99$ до момента отписки.","yearly_notice":"Подписываясь, вы потверждаете ежегодную оплату в размере 29.99$ до момента отписки.","update_notice":"Хотя изменения платежного цикла вступают в силу немедленно, вы не будете платить до тех пор, пока ваш текущий цикл не закончится.","thank_you":"Благодарим вас за покупку ProductivityTab Pro!","thank_you2":"ProductivityTab будет перезагружен через несколько секунд, не волнуйтесь всё будет в порядке!","error":"Что-то пошло не так при попытке обработать ваш платёж.","error2":"Пожалуйста, повторите попытку позже или напишите нам на support@ichro.me","signin":"Войти","signin_desc":"Вы должны войти, прежде чем купить Pro, чтобы мы убедились что это вы","signin_btn":"Войти"},"plan":{"title":"Тариф","desc":"В настоящее время Вы подписаны на ProductivityTab Pro (%s)","types":{"monthly":"Ежемесячно","yearly":"Ежегодно","business":"Компания","education":"Учебное заведение","custom":"Свои"},"uneditable_desc":"Бизнес, образование и пользовательские планы не могут обновляться  в ProductivityTab. Пожалуйста, <a href=\"mailto:support@ichro.me\"> свяжитесь с нами</a> для обновления или отмены подписки.","status":"Состояние","status_active":"Активен","status_trial":"Пробный период","status_pastdue":"Просрочено","subscription_date":"Дата подписки","paid_through":"Оплачено до","next_bill":"Следующий платёж","next_bill_value":"$%s в %s","update_plan":"Обновить тариф","update_billing":"Обновить оплату","cancel":"Отменить подписку","cancel_notice":"Ваша подписка будет отменена немедленно","cancel_notice2":"Если вы хотите вернуть платеж, пожалуйста, свяжитесь с нами по support@ichro.me"}},"ads":{"text1":"ProductivityTab показывает немного реламы, чтобы оплачивать сервера и затраты на разработку. С такой рекламой мы можем позволить ProductivityTab быть бесплатным для всех.","text2":"Здесь вы можете выбрать отображаемую рекламу, или купить ad-free, для её полного удаления.","text3":"Ad-free это одноразовая покупка которая полностью удаляет рекламу из ProductivityTab везде, где вы пользуетесь. Вы можете обновить до Pro для получения дополнительных возможностей в дополнение к этому.","upgrade_btn":"Обновить до ad-free","already_upgraded":"Похоже, вы уже обновлены до ad-free","signin":"Войти","signin_desc":"Войдите в свой аккаунт перед обновлением, чтобы была возможность связать покупку с вашим аккаунтом","signin_btn":"Войти","thank_you":"Спасибо за обновление до ad-free!","placement":{"title":"Расположение рекламы","left":"В крайнем левом столбце","right":"В крайнем правом столбце","top":"Над вкладкой","bottom":"Внизу"}}},"store":{"installation":"Установка","description":"Описание","preview":"Предпросмотр","instructions":"Выберите необходимый размер виджета и перетащите его на Вашу страницу"},"widgets":{"sizes":{"tiny":"Очень маленький","small":"Маленький","medium":"Средний","large":"Большой","variable":"Изменяемый"},"settings":{"title":"Настройки виджета","save":"Сохранить","size":"Размер виджета"},"minimize":"Минимизировать","maximize":"Развернуть","delete_confirm":"Вы действительно хотите убрать виджет?\nЭто действие невозможно отменить. Все данные этого виджета будут удалены безвозвратно.","permissions_request":{"title":"Требуется доступ","button":"Предоставить доступ","desc":"Этому виджету необходимы дополнительные разрешения перед использованием. Предоставьте их ему с помощью кнопки ниже."},"error":{"explanation":"Что-то пошло не так при отображении этого виджета.","advice":"Попробуйте переустановить виджет или перезагрузить страницу. Свяжитесь с нами, если вы видите это сообщение очень часто.","support":"Поддержка","refresh":"Обновить"},"auth":{"message":"Вам нужно предоставить доступ виджету к вашей учетной записи для использования его.","button":"Предоставить доступ"},"shared":{"settings":{"title":"Заголовок виджета","title_placeholder":"Введите заголовок виджета или оставьте поле пустым чтобы скрыть заголовок","height":"Высота виджета","open_options":{"current":"Текущая вкладка","blank":"Новая вкладка"},"footer_link":"Ссылка в нижней части виджета","footer_link_options":{"show":"Показать","hide":"Скрыть"},"account":"ID Аккаунта","account_help":"Если вы выполнили вход в несколько учетных записей, это поле принимает значение\"authuser=\".\n<br /><br />\nНапример, если Вы выполнили вход в две учетные записи, jsmith1@gmail.com и jsmith2@gmail.com, значение поля \"authuser\" для jsmith2@gmail.com будет равно 1, поскольку это второй по счету аккаунт (отсчет начинается с нуля)","account_placeholder":"Значение \"authuser=\"","on":"Включить","off":"Выключить"}},"apps":{"name":"Приложения","desc":"Отображает список установленных приложений в Google Chrome.","settings":{"format":"Формат отображения","format_options":{"tiles":"Иконки","list":"Список"},"display":"Показать","display_options":{"all":"Все приложения","enabled":"Только включенные"},"sort":"Сортировка","sort_options":{"id":"По идентификатору","alphabetically":"По алфавиту","offline":"По автономности","available":"По доступности"},"open":"Открывать приложения во вкладке"},"store_app":"Магазин приложений"},"bookmarks":{"name":"Закладки","desc":"Отображает выбранные закладки и ссылки.","settings":{"title_placeholder":"Введите заголовок виджета","layout":"Раскладка","layout_options":{"single":"Один столбец","double":"Два столбца"},"open":"Открывать во вкладке"},"edit":{"dialog_title":"Изменить закладку","title":"Заголовок","title_placeholder":"Google","url":"URL-адрес","url_placeholder":"https://www.google.com/","save":"Сохранить"},"new_caption":"Создать","new_bookmark":"Закладка","new_folder":"Папка","drop_link":"Перетащите ссылку сюда"},"chrome_bookmarks":{"name":"Закладки","desc":"Отображать ваши закладки Chrome, при необходимости из определенной папки.","settings":{"title_placeholder":"Введите заголовок виджета","from":"Отображать закладки из","open":"Открывать во вкладке"}},"calc":{"name":"Калькулятор","desc":"Отображает калькулятор с поддержкой основных математических операций.","error":"Ошибка!","infinity":"Бесконечность","mismatch":"Несоответствие скобок"},"calendar":{"name":"Календарь","desc":"Отображает предстоящие события для одного из ваших календарей Google.","settings":{"calendar":"Календарь","show":"Отображать события из","show_options":{"all":"За всё время (до 40 событий)","today":"Только сегодня"},"view":"Вид календаря","view_options":{"agenda1d":"Сегодня","list2w":"Список","short1d":"Короткий"},"range":{"start":"Сегодня, С","end":"Сегодня, До"}},"title":"Повестка дня","calendar":"Календарь","noevents":"Событий в ближайшем будущем не найдено, Ваше расписание пустое!"},"clock":{"name":"Часы","desc":"Отображает часы с будильником, таймером и секундомером.","settings":{"timezone":"Часовой пояс","timezone_local":"Системный","format":"Формат часов","format_options":{"ampm":"AM/PM - Цифровые","24hour":"24-часовые цифровые","analog":"12-часовые аналоговые","ampmseconds":"AM/PM - цифровые, без секунд","24hourseconds":"24-часовые цифровые, без секунд"},"sound":"Звук оповещения"},"title":"Часы","alarm":"Будильник","clock":"Часы","timer":"Таймер","stopwatch":"Секундомер","set":"Установить","unset":"Отменить","dismiss":"Выключить","enable_audio":"Включить звук"},"facebook":{"name":"Facebook","desc":"Встраивает Facebook в виджет"},"feedly":{"name":"Feedly","desc":"Отображает статьи из вашего профиля Feedly в настраиваемом формате.","settings":{"source":"Показывать статьи из","source_feeds":"Каналы","show":"Показать","show_options":{"all":"Все статьи","unread":"Только непрочитанные"},"layout":"Внешний вид","layout_options":{"titles":"Только заголовки","magazine":"Журнал","cards":"Карточки","cards_columns":"Карточки (два столбца)"},"mark":"Помечать прочтенным при","mark_options":{"scroll":"Прокручивании или клике","click":"Только при клике"},"sort":"Сортировка","sort_options":{"newest":"Сначала новые","oldest":"Сначала старые"}},"all":"Все","saved":"Сохраненные","uncategorized":"Без категории","author":"автор","go_to_feedly":"Перейти к Feedly"},"notes":{"name":"Заметки","desc":"Очень простые заметки.","settings":{"color":"Цвет заметки","color_options":{"yellow":"Желтый","orange":"Оранжевый","red":"Красный","blue":"Синий","green":"Зелёный","white":"Белый"},"font":"Шрифт","fontsize":"Размер шрифта"}},"now":{"name":"Google Now","desc":"Отображает карточки из Google Now, включая такие как статус вашего рейса, отслеживание посылок.","authorize":"Для отображения карточек необходимо авторизовать ProductivityTab в Google Now.","authorize_btn":"Авторизовать","caught_up":"Все в порядке. Здесь еще ничего нет.","no_title":"Без заголовка"},"plus":{"name":"Google+","desc":"Встраивает Google Plus в виджет"},"notifications":{"name":"Уведомления Google","desc":"Отображает ваши уведомления Google, например Google+ и т.п."},"reddit":{"name":"Reddit","desc":"Отображает лучшее с Reddit из любого выбранного субреддита.","settings":{"subreddit":"Subreddit","subreddit_help":"Введите название субреддита без <b>/r/</b>.\n<br /><br />\nНапример полный адрес субреддита Technology выглядит так: <a href=\"https://www.reddit.com/r/technology\">https://www.reddit.com/r/technology</a>, однако в это поле необходимо написать только <b>technology</b>","subreddit_placeholder":"Введите название субреддита (напр. technology)","sort":"Сортировка","sort_options":{"hot":"Горячее","top":"Лучшее","new":"Свежее","gilded":"Золотое","rising":"Набирающее популярность","controversial":"Спорное"},"links":"Количество отображаемых ссылок","click":"При клике по ссылке показывать","click_options":{"link":"Содержимое","comments":"Комментарии"}},"more":"Ещё"},"tasks":{"name":"Задачи","desc":"Отображать редактируемый список задач из одного из ваших списков Google Tasks.","title":"Задачи","settings":{"list":"Список"},"task_title":"Заголовок","due_date":"Дата окончания","notes":"Заметки","add":"Добавить","delete_task":"Удалить задачу","move_up":"Переместить вверх","move_down":"Переместить вниз","done":"Пометить выполненной","due_today":"Завершающиеся сегодня","overdue":"Просроченные","authorize":"Для отображения чего-либо сначала нужно выбрать список в Google Tasks с помощью Настроек."},"twitter":{"name":"Twitter","desc":"Отображает твиты из вашей ленты, или выбранного списка.","settings":{"source":"Отображать твиты из","show":"Количество отображаемых твитов"},"authorize":"Сначала необходимо авторизовать ProductivityTab","authorize_msg":"Для отображения твитов необходимо авторизовать ProductivityTab в вашем аккаунте Twitter.","authorize_btn":"Авторизовать","no_tweets":"Похоже, что здесь нет твитов...","home":"Главная","mentions":"Уведомления","retweets":"Ретвитнули вас","lists":"Списки","more":"Ещё","reply":"Ответить","retweet":"Ретвитнуть","favorite":"В избранное"},"wolfram":{"name":"Wolfram|Alpha","desc":"Отображает поисковую строку Wolfram|Alpha."},"youtube":{"name":"YouTube","desc":"Отображает популярные видео, или канал выбранного пользователя.","settings":{"format":"Формат","format_options":{"large":"Единственное, большое","large_2":"Одно большое, два маленьких","large_4":"Одно большое, четыре маленьких","four":"Четыре маленьких","six":"Шесть маленьких"},"from":"Канал пользователя","from_help":"Значение этого поля должно <b>соответствовать</b> имени пользователя из адреса который Вы видите при просмотре его канала.\n<br /><br />\nПробелов быть не должно!","from_placeholder":"Оставьте это поле пустым для просмотра Лучших Видео","open":"Открывать результаты поиска в"},"search":"Поиск на YouTube","num_views":"просмотров"},"quotes":{"name":"Цитаты","desc":"Отображать выбранную цитату при каждой загрузке страницы либо раз в день.","settings":{"source":"Источник","method":"Загрузить новые цитаты","method_options":{"daily":"Один раз в день","random":"При каждой загрузке страницы"}},"unknown_author":"Неизвестен"},"html":{"name":"HTML","desc":"Отображает пользовательскую HTML-страницу в iframe.","settings":{"html":"HTML","js":"JavaScript","height":"Высота виджета"}},"sitelink":{"name":"Ссылка на сайт","desc":"Отображает ссылку на сайт с заголовком и миниатюрой","settings":{"link":"Адрес ссылки","link_placeholder":"https://www.google.com/","image":"Адрес изображения","image_placeholder":"https://www.example.com/image.png","color":"Цвет фона","style":"Стиль изображения","style_fill":"Заполнить","style_center":"По центру"}},"stats":{"name":"Статистика системы","desc":"Отображает системную информацию в реальном времени","memory":"Память","battery":"Аккумулятор","usage":"используется","in_use":"используется","remaining":"осталось","charged":"Зарядка закончена","idle":"Полностью заряжен","charging":"Зарядка","discharging":"Разрядка"},"search":{"name":"Поиск","desc":"Отображает строку поиска на странице для быстрого доступа","settings":{"placeholder":"Название строки поиска","search_url":"URL для поиска","param":"Параметр запроса","param_placeholder":"Параметр с которым будет выполняться запрос, напр. \"q\""},"default_placeholder":"Поиск в Google"},"pushbullet":{"name":"Pushbullet","desc":"Отслеживать сообщения с вашего телефона и других устройств","no_pushes":"Пуши не найдены","sign_in":"Войти","no_key":"Не похоже, что вы вошли в Pushbullet.  Войдите сейчас для подключения этого виджета."},"linkedin":{"name":"LinkedIn","desc":"Отображает ваш поток LinkedIn"},"directions":{"name":"Маршруты","desc":"Получает почти любые маршруты К и Из прямо с вашей домашней странички","driving":"На автомобиле","transit":"На общественном транспорте","walking":"Пешком","cycling":"На велосипеде","from":"Укажите начальный адрес","to":"Укажите конечный адрес","loading":"Загрузка маршрутов, пожалуйста подождите...","error":"Что-то пошло не так при попытке загрузить запрошенные маршруты.","error2":"Пожалуйста, проверьте введенные вами адреса начала и назначения.","open_in_maps":"Открыть в картах Google","via":"через"},"pocket":{"name":"Pocket","desc":"Отображает список сохраненных статей, видео и веб-страниц из Pocket","settings":{"links_shown":"Количество отображаемых ссылок","open":"Открывать ссылки","open_pocket":"В Pocket","open_original":"По их исходному адресу"},"by":"Автор","no_links":"Ссылки не найдены","grant_access":"Предоставить доступ","no_key":"Вам нужно предоставить для ProductivityTab доступ к учетной записи Pocket для загрузки ссылок."}},"themes":{"title":"Темы","all":"Все","custom":"Свои","create":"Создать свою тему","url_or_upload":"или","upload_image":"Загрузите изображение","edit_btn":"Изменить","delete":"Удалить","use":"Использовать","preview":"Предпросмотр","author":"Автор","images":"%s изображений","resolution":"Разрешение","categories":"Категории","cached":"Тема скачана для использования при отсутствии сети","random":"Тема показывает случайное изображение при каждом открытии страницы","random_daily":"Тема показывает случайно выбранное каждый день изображение","sunrise_sunset":"Тема показывает изображение в зависимости от времени суток","feed":"Тема показывает изображение из внешнего источника","video":"Эта тема отображает живое видео","pro_only":"Эта тема доступна только для Pro пользователей. Купить Pro можно в настройках.","delete_confirm":"Вы действительно хотите удалить эту тему?\nЭто действие невозможно отменить.","delete_error":"Ошибка удаления темы. Попробуйте снова.","feed_fetching":"Подождите, лента загружается...","feed_error":"Что-то пошло не так при загрузке ленты. Попробуйте повторить попытку позже.","caching":"Тема скачивается. Пожалуйста, подождите...","cache_status":"скачано %s из %s изображений","cache_error":"Ошибка скачивания темы. Попробуйте снова","bginfo":{"view":"Просмотр","source":"Источник","unknown":"Перевод отсутствует","download":"Скачать","pro_only":"Только Pro пользователи могут скачивать обои и видео"},"edit":{"title":"Изменить тему","create_title":"Создать тему","name":"Название темы","default_name":"Новая тема","name_placeholder":"Введите название темы","image":"Адрес изображения","image_placeholder":"Введите URL-адрес изображения","image_help":"Загружаемые изображения <b>не синхронизируются</b> между компьютерами<br /><br />Если для вас это имеет значение - загружайте изображения на сервисы типа <a href=\"https://imgur.com/\" target=\"_blank\">imgur</a>, а затем вставляйте полную ссылку (с расширением, напр .jpg) в поле слева.","color":"Цвет по умолчанию","color_placeholder":"Введите название цвета (на англ)","position":"Положение","position_options":{"center":"По центру","top_left":"Сверху слева","top_center":"Сверху по центру","top_right":"Сверху справа","bottom_left":"Снизу слева","bottom_center":"Снизу по центру","bottom_right":"Снизу справа"},"scaling":"Растяжение","scaling_options":{"auto":"Автоматически","width":"На всю ширину","height":"На всю высоту","none":"Без растяжения (предпросмотр может показать это криво)"},"repeat":"Заполнение изображением","repeat_options":{"none":"Без повтора","horizontal":"Повторять по горизонтали","vertical":"Повторять по вертикали","both":"Повторять в обе стороны"},"attach":"Прицепить изображение к","attach_tab":"Текущей вкладке","attach_window":"Текущему окну","preview":"Предпросмотр","save":"Сохранить и Закрыть","cache_error":"Возникла ошибка при попытке загрузить изображение по указанной ссылке. Пожалуйста, перепроверьте адрес.","upload_error":"Возникла ошибка при попытке загрузить файл. Пожалуйста, убедитесь в том, что это действительно изображение."}}},"sr":{"lang_code":"sr","language":"Енглески","extName":"ProductivityTab — Custom Homepage Dashboard","newtabName":"ProductivityTab — Custom New Tab Dashboard","extDescription":"A remarkably customizable personal homepage featuring 50+ widgets, breathtaking backgrounds and much more.","newtabDescription":"A customizable personal dashboard on your new tab page featuring 50+ widgets, breathtaking backgrounds and much more.","defaults":{"tab":"Почетна страна","me":"Ja"},"remove_widget":"Ukloni","hide_banner":"Hide this banner","hide_ad":{"content":"Hey! We're not crazy about ads either, but we're only able to make ProductivityTab available and continue developing features for our free users (that's you!) by showing ads. If you'd like to support ProductivityTab directly and get rid of ads for free, we would really appreciate if you upgraded to our pro version","upgrade":"Upgrade","hide":"Hide ads"},"alert":{"default_button":"Одбаци","confirm_title":"Да ли сте сигурни да желите то урадити?","confirm_continue":"Настави","confirm_cancel":"Поништи"},"onboarding":{"modal":{"tagline":"Све локације и апликације које користите, на једном месту","wrong_extension":"Желите ли, уместо тога, ProductivityTab на новој картици?","wrong_extension_newtab":"Желите ли, уместо тога, ProductivityTab на матичној страници?","wrong_extension_action":"Кликните овде","about":"ProductivityTab's all about tabs and widgets","about_desc":"Tabs are pages filled with widgets - blocks that show things like the weather, news, and your email. You can customize most widgets and add as many as you want.","terms":"Уколико наставите, прихватате  ProductivityTab-ове <a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\"> услове </a> и <a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\">политику приватности</a>","sign_in":"Пријавите се са Google налогом","sign_in_desc":"Пријавите се са својим Google налогом пре почетка како би безбедно сачували своје измене на мрежи (online).","sign_in_desc2":"Ако желите, можете остати одјављени, али Ваша страница неће бити сачувана на мрежи и нећете моћи да јој приступите са других рачунара.","sign_in_button":"Пријавите се са Google-ом","have_account":"Изгледа да већ имате налог!","have_account_desc":"All your tabs and widgets are ready to use!","get_started":"Хајде да почнемо!","get_started_desc":"Спремни сте да кренете! Хајде да подесимо Вашу страницу."},"widgets":{"configure":"Let's configure a widget.","configure_desc":"Кликните на кључ (дугме са иконицом француског кључа) да бисте отворили алатку (widget) за време <b>settings</b>.","configure_skip":"Skip Tutorial","settings":"Replace <b>Link URL</b> with your favorite site, then press <b>Save</b>.","move":"You can <b>reposition</b> widgets by clicking and dragging the three dots highlighted here.","remove":"To <b>delete</b>, simply click the red trash bin icon.","done":"Got it"},"settings":{"intro":"Now let’s add a new widget. This highlighted button is where you can access the Widget Menu.","instructions":"Click the new widget button on to open the widget menu!","skip":"Прескочи","tooltips":{"settings":"Change the way ProductivityTab looks and works","widgets":"Add new widgets - you can have as many as you want","editing":"Show or hide the editing buttons on widgets","links":"This is a list of links, add sites you use often in the settings","tabs":"These are your tabs. You can add more in the settings","support":"Send us a message or leave a review here"},"finished":"That's it!","finished_next":"Choose an option from the menu (try starting with <b>Widgets</b>) and set your page up!","finished_contact":"Use the support link if you need any help and we'll get back to you ASAP."}},"storage":{"signin":"Sign in with Google now to securely save and sync your configuration","signin_btn":"Sign in","signin_dismiss":"Dismiss","signin_confirm":{"title":"Keep local data?","desc":"Would you like to keep your local data, and replace the configuration in your account with it, or replace this computer's configuration with the one already in your account?","keep_account":"Use account","keep_local":"Keep local"},"signout_confirm":"Signing out will erase your local backups","pastdue":"Your subscription is past due","pastdue_desc":"Please update your billing information in the settings"},"toolbar":{"placeholder":"Унеси тражене термине","placeholder_ok":"Унеси тражене термине и кажи \"OK, Google\"","suggestions":{"url_subtext":"Visit URL","capture_notice":"ProductivityTab handles searches you normally make from the Omnibox. You can disable this at any time from the settings"},"apps":{"search":"Претражи","youtube":"YouTube","maps":"Мапе","play":"Play","news":"Вести","gmail":"Gmail","drive":"Drive","calendar":"Календар","more":"Још"}},"menu":{"settings":"Подешавања","widgets":"Додаци","editing":"Уређивање","editing_enabled":"Укључено","editing_disabled":"Искључено","plus":"Google Plus","tabs":"Картице","footer":{"support":"Подршка","feedback":"Ваше мишљење","review":"Мишљења других","terms":"Terms","privacy":"Privacy","by":"Направио Ави Кон"}},"voice":{"listening":"Слушање...","searching":"Тражење: %s","missed":"Није обављено. <a>Пробај поново</a>"},"settings":{"title":"Подешавања","exit":"Exit settings","saved":"Settings saved","nav":{"visual":"Visual","visual_sections":{"background":"Background","layout":"Распоред","theme":"App theme","ad_placement":"Ad placement"},"toolbar":"Toolbar","toolbar_sections":{"style":"Style","search":"Претражи","links":"Links"},"tabs":"Картице","widgets":"Додаци","ads":"Ads","pro":"Pro","accounts":"Account","misc":"Miscellaneous","advanced":"Advanced","advanced_sections":{"backups":"Backup and restore","css":"Custom CSS","debug_tools":"Debug tools"},"support":"Help and support","suggest":"Suggest a feature"},"visual":{"background":{"title":"Background","desc":"This is the image or set of images shown as a background to your tabs","current":"Current background","custom":"Прилагођено","unnamed":"Theme %s","select":"Select a theme","or":"или","url_placeholder":"Enter an image URL"},"layout":{"title":"Распоред","desc":"Here you can adjust the type and number of columns in each tab","columns":"Columns","grid":"Grid","columns_number":"Number of columns","column_width":"Column width","column_width_fixed":"Fixed","column_width_fluid":"Fluid","column_warning":{"column_to_grid":"Changing to a grid-based layout will move all of your widgets to the top left corner.","grid_to_column":"Changing to a column-based layout will move all of your widgets to the first column."}},"theme":{"title":"App theme","desc":"The app theme controls the style of ProductivityTab itself and all widgets","preview":"Погледај пре објаве","light":"Light (default)","dark":"Тамно","transparent":"Transparent","transparent_darker":"Transparent (darker)"}},"toolbar":{"style":{"title":"Style","desc":"This controls the style of the toolbar.  It can either appear normally or as an out of the way button","normal":"Normal","button":"Button"},"search":{"title":"Претражи","desc":"These settings control how the search box and voice search function","engine":"Search engine","engines_default":"Default","engines_custom":"Прилагођено","engines_custom_desc":"Enter a URL that queries should be sent to, with <b>%s</b> where the query should go.","omnibox_capture":"Handle searches normally made in the Omnibox","voice":"Enable voice search","ok_google":"Enable \"OK Google\" hotword detection","search_tab":"Open search results in a new tab"},"links":{"title":"Links","desc":"These are the items shown at the right of the toolbar","apps":"Apps menu","custom":"Custom links","custom_note1":"Maximum of 3 allowed","custom_note2":"users get 8","custom_name_placeholder":"Link text","custom_url_placeholder":"Link URL, i.e. https://www.google.com/"}},"misc":{"link_tab":"Open links in a new tab by default"},"tabs":{"create_new":"Create new","make_default":"Make default","desc1":"Tabs are pages inside ProductivityTab. Each tab has its own set of widgets that is completely separate from every other tab.","desc2":"You can switch between tabs by clicking the buttons that appear at the left and right of the screen when you move your mouse over a tab or by using the arrow keys on your keyboard.","name_placeholder":"Enter a tab name","delete_confirm":"This action is irreversible. All data from all widgets in the tab will be permanently lost."},"accounts":{"status":{"title":"Status","signed_in":"You are currently <b>signed in</b> as %s (%s).","reset_account":"Reset account","sign_out":"Sign out","signed_out":"You are <b>not currently signed in</b>. Sign in with your Google account now to securely store and sync your configuration.","sign_in":"Sign in with Google"},"reset_confirm_desc":"This will erase all local and synced data, there is no backup and no way to undo this.","reset_confirm_desc2":"You will lose your entire current configuration on all computers connected to this account."},"advanced":{"backups":{"title":"Backup and restore","desc":"Backups are complete copies of all your tabs, settings, and widgets. They're automatically created when you first open ProductivityTab each day.","desc2":"Use the buttons below to roll ProductivityTab back to a particular date or download one of your backups.","backup":"Backup now","upload":"Restore from file","download":"Download","restore":"Restore","download_name":"ProductivityTab Backup","restore_confirm":"This will overwrite all local and synced data. You will lose your entire current configuration on all computers under this account.","restore_error":"An error occurred while trying to parse the provided data, please try again later."},"css":{"title":"Custom CSS","desc":"You can use CSS (<a href=\"https://developer.mozilla.org/en-US/docs/Web/CSS\" target=\"blank\">definition</a>) to customize almost any part of ProductivityTab.","placeholder":"Enter up to 1000 characters of CSS here"},"debug_tools":{"title":"Debug tools","desc":"<b>WARNING:</b> These tools can erase your entire configuration in a single click. Only use them if your developer instructs you to.","open":"Open tools"}},"widgets":{"desc1":"Widgets have their own settings and can't be customized here.","desc2":"To edit a widget's settings, follow these steps:","steps1":"Move your mouse over any widget","steps2":"Click the wrench icon that appears at the top right of the widget. If none appears then the widget doesn't have any settings that can be customized.","steps3":"Edit any of the settings shown in the dialog that's displayed","steps4":"Click Save to save your changes, or any part of the background to discard of them"},"pro":{"promo":{"monthly_price":"$4.99 per month","yearly_price":"or $29.99 per year","upgrade_btn":"Upgrade Now","business":"Interested in buying Pro for your business or school?","business_contact":"Contact us","themes":"Теме","themes_desc":"See more of your backgrounds with dark and transparent themes","bgs":"Live backgrounds","bgs_desc":"Bring your page to life with 20 live high-definition backgrounds","widgets":"Maximizable widgets","widgets_desc":"Take ProductivityTab to another level with maximizable widgets","more_header":"And more","stocks":"Realtime stocks with extended and historical information","rss":"Support for multiple RSS feeds per widget","sports":"General and league-specific sports news","tabbed_widgets":"Tabbed news and RSS widgets","bg_downloads":"Downloadable backgrounds","weather":"Hourly weather forecasts up to 10 days out","toolbar":"More toolbar links","ads":"A completely ad-free experience","support":"Prioritized support and suggestions","buy_pro":"Buy Pro"},"checkout":{"title":"Checkout","updating_title":"Update plan","payment_options":"Pay","pay_monthly":"Monthly ($4.99)","pay_yearly":"Yearly ($29.99)","cancel":"Поништи","update":"Update","subscribe":"Subscribe","braintree_notice":"Payments securely processed by Braintree.","monthly_notice":"By subscribing, you authorize ProductivityTab to charge you $4.99 every month until you cancel your subscription.","yearly_notice":"By subscribing, you authorize ProductivityTab to charge you $29.99 every year until you cancel your subscription.","update_notice":"Although billing cycle changes take effect immediately, you won't be charged until your current cycle ends.","thank_you":"Thank you for buying ProductivityTab Pro!","thank_you2":"ProductivityTab will reload in a few seconds and you'll be all set!","error":"Something went wrong while trying to process your payment.","error2":"Please try again later or email us at support@ichro.me","signin":"Sign in","signin_desc":"You need to sign in before buying Pro so we can make sure it's you","signin_btn":"Sign in"},"plan":{"title":"Plan","desc":"You are currently subscribed to ProductivityTab Pro (%s)","types":{"monthly":"Monthly","yearly":"Yearly","business":"Business","education":"Education","custom":"Прилагођено"},"uneditable_desc":"Business, education, and custom plans cannot be updated from within ProductivityTab. Please <a href=\"mailto:support@ichro.me\">contact us</a> to update or cancel your subscription.","status":"Status","status_active":"Active","status_trial":"Trial","status_pastdue":"Past due","subscription_date":"Subscription date","paid_through":"Paid through","next_bill":"Next bill","next_bill_value":"$%s on %s","update_plan":"Update plan","update_billing":"Update billing","cancel":"Cancel subscription","cancel_notice":"Your subscription will be canceled immediately","cancel_notice2":"If you would like a refund, please contact us at support@ichro.me"}},"ads":{"text1":"ProductivityTab displays a few small ads to pay for server, support and development costs. With these ads, we can afford to offer ProductivityTab free to everyone.","text2":"Here you can choose where those ads are shown, or buy ad-free to permanently remove them.","text3":"Ad-free is a one-time purchase that permanently removes ads from ProductivityTab wherever you're signed in. You can also upgrade to Pro for extra features in addition to an ad-free experience.","upgrade_btn":"Upgrade to ad-free","already_upgraded":"It looks like you've already upgraded to ad-free","signin":"Sign in","signin_desc":"Sign in before upgrading so we can link your purchase to your account","signin_btn":"Sign in","thank_you":"Thank you for upgrading to ad-free!","placement":{"title":"Ad placement","left":"In the leftmost column","right":"In the rightmost column","top":"Above the tab","bottom":"Floating at the bottom"}}},"store":{"installation":"Инсталација","description":"Опис","preview":"Погледај пре објаве","instructions":"Повуци и спусти било коју величину на твоју основну страницу"},"widgets":{"sizes":{"tiny":"Малени","small":"Мала","medium":"Средња","large":"Велика","variable":"Променљива"},"settings":{"title":"Подешавања додатака","save":"Сачувај","size":"Величина додатка"},"minimize":"Minimize","maximize":"Maximize","delete_confirm":"Да ли си сигуран да желиш да обришеш овај додатак?\nОва акција је бесповратна; сви подаци са овог додатка ће бити трајно изгубљени.","permissions_request":{"title":"Access required","button":"Grant Access","desc":"This widget needs extra permissions before it can be used. Grant them using the button below."},"error":{"explanation":"Something went wrong while we were trying to display this widget.","advice":"Try reinstalling the widget or reloading the page. Contact us if you see this message often.","support":"Подршка","refresh":"Refresh"},"auth":{"message":"You'll need to give this widget access to your account before you can use it.","button":"Grant Access"},"shared":{"settings":{"title":"Назив додатка","title_placeholder":"Унеси назив додатка или остави празно","height":"Висина додатка","open_options":{"current":"Тренутна картица","blank":"Нова картица"},"footer_link":"Подножни Линк","footer_link_options":{"show":"Прикажи","hide":"Сакриј"},"account":"ID Налога","account_help":"Ако си уписан у више рачуна, ово је \"ауторизациона=\" вредност.\n<br /><br />\nНа пример, ако си уписан у два рачуна, jsmith1@gmail.com и jsmith2@gmail.com,  \"ауторизациона\" вредност за jsmith2@gmail.com била би 1 пошто је то други рачун (рачунајући од нуле) у који си уписан.","account_placeholder":"Твоја \"ауторизаторска=\" вредност","on":"Укључено","off":"Искључено"}},"apps":{"name":"Апликације","desc":"Показује твоје тренутно инсталиране Google Chrome апликације.","settings":{"format":"Форматирај Додатак","format_options":{"tiles":"Плоче","list":"Листа"},"display":"Прикажи","display_options":{"all":"Све апликације","enabled":"Само укључене апликације"},"sort":"Сортирај","sort_options":{"id":"Ваш ИД ","alphabetically":"По абецеди","offline":"Омогућено ван мреже","available":"Доступност"},"open":"Отвори апликације у"},"store_app":"Продавница"},"bookmarks":{"name":"Сачуване странице","desc":"Приказује селектоване и прилагођене букмаркове ,и остале линкове.","settings":{"title_placeholder":"Унеси назив додатка","layout":"Распоред","layout_options":{"single":"Једна колона","double":"Дупла колона"},"open":"Отвори букмаркове у"},"edit":{"dialog_title":"Измени Букмарк","title":"Назив Букмарка","title_placeholder":"Google","url":"УРЛ Букмарка","url_placeholder":"https://www.google.com/","save":"Сачувај"},"new_caption":"Ново","new_bookmark":"Обележивач","new_folder":"Фасцикла","drop_link":"Спусти линк овде"},"chrome_bookmarks":{"name":"Сачуване странице","desc":"Displays your Chrome bookmarks, optionally from a specific folder.","settings":{"title_placeholder":"Унеси назив додатка","from":"Show bookmarks from","open":"Отвори букмаркове у"}},"calc":{"name":"Дигитрон","desc":"Показује дигитрон са подршком за основне функције.","error":"Грешка!","infinity":"Бесконачност","mismatch":"Неодговарајуће заграде"},"calendar":{"name":"Календар","desc":"Приказује надолазеће догађаје са једног или више твојих Google календара.","settings":{"calendar":"Календар","show":"Show events from","show_options":{"all":"All time","today":"Today only"}},"title":"Agenda","calendar":"Календар","noevents":"No events found in the near future, it looks like your schedule's clear!"},"clock":{"name":"Сат","desc":"Offers alarm, time, timer, and stopwatch functionality.","settings":{"timezone":"Временска зона","timezone_local":"Локално","format":"Формат сата","format_options":{"ampm":"Пре подне/После подне - Дигитални","24hour":"24 часа - Дигитални","analog":"12 сати - Аналогни","ampmseconds":"Пре подне/После подне - Дигитални, Без Секунди","24hourseconds":"24 Часовни - Дигитални, Без Секунди"},"sound":"Alert Sound"},"title":"Сат","alarm":"Alarm","clock":"Сат","timer":"Timer","stopwatch":"Stopwatch","set":"Set","unset":"Unset","dismiss":"Dismiss","enable_audio":"Enable audio"},"facebook":{"name":"Facebook","desc":"Убацује Facebook у додатак"},"feedly":{"name":"Feedly","desc":"Приказује новинске чланке са твог Feedly рачуна у прилагодљивом формату.","settings":{"source":"Прикажи чланке од","source_feeds":"Новински извори","show":"Прикажи","show_options":{"all":"Сви чланци","unread":"Само непрочитани чланци"},"layout":"Распоред","layout_options":{"titles":"Само називи","magazine":"Магазин","cards":"Картице","cards_columns":"Картице (две колумне)"},"mark":"Означи чланак прочитаним кад ја","mark_options":{"scroll":"Скролујем преко њега или га кликнем","click":"Само га кликнем"},"sort":"Ред Сортирања","sort_options":{"newest":"Најновије прво","oldest":"Прво најстарије"}},"all":"Све","saved":"Сачувано за касније","uncategorized":"Некатегоризовано","author":"од","go_to_feedly":"Иди на Feedly"},"notes":{"name":"Белешке","desc":"Убаци једноставну , изменљиву бележницу.","settings":{"color":"Боја белешке","color_options":{"yellow":"Жута","orange":"Наранџаста","red":"Црвена","blue":"Плава","green":"Зелена","white":"Бела"},"font":"Лице Фонта","fontsize":"Величина фонта"}},"now":{"name":"Google Now","desc":"Приказује картице са Google Now укључујући статус лета и праћење пакета.","authorize":"Потребно је да даш овлашћење ProductivityTab-у да види твоје Google Now картице пре него се било шта појави овде. ","authorize_btn":"Ауторизуј","caught_up":"Све свршено, нема ничега овде.","no_title":"Без наслова"},"plus":{"name":"Google+","desc":"Убацује Google Plus у додатак"},"notifications":{"name":"Google Notifications","desc":"Displays your Google Notifications from services such as Google+"},"reddit":{"name":"Reddit","desc":"Приказује најчитаније артикле на Reddit-у за било који дати subreddit.","settings":{"subreddit":"Subreddit","subreddit_help":"Унеси било који subreddit по делу прошлости <b>/r/</b> када на Reddit-у.\n<br /><br />\nНа пример, Технологија је на: <a href=\"https://www.reddit.com/r/technology\">https://www.reddit.com/r/technology</a>, тако да ћеш унети <b>технологија</b>","subreddit_placeholder":"Унеси subreddit да прикажеш линкове са. (прим. технологија)","sort":"Ред Сортирања","sort_options":{"hot":"Вруће","top":"Врх","new":"Ново","gilded":"Позлаћен","rising":"Растуће","controversial":"Контраверзно"},"links":"Приказани Линкови","click":"Када кликнем на линк прикажи ми","click_options":{"link":"Линк","comments":"Коментари"}},"more":"Још"},"tasks":{"name":"Tasks","desc":"Displays an editable list of tasks from one of your Google Tasks lists.","title":"Tasks","settings":{"list":"Листа"},"task_title":"Title","due_date":"Due date","notes":"Белешке","add":"Додај артикл","delete_task":"Delete Task","move_up":"Move Up","move_down":"Move Down","done":"Done","due_today":"Due today","overdue":"Overdue","authorize":"You'll need to select a list from your Google Tasks via the settings before anything can be displayed here."},"twitter":{"name":"Twitter","desc":"Приказује твитове са твог основног твитер профила или специфичне листе.","settings":{"source":"Прикажи Твитове са","show":"Приказани Твитови"},"authorize":"Мораш прво да даш овлашћење ProductivityTab-у","authorize_msg":"Потребно је да даш овлашћење ProductivityTab-у да види твитове са твог рачуна пре него се било шта појави овде. ","authorize_btn":"Ауторизуј","no_tweets":"Изгледа да овде нема твитова...","home":"Почетна страна","mentions":"Спомињање","retweets":"Ретвитови о мени","lists":"Листе","more":"Још","reply":"Одговори","retweet":"Ретвит","favorite":"Омиљено"},"wolfram":{"name":"Wolfram|Alpha","desc":"Убацује малу Wolfram|Alpha кутију за претрагу."},"youtube":{"name":"YouTube","desc":"Приказује или популарне видео фајлове или видео фајлове одабраног корисника.","settings":{"format":"Формат","format_options":{"large":"Један велики","large_2":"Један велики, два мала","large_4":"Један велики, четири мала","four":"Четири мала","six":"Шест малих"},"from":"Прикажи Видео Фајлове Са","from_help":"Ово мора да буде <b>тачно</b> корисничко име као што је приказано у УРЛ-у странице када посећујеш њихов профил.\n<br /><br />\nВредно никада не подразумева размаке.","from_placeholder":"Остави празно ради приказа Најгледанијих Видео Фајлова","open":"Отвори резултате претраге у"},"search":"Претражи YouTube","num_views":"Број прегледа"},"quotes":{"name":"Quotes","desc":"Displays a quote picked either every time you load the page or once daily.","settings":{"source":"Source","method":"Load new quotes","method_options":{"daily":"Once daily","random":"Every time I load the page"}},"unknown_author":"Непознато"},"html":{"name":"HTML","desc":"Displays completely custom HTML in an iframe.","settings":{"html":"HTML","js":"JavaScript","height":"Висина додатка"}},"sitelink":{"name":"Site Link","desc":"Displays a link, optionally with a title and thumbnail","settings":{"link":"Link URL","link_placeholder":"https://www.google.com/","image":"УРЛ слике","image_placeholder":"https://www.example.com/image.png","color":"Image Background Color","style":"Image Style","style_fill":"Fill","style_center":"Средина"}},"stats":{"name":"System Statistics","desc":"Keep an eye on your system with realtime statistics","memory":"Memory","battery":"Battery","usage":"usage","in_use":"in use","remaining":"remaining","charged":"Fully Charged","idle":"Idle","charging":"Charging","discharging":"Discharging"},"search":{"name":"Претражи","desc":"Embeds a search box in your page for easy access","settings":{"placeholder":"Search Field Placeholder","search_url":"Претрага УРЛ-а","param":"Query Parameter","param_placeholder":"The parameter where the query goes, i.e. \"q\""},"default_placeholder":"Search Google"},"pushbullet":{"name":"Pushbullet","desc":"Keep track of notifications from your phone and other devices","no_pushes":"No pushes found","sign_in":"Sign in","no_key":"It doesn't look like you're signed in to Pushbullet.  Sign in now to connect this widget."},"linkedin":{"name":"LinkedIn","desc":"Displays your LinkedIn home stream"},"directions":{"name":"Directions","desc":"Get directions to and from nearly anywhere right from your homepage","driving":"Вожња","transit":"Градски саобраћај","walking":"Пешачење","cycling":"Cycling","from":"Enter a starting point","to":"Enter a destination","loading":"Loading directions, please wait...","error":"Something went wrong while trying to load the directions you requested.","error2":"Please check the start and destination addresses you entered.","open_in_maps":"Open in Google Maps","via":"via"},"pocket":{"name":"Pocket","desc":"Display a list of your saved articles, videos, and web pages from Pocket","settings":{"links_shown":"Number of links shown","open":"Open links","open_pocket":"In Pocket","open_original":"At their original URL"},"by":"од","no_links":"No links found","grant_access":"Grant access","no_key":"You'll need to give ProductivityTab access to your Pocket account before it can load your links."}},"themes":{"title":"Теме","all":"Све","custom":"Прилагођено","create":"Направи тему","url_or_upload":"или","upload_image":"Уплоадуј слику","edit_btn":"Подеси","delete":"Обриши","use":"Користи","preview":"Погледај пре објаве","author":"од","images":"%s Слике","resolution":"Резолуција","categories":"Категорије","cached":"Ова тема је кеширана и доступна је ван мреже","random":"Ова тема приказује наизменичну слику сваки пут кад отвориш страну","random_daily":"Ова тема приказује наизменично одабрану слику сваког дана","sunrise_sunset":"Ова тема приказује слику засновану на времену у току дана","feed":"Ова тема приказује слику свакодневно одабрану са спољашњег извора","video":"This theme displays a live video","pro_only":"This theme is only available to Pro users. Buy Pro in the settings.","delete_confirm":"Да ли си стварно сигуран да желиш да обришеш ову тему?\nОва дело је бесповратно; цела тема ће бити трајно изгубљена.","delete_error":"Десила се грешка док се брисала тема. Молимо Вас покушајте поново.","feed_fetching":"Молимо сачекајте, учитавамо са извора...","feed_error":"Нешто је пошло наопако током сакупљања новинских чланака са извора. Молимо покушајте поново касније.","caching":"Молимо сачекајте, кеширање теме...","cache_status":"%s од %s кешираних слика","cache_error":"Десила се грешка док се кеширала тема. Молимо Вас покушајте поново","bginfo":{"view":"View","source":"Source","unknown":"Непознато","download":"Download","pro_only":"Only Pro users can download background images and videos"},"edit":{"title":"Измени Тему","create_title":"Направи тему","name":"Име Теме","default_name":"Нова Тема","name_placeholder":"Унеси назив теме","image":"УРЛ слике","image_placeholder":"Унеси УРЛ слике за позадину","image_help":"Уплоадоване слике <b>Не може да се синхронизује</b> између рачунара.<br /><br />Ако ти је ово битно, молимо те уплоадуј твоју слику на сервис као <a href=\"https://imgur.com/\" target=\"_blank\">imgur</a>. Онда копирај па проследи крај УРЛ-а са екстензијом (нпр. .jpg) и проследи га у поље са леве стране.","color":"Резервна боја","color_placeholder":"Унеси име било које боје","position":"Позиција","position_options":{"center":"Средина","top_left":"Горе лево","top_center":"Горе центар","top_right":"Горе десно","bottom_left":"Доле лево","bottom_center":"Доле центар","bottom_right":"Доле десно"},"scaling":"Скалирање","scaling_options":{"auto":"Аутоматско","width":"Цела ширина","height":"Цела висина","none":"Без скалирања (преглед пре објаве може бити нетачан)"},"repeat":"Понављање слике","repeat_options":{"none":"Без понављања","horizontal":"Понови хоризонтално","vertical":"Понови Вертикално","both":"Понови Оба"},"attach":"Закачи слику за","attach_tab":"Картицу","attach_window":"Прозор","preview":"Погледај пре објаве","save":"Сачувај & Затвори","cache_error":"Десила се грешка током кешираља слике коју сте пружили, молимо вас да проверите УРЛ. ","upload_error":"Десила се грешка током уплоадовања пруженог фајла, молимо проверите да је фајл одговарајуће величине и да је слика."}}},"tr":{"lang_code":"tr","language":"Türkçe","extName":"ProductivityTab — Custom Homepage Dashboard","newtabName":"ProductivityTab — Custom New Tab Dashboard","extDescription":"A remarkably customizable personal homepage featuring 50+ widgets, breathtaking backgrounds and much more.","newtabDescription":"A customizable personal dashboard on your new tab page featuring 50+ widgets, breathtaking backgrounds and much more.","defaults":{"tab":"Ana Sayfa","me":"Ben"},"remove_widget":"Kaldır","hide_banner":"Bu reklam bandını gizle","hide_ad":{"content":"Hey! We're not crazy about ads either, but we're only able to make ProductivityTab available and continue developing features for our free users (that's you!) by showing ads. If you'd like to support ProductivityTab directly and get rid of ads for free, we would really appreciate if you upgraded to our pro version","upgrade":"Yükseltin","hide":"Reklamları gizle"},"alert":{"default_button":"Yoksay","confirm_title":"Bunu yapmak istediğinizden emin misiniz?","confirm_continue":"Devam et","confirm_cancel":"İptal"},"onboarding":{"modal":{"tagline":"Kullandığınız bütün siteler ve uygulamalar tek bir yerde","wrong_extension":"Yeni sekme sayfasında ProductivityTab ister misin?","wrong_extension_newtab":"Ana sayfanızın ProductivityTab olmasını ister misin?","wrong_extension_action":"Buraya tıkla","about":"ProductivityTab sekmeler ve widgetlardan oluşur","about_desc":"Sekmeler widgedlarla dolu sayfalardır - Hava durumu, haberler ve emaillerinizi gizler. Widgetlarınızı düzenleyebilir ve istediğiniz daha bir çok widget ekleyebilirsiniz.","terms":"Devam etmekle, ProductivityTab'un <a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\">Hükümler </a> ve <a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\"> Koşullarını</a> kabul etmiş sayılırsınız","sign_in":"Google Hesabınızı kullanarak oturum açın","sign_in_desc":"Güvenli bir şekilde ayarlarınızı değiştirmeden önce Google hesabınızla giriş yapın.","sign_in_desc2":"İsterseniz giriş yapmayabilirsiniz, fakat sayfalarınız online olarak kaydedilmez ve siz başka bilgisayarlardan giriş yapıp değiştiremezsiniz.","sign_in_button":"Google ile giriş yap","have_account":"Zaten bir hesabınız var gibi görünüyor!","have_account_desc":"Tüm sekmeleri ve widgetları kullanmaya hazırsınız!","get_started":"Haydi Başlayalım!","get_started_desc":"Gitmeye hazırız! Sayfanı kuralım."},"widgets":{"configure":"Hadi bir widget yapılandırın.","configure_desc":"Click the wrench to open a widget's <b>settings</b>.","configure_skip":"Skip Tutorial","settings":"Replace <b>Link URL</b> with your favorite site, then press <b>Save</b>.","move":"You can <b>reposition</b> widgets by clicking and dragging the three dots highlighted here.","remove":"To <b>delete</b>, simply click the red trash bin icon.","done":"Anladım"},"settings":{"intro":"Now let’s add a new widget. This highlighted button is where you can access the Widget Menu.","instructions":"Click the new widget button on to open the widget menu!","skip":"Geç","tooltips":{"settings":"Change the way ProductivityTab looks and works","widgets":"Add new widgets - you can have as many as you want","editing":"Show or hide the editing buttons on widgets","links":"This is a list of links, add sites you use often in the settings","tabs":"These are your tabs. You can add more in the settings","support":"Send us a message or leave a review here"},"finished":"Hepsi bu kadar!","finished_next":"Choose an option from the menu (try starting with <b>Widgets</b>) and set your page up!","finished_contact":"Use the support link if you need any help and we'll get back to you ASAP."}},"storage":{"signin":"Sign in with Google now to securely save and sync your configuration","signin_btn":"Oturum aç","signin_dismiss":"Yoksay","signin_confirm":{"title":"Keep local data?","desc":"Would you like to keep your local data, and replace the configuration in your account with it, or replace this computer's configuration with the one already in your account?","keep_account":"Use account","keep_local":"Keep local"},"signout_confirm":"Signing out will erase your local backups","pastdue":"Your subscription is past due","pastdue_desc":"Please update your billing information in the settings"},"toolbar":{"placeholder":"Aramak istediğiniz kelimeyi girin","placeholder_ok":"Aramak istediğiniz kelimeyi girin veya \"OK, Google\" deyin","suggestions":{"url_subtext":"Visit URL","capture_notice":"ProductivityTab handles searches you normally make from the Omnibox. You can disable this at any time from the settings"},"apps":{"search":"Ara","youtube":"YouTube","maps":"Haritalar","play":"Oynat","news":"Haberler","gmail":"Gmail","drive":"Drive","calendar":"Takvim","more":"Daha fazla"}},"menu":{"settings":"Ayarlar","widgets":"Widget'lar","editing":"Düzenleme","editing_enabled":"Etkin","editing_disabled":"Etkin Değil","plus":"Google Plus","tabs":"Sekmeler","footer":{"support":"Destek","feedback":"Geri bildirim","review":"Görüşlerin","terms":"Terms","privacy":"Privacy","by":"Avi Kohn tarafından"}},"voice":{"listening":"Dinleniyor...","searching":"%s için arıyor","missed":"Bunu anlamadım. <a>Yeniden Deneyin</a>"},"settings":{"title":"Ayarlar","exit":"Exit settings","saved":"Settings saved","nav":{"visual":"Görsel","visual_sections":{"background":"Background","layout":"Düzen","theme":"App theme","ad_placement":"Ad placement"},"toolbar":"Toolbar","toolbar_sections":{"style":"Style","search":"Ara","links":"Links"},"tabs":"Sekmeler","widgets":"Widget'lar","ads":"Ads","pro":"Pro","accounts":"Account","misc":"Miscellaneous","advanced":"Advanced","advanced_sections":{"backups":"Backup and restore","css":"Custom CSS","debug_tools":"Debug tools"},"support":"Help and support","suggest":"Suggest a feature"},"visual":{"background":{"title":"Background","desc":"This is the image or set of images shown as a background to your tabs","current":"Current background","custom":"Özel","unnamed":"Theme %s","select":"Select a theme","or":"veya","url_placeholder":"Enter an image URL"},"layout":{"title":"Düzen","desc":"Here you can adjust the type and number of columns in each tab","columns":"Columns","grid":"Grid","columns_number":"Number of columns","column_width":"Column width","column_width_fixed":"Fixed","column_width_fluid":"Fluid","column_warning":{"column_to_grid":"Changing to a grid-based layout will move all of your widgets to the top left corner.","grid_to_column":"Changing to a column-based layout will move all of your widgets to the first column."}},"theme":{"title":"App theme","desc":"The app theme controls the style of ProductivityTab itself and all widgets","preview":"Önizleme","light":"Light (default)","dark":"Siyah","transparent":"Transparent","transparent_darker":"Transparent (darker)"}},"toolbar":{"style":{"title":"Style","desc":"This controls the style of the toolbar.  It can either appear normally or as an out of the way button","normal":"Normal","button":"Button"},"search":{"title":"Ara","desc":"These settings control how the search box and voice search function","engine":"Search engine","engines_default":"Default","engines_custom":"Özel","engines_custom_desc":"Enter a URL that queries should be sent to, with <b>%s</b> where the query should go.","omnibox_capture":"Handle searches normally made in the Omnibox","voice":"Enable voice search","ok_google":"Enable \"OK Google\" hotword detection","search_tab":"Open search results in a new tab"},"links":{"title":"Links","desc":"These are the items shown at the right of the toolbar","apps":"Apps menu","custom":"Custom links","custom_note1":"Maximum of 3 allowed","custom_note2":"users get 8","custom_name_placeholder":"Link text","custom_url_placeholder":"Link URL, i.e. https://www.google.com/"}},"misc":{"link_tab":"Open links in a new tab by default"},"tabs":{"create_new":"Create new","make_default":"Make default","desc1":"Tabs are pages inside ProductivityTab. Each tab has its own set of widgets that is completely separate from every other tab.","desc2":"You can switch between tabs by clicking the buttons that appear at the left and right of the screen when you move your mouse over a tab or by using the arrow keys on your keyboard.","name_placeholder":"Enter a tab name","delete_confirm":"This action is irreversible. All data from all widgets in the tab will be permanently lost."},"accounts":{"status":{"title":"Status","signed_in":"You are currently <b>signed in</b> as %s (%s).","reset_account":"Reset account","sign_out":"Sign out","signed_out":"You are <b>not currently signed in</b>. Sign in with your Google account now to securely store and sync your configuration.","sign_in":"Sign in with Google"},"reset_confirm_desc":"This will erase all local and synced data, there is no backup and no way to undo this.","reset_confirm_desc2":"You will lose your entire current configuration on all computers connected to this account."},"advanced":{"backups":{"title":"Backup and restore","desc":"Backups are complete copies of all your tabs, settings, and widgets. They're automatically created when you first open ProductivityTab each day.","desc2":"Use the buttons below to roll ProductivityTab back to a particular date or download one of your backups.","backup":"Backup now","upload":"Restore from file","download":"Download","restore":"Restore","download_name":"ProductivityTab Backup","restore_confirm":"This will overwrite all local and synced data. You will lose your entire current configuration on all computers under this account.","restore_error":"An error occurred while trying to parse the provided data, please try again later."},"css":{"title":"Custom CSS","desc":"You can use CSS (<a href=\"https://developer.mozilla.org/en-US/docs/Web/CSS\" target=\"blank\">definition</a>) to customize almost any part of ProductivityTab.","placeholder":"Enter up to 1000 characters of CSS here"},"debug_tools":{"title":"Debug tools","desc":"<b>WARNING:</b> These tools can erase your entire configuration in a single click. Only use them if your developer instructs you to.","open":"Open tools"}},"widgets":{"desc1":"Widgets have their own settings and can't be customized here.","desc2":"To edit a widget's settings, follow these steps:","steps1":"Move your mouse over any widget","steps2":"Click the wrench icon that appears at the top right of the widget. If none appears then the widget doesn't have any settings that can be customized.","steps3":"Edit any of the settings shown in the dialog that's displayed","steps4":"Click Save to save your changes, or any part of the background to discard of them"},"pro":{"promo":{"monthly_price":"$4.99 per month","yearly_price":"or $29.99 per year","upgrade_btn":"Upgrade Now","business":"Interested in buying Pro for your business or school?","business_contact":"Contact us","themes":"Temalar","themes_desc":"See more of your backgrounds with dark and transparent themes","bgs":"Live backgrounds","bgs_desc":"Bring your page to life with 20 live high-definition backgrounds","widgets":"Maximizable widgets","widgets_desc":"Take ProductivityTab to another level with maximizable widgets","more_header":"And more","stocks":"Realtime stocks with extended and historical information","rss":"Support for multiple RSS feeds per widget","sports":"General and league-specific sports news","tabbed_widgets":"Tabbed news and RSS widgets","bg_downloads":"Downloadable backgrounds","weather":"Hourly weather forecasts up to 10 days out","toolbar":"More toolbar links","ads":"A completely ad-free experience","support":"Prioritized support and suggestions","buy_pro":"Buy Pro"},"checkout":{"title":"Checkout","updating_title":"Update plan","payment_options":"Pay","pay_monthly":"Monthly ($4.99)","pay_yearly":"Yearly ($29.99)","cancel":"İptal","update":"Update","subscribe":"Subscribe","braintree_notice":"Payments securely processed by Braintree.","monthly_notice":"By subscribing, you authorize ProductivityTab to charge you $4.99 every month until you cancel your subscription.","yearly_notice":"By subscribing, you authorize ProductivityTab to charge you $29.99 every year until you cancel your subscription.","update_notice":"Although billing cycle changes take effect immediately, you won't be charged until your current cycle ends.","thank_you":"Thank you for buying ProductivityTab Pro!","thank_you2":"ProductivityTab will reload in a few seconds and you'll be all set!","error":"Something went wrong while trying to process your payment.","error2":"Please try again later or email us at support@ichro.me","signin":"Sign in","signin_desc":"You need to sign in before buying Pro so we can make sure it's you","signin_btn":"Sign in"},"plan":{"title":"Plan","desc":"You are currently subscribed to ProductivityTab Pro (%s)","types":{"monthly":"Monthly","yearly":"Yearly","business":"Business","education":"Education","custom":"Özel"},"uneditable_desc":"Business, education, and custom plans cannot be updated from within ProductivityTab. Please <a href=\"mailto:support@ichro.me\">contact us</a> to update or cancel your subscription.","status":"Status","status_active":"Active","status_trial":"Trial","status_pastdue":"Past due","subscription_date":"Subscription date","paid_through":"Paid through","next_bill":"Next bill","next_bill_value":"$%s on %s","update_plan":"Update plan","update_billing":"Update billing","cancel":"Cancel subscription","cancel_notice":"Your subscription will be canceled immediately","cancel_notice2":"If you would like a refund, please contact us at support@ichro.me"}},"ads":{"text1":"ProductivityTab displays a few small ads to pay for server, support and development costs. With these ads, we can afford to offer ProductivityTab free to everyone.","text2":"Here you can choose where those ads are shown, or buy ad-free to permanently remove them.","text3":"Ad-free is a one-time purchase that permanently removes ads from ProductivityTab wherever you're signed in. You can also upgrade to Pro for extra features in addition to an ad-free experience.","upgrade_btn":"Upgrade to ad-free","already_upgraded":"It looks like you've already upgraded to ad-free","signin":"Sign in","signin_desc":"Sign in before upgrading so we can link your purchase to your account","signin_btn":"Sign in","thank_you":"Thank you for upgrading to ad-free!","placement":{"title":"Ad placement","left":"In the leftmost column","right":"In the rightmost column","top":"Above the tab","bottom":"Floating at the bottom"}}},"store":{"installation":"Installation","description":"Description","preview":"Önizleme","instructions":"Herhangi bir boyutu tutup ana sayfanızın üzerine sürükleyin"},"widgets":{"sizes":{"tiny":"Çok küçük","small":"Küçük","medium":"Orta","large":"Büyük","variable":"Değişken"},"settings":{"title":"Widget Ayarları","save":"Kaydet","size":"Widget Boyutu"},"minimize":"Minimize","maximize":"Maximize","delete_confirm":"Bu widgeti silmek istediğinizden emin misiniz? \nBu eylem geri alınamaz; Bu widgete ait tüm veriler kalıcı olarak kaybolacak.","permissions_request":{"title":"Access required","button":"Grant Access","desc":"This widget needs extra permissions before it can be used. Grant them using the button below."},"error":{"explanation":"Something went wrong while we were trying to display this widget.","advice":"Try reinstalling the widget or reloading the page. Contact us if you see this message often.","support":"Destek","refresh":"Refresh"},"auth":{"message":"You'll need to give this widget access to your account before you can use it.","button":"Grant Access"},"shared":{"settings":{"title":"Widget başlığı","title_placeholder":"Widget için bir başlık girin veya gizlemek için boş bırakın","height":"Widget yüksekliği","open_options":{"current":"Geçerli sekme","blank":"Yeni bir sekme"},"footer_link":"Altbilgi Bağlantısı","footer_link_options":{"show":"Göster","hide":"Gizle"},"account":"Hesap ID'si","account_help":"If you're signed into multiple accounts, this is the \"authuser=\" value.\n<br /><br />\nFor example, if you're signed into two accounts, jsmith1@gmail.com and jsmith2@gmail.com, the \"authuser\" value for jsmith2@gmail.com would be 1 since it's the second account (counting from zero) that you're signed into.","account_placeholder":"Your \"authuser=\" value","on":"Etkin","off":"Etkin değil"}},"apps":{"name":"Uygulamalar","desc":"Şu anda yüklü Google Chrome uygulamalarınızı görüntüler.","settings":{"format":"Widget Biçimi","format_options":{"tiles":"Kutucuklar","list":"Liste"},"display":"Göster","display_options":{"all":"Tüm Uygulamalar","enabled":"Yalnızca etkin uygulamalar"},"sort":"Sırala","sort_options":{"id":"ID","alphabetically":"Alfabetik","offline":"Çevrimdışı Etkin","available":"Uygunluk"},"open":"Open apps in"},"store_app":"Mağaza"},"bookmarks":{"name":"Yer imleri","desc":"Yer imlerinizi ve diğer bağlantıları görüntüler.","settings":{"title_placeholder":"Widget için bir başlık girin","layout":"Düzen","layout_options":{"single":"Tek sütun","double":"Çift sütun"},"open":"Yer imlerini şurada aç"},"edit":{"dialog_title":"Yer imini düzenle","title":"Yer imi adı","title_placeholder":"Google","url":"Yer imi URL","url_placeholder":"https://www.google.com/","save":"Kaydet"},"new_caption":"Yeni","new_bookmark":"Yer imi","new_folder":"Klasör","drop_link":"Bağlantıyı buraya bırakın"},"chrome_bookmarks":{"name":"Yer imleri","desc":"Displays your Chrome bookmarks, optionally from a specific folder.","settings":{"title_placeholder":"Widget için bir başlık girin","from":"Show bookmarks from","open":"Yer imlerini şurada aç"}},"calc":{"name":"Hesap makinesi","desc":"Temel işlemleri yapabilen bir hesap makinesi gösterir.","error":"Hata!","infinity":"Sonsuz","mismatch":"Eşleşmeyen parantezler"},"calendar":{"name":"Takvim","desc":"Bir veya daha fazla Google takviminizde yaklaşan etkinlikleri gösterir.","settings":{"calendar":"Takvim","show":"Show events from","show_options":{"all":"Tüm zamanlar","today":"Sadece bugün"}},"title":"Ajanda","calendar":"Takvim","noevents":"No events found in the near future, it looks like your schedule's clear!"},"clock":{"name":"Saat","desc":"Offers alarm, time, timer, and stopwatch functionality.","settings":{"timezone":"Saat dilimi","timezone_local":"Yerel","format":"Saat biçimi","format_options":{"ampm":"AM/PM - Dijital","24hour":"24 saat - Dijital","analog":"12 Hour - Analog","ampmseconds":"AM/PM - Digital, No Seconds","24hourseconds":"24 Hour - Digital, No Seconds"},"sound":"Alert Sound"},"title":"Saat","alarm":"Alarm","clock":"Saat","timer":"Zamanlayıcı","stopwatch":"Kronometre","set":"Ayarla","unset":"Devre dışı bırak","dismiss":"Yoksay","enable_audio":"Sesi etkinleştirin"},"facebook":{"name":"Facebook","desc":"Embeds Facebook in a widget"},"feedly":{"name":"Feedly","desc":"Displays articles from your Feedly account in a configurable format.","settings":{"source":"Show articles from","source_feeds":"Feeds","show":"Göster","show_options":{"all":"All articles","unread":"Only unread articles"},"layout":"Düzen","layout_options":{"titles":"Titles only","magazine":"Magazine","cards":"Cards","cards_columns":"Cards (two columns)"},"mark":"Mark an article as read when I","mark_options":{"scroll":"Scroll past it or click it","click":"Just click it"},"sort":"Sırala","sort_options":{"newest":"Newest first","oldest":"Oldest first"}},"all":"Tümü","saved":"Saved for later","uncategorized":"Uncategorized","author":"by","go_to_feedly":"Go To Feedly"},"notes":{"name":"Notlar","desc":"Basit, düzenlenebilir, bir not ekler.","settings":{"color":"Not rengi","color_options":{"yellow":"Sarı","orange":"Turuncu","red":"Kırmızı","blue":"Mavi","green":"Yeşil","white":"Beyaz"},"font":"Yazı tipi","fontsize":"Yazı tipi boyutu"}},"now":{"name":"Google Asistan","desc":"Uçuş durumu ve paket izlemeleri dahil olmak üzere tüm Google Asistan kartlarını görüntüler.","authorize":"Google Asistan kartlarınızın burada görüntülenebilmesi için ProductivityTab'a izin vermeniz gerekir.","authorize_btn":"Yetki ver","caught_up":"Görüntülenecek hiçbir şey yok.","no_title":"Başlık yok"},"plus":{"name":"Google +","desc":"Bir Google Plus widgeti gömer"},"notifications":{"name":"Google Notifications","desc":"Displays your Google Notifications from services such as Google+"},"reddit":{"name":"Reddit","desc":"Reddit üzerindeki popüler başlıkları görüntüler.","settings":{"subreddit":"Subreddit","subreddit_help":"Enter any subreddit by the part past <b>/r/</b> when on Reddit.\n<br /><br />\nFor example, Technology is at: <a href=\"https://www.reddit.com/r/technology\">https://www.reddit.com/r/technology</a>, therefore you would enter <b>technology</b>","subreddit_placeholder":"Enter a subreddit to show links from. (i.e. technology)","sort":"Sırala","sort_options":{"hot":"Hot","top":"Top","new":"Yeni","gilded":"Gilded","rising":"Rising","controversial":"Controversial"},"links":"Links Shown","click":"When I click a link show me","click_options":{"link":"The link","comments":"The comments"}},"more":"Daha fazla"},"tasks":{"name":"Tasks","desc":"Displays an editable list of tasks from one of your Google Tasks lists.","title":"Tasks","settings":{"list":"Liste"},"task_title":"Title","due_date":"Due date","notes":"Notlar","add":"Öğe Ekle","delete_task":"Delete Task","move_up":"Move Up","move_down":"Move Down","done":"Done","due_today":"Due today","overdue":"Overdue","authorize":"You'll need to select a list from your Google Tasks via the settings before anything can be displayed here."},"twitter":{"name":"Twitter","desc":"Displays tweets from your home stream or a specified list.","settings":{"source":"Show Tweets from","show":"Tweets Shown"},"authorize":"You'll need to authorize ProductivityTab first","authorize_msg":"You'll need to give ProductivityTab permission to view tweets from your account before anything will show up here.","authorize_btn":"Yetki ver","no_tweets":"There don't seem to be any tweets here...","home":"Ana Sayfa","mentions":"Mentions","retweets":"Retweets of me","lists":"Lists","more":"Daha fazla","reply":"Reply","retweet":"Retweet","favorite":"Favorite"},"wolfram":{"name":"Wolfram|Alpha","desc":"Inserts a small Wolfram|Alpha search box."},"youtube":{"name":"YouTube","desc":"Displays either popular videos or videos from a specified user.","settings":{"format":"Format","format_options":{"large":"One large","large_2":"One large, two small","large_4":"One large, four small","four":"Four small","six":"Six small"},"from":"Show Videos From","from_help":"This must be an <b>exact</b> username as shown in the URL of the page when you're viewing their profile.\n<br /><br />\nThis value never includes spaces.","from_placeholder":"Leave blank to show Top Videos","open":"Open search results in"},"search":"Search YouTube","num_views":"views"},"quotes":{"name":"Quotes","desc":"Displays a quote picked either every time you load the page or once daily.","settings":{"source":"Source","method":"Load new quotes","method_options":{"daily":"Once daily","random":"Every time I load the page"}},"unknown_author":"Unknown"},"html":{"name":"HTML","desc":"Displays completely custom HTML in an iframe.","settings":{"html":"HTML","js":"JavaScript","height":"Widget yüksekliği"}},"sitelink":{"name":"Site Link","desc":"Displays a link, optionally with a title and thumbnail","settings":{"link":"Link URL","link_placeholder":"https://www.google.com/","image":"Resim URL'si","image_placeholder":"https://www.example.com/image.png","color":"Image Background Color","style":"Image Style","style_fill":"Fill","style_center":"Merkez"}},"stats":{"name":"System Statistics","desc":"Keep an eye on your system with realtime statistics","memory":"Memory","battery":"Battery","usage":"usage","in_use":"in use","remaining":"remaining","charged":"Fully Charged","idle":"Idle","charging":"Charging","discharging":"Discharging"},"search":{"name":"Ara","desc":"Embeds a search box in your page for easy access","settings":{"placeholder":"Search Field Placeholder","search_url":"Arama URL'si","param":"Query Parameter","param_placeholder":"The parameter where the query goes, i.e. \"q\""},"default_placeholder":"Search Google"},"pushbullet":{"name":"Pushbullet","desc":"Keep track of notifications from your phone and other devices","no_pushes":"No pushes found","sign_in":"Sign in","no_key":"It doesn't look like you're signed in to Pushbullet.  Sign in now to connect this widget."},"linkedin":{"name":"LinkedIn","desc":"Displays your LinkedIn home stream"},"directions":{"name":"Directions","desc":"Get directions to and from nearly anywhere right from your homepage","driving":"Sürüş","transit":"Toplu taşıma","walking":"Yürüyüş","cycling":"Cycling","from":"Enter a starting point","to":"Enter a destination","loading":"Loading directions, please wait...","error":"Something went wrong while trying to load the directions you requested.","error2":"Please check the start and destination addresses you entered.","open_in_maps":"Open in Google Maps","via":"via"},"pocket":{"name":"Pocket","desc":"Display a list of your saved articles, videos, and web pages from Pocket","settings":{"links_shown":"Number of links shown","open":"Open links","open_pocket":"In Pocket","open_original":"At their original URL"},"by":"Yapan","no_links":"No links found","grant_access":"Grant access","no_key":"You'll need to give ProductivityTab access to your Pocket account before it can load your links."}},"themes":{"title":"Temalar","all":"Tümü","custom":"Özel","create":"Tema yarat","url_or_upload":"veya","upload_image":"Bir resim yükle","edit_btn":"Düzenle","delete":"Sil","use":"Kullan","preview":"Önizleme","author":"Yapan","images":"%s resim","resolution":"Çözünürlük","categories":"Kategoriler","cached":"Bu tema önbelleğe alındı ve çevrimdışı kullanılabilir","random":"Bu tema sayfayı her yüklediğinizde rastgele bir resim gösterir","random_daily":"Bu tema her gün değişen rastgele bir resim gösterir","sunrise_sunset":"Bu tema günün saatine bağlı bir resim gösterir","feed":"This theme displays an image selected daily from an external feed","video":"This theme displays a live video","pro_only":"This theme is only available to Pro users. Buy Pro in the settings.","delete_confirm":"Are you really sure you would like to delete this theme?\r\nThis action is irreversible; the entire theme will be permanently lost.","delete_error":"An error occurred while trying to delete the theme.  Please try again later.","feed_fetching":"Lütfen bekleyin, besleme çekiliyor...","feed_error":"Something went wrong while trying to fetch the feed.  Please try again later.","caching":"Lütfen bekleyin, tema önbelleğe alınıyor...","cache_status":"%s of %s images cached","cache_error":"An error occurred while trying to cache the theme.  Please try again later","bginfo":{"view":"View","source":"Source","unknown":"Unknown","download":"Download","pro_only":"Only Pro users can download background images and videos"},"edit":{"title":"Temayı Düzenle","create_title":"Tema Oluştur","name":"Tema Adı","default_name":"Yeni Tema","name_placeholder":"Tema adı girin","image":"Resim URL'si","image_placeholder":"Bir arka plan görüntüsü URL'si girin","image_help":"Uploaded images <b>cannot be synced</b> between computers.<br /><br />If this is important to you, please upload your image to a service such as <a href=\"https://imgur.com/\" target=\"_blank\">imgur</a>. Then copy the URL ending with an extension (i.e. .jpg) and paste it into the field on the left.","color":"Temel renk","color_placeholder":"Herhangi bir renk adı girin","position":"Konum","position_options":{"center":"Merkez","top_left":"Sol Üst","top_center":"Üst Orta","top_right":"Sağ Üst","bottom_left":"Sol Alt","bottom_center":"Alt Orta","bottom_right":"Sağ alt"},"scaling":"Ölçekleme","scaling_options":{"auto":"Otomatik","width":"Tam Genişlik","height":"Tam Yükseklik","none":"Ölçeklendirme (önizleme hatalı olabilir)"},"repeat":"Görüntü Yineleme","repeat_options":{"none":"Yineleme","horizontal":"Yatay olarak yinele","vertical":"Dikey olarak yinele","both":"Dikey ve Yatay yinele"},"attach":"Görüntüyü şuraya ekle","attach_tab":"Sekme","attach_window":"Pencere","preview":"Önizleme","save":"Kaydet & Kapat","cache_error":"An error occurred while trying to cache the image you provided, please double-check the URL.","upload_error":"An error occurred while trying to upload the file you provided, please make sure that it's a reasonable size and an image."}}},"uk":{"lang_code":"uk","language":"Українська","extName":"ProductivityTab — Custom Homepage Dashboard","newtabName":"ProductivityTab — Custom New Tab Dashboard","extDescription":"A remarkably customizable personal homepage featuring 50+ widgets, breathtaking backgrounds and much more.","newtabDescription":"A customizable personal dashboard on your new tab page featuring 50+ widgets, breathtaking backgrounds and much more.","defaults":{"tab":"Додому","me":"Я"},"remove_widget":"Вилучити","hide_banner":"Hide this banner","hide_ad":{"content":"Гей! Ми також не з'їхали з глузду дивитися рекламу, але показуючи рекламу ми можемо зробити ProductivityTab доступним і продовжувати розробку для наших безкоштовних користувачів (а це Ви!). Якщо ви хочете підтримати ProductivityTab напряму і позбавитись реклами, то ми будемо вдячні якщо Ви заапгрейдeтесь до pro версії","upgrade":"Upgrade","hide":"Hide ads"},"upgrade_to_pro":{"title-weather":"Погода Погодинно","title-default":"Апґрейд","content-default":"Ця функціональність доступна у Про версії","upgrade":"Апґрейд","close":"Закрити"},"alert":{"default_button":"Відмінити","confirm_title":"Ви впевнені, що хочете це зробити?","confirm_continue":"Продовжити","confirm_cancel":"Скасувати"},"onboarding":{"modal":{"tagline":"Всі Ваші сайти й додатки на одній сорінці","wrong_extension":"Використовувати ProductivityTab для нової вкладки?","wrong_extension_newtab":"Використовувати ProductivityTab як домашню сторінку?","wrong_extension_action":"Натисніть тут","about":"ProductivityTab - вкладки та віджети","about_desc":"Вкладки це сторінки з віджетами, блоками які показують таке як погоду, новини і вашу пошту. Ви можете настроїти більшість віджетів і додати стільки скільки забажаєте.","terms":"Продовжуючи, Ви погоджуєтесь з <a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\">Умовами</a> and <a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\">Політики конфіденційності</a>","sign_in":"Увійдіть за допомогою свого облікового запису Google","sign_in_desc":"Увійдіть за допомогою свого облікового запису Google, що безпечно зберегти свої зміни онлайн.","sign_in_desc2":"Ви можете не входити якщо бажаєте, але ваша сторінка не буде збережена в онлайні і ви не зможете отримати до неї доступ з інших комп'ютерів.","sign_in_button":"Увійдіть за допомогою Google","have_account":"Схоже, у вас вже вже є обліковий запис!","have_account_desc":"Ваші вкладки і віджети готові до використання!","get_started":"Давайте почнемо!","get_started_desc":"Все готово! Давайте налаштуємо вашу сторінку."},"widgets":{"configure":"Давайте налаштуємо віджет.","configure_desc":"Click the wrench to open a widget's <b>settings</b>.","configure_skip":"Пропустити Підручник","settings":"Replace <b>Link URL</b> with your favorite site, then press <b>Save</b>.","move":"You can <b>reposition</b> widgets by clicking and dragging the three dots highlighted here.","remove":"To <b>delete</b>, simply click the red trash bin icon.","done":"Зрозуміло"},"settings":{"intro":"Now let’s add a new widget. This highlighted button is where you can access the Widget Menu.","instructions":"Click the new widget button on to open the widget menu!","skip":"Пропустити","tooltips":{"settings":"Change the way ProductivityTab looks and works","widgets":"Додайте нових віджетів - ви можете розмістити стільки, скільки захочете","editing":"Показуйте і сховуйте кнопки змін на віджетах","links":"Це список посилань, додавайте сайти, які ви часто використовуєте, в налаштуваннях","tabs":"Це ваші вкладки. Ви можете додати більше в налаштуваннях","support":"Відправте нам повідомлення чи залиште відгук тут"},"finished":"Ось і все!","finished_next":"Choose an option from the menu (try starting with <b>Widgets</b>) and set your page up!","finished_contact":"Використайте посилання підтримки, якщо вам потрібна будь-яка допомога, ми відповімо вам якомога скоріш."}},"storage":{"signin":"Увійдіть у Google, аби безпечно зберегти і синхронизувати ваші налаштування","signin_btn":"Ввійти","signin_dismiss":"Пропустити","signin_confirm":{"title":"Зберігати локальні дані?","desc":"Хранити ваші локальні дані і замінити налаштування в вашому акаунті ними, чи замінити локальні налаштування існуючими в обліковому запису?","keep_account":"Використати обліковий запис","keep_local":"Використовувати локальне сховище"},"signout_confirm":"Вихід з облікового запису зітре ваші резервні дані","pastdue":"Ваша підписка прострочена","pastdue_desc":"Будь ласка, обновіть вашу інформацію про рахунок в налаштуваннях"},"toolbar":{"placeholder":"Введіть свої значення","placeholder_ok":"Введіть свої значення, чи скажіть \"OK, Google\"","suggestions":{"url_subtext":"Visit URL","capture_notice":"ProductivityTab handles searches you normally make from the Omnibox. You can disable this at any time from the settings"},"apps":{"search":"Пошук","youtube":"YouTube","maps":"Карти","play":"Play","news":"Новини","gmail":"Gmail","drive":"Drive","calendar":"Календар","more":"Більше"}},"menu":{"settings":"Налаштування","widgets":"Віджети","editing":"Редагування","editing_enabled":"Увімкнено","editing_disabled":"Вимкнено","plus":"Google+","tabs":"Вкладки","footer":{"support":"Підтримка","feedback":"Надіслати відгук","review":"Огляд","terms":"Умови","privacy":"Конфіденційність","by":"створено Avi Kohn"}},"voice":{"listening":"Відтворення...","searching":"Шукаємо: %s","missed":"Запит не отримано  <a>Повторити спробу</a>"},"settings":{"title":"Налаштування","exit":"Вийти з налаштувань","saved":"Налаштування збережені","nav":{"visual":"Зовнішній вигляд","visual_sections":{"background":"Тло","layout":"Макет","theme":"Тема додатка","ad_placement":"Ad placement"},"toolbar":"Панель інструментів","toolbar_sections":{"style":"Стиль","search":"Пошук","links":"Посилання"},"tabs":"Вкладки","widgets":"Віджети","ads":"Ads","pro":"Про","accounts":"Обліковий запис","misc":"Змішанне","advanced":"Просунуті","advanced_sections":{"backups":"Резервація і відновлення","css":"Індивідуальний CSS код","debug_tools":"Інструменти налагодження"},"support":"Допомога та підтримка","suggest":"Запропонувати функцію"},"visual":{"background":{"title":"Тло","desc":"Це зображення чи декілька зображень, показані як тло ваших вкладок","current":"Поточне тло","custom":"Індивідуальний","unnamed":"Тема %s","select":"Обрати тему","or":"чи","url_placeholder":"Введіть посилання на зображення"},"layout":{"title":"Макет","desc":"Тут можна настроїти тип і кількість стовпців на кожній вкладці","columns":"Стовпці","grid":"Сітка","columns_number":"Кількість стовпців","column_width":"Ширина стовпця","column_width_fixed":"Фіксована","column_width_fluid":"Плаваюча","column_warning":{"column_to_grid":"Changing to a grid-based layout will move all of your widgets to the top left corner.","grid_to_column":"Changing to a column-based layout will move all of your widgets to the first column."}},"theme":{"title":"Тема додатка","desc":"The app theme controls the style of ProductivityTab itself and all widgets","preview":"Передперегляд","light":"Світла (за замовчуванням)","dark":"Темна","transparent":"Прозора","transparent_darker":"Прозора(темніша)"}},"toolbar":{"style":{"title":"Стиль","desc":"Це визначає стиль панелі інструментів. Він може відображатися зазвичай або у вигляді кнопки","normal":"Звичайний","button":"Кнопка"},"search":{"title":"Пошук","desc":"These settings control how the search box and voice search function","engine":"Пошукова система","engines_default":"Default","engines_custom":"Індивідуальний","engines_custom_desc":"Enter a URL that queries should be sent to, with <b>%s</b> where the query should go.","omnibox_capture":"Handle searches normally made in the Omnibox","voice":"Enable voice search","ok_google":"Enable \"OK Google\" hotword detection","search_tab":"Open search results in a new tab"},"links":{"title":"Посилання","desc":"These are the items shown at the right of the toolbar","apps":"Apps menu","custom":"Custom links","custom_note1":"Maximum of 3 allowed","custom_note2":"users get 8","custom_name_placeholder":"Link text","custom_url_placeholder":"Link URL, i.e. https://www.google.com/"}},"misc":{"link_tab":"Open links in a new tab by default"},"tabs":{"create_new":"Create new","make_default":"Make default","desc1":"Tabs are pages inside ProductivityTab. Each tab has its own set of widgets that is completely separate from every other tab.","desc2":"You can switch between tabs by clicking the buttons that appear at the left and right of the screen when you move your mouse over a tab or by using the arrow keys on your keyboard.","name_placeholder":"Введіть назву вкладки","delete_confirm":"Ця дія незворотня. Всі дані віджетів у вкладці будуть втрачені назавжди."},"accounts":{"status":{"title":"Стан","signed_in":"Ви зараз <b>увійшли в</b> як %s (%s).","reset_account":"Скинути обліковий запис","sign_out":"Вийти з облікового запису","signed_out":"Ви <b>не зайшли у</b>. Увійдіть в обліковий запис Google зараз, аби безпечно зберегти і синхронізувати ваші налаштування.","sign_in":"Зайти в обліковий запис Google"},"reset_confirm_desc":"Це зітре всі локальні і синхронізовані дані, резервної копії немає, ви не зможете відмінити зроблене.","reset_confirm_desc2":"Ви втратете усі поточні налаштування на всіх комп'ютерах, підключених до цього облікового запису."},"advanced":{"backups":{"title":"Резервація і відновлення","desc":"Резервна копія зберігає повністю всі ваші вкладки, налаштування і віджети. Вони автоматично створюються, коли ви відкриваєте ProductivityTab першого разу кожного дня.","desc2":"Use the buttons below to roll ProductivityTab back to a particular date or download one of your backups.","backup":"Створити резервну копію зараз","upload":"Відновити із файла","download":"Завантажити","restore":"Відтворити","download_name":"Резервна копія ProductivityTab","restore_confirm":"Це перезапише всі локальні і синхронізовані дані. Ви втратите усі ваші налаштування на всіх комп'ютерах цього облікового запису.","restore_error":"Відбулася помилка при спробах розібрати предоставлені дані. Будь ласка, спробуйте пізніше."},"css":{"title":"Індивідуальний CSS код","desc":"Ви можете використовувати CSS (<a href=\"https://developer.mozilla.org/en-US/docs/Web/CSS\" target=\"blank\">definition</a>), аби налаштувати під себе майже будь-яку частину ProductivityTab.","placeholder":"Введіть не більше 1000 символів CSS тут"},"debug_tools":{"title":"Інструменти налагодження","desc":"<b>УВАГА:</b> Ці інструменти можуть зтерти всі ваші налаштування одним натиском. Використовуйте їх тільки якщо розробник інструктує вас.","open":"Відкрити інструменти"}},"widgets":{"desc1":"Віджети мають власні налаштування і не можуть бути змінені тут.","desc2":"Аби змінити налаштування віджету:","steps1":"Наведіть курсор на будь-який віджет","steps2":"Натисніть на зображення гайкового ключа у верхньому правому куті віджета. Якщо нічого не з'являється, то віджет не має змінних налаштувань.","steps3":"Змініть будь-яке налаштування у вікні, що відображається","steps4":"Клацніть \"Зберегти\", аби зберегти ваші зміни, або будь яку частину тла, аби відмінити їх"},"pro":{"promo":{"monthly_price":"$4.99 за місяць","yearly_price":"чи $29.99 за рік","upgrade_btn":"Поновити зараз","business":"Хочете придбати Pro для бізнесу чи школи?","business_contact":"Зв'яжіться з нами","themes":"Теми","themes_desc":"Побачити більше ваших фонів із темних і прозорих тем","bgs":"\"Живі\" фони","bgs_desc":"Оживіть сторінку використовуючи 20 високоякісних \"живих\" фонів","widgets":"Максимізувати віджети","widgets_desc":"Виведіть ProductivityTab на новий рівень з максимізованими віджетами","more_header":"І більше","stocks":"Інформація про ринки у реальному часі з розширенною і історичною інформацією","rss":"Support for multiple RSS feeds per widget","sports":"General and league-specific sports news","tabbed_widgets":"Tabbed news and RSS widgets","bg_downloads":"Downloadable backgrounds","weather":"Hourly weather forecasts up to 10 days out","toolbar":"More toolbar links","ads":"A completely ad-free experience","support":"Prioritized support and suggestions","buy_pro":"Buy Pro"},"checkout":{"title":"Checkout","updating_title":"Update plan","payment_options":"Pay","pay_monthly":"Monthly ($4.99)","pay_yearly":"Yearly ($29.99)","cancel":"Скасувати","update":"Update","subscribe":"Subscribe","braintree_notice":"Payments securely processed by Braintree.","monthly_notice":"By subscribing, you authorize ProductivityTab to charge you $4.99 every month until you cancel your subscription.","yearly_notice":"By subscribing, you authorize ProductivityTab to charge you $29.99 every year until you cancel your subscription.","update_notice":"Although billing cycle changes take effect immediately, you won't be charged until your current cycle ends.","thank_you":"Thank you for buying ProductivityTab Pro!","thank_you2":"ProductivityTab will reload in a few seconds and you'll be all set!","error":"Something went wrong while trying to process your payment.","error2":"Please try again later or email us at support@ichro.me","signin":"Sign in","signin_desc":"You need to sign in before buying Pro so we can make sure it's you","signin_btn":"Sign in"},"plan":{"title":"Plan","desc":"You are currently subscribed to ProductivityTab Pro (%s)","types":{"monthly":"Monthly","yearly":"Yearly","business":"Business","education":"Education","custom":"Custom"},"uneditable_desc":"Business, education, and custom plans cannot be updated from within ProductivityTab. Please <a href=\"mailto:support@ichro.me\">contact us</a> to update or cancel your subscription.","status":"Стан","status_active":"Active","status_trial":"Trial","status_pastdue":"Past due","subscription_date":"Subscription date","paid_through":"Paid through","next_bill":"Next bill","next_bill_value":"$%s on %s","update_plan":"Update plan","update_billing":"Update billing","cancel":"Cancel subscription","cancel_notice":"Your subscription will be canceled immediately","cancel_notice2":"If you would like a refund, please contact us at support@ichro.me"}},"ads":{"text1":"ProductivityTab displays a few small ads to pay for server, support and development costs. With these ads, we can afford to offer ProductivityTab free to everyone.","text2":"Here you can choose where those ads are shown, or buy ad-free to permanently remove them.","text3":"Ad-free is a one-time purchase that permanently removes ads from ProductivityTab wherever you're signed in. You can also upgrade to Pro for extra features in addition to an ad-free experience.","upgrade_btn":"Upgrade to ad-free","already_upgraded":"It looks like you've already upgraded to ad-free","signin":"Sign in","signin_desc":"Sign in before upgrading so we can link your purchase to your account","signin_btn":"Sign in","thank_you":"Thank you for upgrading to ad-free!","placement":{"title":"Ad placement","left":"In the leftmost column","right":"In the rightmost column","top":"Above the tab","bottom":"Floating at the bottom"}}},"store":{"installation":"Installation","description":"Description","preview":"Preview","instructions":"Drag and drop any size onto your homepage"},"widgets":{"sizes":{"tiny":"Tiny","small":"Small","medium":"Medium","large":"Large","variable":"Variable"},"settings":{"title":"Widget Settings","save":"Зберегти","size":"Widget Size"},"minimize":"Minimize","maximize":"Maximize","delete_confirm":"Are you really sure you want to delete this widget?\r\nThis action is irreversible; all data from this widget will be permanently lost.","permissions_request":{"title":"Access required","button":"Grant Access","desc":"This widget needs extra permissions before it can be used. Grant them using the button below."},"error":{"explanation":"Something went wrong while we were trying to display this widget.","advice":"Try reinstalling the widget or reloading the page. Contact us if you see this message often.","support":"Підтримка","refresh":"Refresh"},"auth":{"message":"You'll need to give this widget access to your account before you can use it.","button":"Grant Access"},"shared":{"settings":{"title":"Widget Title","title_placeholder":"Enter a widget title or leave blank to hide","height":"Widget Height","open_options":{"current":"The current tab","blank":"A new tab"},"footer_link":"Footer Link","footer_link_options":{"show":"Показати","hide":"Hide"},"account":"Account ID","account_help":"If you're signed into multiple accounts, this is the \"authuser=\" value.\n<br /><br />\nFor example, if you're signed into two accounts, jsmith1@gmail.com and jsmith2@gmail.com, the \"authuser\" value for jsmith2@gmail.com would be 1 since it's the second account (counting from zero) that you're signed into.","account_placeholder":"Your \"authuser=\" value","on":"On","off":"Off"}},"apps":{"name":"Додатки","desc":"Відображає ваші інстальовані програми Google Chrome.","settings":{"format":"Формат віджету","format_options":{"tiles":"Плитки","list":"Список"},"display":"Показати","display_options":{"all":"Усі додатки","enabled":"Лише активні додатки"},"sort":"Упорядкувати","sort_options":{"id":"ID","alphabetically":"За алфавітом","offline":"Увімкнено офлайн","available":"Доступність"},"open":"Відкривати додатки у"},"store_app":"Крамниця"},"bookmarks":{"name":"Закладки","desc":"Відображає виділені і налаштовані закладки та інші посилання.","settings":{"title_placeholder":"Введіть назву віджету","layout":"Layout","layout_options":{"single":"Single column","double":"Double column"},"open":"Open bookmarks in"},"edit":{"dialog_title":"Edit Bookmark","title":"Bookmark Title","title_placeholder":"Google","url":"Bookmark URL","url_placeholder":"https://www.google.com/","save":"Зберегти"},"new_caption":"Нова","new_bookmark":"Закладка","new_folder":"Тека","drop_link":"Drop link here"},"chrome_bookmarks":{"name":"Закладки","desc":"Displays your Chrome bookmarks, optionally from a specific folder.","settings":{"title_placeholder":"Введіть назву віджету","from":"Show bookmarks from","open":"Open bookmarks in"}},"calc":{"name":"Calculator","desc":"Displays a calculator with support for basic operators.","error":"Помилка!","infinity":"Нескінченно","mismatch":"Mismatched parentheses"},"calendar":{"name":"Календар","desc":"Displays upcoming events from one or more of your Google calendars.","settings":{"calendar":"Календар","show":"Show events from","show_options":{"all":"Весь час (до 40 подій)","today":"Сьогодні"},"view":"Тип календаря","view_options":{"agenda1d":"Сьогодні","list2w":"Список","short1d":"Короткий"},"range":{"start":"Сьогодні, З","end":"Сьогодні, До"}},"title":"Agenda","calendar":"Календар","noevents":"No events found in the near future, it looks like your schedule's clear!"},"clock":{"name":"Clock","desc":"Offers alarm, time, timer, and stopwatch functionality.","settings":{"timezone":"Time Zone","timezone_local":"Local","format":"Clock Format","format_options":{"ampm":"AM/PM - Digital","24hour":"24 Hour - Digital","analog":"12 Hour - Analog","ampmseconds":"AM/PM - Digital, No Seconds","24hourseconds":"24 Hour - Digital, No Seconds"},"sound":"Alert Sound"},"title":"Clock","alarm":"Alarm","clock":"Clock","timer":"Timer","stopwatch":"Stopwatch","set":"Set","unset":"Unset","dismiss":"Dismiss","enable_audio":"Enable audio"},"facebook":{"name":"Facebook","desc":"Embeds Facebook in a widget"},"feedly":{"name":"Feedly","desc":"Displays articles from your Feedly account in a configurable format.","settings":{"source":"Show articles from","source_feeds":"Feeds","show":"Показати","show_options":{"all":"All articles","unread":"Only unread articles"},"layout":"Layout","layout_options":{"titles":"Titles only","magazine":"Magazine","cards":"Cards","cards_columns":"Cards (two columns)"},"mark":"Mark an article as read when I","mark_options":{"scroll":"Scroll past it or click it","click":"Just click it"},"sort":"Sort Order","sort_options":{"newest":"Newest first","oldest":"Oldest first"}},"all":"All","saved":"Saved for later","uncategorized":"Uncategorized","author":"за","go_to_feedly":"Go To Feedly"},"notes":{"name":"Notes","desc":"Inserts a simple, editable, note.","settings":{"color":"Note Color","color_options":{"yellow":"Yellow","orange":"Orange","red":"Red","blue":"Blue","green":"Green","white":"White"},"font":"Font Face","fontsize":"Font Size"}},"now":{"name":"Google Now","desc":"Displays cards from Google Now including flight status and package tracking.","authorize":"You'll need to give ProductivityTab permission to view your Google Now cards before anything will show up here.","authorize_btn":"Authorize","caught_up":"All caught up, nothing here.","no_title":"No Title"},"plus":{"name":"Google+","desc":"Embeds Google Plus in a widget"},"notifications":{"name":"Google Notifications","desc":"Displays your Google Notifications from services such as Google+"},"reddit":{"name":"Reddit","desc":"Displays the top items on Reddit for any given subreddit.","settings":{"subreddit":"Subreddit","subreddit_help":"Enter any subreddit by the part past <b>/r/</b> when on Reddit.\n<br /><br />\nFor example, Technology is at: <a href=\"https://www.reddit.com/r/technology\">https://www.reddit.com/r/technology</a>, therefore you would enter <b>technology</b>","subreddit_placeholder":"Enter a subreddit to show links from. (i.e. technology)","sort":"Sort Order","sort_options":{"hot":"Hot","top":"Top","new":"Нова","gilded":"Gilded","rising":"Rising","controversial":"Controversial"},"links":"Links Shown","click":"When I click a link show me","click_options":{"link":"The link","comments":"The comments"}},"more":"Більше"},"tasks":{"name":"Tasks","desc":"Displays an editable list of tasks from one of your Google Tasks lists.","title":"Tasks","settings":{"list":"Список"},"task_title":"Title","due_date":"Due date","notes":"Notes","add":"Add Item","delete_task":"Delete Task","move_up":"Move Up","move_down":"Move Down","done":"Done","due_today":"Due today","overdue":"Overdue","authorize":"You'll need to select a list from your Google Tasks via the settings before anything can be displayed here."},"twitter":{"name":"Twitter","desc":"Displays tweets from your home stream or a specified list.","settings":{"source":"Show Tweets from","show":"Tweets Shown"},"authorize":"You'll need to authorize ProductivityTab first","authorize_msg":"You'll need to give ProductivityTab permission to view tweets from your account before anything will show up here.","authorize_btn":"Authorize","no_tweets":"There don't seem to be any tweets here...","home":"Додому","mentions":"Mentions","retweets":"Retweets of me","lists":"Lists","more":"Більше","reply":"Reply","retweet":"Retweet","favorite":"Favorite"},"wolfram":{"name":"Wolfram|Alpha","desc":"Inserts a small Wolfram|Alpha search box."},"youtube":{"name":"YouTube","desc":"Displays either popular videos or videos from a specified user.","settings":{"format":"Format","format_options":{"large":"One large","large_2":"One large, two small","large_4":"One large, four small","four":"Four small","six":"Six small"},"from":"Show Videos From","from_help":"This must be an <b>exact</b> username as shown in the URL of the page when you're viewing their profile.\n<br /><br />\nThis value never includes spaces.","from_placeholder":"Leave blank to show Top Videos","open":"Open search results in"},"search":"Search YouTube","num_views":"views"},"quotes":{"name":"Quotes","desc":"Displays a quote picked either every time you load the page or once daily.","settings":{"source":"Source","method":"Load new quotes","method_options":{"daily":"Once daily","random":"Every time I load the page"}},"unknown_author":"Unknown"},"html":{"name":"HTML","desc":"Displays completely custom HTML in an iframe.","settings":{"html":"HTML","js":"JavaScript","height":"Widget Height"}},"sitelink":{"name":"Site Link","desc":"Displays a link, optionally with a title and thumbnail","settings":{"link":"Link URL","link_placeholder":"https://www.google.com/","image":"Image URL","image_placeholder":"https://www.example.com/image.png","color":"Image Background Color","style":"Image Style","style_fill":"Fill","style_center":"Center"}},"stats":{"name":"System Statistics","desc":"Keep an eye on your system with realtime statistics","memory":"Memory","battery":"Battery","usage":"usage","in_use":"in use","remaining":"remaining","charged":"Fully Charged","idle":"Idle","charging":"Charging","discharging":"Discharging"},"search":{"name":"Пошук","desc":"Embeds a search box in your page for easy access","settings":{"placeholder":"Search Field Placeholder","search_url":"Пошук посилання","param":"Query Parameter","param_placeholder":"The parameter where the query goes, i.e. \"q\""},"default_placeholder":"Search Google"},"pushbullet":{"name":"Pushbullet","desc":"Keep track of notifications from your phone and other devices","no_pushes":"No pushes found","sign_in":"Sign in","no_key":"It doesn't look like you're signed in to Pushbullet.  Sign in now to connect this widget."},"linkedin":{"name":"LinkedIn","desc":"Displays your LinkedIn home stream"},"directions":{"name":"Directions","desc":"Get directions to and from nearly anywhere right from your homepage","driving":"Driving","transit":"Public Transit","walking":"Walking","cycling":"Cycling","from":"Enter a starting point","to":"Enter a destination","loading":"Loading directions, please wait...","error":"Something went wrong while trying to load the directions you requested.","error2":"Please check the start and destination addresses you entered.","open_in_maps":"Open in Google Maps","via":"via"},"pocket":{"name":"Pocket","desc":"Display a list of your saved articles, videos, and web pages from Pocket","settings":{"links_shown":"Number of links shown","open":"Open links","open_pocket":"In Pocket","open_original":"At their original URL"},"by":"за","no_links":"No links found","grant_access":"Grant access","no_key":"You'll need to give ProductivityTab access to your Pocket account before it can load your links."}},"themes":{"title":"Themes","all":"All","custom":"Custom","create":"Create a theme","url_or_upload":"or","upload_image":"Upload an image","edit_btn":"Edit","delete":"Delete","use":"Use","preview":"Preview","author":"за","images":"%s images","resolution":"Resolution","categories":"Categories","cached":"This theme has been cached and is available offline","random":"This theme displays a random image every time you load the page","random_daily":"This theme displays an image picked randomly every day","sunrise_sunset":"This theme displays an image based on the time of day","feed":"This theme displays an image selected daily from an external feed","video":"This theme displays a live video","pro_only":"This theme is only available to Pro users. Buy Pro in the settings.","delete_confirm":"Are you really sure you would like to delete this theme?\r\nThis action is irreversible; the entire theme will be permanently lost.","delete_error":"An error occurred while trying to delete the theme.  Please try again later.","feed_fetching":"Please wait, fetching feed...","feed_error":"Something went wrong while trying to fetch the feed.  Please try again later.","caching":"Please wait, caching theme...","cache_status":"%s of %s images cached","cache_error":"An error occurred while trying to cache the theme.  Please try again later","bginfo":{"view":"View","source":"Source","unknown":"Unknown","download":"Завантажити","pro_only":"Only Pro users can download background images and videos"},"edit":{"title":"Edit Theme","create_title":"Create Theme","name":"Theme Name","default_name":"New Theme","name_placeholder":"Enter a theme name","image":"Image URL","image_placeholder":"Enter a background image URL","image_help":"Uploaded images <b>cannot be synced</b> between computers.<br /><br />If this is important to you, please upload your image to a service such as <a href=\"https://imgur.com/\" target=\"_blank\">imgur</a>. Then copy the URL ending with an extension (i.e. .jpg) and paste it into the field on the left.","color":"Fallback Color","color_placeholder":"Enter any color name","position":"Position","position_options":{"center":"Center","top_left":"Top Left","top_center":"Top Center","top_right":"Top Right","bottom_left":"Bottom Left","bottom_center":"Bottom Center","bottom_right":"Bottom Right"},"scaling":"Scaling","scaling_options":{"auto":"Auto","width":"Full Width","height":"Full Height","none":"No Scaling (preview may be inaccurate)"},"repeat":"Image Repeat","repeat_options":{"none":"No Repeat","horizontal":"Repeat Horizontally","vertical":"Repeat Vertically","both":"Repeat Both"},"attach":"Attach Image To","attach_tab":"The tab","attach_window":"The window","preview":"Preview","save":"Зберегти та закрити","cache_error":"An error occurred while trying to cache the image you provided, please double-check the URL.","upload_error":"An error occurred while trying to upload the file you provided, please make sure that it's a reasonable size and an image."}}},"zh-CN":{"lang_code":"zh-CN","language":"简体中文","extName":"ProductivityTab — Custom Homepage Dashboard","newtabName":"ProductivityTab — Custom New Tab Dashboard","extDescription":"A remarkably customizable personal homepage featuring 50+ widgets, breathtaking backgrounds and much more.","newtabDescription":"A customizable personal dashboard on your new tab page featuring 50+ widgets, breathtaking backgrounds and much more.","defaults":{"tab":"首页","me":"我"},"remove_widget":"移除","hide_banner":"隐藏横幅广告","hide_ad":{"content":"Hey! We're not crazy about ads either, but we're only able to make ProductivityTab available and continue developing features for our free users (that's you!) by showing ads. If you'd like to support ProductivityTab directly and get rid of ads for free, we would really appreciate if you upgraded to our pro version","upgrade":"立即升级","hide":"隐藏广告"},"alert":{"default_button":"忽略","confirm_title":"您确定要这样做？","confirm_continue":"继续","confirm_cancel":"取消"},"onboarding":{"modal":{"tagline":"您所有的站点及应用，全在这里","wrong_extension":"想将ProductivityTab设为您的新标签页？","wrong_extension_newtab":"想将ProductivityTab设为您的主页？","wrong_extension_action":"请点击此处","about":"ProductivityTab中的一切都基于选项卡和小工具","about_desc":"标签页由小部件组成。小部件可以显示各种各样的信息，例如天气预报，最新新闻以及您的邮件。您可以随心所欲的自定义绝大多数小部件，最妙的是您想添加多少就可以添加多少。","terms":"开始使用ProductivityTab代表您同意ProductivityTab的<a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\">使用条款</a>及<a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\">隐私政策</a>","sign_in":"使用您的 Google 帐户登录","sign_in_desc":"在可在线安全的保存您所做更改前，请登录您的Google账户。","sign_in_desc2":"您可以保持未登录状态，但您的ProductivityTab页面将不会被在线保存，而且您将无法在其他计算机上访问此页面。","sign_in_button":"使用 Google 帐号登录","have_account":"看起来您已经有了一个账户！","have_account_desc":"您现在可以使用所有的标签页和小部件了！","get_started":"让我们开始吧！","get_started_desc":"一切就绪！让我们一起开始设置您的页面。"},"widgets":{"configure":"让我们来配置一个小部件。","configure_desc":"Click the wrench to open a widget's <b>settings</b>.","configure_skip":"Skip Tutorial","settings":"Replace <b>Link URL</b> with your favorite site, then press <b>Save</b>.","move":"You can <b>reposition</b> widgets by clicking and dragging the three dots highlighted here.","remove":"To <b>delete</b>, simply click the red trash bin icon.","done":"好"},"settings":{"intro":"Now let’s add a new widget. This highlighted button is where you can access the Widget Menu.","instructions":"Click the new widget button on to open the widget menu!","skip":"跳过","tooltips":{"settings":"改变 ProductivityTab 的外观和功能","widgets":"添加新小部件 - 您可以添加任意数量的小部件","editing":"显示或隐藏小部件上的编辑按钮","links":"这是常用链接列表，您可以在在设置中添加您经常访问的站点","tabs":"这是您的标签页列表，您可随时在设置中添加更多标签页。","support":"给我们发送消息或在此留下您对ProductivityTab的评价。"},"finished":"就是这样！","finished_next":"您可以从菜单中选择一个选项(试着从<b>小部件</b>开始) ，然后开始自定义您的页面!","finished_contact":"如果您需要任何帮助，请点击“支持”。我们会尽快给您回复。"}},"storage":{"signin":"立即使用谷歌账号登陆以便保存及同步您的设置","signin_btn":"登录","signin_dismiss":"忽略","signin_confirm":{"title":"是否保留本地数据?","desc":"您想保留本地配置并替换您账户中的配置，还是使用您账户中的配置替换本地配置？","keep_account":"使用账户","keep_local":"保留本机设置"},"signout_confirm":"登出将删除你的本地备份","pastdue":"您的订阅已过期","pastdue_desc":"请更新您设置的付费信息"},"toolbar":{"placeholder":"输入并搜索...","placeholder_ok":"请输入或说“OK, Google\"启动语音搜索...","suggestions":{"url_subtext":"访问链接","capture_notice":"ProductivityTab将取代您网址栏的搜索功能，您可随时在设置中禁用此设置。"},"apps":{"search":"搜索","youtube":"Youtube","maps":"地图","play":"Play商店","news":"新闻","gmail":"Gmail","drive":"网盘","calendar":"日历","more":"更多"}},"menu":{"settings":"设置","widgets":"小部件","editing":"编辑","editing_enabled":"开启","editing_disabled":"关闭","plus":"Google+","tabs":"标签页","footer":{"support":"支持","feedback":"反馈","review":"评分","terms":"条款","privacy":"隐私","by":"由Avi Kohn奉献"}},"voice":{"listening":"正在聆听...","searching":"正在搜索：%s","missed":"抱歉，没有听清楚。<a>再试一次</a>"},"settings":{"title":"设置","exit":"退出设置","saved":"更改已保存","nav":{"visual":"外观","visual_sections":{"background":"背景","layout":"布局","theme":"应用主题","ad_placement":"广告位置"},"toolbar":"工具栏","toolbar_sections":{"style":"样式","search":"搜索","links":"链接"},"tabs":"标签页","widgets":"小部件","ads":"广告","pro":"专业版","accounts":"帐户","misc":"其他设置","advanced":"高级","advanced_sections":{"backups":"备份与恢复","css":"自定义 CSS","debug_tools":"调试工具"},"support":"帮助和支持","suggest":"向我们提议新功能"},"visual":{"background":{"title":"背景","desc":"此设置改变您的背景图片或图片组","current":"当前背景","custom":"自定义","unnamed":"主题 %s","select":"选择一个主题","or":"或","url_placeholder":"输入图片地址"},"layout":{"title":"布局","desc":"此设置可调整每个选项卡的排列和类型","columns":"列表","grid":"网格","columns_number":"列数","column_width":"列宽：","column_width_fixed":"固定列宽","column_width_fluid":"弹性页宽","column_warning":{"column_to_grid":"如果将布局改变成为基于网格的布局会使你的所有的小部件都移动至左上角。","grid_to_column":"如果将布局改变成为基于列的布局会使你的所有的小部件都移动至第一列。"}},"theme":{"title":"应用主题","desc":"ProductivityTab及所有小部件的界面设置","preview":"预览","light":"浅色(默认)","dark":"暗色调","transparent":"半透明","transparent_darker":"半透明（暗色）"}},"toolbar":{"style":{"title":"样式","desc":"此设置控制工具栏的样式，其可以以正常或按钮形式显示。","normal":"普通","button":"按钮"},"search":{"title":"搜索","desc":"此设置控制搜索框及语音搜索功能","engine":"搜索引擎","engines_default":"默认","engines_custom":"自定义","engines_custom_desc":"请输入搜索请求所使用的的URL地址，您输入的关键词在此由<b>%s</b>代替。","omnibox_capture":"使用ProductivityTab代替网址栏的搜索功能","voice":"启用语音搜索","ok_google":"启用\"OK Google“声音检测","search_tab":"在新选项卡中打开搜索结果页"},"links":{"title":"链接：","desc":"此设置改变您工具栏右侧显示的链接","apps":"应用菜单","custom":"自定义链接","custom_note1":"普通用户最多可设置3个链接","custom_note2":"用户可以设置高达8条链接","custom_name_placeholder":"链接文本","custom_url_placeholder":"链接地址，例如 https://www.google.com/"}},"misc":{"link_tab":"默认情况下将在新选项卡中打开链接"},"tabs":{"create_new":"新建","make_default":"设为默认","desc1":"标签页是ProductivityTab里的页面。每个标签页都有其自己的小部件，彼此之间完全独立。","desc2":"您可以移动鼠标以点击屏幕左右边的按钮，或使用键盘上的方向键来切换标签页。","name_placeholder":"输入标签页名称","delete_confirm":"警告，此操作并不可逆。此标签页中所有小部件的数据将会永久丢失。"},"accounts":{"status":{"title":"账户状态","signed_in":"您当前正以 %s (%s) 的身份 <b>登录</b>。","reset_account":"重置帐户","sign_out":"登出","signed_out":"您当前并未<b>登录</b>。登录您的谷歌帐户以便安全地存储和同步您的配置。","sign_in":"使用 Google 帐号登录"},"reset_confirm_desc":"该操作将清除所有本地和同步数据，请注意该操作没有备份并且无法撤消。","reset_confirm_desc2":"您将失去所有连接到该账号的电脑上的配置。"},"advanced":{"backups":{"title":"备份与恢复","desc":"备份是指您所有选项卡，设置和小部件的完整备份。在您每天第一次打开ProductivityTab时备份将会自动建立。","desc2":"使用下面的按钮将ProductivityTab回滚至过去的设置，您也可以下载您的备份。","backup":"立即备份","upload":"从文件还原","download":"下载","restore":"还原","download_name":"ProductivityTab 备份","restore_confirm":"警告，这将覆盖您本地及同步的所有数据。您将失去该帐户下所有计算机上的当前配置。","restore_error":"在解析您提供的数据时出错了，请稍后再试。"},"css":{"title":"自定义 CSS","desc":"您可以使用 CSS (<a href=\"https://developer.mozilla.org/en-US/docs/Web/CSS\"target=\"blank\"> 介绍</a>) 来自定义ProductivityTab的几乎任何部分。","placeholder":"您最多可输入1000个字符"},"debug_tools":{"title":"调试工具","desc":"<b>警告:</b>您仅需单击这些工具便有可能清除整个配置，请只有在得到开发人员指示时使用它们。","open":"打开工具"}},"widgets":{"desc1":"每个小部件都有自己独立的设置，您无法在此修改。","desc2":"若您要改变小部件的设置，请参考以下步骤：","steps1":"将鼠标移动到您想更改设置的小部件上","steps2":"单击小部件右上角处显示的扳手图标。如果图标没有显示，代表该小部件没有可自定义的设置。","steps3":"此时您即可编辑显示在对话框中的任意一项设置了","steps4":"单击保存按钮以保存您所作的更改，或单击对话框背景中的任意位置以放弃您的更改"},"pro":{"promo":{"monthly_price":"每月仅需4.99美元","yearly_price":"或年付29.99美元","upgrade_btn":"立即升级","business":"有兴趣为您的企业或学校购买专业版 ?","business_contact":"联系我们","themes":"主题","themes_desc":"全新的典雅黑小部件主题，令您更加愉悦地欣赏您独一无二的背景图片。","bgs":"动态背景","bgs_desc":"二十种高清动态背景令您的标签页富有趣味","widgets":"可最大化的窗口小部件","widgets_desc":"有了可最大化的小部件，ProductivityTab将大有不同","more_header":"以及更多功能","stocks":"带有延伸资料和历史记录的实时股票信息","rss":"支持订阅多RSS源的小部件","sports":"可显示普通和特定联赛的体育快讯","tabbed_widgets":"选项卡式排列的新闻和RSS小部件","bg_downloads":"背景图片可任意下载","weather":"提供长达未来10天每小时的天气预报","toolbar":"可设置更多工具栏链接","ads":"完全无干扰的体验","support":"技术支持及建议优先处理","buy_pro":"立即购买专业版"},"checkout":{"title":"付款","updating_title":"升级套餐","payment_options":"支付","pay_monthly":"每月 (约合4.99美元)","pay_yearly":"每年 (29.99美元)","cancel":"取消","update":"更新","subscribe":"订阅","braintree_notice":"您的付款信息将安全地交由Braintree处理。","monthly_notice":"您如订阅，代表您授权ProductivityTab每个月收取您 4.99 美元，直到您取消订阅。","yearly_notice":"您如订阅，代表您授权ProductivityTab每年收取您 29.99 美元，直到您取消订阅。","update_notice":"虽然计费周期更改将立即生效，直到当前付款周期结束前您将不会被收取任何费用。","thank_you":"感谢您购买 ProductivityTab 专业版!","thank_you2":"一切即将就绪，ProductivityTab将在几秒钟内重新加载。","error":"在尝试处理您的付款时出错了。","error2":"请稍后再试或发给我们发送电子邮件 support@ichro.me","signin":"登录","signin_desc":"您需要先登录才可购买专业版，因为这样我们才能确定是您。","signin_btn":"登录"},"plan":{"title":"套餐","desc":"您目前已订阅 ProductivityTab 专业版 (%s)","types":{"monthly":"月付","yearly":"年付","business":"企业版","education":"教育版","custom":"自定义"},"uneditable_desc":"商业，教育及自定义套餐不能在ProductivityTab内设置。请 <a href=\"mailto:support@ichro.me\"> 联系我们</a>以更新或取消您的订阅。","status":"订阅状态","status_active":"已激活","status_trial":"试用","status_pastdue":"已过期","subscription_date":"订阅日期","paid_through":"已支付至","next_bill":"下次支付日期","next_bill_value":"$%s 于 %s","update_plan":"升级套餐","update_billing":"更新付款信息","cancel":"取消订阅","cancel_notice":"您的订阅将被立即取消","cancel_notice2":"如果您想要退款，请通过邮件support@ichro.me联系我们"}},"ads":{"text1":"ProductivityTab displays a few small ads to pay for server, support and development costs. With these ads, we can afford to offer ProductivityTab free to everyone.","text2":"在这里你可以选择广告在哪里显示，或升级至无广告版以获取无干扰的体验。","text3":"Ad-free is a one-time purchase that permanently removes ads from ProductivityTab wherever you're signed in. You can also upgrade to Pro for extra features in addition to an ad-free experience.","upgrade_btn":"升级至无广告版","already_upgraded":"看起来您已经升级到无广告版了","signin":"登入","signin_desc":"在升级前请您登录以便我们将其关联到您的账号","signin_btn":"登入","thank_you":"感谢您升级到无广告版！","placement":{"title":"广告位置","left":"最左列","right":"最右列","top":"最上方","bottom":"底部漂浮"}}},"store":{"installation":"安装小部件","description":"描述","preview":"预览","instructions":"拖动到您的主页上然后调整至合适的大小"},"widgets":{"sizes":{"tiny":"迷你","small":"小","medium":"中","large":"大","variable":"特大"},"settings":{"title":"小部件设置","save":"保存","size":"小部件大小"},"minimize":"最小化","maximize":"最大化","delete_confirm":"您真的要删除此小部件吗？此操作不可恢复，该小部件的所有数据都将永久丢失。","permissions_request":{"title":"需要访问权限","button":"授予访问权限","desc":"这个小部件需要额外的权限才可使用，点击下方按钮以授予权限。"},"error":{"explanation":"试图显示该小部件时出现了未知错误。","advice":"请尝试重新安装该窗口小部件或重新加载页面。如果您经常看到此消息，请与我们联系。","support":"支持","refresh":"刷新"},"auth":{"message":"在您使用窗口小部件之前您需要授予它访问您帐户的权限。","button":"授予访问权限"},"shared":{"settings":{"title":"小部件标题","title_placeholder":"输入小部件窗口标题或留空隐藏","height":"小部件高度","open_options":{"current":"当前选项卡","blank":"新选项卡"},"footer_link":"”更多“按钮","footer_link_options":{"show":"显示","hide":"隐藏"},"account":"帐户 ID","account_help":"如果您已经登录到多个帐户，这就是\"authuser =\"值。\n<br /><br />例如，如果您已经登录了两个帐户、 jsmith1@gmail.com、 jsmith2@gmail.com、 jsmith2@gmail.com 的\"authuser\"值将为 1 ，因为它是第二个帐户 (authuser值从0开始计数)。","account_placeholder":"您的\"authuser=\"值","on":"开启","off":"关闭"}},"apps":{"name":"应用程序","desc":"显示您当前安装的谷歌Chrome浏览器应用程序。","settings":{"format":"小部件格式","format_options":{"tiles":"磁贴式","list":"列表式"},"display":"显示","display_options":{"all":"所有应用程序","enabled":"仅启用的应用程序"},"sort":"排序","sort_options":{"id":"编号","alphabetically":"按字母顺序排列","offline":"脱机启用","available":"可用性"},"open":"在...中打开应用"},"store_app":"Store"},"bookmarks":{"name":"收藏夹","desc":"显示您可随意定制的收藏夹和其他链接。","settings":{"title_placeholder":"输入小部件标题","layout":"布局","layout_options":{"single":"单列","double":"双列"},"open":"在...中打开书签"},"edit":{"dialog_title":"编辑书签","title":"书签名","title_placeholder":"谷歌（Google）","url":"添加链接","url_placeholder":"https://www.google.com/","save":"保存"},"new_caption":"新建","new_bookmark":"书签","new_folder":"文件夹","drop_link":"将链接拖至此处"},"chrome_bookmarks":{"name":"书签","desc":"显示您的Chrome标签页，并可指定只显示某个文件夹。","settings":{"title_placeholder":"输入小部件标题","from":"收藏夹位置","open":"在...中打开书签"}},"calc":{"name":"计算器","desc":"显示一个支持简单运算的计算器","error":"错误 ！","infinity":"无限","mismatch":"括号不匹配"},"calendar":{"name":"日历","desc":"显示您谷歌日历即中将发生的事件。","settings":{"calendar":"日历","show":"从 显示活动","show_options":{"all":"所有时间","today":"仅显示今天"}},"title":"日程","calendar":"日历","noevents":"没有新的日程安排"},"clock":{"name":"时钟","desc":"提供闹钟、 时间、 计时器和秒表功能。","settings":{"timezone":"时区","timezone_local":"本地","format":"时钟格式","format_options":{"ampm":"AM/PM-数字","24hour":"24 小时-数字","analog":"12 小时-模拟","ampmseconds":"AM/PM-数字（无“秒”）","24hourseconds":"24 小时-数字（无“秒”）"},"sound":"提示声"},"title":"时钟","alarm":"闹钟","clock":"时钟","timer":"计时器","stopwatch":"秒表","set":"设定","unset":"取消设置","dismiss":"忽略","enable_audio":"提示音"},"facebook":{"name":"Facebook","desc":"在小部件中嵌入Facebook"},"feedly":{"name":"Feedly","desc":"用可配置的格式显示您Feedly账户中的文章。","settings":{"source":"显示文章来源","source_feeds":"订阅源","show":"显示","show_options":{"all":"所有文章","unread":"仅显示未读的文章"},"layout":"布局","layout_options":{"titles":"仅显示标题","magazine":"杂志","cards":"卡片","cards_columns":"卡片（两列）"},"mark":"将文章标为已读当我：","mark_options":{"scroll":"滚动滚动条经过其或点击其时","click":"点击其时"},"sort":"排序方式","sort_options":{"newest":"从最新开始","oldest":"从最旧开始"}},"all":"全部","saved":"为将来阅读保存","uncategorized":"未分类","author":"作者","go_to_feedly":"打开Feedly"},"notes":{"name":"便签","desc":"插入简单、 可编辑的便签。","settings":{"color":"便签颜色","color_options":{"yellow":"黄色","orange":"橙色","red":"红色","blue":"蓝色","green":"绿色","white":"白色"},"font":"字体","fontsize":"字体大小"}},"now":{"name":"Google Now","desc":"显示Google Now卡片，提供包括并不限于航班状态和包裹追踪的各种卡片。","authorize":"在任何东西显示之前您需要授予ProductivityTab查看您Google Now卡片的权限。","authorize_btn":"授权","caught_up":"没有新通知","no_title":"无标题"},"plus":{"name":"Google+","desc":"Google+小部件"},"notifications":{"name":"Google通知","desc":"显示您谷歌服务的通知，例如Google+"},"reddit":{"name":"Reddit","desc":"显示Reddit上的热门话题","settings":{"subreddit":"Reddit分类","subreddit_help":"输入在Reddit分类网页链接<b>/r/</b>后的字符。\n<br /><br />\n例如，科技类的链接是<a href=\"https://www.reddit.com/r/technology\">https://www.reddit.com/r/technology</a>所以您需要输入<b>technology</b>","subreddit_placeholder":"输入Reddit分类的显示链接。（例如technology）","sort":"排序方式","sort_options":{"hot":"热门","top":"置顶","new":"新建","gilded":"高亮","rising":"上升","controversial":"有争议"},"links":"显示链接","click":"当我点击链接时显示","click_options":{"link":"链接本身","comments":"评论"}},"more":"更多"},"tasks":{"name":"Google Tasks","desc":"显示并可编辑您Google任务列表中的待办事项","title":"Google Tasks","settings":{"list":"列表"},"task_title":"标题","due_date":"截止日期","notes":"便签","add":"新建","delete_task":"删除任务","move_up":"上移","move_down":"下移","done":" 完成","due_today":"截止于今天","overdue":"已过期","authorize":"在任何东西显示之前您需要到设置选项卡中在您的Google Tasks里指定一个列表。"},"twitter":{"name":"Twitter","desc":"显示您的信息流或指定列表中的Tweets。","settings":{"source":"显示从推文来源","show":"显示Tweets"},"authorize":"您需要给予ProductivityTab授权","authorize_msg":"在显示任何东西之前您需要授予ProductivityTab权限以查看您账户中的推文。","authorize_btn":"授权","no_tweets":"似乎这里没有任何Tweets...","home":"首页","mentions":"提及","retweets":"转发","lists":"列表","more":"更多","reply":"回复","retweet":"转推","favorite":"收藏"},"wolfram":{"name":"Wolfram|Alpha","desc":"插入一个小巧的Wolfram Alpha搜索框。"},"youtube":{"name":"Youtube","desc":"显示热门视频或显示特定用户的视频。","settings":{"format":"格式","format_options":{"large":"一个大位置","large_2":"一个大位置两个小位置","large_4":"一个大位置四个小位置","four":"四个小位置","six":"六个小位置"},"from":"显示视频来源","from_help":"这必须是与您查看个人资料时<b>完全一致</b>的用户名。\n<br /><br />\n此值永远不会包含空格。","from_placeholder":"为空则显示热门视频","open":"搜索结果打开方式"},"search":"搜索 YouTube","num_views":"浏览次数"},"quotes":{"name":"语录","desc":"显示名人名言和经典语录，每天或每次加载页面时更新。","settings":{"source":"来源","method":"加载新语录","method_options":{"daily":"每天一次","random":"每次加载页面时"}},"unknown_author":"无名"},"html":{"name":"HTML","desc":"在iframe标签中显示您完全自定义的HTML代码。","settings":{"html":"HTML","js":"JavaScript","height":"小部件高度"}},"sitelink":{"name":"站点链接","desc":"显示一个带有标题和缩略图（可选）的链接","settings":{"link":"链接 URL：","link_placeholder":"https://www.google.com/","image":"图像地址","image_placeholder":"https://www.example.com/image.png","color":"图像背景色","style":"图像样式","style_fill":"填充","style_center":"居中"}},"stats":{"name":"系统状态","desc":"用实时统计监控您的系统","memory":"内存","battery":"电量","usage":"已使用","in_use":"已使用","remaining":"剩余","charged":"已充满","idle":"电量剩余","charging":"充电中","discharging":"外部电源未连接"},"search":{"name":"搜索","desc":"在您的页面中插入一个搜索框来实现快速访问","settings":{"placeholder":"搜索字段占位符","search_url":"搜索链接","param":"查询参数","param_placeholder":"参数查询的指向，即为“q”"},"default_placeholder":"用谷歌（Google）搜索"},"pushbullet":{"name":"Pushbullet","desc":"追踪您的手机及其他设备的通知","no_pushes":"没有新推送","sign_in":"登入","no_key":"您似乎并没有登录到 Pushbullet。请登录以连接此部件。"},"linkedin":{"name":"领英（LinkedIn）","desc":"显示你的 LinkedIn 首页信息流"},"directions":{"name":"路线","desc":"从您的主页获得从任意地点到达另一任意地点的路线","driving":"开车","transit":"公共交通","walking":"步行","cycling":"自行车","from":"输入一个起点","to":"输入目的地","loading":"载入路线中，请稍后...","error":"在尝试加载您输入的路线时出错了。","error2":"请检查您输入的起点与终点地址。","open_in_maps":"在谷歌地图中打开","via":"通过"},"pocket":{"name":"Pocket","desc":"显示您在Pocket中保存的文章，视频及网页列表","settings":{"links_shown":"显示链接数","open":"打开链接","open_pocket":"打开Pocket","open_original":"打开原始地址"},"by":"作者","no_links":"找不到链接","grant_access":"授予访问权限","no_key":"在加载您保存在Pocket中的链接前，请先授权ProductivityTab访问您的Pocket账号。"}},"themes":{"title":"主题","all":"全部","custom":"自定义","create":"创建主题","url_or_upload":"或","upload_image":"上传图像","edit_btn":"编辑","delete":"刪除","use":"使用","preview":"预览","author":"作者","images":"含有 %s 个图像","resolution":"分辨率","categories":"所属分类","cached":"该主题已缓存，可脱机使用","random":"该主题在每次重新加载页面时显示随机图片","random_daily":"该主题每天随机显示一张新图片","sunrise_sunset":"该主题基于一天的时间显示图片","feed":"该主题从外部源每天获取新图像","video":"该主题显示动态视频","pro_only":"该主题仅限专业版用户使用，您可以在设置中购买专业版。","delete_confirm":"您真的要删除这个主题吗？\n此操作不可恢复 ；整个主题将永久丢失。","delete_error":"试图删除该主题时出错。请稍后再试。","feed_fetching":"请稍候，源正在获取......","feed_error":"在尝试刷新源时出错，请稍后重试。","caching":"请稍候，正在缓存主题...","cache_status":"%s 个图片被缓存，还有 %s 个","cache_error":"试图删除该主题时出错。请稍后再试。","bginfo":{"view":"查看","source":"来源","unknown":"未知","download":"下载","pro_only":"只有专业版用户可以下载背景图像和视频"},"edit":{"title":"编辑主题","create_title":"创建主题","name":"主题名称","default_name":"新主题","name_placeholder":"输入主题名称","image":"图像地址","image_placeholder":"背景图像链接","image_help":"上传的图片<b>无法在电脑之间同步</b><br /><br />如果这对您很重要，请将您的图像上传到类似 <a href=\"https://imgur.com/\"target=\"_blank\"> imgur</a> 的图床服务。然后复制和粘贴带扩展名的链接 (例如.jpg) 并将其粘贴到左侧的文本框中。","color":"回退颜色","color_placeholder":"输入颜色名称","position":"位置","position_options":{"center":"中","top_left":"左上角","top_center":"顶部居中","top_right":"右上角","bottom_left":"左下角","bottom_center":"底部居中","bottom_right":"右下角"},"scaling":"缩放比例","scaling_options":{"auto":"自动","width":"全宽度","height":"全高度","none":"无缩放比例 （预览时可能会不准确）"},"repeat":"图像重复","repeat_options":{"none":"不重复","horizontal":"水平重复","vertical":"垂直重复","both":"全部重复"},"attach":"将图像使用在","attach_tab":"选项卡","attach_window":"窗口","preview":"预览","save":"保存并关闭","cache_error":"在缓存您提供的图像链接时出错，请仔细检查该链接是否正确。","upload_error":"在上传您提供的文件时出错，请确保其大小正确和是否是一张图片。"}}},"zh-TW":{"lang_code":"zh-TW","language":"正體中文（臺灣）","extName":"ProductivityTab — Custom Homepage Dashboard","newtabName":"ProductivityTab — Custom New Tab Dashboard","extDescription":"A remarkably customizable personal homepage featuring 50+ widgets, breathtaking backgrounds and much more.","newtabDescription":"A customizable personal dashboard on your new tab page featuring 50+ widgets, breathtaking backgrounds and much more.","defaults":{"tab":"主頁","me":"我"},"remove_widget":"刪除","hide_banner":"Hide this banner","hide_ad":{"content":"Hey! We're not crazy about ads either, but we're only able to make ProductivityTab available and continue developing features for our free users (that's you!) by showing ads. If you'd like to support ProductivityTab directly and get rid of ads for free, we would really appreciate if you upgraded to our pro version","upgrade":"Upgrade","hide":"Hide ads"},"alert":{"default_button":"取消","confirm_title":"你確定要這樣做嗎？","confirm_continue":"繼續。","confirm_cancel":"取消"},"onboarding":{"modal":{"tagline":"您所有的網站與應用程式都放在同一個地方。","wrong_extension":"你希望ProductivityTab取代在你的新分頁上嗎？","wrong_extension_newtab":"你希望使用ProductivityTab來作為首頁嗎？","wrong_extension_action":"點擊此處","about":"ProductivityTab是關於分頁與小工具","about_desc":"分頁是由小工具構成，顯示像是天氣、新聞和您的電子郵件。你可以客製化大部分的小工具，並且如果您想要，你可以添加更多。","terms":"若繼續，您將同意 ProductivityTab 的 <a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\">使用條款</a> 和 <a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\">隱私權政策</a>","sign_in":"以Google帳號登入","sign_in_desc":"在開始之前請登入你的 Google 帳號以便安全地將你的更懂保存在線上","sign_in_desc2":"你可以保持不登入，但你的頁面將不會被儲存在線上而且你也不能從別臺電腦上存取。","sign_in_button":"使用Google登入","have_account":"看起來你已經有個帳號了！","have_account_desc":"您所有的分頁及小工具都已經準備就緒！","get_started":"讓我們開始吧！","get_started_desc":"你已經準備好了！讓我們開始設定你的頁面吧！"},"widgets":{"configure":"點此設定小部件","configure_desc":"Click the wrench to open a widget's <b>settings</b>.","configure_skip":"Skip Tutorial","settings":"Replace <b>Link URL</b> with your favorite site, then press <b>Save</b>.","move":"You can <b>reposition</b> widgets by clicking and dragging the three dots highlighted here.","remove":"To <b>delete</b>, simply click the red trash bin icon.","done":"我知道了"},"settings":{"intro":"Now let’s add a new widget. This highlighted button is where you can access the Widget Menu.","instructions":"Click the new widget button on to open the widget menu!","skip":"跳過","tooltips":{"settings":"設置ProductivityTab的外觀與內容","widgets":"新增新的小部件 — 你想有幾個都行","editing":"顯示或隱藏在小部件上的編輯按鈕","links":"這是連結的列表，可在設定中將常用的網站設定上去","tabs":"這是你的Tab，你可以在設定中增加更多","support":"發送給我們訊息或是在這裡留下回覆"},"finished":"輕鬆、簡單！","finished_next":"選擇功能表中的一個功能 (可試著從 <b>小部件</b> 開始) 並開始設置您的頁面！","finished_contact":"若您需要任何説明可以使用支援連結，我們會儘快給你回覆。"}},"storage":{"signin":"使用Google 登入來安全的同步資料與儲存您的配置","signin_btn":"登入","signin_dismiss":"不理會","signin_confirm":{"title":"保留線下資料？","desc":"你想要使用本機資料來取代你帳戶中的設定嗎？ 還是保持您帳戶的配置，並替換掉本機端的資料？","keep_account":"使用帳號","keep_local":"儲存在本機中"},"signout_confirm":"登出將會清楚你的本地備份","pastdue":"您的訂閱已經過期","pastdue_desc":"請更新您在設定中的付款資訊"},"toolbar":{"placeholder":"輸入並搜尋","placeholder_ok":"輸入並搜尋或說“OK, Google\"...","suggestions":{"url_subtext":"訪問網址","capture_notice":"ProductivityTab將取代您地址欄的搜尋功能，您可隨時在設定中禁用此設置。"},"apps":{"search":"搜尋","youtube":"YouTube","maps":"地圖","play":"Play","news":"新聞","gmail":"Gmail","drive":"Drive","calendar":"行事曆","more":"更多"}},"menu":{"settings":"設定","widgets":"小工具","editing":"編輯","editing_enabled":"開啟","editing_disabled":"關閉","plus":"Google+","tabs":"分頁","footer":{"support":"支援","feedback":"意見回報","review":"評論","terms":"條款","privacy":"隱私政策","by":"由 Avi Kohn 製作"}},"voice":{"listening":"正在聆聽...","searching":"檢索：%s","missed":"抱歉，沒有聽到。<a>再試一次</a>"},"settings":{"title":"設定","exit":"退出設定","saved":"已儲存設定","nav":{"visual":"外觀","visual_sections":{"background":"背景","layout":"配罝","theme":"App主題","ad_placement":"Ad placement"},"toolbar":"工具列","toolbar_sections":{"style":"樣式","search":"搜尋","links":"連結"},"tabs":"分頁","widgets":"小工具","ads":"Ads","pro":"Pro","accounts":"賬號","misc":"雜項","advanced":"進階","advanced_sections":{"backups":"備份與還原","css":"自訂 CSS","debug_tools":"除錯工具"},"support":"説明和支援","suggest":"提供意見"},"visual":{"background":{"title":"背景","desc":"這裡會是一張圖或是整個圖片集來作為您Tab的背景","current":"目前的背景","custom":"自訂","unnamed":"主題 %s","select":"選擇一個主題","or":"或","url_placeholder":"輸入圖片網址"},"layout":{"title":"配罝","desc":"在這裡你可以調整每個tab中的排列方式和欄數","columns":"直欄","grid":"格狀","columns_number":"欄數","column_width":"欄寬","column_width_fixed":"固定","column_width_fluid":"動態","column_warning":{"column_to_grid":"更改為格網佈局將會把你所有的 widget 移動到左上角","grid_to_column":"切換到以欄為檢視的方式將會移動您所有的小部件到第一個欄位中。"}},"theme":{"title":"App主題","desc":"App主題將會套用在ProductivityTab與其他所有小部件的樣式上。","preview":"預覽","light":"明亮（預設）","dark":"暗色","transparent":"透明","transparent_darker":"透明（黑調）"}},"toolbar":{"style":{"title":"樣式","desc":"設定工具列樣式。可以一般方式顯示，或僅顯示開啟工具列的按鈕。","normal":"一般","button":"按鈕"},"search":{"title":"搜尋","desc":"這些設定控制著搜尋框與語音搜尋將如何運作","engine":"搜尋引擎","engines_default":"預設","engines_custom":"自訂","engines_custom_desc":"輸入一個搜尋網址可用來接收查詢，替換<b>%s</b> 以自製查詢要求","omnibox_capture":"使用ProductivityTab取代地址欄的搜尋功能","voice":"啟用語音搜尋","ok_google":"啟用 \"OK Google\" 指令偵測","search_tab":"在新分頁中顯示搜尋結果"},"links":{"title":"連結","desc":"這些項目顯示在工具列的右側中","apps":"App選單","custom":"自訂連結","custom_note1":"最多允許3個","custom_note2":"使用者取得'8'","custom_name_placeholder":"連結文字","custom_url_placeholder":"連結網址，例如：https://www.google.com/"}},"misc":{"link_tab":"設定在新的Tab中開啟連結"},"tabs":{"create_new":"創建新項目","make_default":"設為預設值","desc1":"Tab是在ProductivityTab中的一個一個頁面，每個Tab皆有它自己的完全獨立於其他Tab的小部件集。","desc2":"您可以透過點擊ProductivityTab首頁左右兩側的箭頭圖示按鈕，或是使用鍵盤上的左右方向鍵來切換不同的ProductivityTab分頁。","name_placeholder":"輸入一個Tab名稱","delete_confirm":"此操作將會是是不可逆的。在這個tab中的所有資料與部件將會永久遺失。"},"accounts":{"status":{"title":"狀態","signed_in":"您目前 <b>登入</b> 為 %s (%s)。","reset_account":"重設帳號","sign_out":"登出","signed_out":"您目前<b>尚未登入</b>。請登入您的 Google 帳戶來安全的存儲並同步您的設定。","sign_in":"使用Google登入"},"reset_confirm_desc":"此行為將清除所有線下與同步資料，此行為將不留任何備份並且無法撤消。","reset_confirm_desc2":"你將失去當前的配置在所有連接到此帳戶的電腦上。"},"advanced":{"backups":{"title":"備份與還原","desc":"備份功能將完全複製您所有的分頁及小工具的設置。此功能會在您每一天初次開啟ProductivityTab時自動執行。","desc2":"使用這個按鈕來還原ProductivityTab至特定日期或下載您其中的一個備份。","backup":"立即備份","upload":"從檔案還原","download":"下載","restore":"還原","download_name":"備份ProductivityTab","restore_confirm":"這將覆蓋所有的本機與同步資料。你將失去當前所有連結於此帳戶電腦中的全部配置，","restore_error":"在解析您所提供的資料時發生錯誤，請稍後再嘗試。"},"css":{"title":"自訂 CSS","desc":"您可以使用 CSS語法 (<a href=\"HTTPs://developer.mozilla.org/en-US/docs/Web/CSS\"target=\"blank\"> 定義</a>) 來自訂幾乎任何部分的 ProductivityTab。","placeholder":"在此可輸入最高1000字元的CSS語法"},"debug_tools":{"title":"檢錯工具","desc":"<b>警告:</b>這些工具能夠在一個點下就移除整個配置。請在有開發人員指示下才只使用它們。","open":"打開測試工具"}},"widgets":{"desc1":"每個小部件都有它自己的設定，並且無法在此處自訂。","desc2":"若要編輯一個部件的設置，請遵照以下步驟：","steps1":"將滑鼠移動到任一個部件上","steps2":"點選在小部件右上角的板手圖示。如果沒有顯示代表小部件沒有任何可以自定化的設定。","steps3":"編輯任何顯示在對話方塊中的設置","steps4":"點擊保存來儲存您的設定，或者點擊背景的任意地方來放棄設定。"},"pro":{"promo":{"monthly_price":"每月 4.99 美元","yearly_price":"或是每一年29.99美元","upgrade_btn":"立即升級！","business":"對於企業或校園方的Pro方案有興趣嗎？","business_contact":"聯絡我們","themes":"主題","themes_desc":"讓小部件有更多像雅典黑或透明的主題背景","bgs":"動態背景","bgs_desc":"多達20 種高解析背景將使你的頁面活躍起來","widgets":"更大可能化的部件","widgets_desc":"透過更多可能化的小工具，將ProductivityTab帶往另外一個境界","more_header":"以及更多功能","stocks":"即時股票資訊加上過往或相關延伸消息","rss":"支援一次多個RSS來源的小部件","sports":"一般與特定聯賽的體育新聞","tabbed_widgets":"更多部件化的新聞與RSS","bg_downloads":"可下載的背景","weather":"每小時的天氣預測將可達 10 天以上","toolbar":"更多工具列連結","ads":"A completely ad-free experience","support":"優先的需求或建議","buy_pro":"購買Pro"},"checkout":{"title":"結帳","updating_title":"升級方案","payment_options":"支付","pay_monthly":"每月（約4.99美元）","pay_yearly":"每年（約29.99美元）","cancel":"取消","update":"更新","subscribe":"訂閱","braintree_notice":"訂單將交由Braintree安全的處理。","monthly_notice":"藉由訂閱，您將授權ProductivityTab每個月收取4.99美金直到您取消訂閱為止。","yearly_notice":"藉由訂閱，您將授權ProductivityTab每年收取29.99美金直到您取消訂閱為止。","update_notice":"儘管購買週期的變更已經立即生效了，但你將不會有費用的收取直到下次週期結束為止。","thank_you":"感謝您購買 ProductivityTab Pro!","thank_you2":"ProductivityTab將需要幾秒來重新載入，並且為您準備好一切！","error":"我們在處理您的訂單時出了點問題。","error2":"請稍後在做嘗試，或使用E-mail聯繫我們： support@ichro.me","signin":"登入","signin_desc":"在購買Pro方案前，您必須先行登入來辨識身份","signin_btn":"登入"},"plan":{"title":"方案","desc":"您目前正訂閱著 ProductivityTab Pro (%s)","types":{"monthly":"每月","yearly":"每年","business":"商業","education":"教育","custom":"自訂"},"uneditable_desc":"商業，教育和自訂的方案無法從 ProductivityTab內部更新。請 <a href=\"mailto:support@ichro.me\"> 聯繫我們</a> 來更新或取消您的訂閱。","status":"狀態","status_active":"啟動","status_trial":"試用","status_pastdue":"逾期","subscription_date":"訂閱日期","paid_through":"支付方式","next_bill":"下一個訂單","next_bill_value":"$%s 於 %s","update_plan":"升級方案","update_billing":"升級帳單","cancel":"取消訂閱","cancel_notice":"您的訂閱將會立刻取消","cancel_notice2":"若您想要退款，請寄信到support@ichro.me來聯絡我們"}},"ads":{"text1":"ProductivityTab displays a few small ads to pay for server, support and development costs. With these ads, we can afford to offer ProductivityTab free to everyone.","text2":"Here you can choose where those ads are shown, or buy ad-free to permanently remove them.","text3":"Ad-free is a one-time purchase that permanently removes ads from ProductivityTab wherever you're signed in. You can also upgrade to Pro for extra features in addition to an ad-free experience.","upgrade_btn":"Upgrade to ad-free","already_upgraded":"It looks like you've already upgraded to ad-free","signin":"登入","signin_desc":"Sign in before upgrading so we can link your purchase to your account","signin_btn":"登入","thank_you":"Thank you for upgrading to ad-free!","placement":{"title":"Ad placement","left":"In the leftmost column","right":"In the rightmost column","top":"Above the tab","bottom":"Floating at the bottom"}}},"store":{"installation":"安裝","description":"描述","preview":"預覽","instructions":"拖曳任何大小至您的主頁上"},"widgets":{"sizes":{"tiny":"更小","small":"小","medium":"中","large":"大","variable":"變數"},"settings":{"title":"小工具設定","save":"儲存","size":"小工具的大小"},"minimize":"最小化","maximize":"最大化","delete_confirm":"您確定要刪除這個小工具嗎？\n此操作無法復原；這個小工具的所有資料都將永遠移除。","permissions_request":{"title":"需要權限","button":"給予權限","desc":"這個小部件需要額外的許可權才可以使用。使用下方的按鈕來授予他們權限。"},"error":{"explanation":"當我們嘗試顯示這個小部件的時候出了點狀況","advice":"請嘗試重新安裝這個小部件或重新載入頁面。如果你經常看到此訊息，請與我們聯繫。","support":"支援","refresh":"重新整理"},"auth":{"message":"在您的帳號使用這個小部件前，您需要先授與相關權限。","button":"給予權限"},"shared":{"settings":{"title":"小工具標題","title_placeholder":"輸入小工具標題，保留空白的話標題列就不會顯示","height":"小工具高度","open_options":{"current":"當前分頁","blank":"新的分頁"},"footer_link":"頁腳連結","footer_link_options":{"show":"顯示","hide":"隱藏"},"account":"帳號","account_help":"如果你已經登錄到多個帳戶，這裡是用來設定\"authuser =\"值。\n<br /><br />\n舉例，如果你已經登錄到兩個帳戶、 jsmith1@gmail.com 和  jsmith2@gmail.com，jsmith2@gmail.com 的\"authuser\"值會是 1 ，因為它是您已經登錄的第二個帳戶（從零開始計算）。","account_placeholder":"你的\"authuser =\"值","on":"開啟","off":"關閉"}},"apps":{"name":"應用程式","desc":"顯示當前安裝的Chrome瀏覽器的應用程式。","settings":{"format":"小工具格式","format_options":{"tiles":"方塊式","list":"清單檢視"},"display":"顯示","display_options":{"all":"所有應用程式","enabled":"只有啟用後的應用程式"},"sort":"排序","sort_options":{"id":"ID","alphabetically":"按字母排序","offline":"離線啟用","available":"可用性"},"open":"打開方式"},"store_app":"商店"},"bookmarks":{"name":"書籤","desc":"顯示選定和個性書籤，及其他連結。","settings":{"title_placeholder":"輸入小工具標題","layout":"配罝","layout_options":{"single":"單列","double":"雙列"},"open":"打開書籤於..."},"edit":{"dialog_title":"編輯書籤","title":"書籤標題","title_placeholder":"Google","url":"書籤網址","url_placeholder":"https://www.google.com/","save":"儲存"},"new_caption":"新增","new_bookmark":"書籤","new_folder":"資料夾","drop_link":"拖曳連結至此"},"chrome_bookmarks":{"name":"書籤","desc":"顯示您的 Chrome 書簽，也可以設定特定的資料夾。","settings":{"title_placeholder":"輸入小工具標題","from":"顯示書籤來源","open":"打開書籤於..."}},"calc":{"name":"計算機","desc":"顯示含有基本運算符的計算器。","error":"錯誤 ！","infinity":"無限","mismatch":"不匹配的括弧"},"calendar":{"name":"行事曆","desc":"顯示接下來一或多個來自Google日曆的事件","settings":{"calendar":"行事曆","show":"顯示事件來源","show_options":{"all":"全時間","today":"僅有今天"}},"title":"行程","calendar":"行事曆","noevents":"沒有近期活動，看起來你的行程都搞定了！"},"clock":{"name":"時鐘","desc":"提供提醒、時間、計時器還有碼錶功能。","settings":{"timezone":"時區","timezone_local":"本地","format":"時鐘格式","format_options":{"ampm":"上午/下午 - 數位時鐘","24hour":"24 小時 - 數位時鐘","analog":"12 小時 - 類比時鐘","ampmseconds":"上午/下午 - 數位時鐘，沒有「秒」","24hourseconds":"24 小時 - 數位時鐘，沒有「秒」"},"sound":"提示音效"},"title":"時鐘","alarm":"提醒","clock":"時鐘","timer":"計時器","stopwatch":"碼錶","set":"設定","unset":"取消設定","dismiss":"不理會","enable_audio":"啟動音效"},"facebook":{"name":"FACEBOOK","desc":"將Facebook嵌入小工具中"},"feedly":{"name":"Feedly","desc":"從您的Feedly帳戶中顯示可配置格式的文章","settings":{"source":"顯示文章從...","source_feeds":"訂閱","show":"顯示","show_options":{"all":"所有文章","unread":"只顯示未讀的文章"},"layout":"介面樣式","layout_options":{"titles":"只顯示標題","magazine":"雜誌","cards":"卡片","cards_columns":"卡片(兩列)"},"mark":"將文章標記為已讀在...","mark_options":{"scroll":"滾動過去或按一下它","click":"只要點選"},"sort":"排列次序","sort_options":{"newest":"最新的優先","oldest":"最舊的優先"}},"all":"全部","saved":"儲存為以後之用","uncategorized":"未分類","author":"作者","go_to_feedly":"前往 Feedly"},"notes":{"name":"備註","desc":"插入一個簡單，可編輯的備忘錄。","settings":{"color":"備忘錄顏色","color_options":{"yellow":"黃色","orange":"橘色","red":"紅色","blue":"藍色","green":"綠色","white":"白色"},"font":"字體","fontsize":"字體大小"}},"now":{"name":"Google 即時資訊","desc":"顯示Google即時資訊的卡片，包含航班資訊以及包裹追蹤","authorize":"你需要給予ProductivityTab許可才能查看Google即時資訊的卡片","authorize_btn":"授權","caught_up":"沒有新通知","no_title":"無標題"},"plus":{"name":"Google+","desc":"在小工具嵌入 Google Plus"},"notifications":{"name":"Google即時提醒","desc":"顯示您的Google相關服務即時提醒，如：Google+"},"reddit":{"name":"熱迪特","desc":"根據提供的reddit細目顯示Reddit上熱門話題。","settings":{"subreddit":"Subreddit","subreddit_help":"在網址的<b>/r/</b>之後輸入任何reddit細目。\n<br /><br />\n例如，科技類的網址是<a href=\"https://www.reddit.com/r/technology\">https://www.reddit.com/r/technology</a>, 因此你需要輸入<b>technology</b>","subreddit_placeholder":"輸入 reddit 細目（例如：technology）以顯示連結。","sort":"排列次序","sort_options":{"hot":"熱門","top":"頂部","new":"新增","gilded":"鍍金的","rising":"上升","controversial":"有爭議的"},"links":"已顯示連結","click":"當我點擊連結時顯示","click_options":{"link":"連結","comments":"評論"}},"more":"更多"},"tasks":{"name":"任務","desc":"從你的 Google Task 顯示一組可以編輯的工作清單。","title":"任務","settings":{"list":"清單檢視"},"task_title":"標題","due_date":"最後期限","notes":"備註","add":"加入項目","delete_task":"刪除任務","move_up":"上移","move_down":"下移","done":" 完成","due_today":"今天到期","overdue":"逾期","authorize":"你需要先通過設置從你的谷歌任務(Google Tasks) 中挑選清單(list), 否則什麼都無法在這裡顯示。"},"twitter":{"name":"Twitter","desc":"從你家的流或指定的清單的顯示鳴叫。","settings":{"source":"從...顯示推文。","show":"推文所示"},"authorize":"你必須先授權ProductivityTab。","authorize_msg":"在顯示任何東西之前，你必須給 ProductivityTab 許可權來查看你帳戶裡的推文","authorize_btn":"授權","no_tweets":"這裡似乎沒有任何推文...","home":"主頁","mentions":"提及","retweets":"我的轉推","lists":"清單","more":"更多","reply":"回覆","retweet":"轉推","favorite":"我的最愛"},"wolfram":{"name":"WolframAlpha網站","desc":"插入一個小的 Wolfram|Alpha 搜尋框。"},"youtube":{"name":"YouTube","desc":"顯示熱門影片或一個指定使用者的影片。","settings":{"format":"格式","format_options":{"large":"一個大的","large_2":"一大，兩小","large_4":"一大，四小","four":"四個小的","six":"六個小的"},"from":"顯示影片從","from_help":"這個使用者名稱必須和你在檢視他們的個人資料時所顯示在該頁面網址中的名稱<b>一模一樣</b>。\n<br /><br />\n其中絕對不會有任何空格。","from_placeholder":"留空格來顯示精華影片。","open":"開啟搜尋結果於"},"search":"搜尋 YouTube","num_views":"觀賞"},"quotes":{"name":"名句","desc":"每天一次或在你每次讀取頁面顯示一則名句","settings":{"source":"來源","method":"載入新的報價","method_options":{"daily":"每天一次","random":"每次載入頁面"}},"unknown_author":"未知"},"html":{"name":"HTML","desc":"在 iframe 中顯示完全自訂的 HTML。","settings":{"html":"HTML","js":"JavaScript","height":"小工具高度"}},"sitelink":{"name":"網站連結","desc":"在頁面上顯示一個包含網站名稱與縮圖的連結","settings":{"link":"連結網址：","link_placeholder":"https://www.google.com/","image":"圖像網址","image_placeholder":"https://www.example.com/image.png","color":"圖片背景顏色","style":"圖片樣式","style_fill":"填滿","style_center":"置中"}},"stats":{"name":"系統狀態","desc":"監視您的系統與即時統計","memory":"記憶體：","battery":"電池","usage":"使用率","in_use":"可用","remaining":"剩餘","charged":"完成充電","idle":"閒置","charging":"充電中","discharging":"電池使用中"},"search":{"name":"搜尋","desc":"在頁面上插入一個搜尋框，方便您連結","settings":{"placeholder":"搜尋框顯示文字","search_url":"搜尋網址","param":"查詢參數","param_placeholder":"搜尋參數設定，例如＂q＂"},"default_placeholder":"以 Google 搜尋"},"pushbullet":{"name":"Pushbullet","desc":"從你的手機或是其他裝置持續關注通知","no_pushes":"未發現新訊息","sign_in":"登入","no_key":"看來你還沒註冊Pushullet，現在就註冊以啟用這項小工具"},"linkedin":{"name":"LinkedIn","desc":"顯示你的 LinkedIn 首頁流"},"directions":{"name":"方向","desc":"在您的首頁規劃任意地點間的路線","driving":"開車","transit":"大眾運輸工具","walking":"步行","cycling":"騎自行車","from":"輸入一個起始點","to":"輸入目的地","loading":"跳轉頁面中，請稍後","error":"在試圖載入您所要求的方向時發生了錯誤","error2":"請檢查您輸入的起點和目的地位址。","open_in_maps":"在谷歌地圖中打開","via":"透過"},"pocket":{"name":"Pocket","desc":"從 Pocket 裡的清單顯示您已保存的文章、視頻和網頁","settings":{"links_shown":"顯示的連結數目","open":"打開連結","open_pocket":"在 Pocket 裡","open_original":"在其原始 URL"},"by":"由","no_links":"找不到連結","grant_access":"授予存取權限","no_key":"你需要給 ProductivityTab 存取 Pocket 帳戶權限, 才能載入你的連結。"}},"themes":{"title":"主題","all":"全部","custom":"自訂","create":"建立新的主題","url_or_upload":"或","upload_image":"上傳圖像","edit_btn":"編輯","delete":"刪除","use":"使用","preview":"預覽","author":"由","images":"%s 張圖像","resolution":"解析度","categories":"分類","cached":"這主題已緩存，也可以離線使用","random":"此主題會在每次載入頁時隨機顯示圖像","random_daily":"此主題每一天隨機顯示圖像","sunrise_sunset":"這個主題基於一天的時間顯示圖像","feed":"該主題每天從外部源獲取新圖像","video":"這個主題展示一個動態影片","pro_only":"這個主題僅提供給Pro用戶。您可以考慮在設定中購買Pro。","delete_confirm":"你真的確定你想要刪除這個主題嗎？\n此操作是不可逆的；整個主題將永久消失。","delete_error":"試圖刪除該主題時出錯。請稍後再試。","feed_fetching":"我們正在讀取摘要，請耐心等候。","feed_error":"在嘗試刷新源時出錯，請稍後重試。","caching":"請稍候，正在緩存主題中...","cache_status":"緩存了 %s / %s 張圖像","cache_error":"快取主題內容時出錯。請稍後再試。","bginfo":{"view":"檢視","source":"來源","unknown":"未知","download":"下載","pro_only":"僅有Pro使用者能夠下載背景圖片或影片。"},"edit":{"title":"編輯主題","create_title":"創建主題","name":"主題名稱","default_name":"新增主題","name_placeholder":"請輸入主題名稱","image":"圖像網址","image_placeholder":"輸入背景圖像的網址","image_help":"上載了的圖像在電腦之間 <b>無法同步</b> <br /> <br /> 如果這對你很重要，請將您的圖像上載到 <a href=\"HTTP://imgur.com/\"target=\"_blank\"> imgur</a> 類似的服務。然後複製和貼上含有副檔名 (即.jpg) 的網址到左側欄內。","color":"背景顏色","color_placeholder":"輸入顏色名稱","position":"位置","position_options":{"center":"置中","top_left":"左上方","top_center":"中央置頂","top_right":"右上方","bottom_left":"左下方","bottom_center":"中央底端","bottom_right":"右下方"},"scaling":"縮放","scaling_options":{"auto":"自動","width":"跟隨寬度","height":"跟隨高度","none":"不縮放 （預覽可能不準確）"},"repeat":"圖像重複","repeat_options":{"none":"不重複","horizontal":"水平重複","vertical":"垂直重複","both":"重複"},"attach":"附加圖像到","attach_tab":"分頁","attach_window":"視窗","preview":"預覽","save":"保存並關閉","cache_error":"不能由連結取得圖片，請確保輸入的圖片連結正確","upload_error":"嘗試上傳檔案時出錯。請確認該檔案為合理大小的圖片檔。"}}}});
/**
 * I18N
 * 
 * This system uses custom JSON files for simplicity and loads them using
 * the JSON plugin. They're then pre-processed and inlined at build time
 * using a system similar to the templates.
 */
define('i18n/i18n',["lodash", "moment", "browser/api", "i18n/locales"], function(_, moment, Browser, locales) {
	/**
	 * This gets the language code from the Chrome-selected file, it effectively uses
	 * Chrome's language code parsing while getting strings from its own internal locale files.
	 */
	var language = Browser.language || "en";

	document.body.lang = language;

	moment.locale(language);


	/**
	 * Gets a string in the chosen language and returns it, optionally with interpolated variables
	 *
	 * @api    private
	 * @param  {String}   id     The key of the string to get
	 * @param  {...*}     [data] The data to interpolate
	 * @return {String}          The returned string, interpolated if variables were provided
	 */
	var translate = function(id) {
		id = id || "";

		var data = _.rest(arguments);

		try {
			// Adapted from http://stackoverflow.com/a/6394168/900747
			var string = _.reduce(
				id.split("."),
				function(obj, i) { return obj[i]; },
				locales[language]
			) || "";


			if (!string) {
				string = _.reduce(
					id.split("."),
					function(obj, i) { return obj[i]; },
					locales.en
				) || "";
			}


			// This replaces every instance of %s in the string one-by-one with
			// it's match from the arguments until none are left
			// 
			// It's simple and a bit blunt but it'll only rarely, if ever, get used.
			while (data.length) {
				string = string.replace("%s", data.shift());
			}


			return string;
		}
		catch (e) {
			return "";
		}
	};


	/**
	 * Gets the entire object for a particular language.  Used by the render function to expose i18n strings to templates
	 *
	 * @api    private
	 * @param  {String} [lang] The language code to retrieve for, defaults to the current language
	 * @return {Object}        The language object
	 */
	translate.getAll = function(lang) {
		return locales[lang || language];
	};

	return translate;
});
/*!
 *  Copyright 2011 Twitter, Inc.
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */



var Hogan = {};

(function (Hogan) {
  Hogan.Template = function (codeObj, text, compiler, options) {
    codeObj = codeObj || {};
    this.r = codeObj.code || this.r;
    this.c = compiler;
    this.options = options || {};
    this.text = text || '';
    this.partials = codeObj.partials || {};
    this.subs = codeObj.subs || {};
    this.buf = '';
  }

  Hogan.Template.prototype = {
    // render: replaced by generated code.
    r: function (context, partials, indent) { return ''; },

    // variable escaping
    v: hoganEscape,

    // triple stache
    t: coerceToString,

    render: function render(context, partials, indent) {
      return this.ri([context], partials || {}, indent);
    },

    // render internal -- a hook for overrides that catches partials too
    ri: function (context, partials, indent) {
      return this.r(context, partials, indent);
    },

    // ensurePartial
    ep: function(symbol, partials) {
      var partial = this.partials[symbol];

      // check to see that if we've instantiated this partial before
      var template = partials[partial.name];
      if (partial.instance && partial.base == template) {
        return partial.instance;
      }

      if (typeof template == 'string') {
        if (!this.c) {
          throw new Error("No compiler available.");
        }
        template = this.c.compile(template, this.options);
      }

      if (!template) {
        return null;
      }

      // We use this to check whether the partials dictionary has changed
      this.partials[symbol].base = template;

      if (partial.subs) {
        // Make sure we consider parent template now
        if (!partials.stackText) partials.stackText = {};
        for (key in partial.subs) {
          if (!partials.stackText[key]) {
            partials.stackText[key] = (this.activeSub !== undefined && partials.stackText[this.activeSub]) ? partials.stackText[this.activeSub] : this.text;
          }
        }
        template = createSpecializedPartial(template, partial.subs, partial.partials,
          this.stackSubs, this.stackPartials, partials.stackText);
      }
      this.partials[symbol].instance = template;

      return template;
    },

    // tries to find a partial in the current scope and render it
    rp: function(symbol, context, partials, indent) {
      var partial = this.ep(symbol, partials);
      if (!partial) {
        return '';
      }

      return partial.ri(context, partials, indent);
    },

    // render a section
    rs: function(context, partials, section) {
      var tail = context[context.length - 1];

      if (!isArray(tail)) {
        section(context, partials, this);
        return;
      }

      for (var i = 0; i < tail.length; i++) {
        context.push(tail[i]);
        section(context, partials, this);
        context.pop();
      }
    },

    // maybe start a section
    s: function(val, ctx, partials, inverted, start, end, tags) {
      var pass;

      if (isArray(val) && val.length === 0) {
        return false;
      }

      if (typeof val == 'function') {
        val = this.ms(val, ctx, partials, inverted, start, end, tags);
      }

      pass = !!val;

      if (!inverted && pass && ctx) {
        ctx.push((typeof val == 'object') ? val : ctx[ctx.length - 1]);
      }

      return pass;
    },

    // find values with dotted names
    d: function(key, ctx, partials, returnFound) {
      var found,
          names = key.split('.'),
          val = this.f(names[0], ctx, partials, returnFound),
          doModelGet = this.options.modelGet,
          cx = null;

      if (key === '.' && isArray(ctx[ctx.length - 2])) {
        val = ctx[ctx.length - 1];
      } else {
        for (var i = 1; i < names.length; i++) {
          found = findInScope(names[i], val, doModelGet);
          if (found !== undefined) {
            cx = val;
            val = found;
          } else {
            val = '';
          }
        }
      }

      if (returnFound && !val) {
        return false;
      }

      if (!returnFound && typeof val == 'function') {
        ctx.push(cx);
        val = this.mv(val, ctx, partials);
        ctx.pop();
      }

      return val;
    },

    // find values with normal names
    f: function(key, ctx, partials, returnFound) {
      var val = false,
          v = null,
          found = false,
          doModelGet = this.options.modelGet;

      for (var i = ctx.length - 1; i >= 0; i--) {
        v = ctx[i];
        val = findInScope(key, v, doModelGet);
        if (val !== undefined) {
          found = true;
          break;
        }
      }

      if (!found) {
        return (returnFound) ? false : "";
      }

      if (!returnFound && typeof val == 'function') {
        val = this.mv(val, ctx, partials);
      }

      return val;
    },

    // higher order templates
    ls: function(func, cx, partials, text, tags) {
      var oldTags = this.options.delimiters;

      this.options.delimiters = tags;
      this.b(this.ct(coerceToString(func.call(cx, text)), cx, partials));
      this.options.delimiters = oldTags;

      return false;
    },

    // compile text
    ct: function(text, cx, partials) {
      if (this.options.disableLambda) {
        throw new Error('Lambda features disabled.');
      }
      return this.c.compile(text, this.options).render(cx, partials);
    },

    // template result buffering
    b: function(s) { this.buf += s; },

    fl: function() { var r = this.buf; this.buf = ''; return r; },

    // method replace section
    ms: function(func, ctx, partials, inverted, start, end, tags) {
      var textSource,
          cx = ctx[ctx.length - 1],
          result = func.call(cx);

      if (typeof result == 'function') {
        if (inverted) {
          return true;
        } else {
          textSource = (this.activeSub && this.subsText && this.subsText[this.activeSub]) ? this.subsText[this.activeSub] : this.text;
          return this.ls(result, cx, partials, textSource.substring(start, end), tags);
        }
      }

      return result;
    },

    // method replace variable
    mv: function(func, ctx, partials) {
      var cx = ctx[ctx.length - 1];
      var result = func.call(cx);

      if (typeof result == 'function') {
        return this.ct(coerceToString(result.call(cx)), cx, partials);
      }

      return result;
    },

    sub: function(name, context, partials, indent) {
      var f = this.subs[name];
      if (f) {
        this.activeSub = name;
        f(context, partials, this, indent);
        this.activeSub = false;
      }
    }

  };

  //Find a key in an object
  function findInScope(key, scope, doModelGet) {
    var val;

    if (scope && typeof scope == 'object') {

      if (scope[key] !== undefined) {
        val = scope[key];

      // try lookup with get for backbone or similar model data
      } else if (doModelGet && scope.get && typeof scope.get == 'function') {
        val = scope.get(key);
      }
    }

    return val;
  }

  function createSpecializedPartial(instance, subs, partials, stackSubs, stackPartials, stackText) {
    function PartialTemplate() {};
    PartialTemplate.prototype = instance;
    function Substitutions() {};
    Substitutions.prototype = instance.subs;
    var key;
    var partial = new PartialTemplate();
    partial.subs = new Substitutions();
    partial.subsText = {};  //hehe. substext.
    partial.buf = '';

    stackSubs = stackSubs || {};
    partial.stackSubs = stackSubs;
    partial.subsText = stackText;
    for (key in subs) {
      if (!stackSubs[key]) stackSubs[key] = subs[key];
    }
    for (key in stackSubs) {
      partial.subs[key] = stackSubs[key];
    }

    stackPartials = stackPartials || {};
    partial.stackPartials = stackPartials;
    for (key in partials) {
      if (!stackPartials[key]) stackPartials[key] = partials[key];
    }
    for (key in stackPartials) {
      partial.partials[key] = stackPartials[key];
    }

    return partial;
  }

  var rAmp = /&/g,
      rLt = /</g,
      rGt = />/g,
      rApos = /\'/g,
      rQuot = /\"/g,
      hChars = /[&<>\"\']/;

  function coerceToString(val) {
    return String((val === null || val === undefined) ? '' : val);
  }

  function hoganEscape(str) {
    str = coerceToString(str);
    return hChars.test(str) ?
      str
        .replace(rAmp, '&amp;')
        .replace(rLt, '&lt;')
        .replace(rGt, '&gt;')
        .replace(rApos, '&#39;')
        .replace(rQuot, '&quot;') :
      str;
  }

  var isArray = Array.isArray || function(a) {
    return Object.prototype.toString.call(a) === '[object Array]';
  };

})(typeof exports !== 'undefined' ? exports : Hogan);



(function (Hogan) {
  // Setup regex  assignments
  // remove whitespace according to Mustache spec
  var rIsWhitespace = /\S/,
      rQuot = /\"/g,
      rNewline =  /\n/g,
      rCr = /\r/g,
      rSlash = /\\/g,
      rLineSep = /\u2028/,
      rParagraphSep = /\u2029/;

  Hogan.tags = {
    '#': 1, '^': 2, '<': 3, '$': 4,
    '/': 5, '!': 6, '>': 7, '=': 8, '_v': 9,
    '{': 10, '&': 11, '_t': 12
  };

  Hogan.scan = function scan(text, delimiters) {
    var len = text.length,
        IN_TEXT = 0,
        IN_TAG_TYPE = 1,
        IN_TAG = 2,
        state = IN_TEXT,
        tagType = null,
        tag = null,
        buf = '',
        tokens = [],
        seenTag = false,
        i = 0,
        lineStart = 0,
        otag = '{{',
        ctag = '}}';

    function addBuf() {
      if (buf.length > 0) {
        tokens.push({tag: '_t', text: new String(buf)});
        buf = '';
      }
    }

    function lineIsWhitespace() {
      var isAllWhitespace = true;
      for (var j = lineStart; j < tokens.length; j++) {
        isAllWhitespace =
          (Hogan.tags[tokens[j].tag] < Hogan.tags['_v']) ||
          (tokens[j].tag == '_t' && tokens[j].text.match(rIsWhitespace) === null);
        if (!isAllWhitespace) {
          return false;
        }
      }

      return isAllWhitespace;
    }

    function filterLine(haveSeenTag, noNewLine) {
      addBuf();

      if (haveSeenTag && lineIsWhitespace()) {
        for (var j = lineStart, next; j < tokens.length; j++) {
          if (tokens[j].text) {
            if ((next = tokens[j+1]) && next.tag == '>') {
              // set indent to token value
              next.indent = tokens[j].text.toString()
            }
            tokens.splice(j, 1);
          }
        }
      } else if (!noNewLine) {
        tokens.push({tag:'\n'});
      }

      seenTag = false;
      lineStart = tokens.length;
    }

    function changeDelimiters(text, index) {
      var close = '=' + ctag,
          closeIndex = text.indexOf(close, index),
          delimiters = trim(
            text.substring(text.indexOf('=', index) + 1, closeIndex)
          ).split(' ');

      otag = delimiters[0];
      ctag = delimiters[delimiters.length - 1];

      return closeIndex + close.length - 1;
    }

    if (delimiters) {
      delimiters = delimiters.split(' ');
      otag = delimiters[0];
      ctag = delimiters[1];
    }

    for (i = 0; i < len; i++) {
      if (state == IN_TEXT) {
        if (tagChange(otag, text, i)) {
          --i;
          addBuf();
          state = IN_TAG_TYPE;
        } else {
          if (text.charAt(i) == '\n') {
            filterLine(seenTag);
          } else {
            buf += text.charAt(i);
          }
        }
      } else if (state == IN_TAG_TYPE) {
        i += otag.length - 1;
        tag = Hogan.tags[text.charAt(i + 1)];
        tagType = tag ? text.charAt(i + 1) : '_v';
        if (tagType == '=') {
          i = changeDelimiters(text, i);
          state = IN_TEXT;
        } else {
          if (tag) {
            i++;
          }
          state = IN_TAG;
        }
        seenTag = i;
      } else {
        if (tagChange(ctag, text, i)) {
          tokens.push({tag: tagType, n: trim(buf), otag: otag, ctag: ctag,
                       i: (tagType == '/') ? seenTag - otag.length : i + ctag.length});
          buf = '';
          i += ctag.length - 1;
          state = IN_TEXT;
          if (tagType == '{') {
            if (ctag == '}}') {
              i++;
            } else {
              cleanTripleStache(tokens[tokens.length - 1]);
            }
          }
        } else {
          buf += text.charAt(i);
        }
      }
    }

    filterLine(seenTag, true);

    return tokens;
  }

  function cleanTripleStache(token) {
    if (token.n.substr(token.n.length - 1) === '}') {
      token.n = token.n.substring(0, token.n.length - 1);
    }
  }

  function trim(s) {
    if (s.trim) {
      return s.trim();
    }

    return s.replace(/^\s*|\s*$/g, '');
  }

  function tagChange(tag, text, index) {
    if (text.charAt(index) != tag.charAt(0)) {
      return false;
    }

    for (var i = 1, l = tag.length; i < l; i++) {
      if (text.charAt(index + i) != tag.charAt(i)) {
        return false;
      }
    }

    return true;
  }

  // the tags allowed inside super templates
  var allowedInSuper = {'_t': true, '\n': true, '$': true, '/': true};

  function buildTree(tokens, kind, stack, customTags) {
    var instructions = [],
        opener = null,
        tail = null,
        token = null;

    tail = stack[stack.length - 1];

    while (tokens.length > 0) {
      token = tokens.shift();

      if (tail && tail.tag == '<' && !(token.tag in allowedInSuper)) {
        throw new Error('Illegal content in < super tag.');
      }

      if (Hogan.tags[token.tag] <= Hogan.tags['$'] || isOpener(token, customTags)) {
        stack.push(token);
        token.nodes = buildTree(tokens, token.tag, stack, customTags);
      } else if (token.tag == '/') {
        if (stack.length === 0) {
          throw new Error('Closing tag without opener: /' + token.n);
        }
        opener = stack.pop();
        if (token.n != opener.n && !isCloser(token.n, opener.n, customTags)) {
          throw new Error('Nesting error: ' + opener.n + ' vs. ' + token.n);
        }
        opener.end = token.i;
        return instructions;
      } else if (token.tag == '\n') {
        token.last = (tokens.length == 0) || (tokens[0].tag == '\n');
      }

      instructions.push(token);
    }

    if (stack.length > 0) {
      throw new Error('missing closing tag: ' + stack.pop().n);
    }

    return instructions;
  }

  function isOpener(token, tags) {
    for (var i = 0, l = tags.length; i < l; i++) {
      if (tags[i].o == token.n) {
        token.tag = '#';
        return true;
      }
    }
  }

  function isCloser(close, open, tags) {
    for (var i = 0, l = tags.length; i < l; i++) {
      if (tags[i].c == close && tags[i].o == open) {
        return true;
      }
    }
  }

  function stringifySubstitutions(obj) {
    var items = [];
    for (var key in obj) {
      items.push('"' + esc(key) + '": function(c,p,t,i) {' + obj[key] + '}');
    }
    return "{ " + items.join(",") + " }";
  }

  function stringifyPartials(codeObj) {
    var partials = [];
    for (var key in codeObj.partials) {
      partials.push('"' + esc(key) + '":{name:"' + esc(codeObj.partials[key].name) + '", ' + stringifyPartials(codeObj.partials[key]) + "}");
    }
    return "partials: {" + partials.join(",") + "}, subs: " + stringifySubstitutions(codeObj.subs);
  }

  Hogan.stringify = function(codeObj, text, options) {
    return "{code: function (c,p,i) { " + Hogan.wrapMain(codeObj.code) + " }," + stringifyPartials(codeObj) +  "}";
  }

  var serialNo = 0;
  Hogan.generate = function(tree, text, options) {
    serialNo = 0;
    var context = { code: '', subs: {}, partials: {} };
    Hogan.walk(tree, context);

    if (options.asString) {
      return this.stringify(context, text, options);
    }

    return this.makeTemplate(context, text, options);
  }

  Hogan.wrapMain = function(code) {
    return 'var t=this;t.b(i=i||"");' + code + 'return t.fl();';
  }

  Hogan.template = Hogan.Template;

  Hogan.makeTemplate = function(codeObj, text, options) {
    var template = this.makePartials(codeObj);
    template.code = new Function('c', 'p', 'i', this.wrapMain(codeObj.code));
    return new this.template(template, text, this, options);
  }

  Hogan.makePartials = function(codeObj) {
    var key, template = {subs: {}, partials: codeObj.partials, name: codeObj.name};
    for (key in template.partials) {
      template.partials[key] = this.makePartials(template.partials[key]);
    }
    for (key in codeObj.subs) {
      template.subs[key] = new Function('c', 'p', 't', 'i', codeObj.subs[key]);
    }
    return template;
  }

  function esc(s) {
    return s.replace(rSlash, '\\\\')
            .replace(rQuot, '\\\"')
            .replace(rNewline, '\\n')
            .replace(rCr, '\\r')
            .replace(rLineSep, '\\u2028')
            .replace(rParagraphSep, '\\u2029');
  }

  function chooseMethod(s) {
    return (~s.indexOf('.')) ? 'd' : 'f';
  }

  function createPartial(node, context) {
    var prefix = "<" + (context.prefix || "");
    var sym = prefix + node.n + serialNo++;
    context.partials[sym] = {name: node.n, partials: {}};
    context.code += 't.b(t.rp("' +  esc(sym) + '",c,p,"' + (node.indent || '') + '"));';
    return sym;
  }

  Hogan.codegen = {
    '#': function(node, context) {
      context.code += 'if(t.s(t.' + chooseMethod(node.n) + '("' + esc(node.n) + '",c,p,1),' +
                      'c,p,0,' + node.i + ',' + node.end + ',"' + node.otag + " " + node.ctag + '")){' +
                      't.rs(c,p,' + 'function(c,p,t){';
      Hogan.walk(node.nodes, context);
      context.code += '});c.pop();}';
    },

    '^': function(node, context) {
      context.code += 'if(!t.s(t.' + chooseMethod(node.n) + '("' + esc(node.n) + '",c,p,1),c,p,1,0,0,"")){';
      Hogan.walk(node.nodes, context);
      context.code += '};';
    },

    '>': createPartial,
    '<': function(node, context) {
      var ctx = {partials: {}, code: '', subs: {}, inPartial: true};
      Hogan.walk(node.nodes, ctx);
      var template = context.partials[createPartial(node, context)];
      template.subs = ctx.subs;
      template.partials = ctx.partials;
    },

    '$': function(node, context) {
      var ctx = {subs: {}, code: '', partials: context.partials, prefix: node.n};
      Hogan.walk(node.nodes, ctx);
      context.subs[node.n] = ctx.code;
      if (!context.inPartial) {
        context.code += 't.sub("' + esc(node.n) + '",c,p,i);';
      }
    },

    '\n': function(node, context) {
      context.code += write('"\\n"' + (node.last ? '' : ' + i'));
    },

    '_v': function(node, context) {
      context.code += 't.b(t.v(t.' + chooseMethod(node.n) + '("' + esc(node.n) + '",c,p,0)));';
    },

    '_t': function(node, context) {
      context.code += write('"' + esc(node.text) + '"');
    },

    '{': tripleStache,

    '&': tripleStache
  }

  function tripleStache(node, context) {
    context.code += 't.b(t.t(t.' + chooseMethod(node.n) + '("' + esc(node.n) + '",c,p,0)));';
  }

  function write(s) {
    return 't.b(' + s + ');';
  }

  Hogan.walk = function(nodelist, context) {
    var func;
    for (var i = 0, l = nodelist.length; i < l; i++) {
      func = Hogan.codegen[nodelist[i].tag];
      func && func(nodelist[i], context);
    }
    return context;
  }

  Hogan.parse = function(tokens, text, options) {
    options = options || {};
    return buildTree(tokens, '', [], options.sectionTags || []);
  }

  Hogan.cache = {};

  Hogan.cacheKey = function(text, options) {
    return [text, !!options.asString, !!options.disableLambda, options.delimiters, !!options.modelGet].join('||');
  }

  Hogan.compile = function(text, options) {
    options = options || {};
    var key = Hogan.cacheKey(text, options);
    var template = this.cache[key];

    if (template) {
      var partials = template.partials;
      for (var name in partials) {
        delete partials[name].instance;
      }
      return template;
    }

    template = this.generate(this.parse(this.scan(text, options.delimiters), text, options), text, options);
    return this.cache[key] = template;
  }
})(typeof exports !== 'undefined' ? exports : Hogan);


if (typeof define === 'function' && define.amd) {
  define('hogan',Hogan);
};
/**
 * Status logger and profiler
 */
define('core/status',["moment"], function(moment) {
	var first = 0,
		last = 0,
		logs = {
			info: [],
			error: [],
			status: []
		};

	return {
		get: function(which) {
			logs[which || "status"].forEach(function(e) {
				console.log(moment(e[0]).toISOString().replace("T", " ").replace("Z", "") + "\t\t\t\t" + e[1]);
			});

			return logs[which || "status"];
		},
		mark: function() {
			last = new Date().getTime();
		},
		getTime: function() {
			return (last || logs.status[logs.status.length - 1][0]) - first;
		},
		log: function(msg) {
			logs.status.push([new Date().getTime(), msg]);

			if (!first) {
				first = new Date().getTime();
			}
		},
		error: function(msg) {
			var length = logs.error.length;

			logs.error.push([new Date().getTime(), msg]);

			console.log("There" + (length === 0 ? " is " : " are ") + (length + 1) + " error" + (length === 0 ? "" : "s") + " in the log.");
		},
		info: function(msg) {
			logs.info.push([new Date().getTime(), msg]);
		}
	};
});
define('core/templates',["hogan"], function(Hogan) {
	return {
		raw: {},
		compiled: { "alert": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("title",c,p,1),c,p,0,10,28,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<h2>");t.b(t.v(t.f("title",c,p,0)));t.b("</h2>");});c.pop();}t.b(" <div class=\"content\"> ");if(t.s(t.f("contents",c,p,1),c,p,0,74,88,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <p>");t.b(t.v(t.d(".",c,p,0)));t.b("</p> ");});c.pop();}t.b(" ");if(!t.s(t.f("contents",c,p,1),c,p,1,0,0,"")){t.b(" ");t.b(t.t(t.f("html",c,p,0)));t.b(" ");};t.b(" </div> <footer> ");if(t.s(t.f("buttons",c,p,1),c,p,0,169,315,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<button type=\"button\" data-action=\"");t.b(t.v(t.f("action",c,p,0)));t.b("\" class=\"material flat ");t.b(t.v(t.f("class",c,p,0)));t.b("\">");t.b(t.v(t.f("label",c,p,0)));if(!t.s(t.f("label",c,p,1),c,p,1,0,0,"")){t.b(t.v(t.d("i18n.alert.default_button",c,p,0)));};t.b("</button>");});c.pop();}t.b(" </footer>");return t.fl(); },partials: {}, subs: {  }}),"bginfo": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<button type=\"button\" class=\"material toggle close\"> <svg viewBox=\"0 0 24 24\"> <path d=\"M19 6.41l-1.41-1.41-5.59 5.59-5.59-5.59-1.41 1.41 5.59 5.59-5.59 5.59 1.41 1.41 5.59-5.59 5.59 5.59 1.41-1.41-5.59-5.59z\"></path> </svg> </button> <div class=\"preview\" style=\"background-image: url('");t.b(t.v(t.f("preview",c,p,0)));t.b("')\"></div> <div class=\"image-info\"> <h2 class=\"name\">");t.b(t.v(t.f("name",c,p,0)));t.b("</h2> <span class=\"subheader\">");if(t.s(t.f("themename",c,p,1),c,p,0,402,424,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(t.v(t.f("themename",c,p,0)));t.b(" &mdash; ");});c.pop();}t.b(t.v(t.f("copyright",c,p,0)));t.b("</span> ");if(t.s(t.f("desc",c,p,1),c,p,0,468,496,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<p class=\"desc\">");t.b(t.v(t.f("desc",c,p,0)));t.b("</p>");});c.pop();}t.b(" <div class=\"footer\"> <button type=\"button\" class=\"material flat blue download");if(!t.s(t.f("isPro",c,p,1),c,p,1,0,0,"")){t.b(" disabled");};t.b("\" title=\"");t.b(t.v(t.d("i18n.themes.bginfo.pro_only",c,p,0)));t.b("\">");t.b(t.v(t.d("i18n.themes.bginfo.download",c,p,0)));t.b("</button> <button type=\"button\" class=\"material flat blue view\">");t.b(t.v(t.d("i18n.themes.bginfo.view",c,p,0)));t.b("</button> ");if(t.s(t.f("sourceUrl",c,p,1),c,p,0,800,894,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<button type=\"button\" class=\"material flat blue source\">");t.b(t.v(t.d("i18n.themes.bginfo.source",c,p,0)));t.b("</button>");});c.pop();}t.b(" </div> </div>");return t.fl(); },partials: {}, subs: {  }}),"css": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("wcolor",c,p,1),c,p,0,11,271,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" .widget-preview .widget, .widgets-container .widget, .store-detail > .content > section.preview > .widget, .dark .widget-preview .widget, .dark .widgets-container .widget, .dark .store-detail > .content > section.preview > .widget { background: ");t.b(t.v(t.f("wcolor",c,p,0)));t.b("; } ");});c.pop();}t.b(" ");if(t.s(t.f("hcolor",c,p,1),c,p,0,294,348,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" .toolbar, .dark .toolbar { background: ");t.b(t.v(t.f("hcolor",c,p,0)));t.b("; } ");});c.pop();}t.b(" ");t.b(t.t(t.f("custom",c,p,0)));return t.fl(); },partials: {}, subs: {  }}),"menu": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<div class=\"menu-wrapper\"> <nav class=\"menu\"> <div data-item=\"notifications\" ");if(!t.s(t.f("notifications",c,p,1),c,p,1,0,0,"")){t.b("style=\"display: none\"");};t.b("> <svg width=\"18\" height=\"18\" > <circle cx=\"9\" cy=\"9\" r=\"8\" fill=\"#D23F31\"  /> <text x=\"50%\" y=\"50%\" text-anchor=\"middle\" fill=\"white\" font-size=\"8px\" font-weight=\"bold\" font-family=\"Helvetica\" dy=\".4em\">");t.b(t.v(t.f("notifications",c,p,0)));t.b("</text> </svg> ");t.b(t.v(t.d("i18n.menu.notifications",c,p,0)));t.b(" </div> <div data-item=\"settings\"> <svg viewBox=\"0 0 18 18\"> <path fill=\"#999\" d=\"M15.605,9.879c0.036-0.288,0.062-0.58,0.062-0.879s-0.025-0.589-0.062-0.878l1.878-1.488  c0.168-0.137,0.216-0.38,0.105-0.575l-1.778-3.117c-0.111-0.195-0.344-0.274-0.545-0.196l-2.213,0.903  c-0.459-0.356-0.962-0.658-1.503-0.885L11.217,0.38C11.184,0.165,11,0,10.778,0H7.222C7,0,6.816,0.165,6.783,0.379L6.449,2.763  c-0.542,0.228-1.044,0.53-1.503,0.886L2.734,2.746C2.533,2.667,2.3,2.747,2.189,2.941L0.412,6.059  C0.3,6.253,0.349,6.496,0.517,6.633l1.877,1.488C2.357,8.409,2.331,8.701,2.331,9s0.026,0.591,0.063,0.879l-1.877,1.487  c-0.168,0.137-0.216,0.38-0.105,0.574l1.778,3.119c0.111,0.194,0.344,0.272,0.544,0.194l2.213-0.903  c0.459,0.357,0.961,0.658,1.502,0.886l0.333,2.384C6.816,17.835,7,18,7.222,18h3.557c0.222,0,0.405-0.165,0.439-0.379l0.333-2.385  c0.542-0.228,1.044-0.527,1.502-0.886l2.213,0.904c0.201,0.077,0.434-0.001,0.545-0.195l1.778-3.117  c0.11-0.195,0.063-0.438-0.105-0.575L15.605,9.879z M9,12.6c-1.965,0-3.556-1.611-3.556-3.6c0-1.989,1.591-3.6,3.556-3.6  c1.963,0,3.557,1.611,3.557,3.6C12.557,10.988,10.963,12.6,9,12.6z\"></path> </svg> ");t.b(t.v(t.d("i18n.menu.settings",c,p,0)));t.b(" </div> <div data-item=\"widgets\"> <svg viewBox=\"0 0 18 18\"> <rect fill=\"#4285F4\" width=\"8\" height=\"10\"></rect> <rect y=\"12\" fill=\"#AAA\" width=\"8\" height=\"6\"></rect> <rect x=\"10\" fill=\"#AAA\" width=\"8\" height=\"6\"></rect> <rect x=\"10\" y=\"8\" fill=\"#FFBB1B\" width=\"8\" height=\"10\"></rect> </svg> ");t.b(t.v(t.d("i18n.menu.widgets",c,p,0)));t.b(" </div> ");if(!t.s(t.f("isPro",c,p,1),c,p,1,0,0,"")){t.b(" <div data-item=\"upgrade\"> <svg version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\" width=\"32px\" height=\"32px\" viewBox=\"0 0 32 32\" enable-background=\"new 0 0 32 32\" xml:space=\"preserve\"><path d=\"M16,0C7.163,0,0,7.163,0,16c0,8.836,7.163,16,16,16c8.836,0,16-7.164,16-16C32,7.163,24.836,0,16,0z M22.507,21.779	c-0.559,0-5.978-7.687-6.372-7.687c-0.394,0-6.126,7.687-6.636,7.687c-0.509,0-2.759-2.495-2.759-2.954	c0-0.461,8.885-8.605,9.46-8.605s8.54,8.982,8.54,9.525C24.74,20.286,23.064,21.779,22.507,21.779z\" fill=\"#009000\" /></svg> ");t.b(t.v(t.d("i18n.menu.upgrade",c,p,0)));t.b(" </div> ");};t.b(" <div data-item=\"support\"> <svg enable-background=\"new 0 0 500 300\" height=\"260px\" id=\"Layer_1\" version=\"1.1\" viewBox=\"20 20 280 280\" width=\"260px\" xml:space=\"preserve\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\"><g><path d=\"M150.842,14.519c-74.785,0-135.409,60.631-135.409,135.415c0,74.783,60.624,135.415,135.409,135.415   c74.788,0,135.411-60.632,135.411-135.415C286.253,75.15,225.63,14.519,150.842,14.519z M150.842,266.196   c-64.209,0-116.262-52.055-116.262-116.263c0-64.208,52.053-116.267,116.262-116.267c64.212,0,116.263,52.059,116.263,116.267   C267.104,214.142,215.054,266.196,150.842,266.196z\" fill=\"#BF360C\"/><path d=\"M255.587,149.934c0,57.852-46.894,104.745-104.745,104.745c-57.85,0-104.743-46.894-104.743-104.745   S92.992,45.188,150.842,45.188C208.693,45.188,255.587,92.082,255.587,149.934z\" fill=\"#BF360C\"/><g><path d=\"M164.922,204.148c-3.927,3.838-8.669,5.761-14.221,5.761c-5.775,0-10.525-1.858-14.259-5.592    c-3.725-3.733-5.59-8.483-5.59-14.261c0-5.607,1.931-10.362,5.801-14.257c3.866-3.897,8.552-5.845,14.043-5.845    c5.495,0,10.218,1.991,14.176,5.97c3.951,3.982,5.93,8.722,5.93,14.217C170.807,195.641,168.844,200.307,164.922,204.148z\" fill=\"#FFFFFF\"/><path d=\"M172.995,153.216c-3.358,1.686-5.414,3.143-6.139,4.377c-0.731,1.228-1.086,3.87-1.086,7.909h-31.205    v-5.303c0-7.011,0.78-12.185,2.355-15.527c1.567-3.335,4.429-5.926,8.583-7.78l5.721-2.518c4.32-1.911,6.477-4.598,6.477-8.078    c0-2.023-0.712-3.725-2.104-5.137c-1.399-1.392-3.117-2.104-5.133-2.104c-5.495,0-8.247,3.822-8.247,11.445h-29.019    c0-10.21,2.361-18.533,7.07-24.981c3.479-4.767,7.989-8.552,13.541-11.356c5.553-2.8,11.3-4.208,17.246-4.208    c10.547,0,19.413,3.496,26.622,10.475s10.81,15.632,10.81,25.951C188.471,139.108,183.313,148.059,172.995,153.216z\" fill=\"#FFFFFF\"/></g></g></svg> ");t.b(t.v(t.d("i18n.menu.support",c,p,0)));t.b(" </div> <div data-item=\"editmode\"> <svg viewBox=\"0 0 18 18\"> <path fill=\"#666\" d=\"M0,14.25V18h3.75L14.813,6.936l-3.75-3.75L0,14.25z M17.706,4.042c0.393-0.39,0.393-1.022,0-1.414l-2.335-2.336c-0.393-0.391-1.025-0.391-1.414,0l-1.832,1.833l3.749,3.75L17.706,4.042z\" /> </svg> ");t.b(t.v(t.d("i18n.menu.editing",c,p,0)));t.b(" ");if(t.s(t.f("editing",c,p,1),c,p,0,4636,4700,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span class=\"state enabled\">");t.b(t.v(t.d("i18n.menu.editing_enabled",c,p,0)));t.b("</span>");});c.pop();}t.b(" ");if(!t.s(t.f("editing",c,p,1),c,p,1,0,0,"")){t.b("<span class=\"state\">");t.b(t.v(t.d("i18n.menu.editing_disabled",c,p,0)));t.b("</span>");};t.b(" </div> <hr class=\"separator\" /> ");if(t.s(t.f("links",c,p,1),c,p,0,4837,4905,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<a data-item=\"link\" href=\"");t.b(t.v(t.f("link",c,p,0)));t.b("\" class=\"custom-link\">");t.b(t.v(t.f("text",c,p,0)));t.b("</a>");});c.pop();}t.b(" ");if(t.s(t.f("plus",c,p,1),c,p,0,4925,5003,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<a data-item=\"link\" href=\"https://plus.google.com/u/0/\">");t.b(t.v(t.d("i18n.menu.plus",c,p,0)));t.b("</a>");});c.pop();}t.b(" ");if(t.s(t.f("gmail",c,p,1),c,p,0,5023,5111,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<a data-item=\"link\" href=\"https://mail.google.com/mail/\">");t.b(t.v(t.d("i18n.toolbar.apps.gmail",c,p,0)));t.b("</a>");});c.pop();}t.b(" <hr class=\"separator\" /> <div class=\"section tabs\"> <h2> <div class=\"add\">+</div> ");t.b(t.v(t.d("i18n.menu.tabs",c,p,0)));t.b(" </h2> ");if(t.s(t.f("tabs",c,p,1),c,p,0,5238,5290,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div data-item=\"tab\" data-id=\"");t.b(t.v(t.f("id",c,p,0)));t.b("\">");t.b(t.v(t.f("name",c,p,0)));t.b("</div>");});c.pop();}t.b(" </div> <div class=\"footer\"> <div class=\"social-buttons\"> <a href=\"https://www.twitter.com/iChromeHQ\" target=\"_blank\" class=\"twitter\"> <svg xmlns=\"http://www.w3.org/2000/svg\" width=\"19.69\" height=\"16\" viewBox=\"423.89 491.854 19.69 16\"> <path fill=\"#55ACEE\" d=\"M443.58 493.747c-.725.322-1.502.538-2.32.637.834-.5 1.475-1.29 1.775-2.234-.78.464-1.643.8-2.565.982-.736-.787-1.786-1.277-2.948-1.277-2.23 0-4.04 1.81-4.04 4.04 0 .314.036.623.105.918-3.356-.168-6.333-1.776-8.325-4.22-.348.595-.547 1.29-.547 2.03 0 1.4.713 2.637 1.798 3.362-.664-.02-1.286-.204-1.83-.507v.052c0 1.957 1.39 3.59 3.24 3.96-.34.093-.695.144-1.064.144-.263 0-.516-.027-.763-.073.515 1.605 2.006 2.773 3.772 2.806-1.382 1.084-3.122 1.73-5.017 1.73-.326 0-.647-.02-.964-.056 1.786 1.145 3.908 1.814 6.19 1.814 7.43 0 11.493-6.155 11.493-11.493 0-.176-.005-.348-.014-.522.793-.568 1.48-1.28 2.02-2.09z\"></path> </svg> </a> <a href=\"https://plus.google.com/105753616949940055287\" target=\"_blank\" class=\"gplus\"> <svg xmlns=\"http://www.w3.org/2000/svg\" width=\"25.73\" height=\"16\" viewBox=\"302.21 393.45 25.73 16\"> <path fill=\"#DB4437\" d=\"M325.058 397.558h-2.163v2.883h-2.883v2.02h2.883v2.883h2.163v-2.883h2.883v-2.09h-2.882v-2.812zm-14.848 2.234v3.243h4.325c-.29 1.874-1.946 3.243-4.325 3.243-2.595 0-4.756-2.234-4.756-4.83 0-2.593 2.09-4.827 4.756-4.827 1.226 0 2.234.36 3.1 1.226l2.307-2.306c-1.442-1.297-3.244-2.09-5.406-2.09-4.395 0-8 3.604-8 8s3.605 8 8 8c4.686 0 7.713-3.314 7.713-7.855 0-.576-.072-1.225-.144-1.802h-7.57z\"></path> </svg> </a> <a href=\"https://www.facebook.com/iChrome-1116504205031129/\" target=\"_blank\" class=\"facebook\"> <svg xmlns=\"http://www.w3.org/2000/svg\" width=\"8.31\" height=\"16\" viewBox=\"301.845 388 8.31 16\"> <path fill=\"#48649F\" d=\"M307.238 404v-7.3h2.45l.367-2.844h-2.817v-1.815c0-.822.23-1.383 1.41-1.383h1.507v-2.546c-.262-.03-1.153-.11-2.196-.11-2.17 0-3.657 1.325-3.657 3.76v2.1h-2.458v2.844h2.458V404h2.935z\"></path> </svg> </a> </div> <a href=\"https://ichrome.uservoice.com/\" class=\"support\">");t.b(t.v(t.d("i18n.menu.footer.support",c,p,0)));t.b("</a> &nbsp;·&nbsp; <a href=\"https://ichrome.uservoice.com/\" class=\"feedback\">");t.b(t.v(t.d("i18n.menu.footer.feedback",c,p,0)));t.b("</a> &nbsp;·&nbsp; <a href=\"https://chrome.google.com/webstore/detail/ichrome-new-tab/iccjgbbjckehppnpajnmplcccjcgbdep/reviews\">");t.b(t.v(t.d("i18n.menu.footer.review",c,p,0)));t.b("</a> <br /> <a href=\"https://productivitytab.co/terms-of-service\" class=\"terms\">");t.b(t.v(t.d("i18n.menu.footer.terms",c,p,0)));t.b("</a> &nbsp;·&nbsp; <a href=\"https://productivitytab.co/privacy-policy\" class=\"privacy\">");t.b(t.v(t.d("i18n.menu.footer.privacy",c,p,0)));t.b("</a> &nbsp;·&nbsp; <a href=\"https://productivitytab.co/permissions\" class=\"permissions\">");t.b(t.v(t.d("i18n.menu.footer.permissions",c,p,0)));t.b("</a> <hr class=\"separator\" /> <span>");t.b(t.v(t.d("i18n.menu.footer.by",c,p,0)));t.b("</span> <a rel=\"license\" href=\"http://creativecommons.org/licenses/by-sa/3.0/deed.en_US\" target=\"_blank\">CC BY-SA 3.0</a> </div> </nav> <nav class=\"menu-announcements\"> <div data-item=\"back\" class=\"m-icon back\">backspace</div> ");if(t.s(t.f("notificationsList",c,p,1),c,p,0,8236,8539,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"item\"> <div class=\"m-icon\" style=\"color:grey\">notifications_none</div> <div data-type=\"");t.b(t.v(t.f("type",c,p,0)));t.b("\" data-id=\"");t.b(t.v(t.f("id",c,p,0)));t.b("\" data-item=\"item-announcement\" class=\"title\">");t.b(t.v(t.f("title",c,p,0)));t.b("</div> <div data-type=\"");t.b(t.v(t.f("type",c,p,0)));t.b("\" data-id=\"");t.b(t.v(t.f("id",c,p,0)));t.b("\" data-item=\"dismiss-announcement\" class=\"m-icon close\">close</div> </div> ");});c.pop();}t.b(" </nav> </div> ");return t.fl(); },partials: {}, subs: {  }}),"onboarding/introduction": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<div class=\"intro\" > <h2 class=\"appname\">");t.b(t.v(t.d("i18n.onboarding.modal.intro_title",c,p,0)));t.b("</h2> <div class=\"tagline\">");t.b(t.v(t.d("i18n.onboarding.modal.intro_moto",c,p,0)));t.b("</div> <div class=\"desc\">");t.b(t.v(t.d("i18n.onboarding.modal.intro_desc",c,p,0)));t.b("</span> <div class=\"note\"><input type=\"checkbox\" class=\"terms_checkbox\"> ");t.b(t.t(t.d("i18n.onboarding.modal.terms",c,p,0)));t.b(". ");t.b(t.t(t.d("i18n.onboarding.modal.terms_desc",c,p,0)));t.b("</span> <style> .invisible { display: none; } </style> <div class=\"tutorial-buttons\"> <button type=\"button\" class=\"button material flat invisible done\">");t.b(t.v(t.d("i18n.onboarding.next",c,p,0)));t.b("</button> <button type=\"button\" class=\"button material flat invisible skip\">");t.b(t.v(t.d("i18n.onboarding.widgets.configure_skip",c,p,0)));t.b("</button> </div> </div> ");return t.fl(); },partials: {}, subs: {  }}),"onboarding/modal": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<div class=\"nav\"> <button type=\"button\" class=\"material fab m-icon prev\" data-direction=\"prev\">arrow_back</button> <button type=\"button\" class=\"material fab m-icon next close\" data-direction=\"next\"></button> </div> <section class=\"slide active sign-in final\"> <div class=\"pending visible\"> <div class=\"caption\"> <h2>");t.b(t.v(t.d("i18n.onboarding.modal.signin_title",c,p,0)));t.b("</h2> <p>");t.b(t.v(t.d("i18n.onboarding.modal.signin_desc1",c,p,0)));t.b("</p> <p>");t.b(t.v(t.d("i18n.onboarding.modal.signin_desc2",c,p,0)));t.b("</p> </div> <div class=\"row text-left\" style=\"margin-left: 45px; margin-right: 60px\"> <div class=\"col-xs-12 text-center\" style=\"font-size: 15px\">");t.b(t.v(t.d("i18n.onboarding.modal.pro_desc1",c,p,0)));t.b("</div> <div class=\"col-xs-6\"> <ul> <li>");t.b(t.v(t.d("i18n.onboarding.modal.pro_desc2",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.onboarding.modal.pro_desc3",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.onboarding.modal.pro_desc4",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.onboarding.modal.pro_desc5",c,p,0)));t.b("</li> </ul> </div> <div class=\"col-xs-6\"> <ul> <li>");t.b(t.v(t.d("i18n.onboarding.modal.pro_desc6",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.onboarding.modal.pro_desc7",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.onboarding.modal.pro_desc8",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.onboarding.modal.pro_desc9",c,p,0)));t.b("</li> </ul> </div> <div style=\"margin-top: 140px; font-size: 15px\" class=\"text-center\"> <p>");t.b(t.v(t.d("i18n.onboarding.modal.signin_desc3",c,p,0)));t.b("</p> </div> <div class=\"col-xs-12 text-center\" > <button style=\"margin-top: 50px\" type=\"button\" class=\"material large red sign-in\">");t.b(t.v(t.d("i18n.onboarding.modal.sign_in_button",c,p,0)));t.b("</button> </div> </div> </div> <div class=\"complete existing\"> <h2>");t.b(t.v(t.d("i18n.onboarding.modal.have_account",c,p,0)));t.b("</h2> <p>");t.b(t.v(t.d("i18n.onboarding.modal.have_account_desc",c,p,0)));t.b("</p> </div> <div class=\"complete new\"> <h2>");t.b(t.v(t.d("i18n.onboarding.modal.get_started",c,p,0)));t.b("</h2> <p>");t.b(t.v(t.d("i18n.onboarding.modal.get_started_desc",c,p,0)));t.b("</p> </div> </section> <section1 class=\"pro final\" data-id=\"4\"> <div class=\"hero\" style=\"background-image: url(images/onboarding_pro.png)\"></div> <div class=\"caption\"> <h2>");t.b(t.v(t.d("i18n.onboarding.modal.pro_title",c,p,0)));t.b("</h2> <div class=\"row\"> <div class=\"col-xs-12\">");t.b(t.v(t.d("i18n.onboarding.modal.pro_desc1",c,p,0)));t.b("</div> <div class=\"col-xs-6\"> <ul> <li>");t.b(t.v(t.d("i18n.onboarding.modal.pro_desc2",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.onboarding.modal.pro_desc3",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.onboarding.modal.pro_desc4",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.onboarding.modal.pro_desc5",c,p,0)));t.b("</li> </ul> </div> <div class=\"col-xs-6\"> <ul> <li>");t.b(t.v(t.d("i18n.onboarding.modal.pro_desc6",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.onboarding.modal.pro_desc7",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.onboarding.modal.pro_desc8",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.onboarding.modal.pro_desc9",c,p,0)));t.b("</li> </ul> </div> <div class=\"col-xs-12\"> ");t.b(t.v(t.d("i18n.onboarding.modal.pro_upgrade",c,p,0)));t.b(" </div> </div> <span class=\"footer note\">");t.b(t.t(t.d("i18n.onboarding.modal.pro_mback",c,p,0)));t.b("</span> </section1> ");return t.fl(); },partials: {}, subs: {  }}),"onboarding/settings": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("labels",c,p,1),c,p,0,11,414,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <ul class=\"labels\"> <li>");t.b(t.v(t.d("i18n.onboarding.settings.tooltips.settings",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.onboarding.settings.tooltips.widgets",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.onboarding.settings.tooltips.editing",c,p,0)));t.b("</li> <li class=\"custom-links\">");t.b(t.v(t.d("i18n.onboarding.settings.tooltips.links",c,p,0)));t.b("</li> <li class=\"tabs\">");t.b(t.v(t.d("i18n.onboarding.settings.tooltips.tabs",c,p,0)));t.b("</li> <li class=\"support\">");t.b(t.v(t.d("i18n.onboarding.settings.tooltips.support",c,p,0)));t.b("</li> </ul> ");});c.pop();}t.b(" ");if(t.s(t.f("overlayCaption",c,p,1),c,p,0,445,632,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"caption\"> <p><b>");t.b(t.v(t.d("i18n.onboarding.settings.finished",c,p,0)));t.b("</b></p> <p>");t.b(t.t(t.d("i18n.onboarding.settings.finished_next",c,p,0)));t.b("</p> <p>");t.b(t.v(t.d("i18n.onboarding.settings.finished_contact",c,p,0)));t.b("</p> </div> ");});c.pop();}t.b(" ");if(t.s(t.f("intro",c,p,1),c,p,0,662,1065,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"caption bottom-left\"> <p>");t.b(t.t(t.d("i18n.onboarding.settings.intro",c,p,0)));t.b("</p> <p>");t.b(t.v(t.d("i18n.onboarding.settings.instructions",c,p,0)));t.b("</p> <div class=\"tutorial-buttons\"> <button type=\"button\" class=\"button material flat next\">");t.b(t.v(t.d("i18n.onboarding.next",c,p,0)));t.b("</button> <button type=\"button\" class=\"button material flat skip\">");t.b(t.v(t.d("i18n.onboarding.widgets.configure_skip",c,p,0)));t.b("</button> </div> </div> <div class=\"action-mask\"></div> ");});c.pop();}return t.fl(); },partials: {}, subs: {  }}),"onboarding/upgrade": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<div class=\"nav\"> <button type=\"button\" class=\"material fab m-icon prev\" data-direction=\"prev\">arrow_back</button> <button type=\"button\" class=\"material fab m-icon next close\" data-direction=\"next\"></button> </div> <section class=\"final wrapper onboarding-upgrade\" style=\"overflow: scroll\"> <main class=\"content\" tabindex=\"-1\"> <header class=\"large-header\"> <h2 class=\"page-name\">ProductivityTab Pro</h2> ");if(t.s(t.f("isTrial",c,p,1),c,p,0,417,583,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <p style=\"color:yellow\">Your ProductivityTab Pro trial expires on ");t.b(t.v(t.f("trialExpiration",c,p,0)));t.b("! Click upgrade to keep advanced widget features and customization options.</p> ");});c.pop();}t.b(" <h3 class=\"subheader pricing\"> ");t.b(t.v(t.d("i18n.settings.pro.promo.monthly_price",c,p,0)));t.b(" <span class=\"yearly\">");t.b(t.v(t.d("i18n.settings.pro.promo.yearly_price",c,p,0)));t.b("</span> </h3> <button type=\"button\" class=\"material large blue upgrade\">");t.b(t.v(t.d("i18n.settings.pro.promo.upgrade_btn",c,p,0)));t.b("</button> <p class=\"business\">");t.b(t.v(t.d("i18n.settings.pro.promo.business",c,p,0)));t.b(" <a href=\"mailto:support@ichro.me\">");t.b(t.v(t.d("i18n.settings.pro.promo.business_contact",c,p,0)));t.b("</a></p> </header> <section> <div class=\"content\"> <h3>");t.b(t.v(t.d("i18n.settings.pro.promo.themes",c,p,0)));t.b("</h3> <p>");t.b(t.v(t.d("i18n.settings.pro.promo.themes_desc",c,p,0)));t.b("</p> </div> <div class=\"media\" style=\"background-image: url(https://ichro.me/img/pro/themes.png)\"></div> </section> <section class=\"live-bgs\"> <div class=\"content\"> <h3>");t.b(t.v(t.d("i18n.settings.pro.promo.bgs",c,p,0)));t.b("</h3> <p>");t.b(t.v(t.d("i18n.settings.pro.promo.bgs_desc",c,p,0)));t.b("</p> </div> <video class=\"media\" src=\"https://ichro.me/img/pro/backgrounds.mp4\" autoplay loop></video> </section> <section> <div class=\"content\"> <h3>");t.b(t.v(t.d("i18n.settings.pro.promo.widgets",c,p,0)));t.b("</h3> <p>");t.b(t.v(t.d("i18n.settings.pro.promo.widgets_desc",c,p,0)));t.b("</p> </div> <div class=\"media\" style=\"background-image: url(https://ichro.me/img/pro/widgets.png)\"></div> </section> <section class=\"more\"> <div class=\"content\"> <h3>");t.b(t.v(t.d("i18n.settings.pro.promo.more_header",c,p,0)));t.b("</h3> <ul> <li>");t.b(t.v(t.d("i18n.settings.pro.promo.stocks",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.settings.pro.promo.rss",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.settings.pro.promo.sports",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.settings.pro.promo.tabbed_widgets",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.settings.pro.promo.bg_downloads",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.settings.pro.promo.weather",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.settings.pro.promo.toolbar",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.settings.pro.promo.ads",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.settings.pro.promo.support",c,p,0)));t.b("</li> </ul> </div> </section> <section class=\"get\"> <div class=\"content\"> <h3>");t.b(t.v(t.d("i18n.settings.pro.promo.buy_pro",c,p,0)));t.b("</h3> <button type=\"button\" class=\"material large blue upgrade\">");t.b(t.v(t.d("i18n.settings.pro.promo.upgrade_btn",c,p,0)));t.b("</button> </div> </section> </main> </section1> ");return t.fl(); },partials: {}, subs: {  }}),"onboarding/widgets": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("screenOne",c,p,1),c,p,0,14,390,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"caption bottom-right\"> <p>");t.b(t.v(t.d("i18n.onboarding.widgets.configure",c,p,0)));t.b("</p> <p>");t.b(t.t(t.d("i18n.onboarding.widgets.configure_desc",c,p,0)));t.b("</p> <div class=\"tutorial-buttons\"> <button type=\"button\" class=\"button material flat next\">");t.b(t.v(t.d("i18n.onboarding.next",c,p,0)));t.b("</button> <button type=\"button\" class=\"button material flat skip\">");t.b(t.v(t.d("i18n.onboarding.widgets.configure_skip",c,p,0)));t.b("</button> </div> </div> ");});c.pop();}t.b(" ");if(t.s(t.f("screenTwo",c,p,1),c,p,0,419,784,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"caption bottom-right\"> <p>");t.b(t.t(t.d("i18n.onboarding.widgets.move",c,p,0)));t.b("</p> <p>");t.b(t.t(t.d("i18n.onboarding.widgets.remove",c,p,0)));t.b("</p> <div class=\"tutorial-buttons\"> <button type=\"button\" class=\"button material flat done\">");t.b(t.v(t.d("i18n.onboarding.next",c,p,0)));t.b("</button> <button type=\"button\" class=\"button material flat skip\">");t.b(t.v(t.d("i18n.onboarding.widgets.configure_skip",c,p,0)));t.b("</button> </div> </div> ");});c.pop();}t.b(" <div class=\"action-mask\"></div>");return t.fl(); },partials: {}, subs: {  }}),"search-page": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("initial",c,p,1),c,p,0,12,1448,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <header> <div class=\"exit\"> <button type=\"button\" class=\"material toggle\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"> <path d=\"M20 11H7.83l5.59-5.59L12 4l-8 8 8 8 1.41-1.41L7.83 13H20v-2z\"></path> </svg> </button> <button type=\"button\" class=\"material flat\">Back</button> </div> <div class=\"search\"> <input type=\"search\" value=\"");t.b(t.v(t.f("query",c,p,0)));t.b("\" /> <button type=\"button\" class=\"speech\"></button> <button class=\"submit\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"> <path d=\"M15.5 14h-.79l-.28-.27C15.41 12.59 16 11.11 16 9.5 16 5.91 13.09 3 9.5 3S3 5.91 3 9.5 5.91 16 9.5 16c1.61 0 3.09-.59 4.23-1.57l.27.28v.79l5 4.99L20.49 19l-4.99-5zm-6 0C7.01 14 5 11.99 5 9.5S7.01 5 9.5 5 14 7.01 14 9.5 11.99 14 9.5 14z\"></path> </svg> </button> <div class=\"suggestions\"></div> </div> <ul class=\"tabs\"> <li class=\"active\"> <a href=\"https://www.google.com/search?q=\">All</a> </li> <li> <a href=\"https://www.google.com/search?tbm=isch&amp;q=\">Images</a> </li> <li> <a href=\"https://www.google.com/search?tbm=vid&amp;q=\">Videos</a> </li> <li> <a href=\"https://maps.google.com/maps?q=\">Maps</a> </li> <li> <a href=\"https://www.google.com/search?tbm=nws&amp;q=\">News</a> </li> <li> <a href=\"https://www.google.com/search?tbm=shop&amp;q=\">Shopping</a> </li> <li> <a href=\"https://www.google.com/search?tbm=bks&amp;q=\">Books</a> </li> <li> <a href=\"https://www.google.com/search?tbm=app&amp;q=\">Apps</a> </li> </ul> </header> ");});c.pop();}t.b(" <div class=\"results-container\"> ");if(t.s(t.f("hasResults",c,p,1),c,p,0,1508,2086,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <ul class=\"results\"> ");if(t.s(t.d("ads.0",c,p,1),c,p,0,1540,1780,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <li class=\"ads\"> <p class=\"notice\">Ads related to: ");t.b(t.v(t.f("query",c,p,0)));t.b("</p> <ul> ");if(t.s(t.f("ads",c,p,1),c,p,0,1619,1759,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <li class=\"result\"> <h2><a href=\"");t.b(t.v(t.f("link",c,p,0)));t.b("\" target=\"_self\">");t.b(t.t(t.f("title",c,p,0)));t.b("</a></h2> <cite class=\"url\">");t.b(t.v(t.f("domain",c,p,0)));t.b("</cite> <p>");t.b(t.t(t.f("text",c,p,0)));t.b("</p> </li> ");});c.pop();}t.b(" </ul> </li> ");});c.pop();}t.b(" ");if(t.s(t.f("results",c,p,1),c,p,0,1803,1960,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <li class=\"result");if(t.s(t.f("ad",c,p,1),c,p,0,1828,1831,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" ad");});c.pop();}t.b("\"> <h2><a href=\"");t.b(t.v(t.f("link",c,p,0)));t.b("\" target=\"_self\">");t.b(t.t(t.f("title",c,p,0)));t.b("</a></h2> <cite class=\"url\">");t.b(t.v(t.f("domain",c,p,0)));t.b("</cite> <p>");t.b(t.t(t.f("text",c,p,0)));t.b("</p> </li> ");});c.pop();}t.b(" </ul> <div class=\"more\"> <button type=\"button\" class=\"material blue load-more\">Load more results</button> </div> ");});c.pop();}t.b(" ");if(t.s(t.f("query",c,p,1),c,p,0,2112,2378,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" ");if(!t.s(t.f("hasResults",c,p,1),c,p,1,0,0,"")){t.b(" <div class=\"loading\"> <svg class=\"spinner\" width=\"65px\" height=\"65px\" viewBox=\"0 0 66 66\" xmlns=\"http://www.w3.org/2000/svg\"> <circle fill=\"none\" stroke-width=\"6\" stroke-linecap=\"round\" cx=\"33\" cy=\"33\" r=\"30\"></circle> </svg> </div> ");};t.b(" ");});c.pop();}t.b(" </div>");return t.fl(); },partials: {}, subs: {  }}),"search": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\" class=\"icon\"> <path d=\"M15.5 14h-.79l-.28-.27C15.41 12.59 16 11.11 16 9.5 16 5.91 13.09 3 9.5 3S3 5.91 3 9.5 5.91 16 9.5 16c1.61 0 3.09-.59 4.23-1.57l.27.28v.79l5 4.99L20.49 19l-4.99-5zm-6 0C7.01 14 5 11.99 5 9.5S7.01 5 9.5 5 14 7.01 14 9.5 11.99 14 9.5 14z\"></path> </svg> <input type=\"search\" autocomplete=\"off\" placeholder=\"");if(t.s(t.f("ok",c,p,1),c,p,0,394,425,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(t.v(t.d("i18n.toolbar.placeholder_ok",c,p,0)));});c.pop();}if(!t.s(t.f("ok",c,p,1),c,p,1,0,0,"")){t.b(t.v(t.d("i18n.toolbar.placeholder",c,p,0)));};t.b("\" autofocus=\"autofocus\" /> ");if(t.s(t.f("voice",c,p,1),c,p,0,511,537,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div class=\"speech\"></div>");});c.pop();}t.b(" <div class=\"suggestions\"></div>");return t.fl(); },partials: {}, subs: {  }}),"settings": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<div class=\"side-nav\"> <button type=\"button\" class=\"material flat exit\" data-m-icon-before=\"navigate_before\">");t.b(t.v(t.d("i18n.settings.exit",c,p,0)));t.b("</button> <nav> <ul> <li data-id=\"visual\"> <span class=\"header\">");t.b(t.v(t.d("i18n.settings.nav.visual",c,p,0)));t.b("</span> <ul class=\"sections\"> <li data-id=\"background\">");t.b(t.v(t.d("i18n.settings.nav.visual_sections.background",c,p,0)));t.b("</li> <li data-id=\"layout\">");t.b(t.v(t.d("i18n.settings.nav.visual_sections.layout",c,p,0)));t.b("</li> <li data-id=\"theme\">");t.b(t.v(t.d("i18n.settings.nav.visual_sections.theme",c,p,0)));t.b("</li> </ul> </li> <li data-id=\"toolbar\"> <span class=\"header\">");t.b(t.v(t.d("i18n.settings.nav.toolbar",c,p,0)));t.b("</span> <ul class=\"sections\"> <li data-id=\"style\">");t.b(t.v(t.d("i18n.settings.nav.toolbar_sections.style",c,p,0)));t.b("</li> <li data-id=\"search\">");t.b(t.v(t.d("i18n.settings.nav.toolbar_sections.search",c,p,0)));t.b("</li> <li data-id=\"links\">");t.b(t.v(t.d("i18n.settings.nav.toolbar_sections.links",c,p,0)));t.b("</li> </ul> </li> <li data-id=\"tabs\"> <span class=\"header\">");t.b(t.v(t.d("i18n.settings.nav.tabs",c,p,0)));t.b("</span> </li> <li data-id=\"ads\"> <span class=\"header\">");t.b(t.v(t.d("i18n.settings.nav.ads",c,p,0)));t.b("</span> </li> <li data-id=\"widgets\"> <span class=\"header\">");t.b(t.v(t.d("i18n.settings.nav.widgets",c,p,0)));t.b("</span> </li> <li data-id=\"pro\"> <span class=\"header\">");t.b(t.v(t.d("i18n.settings.nav.pro",c,p,0)));t.b("</span> </li> <li data-id=\"accounts\"> <span class=\"header\">");t.b(t.v(t.d("i18n.settings.nav.accounts",c,p,0)));t.b("</span> </li> <li data-id=\"misc\"> <span class=\"header\">");t.b(t.v(t.d("i18n.settings.nav.misc",c,p,0)));t.b("</span> </li> <li data-id=\"advanced\"> <span class=\"header\">");t.b(t.v(t.d("i18n.settings.nav.advanced",c,p,0)));t.b("</span> <ul class=\"sections\"> <li data-id=\"backups\">");t.b(t.v(t.d("i18n.settings.nav.advanced_sections.backups",c,p,0)));t.b("</li> <li data-id=\"css\">");t.b(t.v(t.d("i18n.settings.nav.advanced_sections.css",c,p,0)));t.b("</li> <li data-id=\"debug-tools\">");t.b(t.v(t.d("i18n.settings.nav.advanced_sections.debug_tools",c,p,0)));t.b("</li> </ul> </li> <li data-id=\"support\"> <a class=\"header\" href=\"https://ichrome.uservoice.com/knowledgebase\" target=\"_blank\">");t.b(t.v(t.d("i18n.settings.nav.support",c,p,0)));t.b("</a> </li> <li data-id=\"suggest\"> <a class=\"header\" href=\"https://ichrome.uservoice.com/\" target=\"_blank\">");t.b(t.v(t.d("i18n.settings.nav.suggest",c,p,0)));t.b("</a> </li> </ul> </nav> </div>");return t.fl(); },partials: {}, subs: {  }}),"settings/accounts": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<header> <h2 class=\"page-name\">");t.b(t.v(t.d("i18n.settings.title",c,p,0)));t.b(" &ndash; ");t.b(t.v(t.d("i18n.settings.nav.accounts",c,p,0)));t.b("</h2> </header> <main class=\"content\" tabindex=\"-1\"> <section class=\"status\" data-id=\"status\"> <h3>");t.b(t.v(t.d("i18n.settings.accounts.status.title",c,p,0)));t.b("</h3> ");if(t.s(t.f("signedIn",c,p,1),c,p,0,250,539,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <p class=\"desc\">");t.b(t.t(t.f("signedInMsg",c,p,0)));t.b("</p> <div class=\"input no-label actions\"> <button type=\"button\" class=\"material red reset\">");t.b(t.v(t.d("i18n.settings.accounts.status.reset_account",c,p,0)));t.b("</button> <button type=\"button\" class=\"material sign-out\">");t.b(t.v(t.d("i18n.settings.accounts.status.sign_out",c,p,0)));t.b("</button> </div> ");});c.pop();}t.b(" ");if(!t.s(t.f("signedIn",c,p,1),c,p,1,0,0,"")){t.b(" <p class=\"desc\">");t.b(t.t(t.d("i18n.settings.accounts.status.signed_out",c,p,0)));t.b("</p> <div class=\"input no-label actions\"> <button type=\"button\" class=\"material red sign-in\">");t.b(t.v(t.d("i18n.settings.accounts.status.sign_in",c,p,0)));t.b("</button> </div> ");};t.b(" </section> </main>");return t.fl(); },partials: {}, subs: {  }}),"settings/ads": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<header class=\"large-header\"> <h2 class=\"page-name\">");t.b(t.v(t.d("i18n.settings.nav.ads",c,p,0)));t.b("</h2> </header> <main class=\"content\" tabindex=\"-1\"> <section class=\"text\"> <div class=\"controls\"> ");if(t.s(t.f("adFree",c,p,1),c,p,0,187,236,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <h3>");t.b(t.v(t.d("i18n.settings.ads.already_upgraded",c,p,0)));t.b("</h3> ");});c.pop();}t.b(" ");if(!t.s(t.f("adFree",c,p,1),c,p,1,0,0,"")){t.b(" <div class=\"placement\"> <h3>");t.b(t.v(t.d("i18n.settings.ads.placement.title",c,p,0)));t.b("</h3> <div class=\"input main radios no-label\"> <label> <input type=\"radio\" name=\"adPlacement\" value=\"widget_block\" /> <span>");t.b(t.v(t.d("i18n.settings.ads.placement.left",c,p,0)));t.b("</span> </label> <label> <input type=\"radio\" name=\"adPlacement\" value=\"header_leaderboard\" /> <span>");t.b(t.v(t.d("i18n.settings.ads.placement.top",c,p,0)));t.b("</span> </label> <label> <input type=\"radio\" name=\"adPlacement\" value=\"right_block\" /> <span>");t.b(t.v(t.d("i18n.settings.ads.placement.right",c,p,0)));t.b("</span> </label> <label> <input type=\"radio\" name=\"adPlacement\" value=\"footer_leaderboard\" /> <span>");t.b(t.v(t.d("i18n.settings.ads.placement.bottom",c,p,0)));t.b("</span> </label> </div> </div> ");};t.b(" </div> <p> ");t.b(t.v(t.d("i18n.settings.ads.text1",c,p,0)));t.b(" <br /><br /> ");t.b(t.v(t.d("i18n.settings.ads.text2",c,p,0)));t.b(" <br /><br /> ");t.b(t.v(t.d("i18n.settings.ads.text3",c,p,0)));t.b(" </p> </section> </main>");return t.fl(); },partials: {}, subs: {  }}),"settings/advanced": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<header> <h2 class=\"page-name\">");t.b(t.v(t.d("i18n.settings.title",c,p,0)));t.b(" &ndash; ");t.b(t.v(t.d("i18n.settings.nav.advanced",c,p,0)));t.b("</h2> </header> <main class=\"content\" tabindex=\"-1\"> <section class=\"backups\" data-id=\"backups\"> <h3>");t.b(t.v(t.d("i18n.settings.advanced.backups.title",c,p,0)));t.b("</h3> <p class=\"desc\"> ");t.b(t.v(t.d("i18n.settings.advanced.backups.desc",c,p,0)));t.b(" <br /><br /> ");t.b(t.v(t.d("i18n.settings.advanced.backups.desc2",c,p,0)));t.b(" </p> <div class=\"input no-label actions\"> <input type=\"file\" name=\"backup-upload\" class=\"upload hide\" /> <button type=\"button\" class=\"material blue backup\">");t.b(t.v(t.d("i18n.settings.advanced.backups.backup",c,p,0)));t.b("</button> <button type=\"button\" class=\"material blue upload\">");t.b(t.v(t.d("i18n.settings.advanced.backups.upload",c,p,0)));t.b("</button> </div> ");if(t.s(t.f("backups",c,p,1),c,p,0,679,974,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"input backup\" data-date=\"");t.b(t.v(t.f("date",c,p,0)));t.b("\"> <h4>");t.b(t.v(t.f("label",c,p,0)));t.b("</h4> <button type=\"button\" class=\"material flat blue download\">");t.b(t.v(t.d("i18n.settings.advanced.backups.download",c,p,0)));t.b("</button> <button type=\"button\" class=\"material flat blue restore\">");t.b(t.v(t.d("i18n.settings.advanced.backups.restore",c,p,0)));t.b("</button> </div> ");});c.pop();}t.b(" </section> <section class=\"css\" data-id=\"css\"> <h3>");t.b(t.v(t.d("i18n.settings.advanced.css.title",c,p,0)));t.b("</h3> <p class=\"desc\">");t.b(t.t(t.d("i18n.settings.advanced.css.desc",c,p,0)));t.b("</p> <div class=\"input textarea\"> <textarea name=\"css\" maxlength=\"1000\" placeholder=\"");t.b(t.v(t.d("i18n.settings.advanced.css.placeholder",c,p,0)));t.b("\">");t.b(t.v(t.f("css",c,p,0)));t.b("</textarea> </div> </section> <section class=\"debug-tools\" data-id=\"debug-tools\"> <h3>");t.b(t.v(t.d("i18n.settings.advanced.debug_tools.title",c,p,0)));t.b("</h3> <p class=\"desc\">");t.b(t.t(t.d("i18n.settings.advanced.debug_tools.desc",c,p,0)));t.b("</p> <div class=\"input no-label\"> <button type=\"button\" class=\"material red\">");t.b(t.v(t.d("i18n.settings.advanced.debug_tools.open",c,p,0)));t.b("</button> </div> </section> </main>");return t.fl(); },partials: {}, subs: {  }}),"settings/debug": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<h2 class=\"title\">Debug Tools</h2> <p class=\"section status no-status\"></p> <div class=\"section storage\"> <h3 class=\"title\">Storage</h3> <button type=\"button\" class=\"material flat blue\" data-action=\"clear-sync\">Clear Sync</button> <button type=\"button\" class=\"material flat blue\" data-action=\"clear-local\">Clear Local</button> <button type=\"button\" class=\"material flat blue\" data-action=\"clear-localstorage\">Clear LocalStorage</button> <button type=\"button\" class=\"material flat blue\" data-action=\"clear-fs\">Clear FileSystem</button> </div> <div class=\"section oauth\"> <h3 class=\"title\">OAuth</h3> <button type=\"button\" class=\"material flat blue\" data-action=\"clear-oauth\">Clear Cache</button> </div> <div class=\"section extension\"> <h3 class=\"title\">Extension</h3> <button type=\"button\" class=\"material flat blue\" data-action=\"get-info\">Info</button> <button type=\"button\" class=\"material flat blue\" data-action=\"update\">Check for updates</button> <button type=\"button\" class=\"material flat blue\" data-action=\"reload-extension\">Reload</button> </div> <div class=\"section console\"> <h3 class=\"title\">Console</h3> <textarea placeholder=\"Enter code here\"></textarea> <button type=\"button\" class=\"material flat green\" data-action=\"execute\">Execute</button> </div>");return t.fl(); },partials: {}, subs: {  }}),"settings/misc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<header> <h2 class=\"page-name\">");t.b(t.v(t.d("i18n.settings.title",c,p,0)));t.b(" &ndash; ");t.b(t.v(t.d("i18n.settings.nav.misc",c,p,0)));t.b("</h2> </header> <main class=\"content\" tabindex=\"-1\"> <section> <label class=\"input switch\"> <h4>");t.b(t.v(t.d("i18n.settings.misc.link_tab",c,p,0)));t.b("</h4> <input type=\"checkbox\" name=\"openLinksInNewTab\" value=\"1\" checked /> <span class=\"switch\"></span> </label> </section> </main>");return t.fl(); },partials: {}, subs: {  }}),"settings/pro": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("isSubscribed",c,p,1),c,p,0,17,1258,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <header> <h2 class=\"page-name\">");t.b(t.v(t.d("i18n.settings.title",c,p,0)));t.b(" &ndash; ");t.b(t.v(t.d("i18n.settings.nav.pro",c,p,0)));t.b("</h2> </header> <main class=\"content\" tabindex=\"-1\"> <section class=\"plan\" data-id=\"plan\"> <h3>");t.b(t.v(t.d("i18n.settings.pro.plan.title",c,p,0)));t.b("</h3> <p class=\"desc\">");t.b(t.v(t.f("desc",c,p,0)));t.b("</p> ");if(t.s(t.f("uneditable",c,p,1),c,p,0,283,355,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <p class=\"uneditable\">");t.b(t.t(t.d("i18n.settings.pro.plan.uneditable_desc",c,p,0)));t.b("</p> ");});c.pop();}t.b(" ");if(!t.s(t.f("uneditable",c,p,1),c,p,1,0,0,"")){t.b(" <ul class=\"info\"> ");if(t.s(t.f("status",c,p,1),c,p,0,416,493,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <li> <b>");t.b(t.v(t.d("i18n.settings.pro.plan.status",c,p,0)));t.b("</b> <span>");t.b(t.v(t.f("status",c,p,0)));t.b("</span> </li> ");});c.pop();}t.b(" ");if(t.s(t.f("subscriptionDate",c,p,1),c,p,0,526,624,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <li> <b>");t.b(t.v(t.d("i18n.settings.pro.plan.subscription_date",c,p,0)));t.b("</b> <span>");t.b(t.v(t.f("subscriptionDate",c,p,0)));t.b("</span> </li> ");});c.pop();}t.b(" ");if(t.s(t.f("paidThrough",c,p,1),c,p,0,662,750,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <li> <b>");t.b(t.v(t.d("i18n.settings.pro.plan.paid_through",c,p,0)));t.b("</b> <span>");t.b(t.v(t.f("paidThrough",c,p,0)));t.b("</span> </li> ");});c.pop();}t.b(" ");if(t.s(t.f("nextBill",c,p,1),c,p,0,780,862,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <li> <b>");t.b(t.v(t.d("i18n.settings.pro.plan.next_bill",c,p,0)));t.b("</b> <span>");t.b(t.v(t.f("nextBill",c,p,0)));t.b("</span> </li> ");});c.pop();}t.b(" </ul> <div class=\"input no-label actions\"> <button type=\"button\" class=\"material update-plan\">");t.b(t.v(t.d("i18n.settings.pro.plan.update_plan",c,p,0)));t.b("</button> <button type=\"button\" class=\"material update-billing\">");t.b(t.v(t.d("i18n.settings.pro.plan.update_billing",c,p,0)));t.b("</button> <button type=\"button\" class=\"material red cancel\">");t.b(t.v(t.d("i18n.settings.pro.plan.cancel",c,p,0)));t.b("</button> </div> ");};t.b(" </section> </main> ");});c.pop();}t.b(" ");if(!t.s(t.f("isSubscribed",c,p,1),c,p,1,0,0,"")){t.b(" <main class=\"content\" tabindex=\"-1\"> <header class=\"large-header\"> <h2 class=\"page-name\">ProductivityTab Pro</h2> ");if(t.s(t.f("isTrial",c,p,1),c,p,0,1420,1586,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <p style=\"color:yellow\">Your ProductivityTab Pro trial expires on ");t.b(t.v(t.f("trialExpiration",c,p,0)));t.b("! Click upgrade to keep advanced widget features and customization options.</p> ");});c.pop();}t.b(" <h3 class=\"subheader pricing\"> ");t.b(t.v(t.d("i18n.settings.pro.promo.monthly_price",c,p,0)));t.b(" <span class=\"yearly\">");t.b(t.v(t.d("i18n.settings.pro.promo.yearly_price",c,p,0)));t.b("</span> </h3> <button type=\"button\" class=\"material large blue upgrade\">");t.b(t.v(t.d("i18n.settings.pro.promo.upgrade_btn",c,p,0)));t.b("</button> <p class=\"business\">");t.b(t.v(t.d("i18n.settings.pro.promo.business",c,p,0)));t.b(" <a href=\"mailto:support@ichro.me\">");t.b(t.v(t.d("i18n.settings.pro.promo.business_contact",c,p,0)));t.b("</a></p> </header> <section> <div class=\"content\"> <h3>");t.b(t.v(t.d("i18n.settings.pro.promo.themes",c,p,0)));t.b("</h3> <p>");t.b(t.v(t.d("i18n.settings.pro.promo.themes_desc",c,p,0)));t.b("</p> </div> <div class=\"media\" style=\"background-image: url(https://ichro.me/img/pro/themes.png)\"></div> </section> <section class=\"live-bgs\"> <div class=\"content\"> <h3>");t.b(t.v(t.d("i18n.settings.pro.promo.bgs",c,p,0)));t.b("</h3> <p>");t.b(t.v(t.d("i18n.settings.pro.promo.bgs_desc",c,p,0)));t.b("</p> </div> <video class=\"media\" src=\"https://ichro.me/img/pro/backgrounds.mp4\" autoplay loop></video> </section> <section> <div class=\"content\"> <h3>");t.b(t.v(t.d("i18n.settings.pro.promo.widgets",c,p,0)));t.b("</h3> <p>");t.b(t.v(t.d("i18n.settings.pro.promo.widgets_desc",c,p,0)));t.b("</p> </div> <div class=\"media\" style=\"background-image: url(https://ichro.me/img/pro/widgets.png)\"></div> </section> <section class=\"more\"> <div class=\"content\"> <h3>");t.b(t.v(t.d("i18n.settings.pro.promo.more_header",c,p,0)));t.b("</h3> <ul> <li>");t.b(t.v(t.d("i18n.settings.pro.promo.stocks",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.settings.pro.promo.rss",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.settings.pro.promo.sports",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.settings.pro.promo.tabbed_widgets",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.settings.pro.promo.bg_downloads",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.settings.pro.promo.weather",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.settings.pro.promo.toolbar",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.settings.pro.promo.ads",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.settings.pro.promo.support",c,p,0)));t.b("</li> </ul> </div> </section> <section class=\"get\"> <div class=\"content\"> <h3>");t.b(t.v(t.d("i18n.settings.pro.promo.buy_pro",c,p,0)));t.b("</h3> <button type=\"button\" class=\"material large blue upgrade\">");t.b(t.v(t.d("i18n.settings.pro.promo.upgrade_btn",c,p,0)));t.b("</button> </div> </section> </main> ");};return t.fl(); },partials: {}, subs: {  }}),"settings/tabs": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<header> <h2 class=\"page-name\">");t.b(t.v(t.d("i18n.settings.title",c,p,0)));t.b(" &ndash; ");t.b(t.v(t.d("i18n.settings.nav.tabs",c,p,0)));t.b("</h2> </header> <main class=\"content\" tabindex=\"-1\"> <section class=\"tabs\" data-id=\"tabs\"> <h3> ");t.b(t.v(t.d("i18n.settings.nav.tabs",c,p,0)));t.b(" <button type=\"button\" class=\"material blue create-new\">");t.b(t.v(t.d("i18n.settings.tabs.create_new",c,p,0)));t.b("</button> </h3> <p class=\"desc\"> ");t.b(t.v(t.d("i18n.settings.tabs.desc1",c,p,0)));t.b(" <br /><br /> ");t.b(t.v(t.d("i18n.settings.tabs.desc2",c,p,0)));t.b(" </p> ");if(t.s(t.f("tabs",c,p,1),c,p,0,418,1063,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"input text tab\" data-id=\"");t.b(t.v(t.f("index",c,p,0)));t.b("\"> <input type=\"text\" name=\"tab-name\" placeholder=\"");t.b(t.v(t.d("i18n.settings.tabs.name_placeholder",c,p,0)));t.b("\" maxlength=\"40\" value=\"");t.b(t.v(t.f("name",c,p,0)));t.b("\" /> <button type=\"button\" class=\"material flat blue default\" data-action=\"make-default\"");if(t.s(t.f("isDefault",c,p,1),c,p,0,689,698,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" disabled");});c.pop();}t.b(">");t.b(t.v(t.d("i18n.settings.tabs.make_default",c,p,0)));t.b("</button> <button type=\"button\" class=\"material toggle m-icon\" data-action=\"move-up\">keyboard_arrow_up</button> <button type=\"button\" class=\"material toggle m-icon\" data-action=\"move-down\">keyboard_arrow_down</button> <button type=\"button\" class=\"material toggle m-icon\" data-action=\"delete\">delete</button> </div> ");});c.pop();}t.b(" </section> </main>");return t.fl(); },partials: {}, subs: {  }}),"settings/toolbar": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<header> <h2 class=\"page-name\">");t.b(t.v(t.d("i18n.settings.title",c,p,0)));t.b(" &ndash; ");t.b(t.v(t.d("i18n.settings.nav.toolbar",c,p,0)));t.b("</h2> </header> <main class=\"content\" tabindex=\"-1\"> <section class=\"style\" data-id=\"style\"> <h3>");t.b(t.v(t.d("i18n.settings.toolbar.style.title",c,p,0)));t.b("</h3> <p class=\"desc\">");t.b(t.v(t.d("i18n.settings.toolbar.style.desc",c,p,0)));t.b("</p> <div class=\"input radios no-label\"> <label> <input type=\"radio\" name=\"style\" value=\"button\" /> <span>");t.b(t.v(t.d("i18n.settings.toolbar.style.button",c,p,0)));t.b("</span> </label> <label> <input type=\"radio\" name=\"style\" value=\"button_ns\" /> <span>");t.b(t.v(t.d("i18n.settings.toolbar.style.button_ns",c,p,0)));t.b("</span> </label> </div> </section> <section class=\"search\" data-id=\"search\"> <h3>");t.b(t.v(t.d("i18n.settings.toolbar.search.title",c,p,0)));t.b("</h3> <p class=\"desc\">");t.b(t.v(t.d("i18n.settings.toolbar.search.desc",c,p,0)));t.b("</p> ");if(t.s(t.f("canSelectSearch",c,p,1),c,p,0,757,1479,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"input select other\"> <label> <h4>");t.b(t.v(t.d("i18n.settings.toolbar.search.engine",c,p,0)));t.b("</h4> <select name=\"search-engine\"> <option value=\"default\">");t.b(t.v(t.d("i18n.settings.toolbar.search.engines_default",c,p,0)));t.b("</option> <option value=\"bing\">Bing</option> <option value=\"duckduckgo\">DuckDuckGo</option> <option value=\"startpage\">Startpage</option> <option value=\"custom\">");t.b(t.v(t.d("i18n.settings.toolbar.search.engines_custom",c,p,0)));t.b("</option> </select> </label> <label class=\"input other");if(t.s(t.f("customSearchURL",c,p,1),c,p,0,1231,1239,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" visible");});c.pop();}t.b("\"> <span class=\"desc\">");t.b(t.t(t.d("i18n.settings.toolbar.search.engines_custom_desc",c,p,0)));t.b("</span> <input type=\"text\" name=\"search-url\" placeholder=\"i.e. https://www.bing.com/search?q=%s\" value=\"");t.b(t.v(t.f("customSearchURL",c,p,0)));t.b("\" /> </label> </div> ");});c.pop();}t.b(" <label class=\"input switch\"> <h4>");t.b(t.v(t.d("i18n.settings.toolbar.search.voice",c,p,0)));t.b("</h4> <input type=\"checkbox\" name=\"voice-search\" value=\"1\" checked /> <span class=\"switch\"></span> </label> <label class=\"input switch\"> <h4>");t.b(t.v(t.d("i18n.settings.toolbar.search.ok_google",c,p,0)));t.b("</h4> <input type=\"checkbox\" name=\"ok-google\" value=\"1\" /> <span class=\"switch\"></span> </label> <label class=\"input switch\"> <h4>");t.b(t.v(t.d("i18n.settings.toolbar.search.search_tab",c,p,0)));t.b("</h4> <input type=\"checkbox\" name=\"new-tab\" value=\"1\" /> <span class=\"switch\"></span> </label> </section> <section class=\"links\" data-id=\"links\"> <h3>");t.b(t.v(t.d("i18n.settings.toolbar.links.title",c,p,0)));t.b("</h3> <p class=\"desc\">");t.b(t.v(t.d("i18n.settings.toolbar.links.desc",c,p,0)));t.b("</p> <label class=\"input switch\"> <h4>Google+</h4> <input type=\"checkbox\" name=\"google-plus\" value=\"1\" checked /> <span class=\"switch\"></span> </label> <label class=\"input switch\"> <h4>Gmail</h4> <input type=\"checkbox\" name=\"gmail\" value=\"1\" checked /> <span class=\"switch\"></span> </label> <label class=\"input switch\"> <h4>");t.b(t.v(t.d("i18n.settings.toolbar.links.apps",c,p,0)));t.b("</h4> <input type=\"checkbox\" name=\"apps-menu\" value=\"1\" checked /> <span class=\"switch\"></span> </label> <div class=\"input links\"> <h4>");t.b(t.v(t.d("i18n.settings.toolbar.links.custom",c,p,0)));t.b("</h4> <span class=\"note\">");t.b(t.v(t.d("i18n.settings.toolbar.links.custom_note1",c,p,0)));t.b(", <span class=\"pro-badge\"></span> ");t.b(t.v(t.d("i18n.settings.toolbar.links.custom_note2",c,p,0)));t.b("</span> ");if(t.s(t.f("customLinks",c,p,1),c,p,0,2876,3245,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"link\" data-link=\"");t.b(t.v(t.f("i",c,p,0)));t.b("\"> <input type=\"text\" name=\"link-text\" placeholder=\"");t.b(t.v(t.d("i18n.settings.toolbar.links.custom_name_placeholder",c,p,0)));t.b("\" value=\"");t.b(t.v(t.f("text",c,p,0)));t.b("\" /> <input type=\"url\" name=\"link-url\" placeholder=\"");t.b(t.v(t.d("i18n.settings.toolbar.links.custom_url_placeholder",c,p,0)));t.b("\" value=\"");t.b(t.v(t.f("link",c,p,0)));t.b("\" /> <button type=\"button\" class=\"material toggle m-icon remove\">close</button> </div> ");});c.pop();}t.b(" ");if(t.s(t.f("canAddLinks",c,p,1),c,p,0,3278,3615,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"link new\" data-link=\"new\"> <input type=\"text\" name=\"link-text\" placeholder=\"");t.b(t.v(t.d("i18n.settings.toolbar.links.custom_name_placeholder",c,p,0)));t.b("\" /> <input type=\"url\" name=\"link-url\" placeholder=\"");t.b(t.v(t.d("i18n.settings.toolbar.links.custom_url_placeholder",c,p,0)));t.b("\" /> <button type=\"button\" class=\"material toggle m-icon remove\">close</button> </div> ");});c.pop();}t.b(" </div> </section> </main>");return t.fl(); },partials: {}, subs: {  }}),"settings/visual": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<header> <h2 class=\"page-name\">");t.b(t.v(t.d("i18n.settings.title",c,p,0)));t.b(" &ndash; ");t.b(t.v(t.d("i18n.settings.nav.visual",c,p,0)));t.b("</h2> </header> <main class=\"content\" tabindex=\"-1\"> <section class=\"background\" data-id=\"background\"> <h3>");t.b(t.v(t.d("i18n.settings.visual.background.title",c,p,0)));t.b("</h3> <p class=\"desc\"> ");t.b(t.v(t.d("i18n.settings.visual.background.desc",c,p,0)));t.b(" <br /><br /> <b>");t.b(t.v(t.d("i18n.settings.visual.background.current",c,p,0)));t.b(":</b> <span class=\"current-background\">");t.b(t.v(t.f("currentBackground",c,p,0)));if(!t.s(t.f("currentBackground",c,p,1),c,p,1,0,0,"")){t.b(t.v(t.d("i18n.settings.visual.background.custom",c,p,0)));};t.b("</span> </p> <div class=\"input no-label\"> <button type=\"button\" class=\"material blue select\">");t.b(t.v(t.d("i18n.settings.visual.background.select",c,p,0)));t.b("</button> <span class=\"or\">");t.b(t.v(t.d("i18n.settings.visual.background.or",c,p,0)));t.b("</span> <input type=\"url\" name=\"background-url\" placeholder=\"");t.b(t.v(t.d("i18n.settings.visual.background.url_placeholder",c,p,0)));t.b("\"");if(t.s(t.f("backgroundURL",c,p,1),c,p,0,839,865,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" value=\"");t.b(t.v(t.f("backgroundURL",c,p,0)));t.b("\"");});c.pop();}t.b(" /> </div> </section> <section class=\"layout\" data-id=\"layout\"> <h3>");t.b(t.v(t.d("i18n.settings.visual.layout.title",c,p,0)));t.b("</h3> <p class=\"desc\">");t.b(t.v(t.d("i18n.settings.visual.layout.desc",c,p,0)));t.b("</p> <div class=\"input main radios no-label\"> <label> <input type=\"radio\" name=\"layout\" value=\"columns\" checked /> <span>");t.b(t.v(t.d("i18n.settings.visual.layout.columns",c,p,0)));t.b("</span> </label> <label> <input type=\"radio\" name=\"layout\" value=\"grid\" /> <span>");t.b(t.v(t.d("i18n.settings.visual.layout.grid",c,p,0)));t.b("</span> </label> </div> <label class=\"input text\"> <h4>");t.b(t.v(t.d("i18n.settings.visual.layout.columns_number",c,p,0)));t.b("</h4> <input type=\"number\" name=\"columns\" min=\"1\" max=\"5\" placeholder=\"1-5\" value=\"");t.b(t.v(t.f("columns",c,p,0)));t.b("\" /> </label> <div class=\"input radios\"> <h4>");t.b(t.v(t.d("i18n.settings.visual.layout.column_width",c,p,0)));t.b("</h4> <label> <input type=\"radio\" name=\"column_width\" value=\"fixed\" checked /> <span>");t.b(t.v(t.d("i18n.settings.visual.layout.column_width_fixed",c,p,0)));t.b("</span> </label> <label> <input type=\"radio\" name=\"column_width\" value=\"fluid\" /> <span>");t.b(t.v(t.d("i18n.settings.visual.layout.column_width_fluid",c,p,0)));t.b("</span> </label> </div> </section> <section class=\"theme list-select pro-only\" data-id=\"theme\"> <h3>");t.b(t.v(t.d("i18n.settings.visual.theme.title",c,p,0)));t.b("</h3> <p class=\"desc\">");t.b(t.v(t.d("i18n.settings.visual.theme.desc",c,p,0)));t.b("</p> <label class=\"input\" data-id=\"light\"> <input type=\"radio\" name=\"theme\" value=\"light\" checked /> <h4>");t.b(t.v(t.d("i18n.settings.visual.theme.light",c,p,0)));t.b("</h4> <button type=\"button\" class=\"material flat blue preview\">");t.b(t.v(t.d("i18n.settings.visual.theme.preview",c,p,0)));t.b("</button> </label> <label class=\"input\" data-id=\"dark\"> <input type=\"radio\" name=\"theme\" value=\"dark\" ");if(!t.s(t.f("isPro",c,p,1),c,p,1,0,0,"")){t.b("disabled ");};t.b("/> <h4>");t.b(t.v(t.d("i18n.settings.visual.theme.dark",c,p,0)));t.b("</h4> <button type=\"button\" class=\"material flat blue preview\">");t.b(t.v(t.d("i18n.settings.visual.theme.preview",c,p,0)));t.b("</button> </label> <label class=\"input\" data-id=\"transparent dark\"> <input type=\"radio\" name=\"theme\" value=\"transparent dark\" ");if(!t.s(t.f("isPro",c,p,1),c,p,1,0,0,"")){t.b("disabled ");};t.b("/> <h4>");t.b(t.v(t.d("i18n.settings.visual.theme.transparent",c,p,0)));t.b("</h4> <button type=\"button\" class=\"material flat blue preview\">");t.b(t.v(t.d("i18n.settings.visual.theme.preview",c,p,0)));t.b("</button> </label> <label class=\"input\" data-id=\"transparent dark darker\"> <input type=\"radio\" name=\"theme\" value=\"transparent dark darker\" ");if(!t.s(t.f("isPro",c,p,1),c,p,1,0,0,"")){t.b("disabled ");};t.b("/> <h4>");t.b(t.v(t.d("i18n.settings.visual.theme.transparent_darker",c,p,0)));t.b("</h4> <button type=\"button\" class=\"material flat blue preview\">");t.b(t.v(t.d("i18n.settings.visual.theme.preview",c,p,0)));t.b("</button> </label> </section> </main>");return t.fl(); },partials: {}, subs: {  }}),"settings/widgets": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<header class=\"large-header\"> <h2 class=\"page-name\">");t.b(t.v(t.d("i18n.settings.nav.widgets",c,p,0)));t.b("</h2> </header> <main class=\"content\" tabindex=\"-1\"> <section class=\"text\"> <img class=\"widget-demo\" src=\"images/widget_demo.png\" /> <p> ");t.b(t.v(t.d("i18n.settings.widgets.desc1",c,p,0)));t.b(" <br /><br /> ");t.b(t.v(t.d("i18n.settings.widgets.desc2",c,p,0)));t.b(" </p> <ol> <li>");t.b(t.v(t.d("i18n.settings.widgets.steps1",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.settings.widgets.steps2",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.settings.widgets.steps3",c,p,0)));t.b("</li> <li>");t.b(t.v(t.d("i18n.settings.widgets.steps4",c,p,0)));t.b("</li> </ol> </section> </main>");return t.fl(); },partials: {}, subs: {  }}),"store-detail": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<h2 class=\"title\">");t.b(t.v(t.f("name",c,p,0)));t.b("</h2> <div class=\"content\"> <section class=\"installation\"> <h3>");t.b(t.v(t.d("i18n.store.installation",c,p,0)));t.b(" <span class=\"legend\">");t.b(t.v(t.d("i18n.store.instructions",c,p,0)));t.b("</span></h3> <div class=\"sizes\"> ");if(t.s(t.f("sizes",c,p,1),c,p,0,208,267,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <section class=\"handle\" data-size=\"");t.b(t.v(t.f("0",c,p,0)));t.b("\">");t.b(t.v(t.f("1",c,p,0)));t.b("</section> ");});c.pop();}t.b(" </div> </section> ");if(t.s(t.f("desc",c,p,1),c,p,0,305,420,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <section class=\"description\"> <h3>");t.b(t.v(t.d("i18n.store.description",c,p,0)));t.b("</h3> <div class=\"desc\"> ");t.b(t.t(t.f("desc",c,p,0)));t.b(" </div> </section> ");});c.pop();}t.b(" <section class=\"preview\"> <h3>");t.b(t.v(t.d("i18n.store.preview",c,p,0)));t.b("</h3> </section> </div>");return t.fl(); },partials: {}, subs: {  }}),"store": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<h2 class=\"title\">");t.b(t.v(t.d("i18n.menu.widgets",c,p,0)));t.b("</h2> <div class=\"content\"> ");if(t.s(t.f("widgets",c,p,1),c,p,0,79,213,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div data-id=\"");t.b(t.v(t.f("id",c,p,0)));t.b("\" class=\"widget\"> <img src=\"");t.b(t.v(t.f("icon",c,p,0)));t.b("\" /> <h2 class=\"title\">");t.b(t.v(t.f("name",c,p,0)));t.b("</h2> <div class=\"desc\">");t.b(t.v(t.f("desc",c,p,0)));t.b("</div> </div> ");});c.pop();}t.b(" </div>");return t.fl(); },partials: {}, subs: {  }}),"themes.custom": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("edit",c,p,1),c,p,0,9,58,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<h2 class=\"title\">");t.b(t.v(t.d("i18n.themes.edit.title",c,p,0)));t.b("</h2>");});c.pop();}t.b(" ");if(!t.s(t.f("edit",c,p,1),c,p,1,0,0,"")){t.b("<h2 class=\"title\">");t.b(t.v(t.d("i18n.themes.edit.create_title",c,p,0)));t.b("</h2>");};t.b(" <form> <div class=\"form-group\"> <label for=\"name\">");t.b(t.v(t.d("i18n.themes.edit.name",c,p,0)));t.b("</label> ");if(t.s(t.f("name",c,p,1),c,p,0,236,374,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<input type=\"text\" class=\"form-control name\" id=\"name\" name=\"name\" placeholder=\"");t.b(t.v(t.d("i18n.themes.edit.name_placeholder",c,p,0)));t.b("\" value=\"");t.b(t.v(t.f("name",c,p,0)));t.b("\" />");});c.pop();}t.b(" ");if(!t.s(t.f("name",c,p,1),c,p,1,0,0,"")){t.b("<input type=\"text\" class=\"form-control name\" id=\"name\" name=\"name\" placeholder=\"");t.b(t.v(t.d("i18n.themes.edit.name_placeholder",c,p,0)));t.b("\" value=\"");t.b(t.v(t.d("i18n.themes.default_name",c,p,0)));t.b("\" />");};t.b(" </div> <div class=\"form-group\"> <label for=\"image\">");t.b(t.v(t.d("i18n.themes.edit.image",c,p,0)));t.b("</label> <div> <div class=\"help\" data-m-icon-before=\"help\" data-tooltip=\"");t.b(t.v(t.d("i18n.themes.edit.image_help",c,p,0)));t.b("\"></div> <div class=\"upload\">");t.b(t.v(t.d("i18n.themes.url_or_upload",c,p,0)));t.b("<input type=\"file\" class=\"btn btn-primary\" id=\"upload\" /></div> <input type=\"text\" class=\"form-control image\" id=\"image\" name=\"image\" placeholder=\"");t.b(t.v(t.d("i18n.themes.edit.image_placeholder",c,p,0)));t.b("\" value=\"");t.b(t.v(t.f("image",c,p,0)));t.b("\" /> </div> </div> <div class=\"form-group color\"> <label for=\"color\">");t.b(t.v(t.d("i18n.themes.edit.color",c,p,0)));t.b("</label> <input type=\"text\" class=\"form-control color\" id=\"color\" name=\"color\" value=\"");t.b(t.v(t.f("color",c,p,0)));t.b("\" /> </div> <div class=\"form-group\"> <label for=\"position\">");t.b(t.v(t.d("i18n.themes.edit.position",c,p,0)));t.b("</label> <select class=\"form-control position\" id=\"position\" name=\"position\"> <option value=\"center\">");t.b(t.v(t.d("i18n.themes.edit.position_options.center",c,p,0)));t.b("</option> <option value=\"top left\">");t.b(t.v(t.d("i18n.themes.edit.position_options.top_left",c,p,0)));t.b("</option> <option value=\"top center\" selected>");t.b(t.v(t.d("i18n.themes.edit.position_options.top_center",c,p,0)));t.b("</option> <option value=\"top right\">");t.b(t.v(t.d("i18n.themes.edit.position_options.top_right",c,p,0)));t.b("</option> <option value=\"bottom left\">");t.b(t.v(t.d("i18n.themes.edit.position_options.bottom_left",c,p,0)));t.b("</option> <option value=\"bottom center\">");t.b(t.v(t.d("i18n.themes.edit.position_options.bottom_center",c,p,0)));t.b("</option> <option value=\"bottom right\">");t.b(t.v(t.d("i18n.themes.edit.position_options.bottom_right",c,p,0)));t.b("</option> </select> </div> <div class=\"form-group\"> <label for=\"scaling\">");t.b(t.v(t.d("i18n.themes.edit.scaling",c,p,0)));t.b("</label> <select class=\"form-control scaling\" id=\"scaling\" name=\"scaling\"> <option value=\"cover\">");t.b(t.v(t.d("i18n.themes.edit.scaling_options.auto",c,p,0)));t.b("</option> <option value=\"100% auto\">");t.b(t.v(t.d("i18n.themes.edit.scaling_options.width",c,p,0)));t.b("</option> <option value=\"auto 100%\">");t.b(t.v(t.d("i18n.themes.edit.scaling_options.height",c,p,0)));t.b("</option> <option value=\"auto\">");t.b(t.v(t.d("i18n.themes.edit.scaling_options.none",c,p,0)));t.b("</option> </select> </div> <div class=\"form-group\"> <label for=\"repeat\">");t.b(t.v(t.d("i18n.themes.edit.repeat",c,p,0)));t.b("</label> <select class=\"form-control repeat\" id=\"repeat\" name=\"repeat\"> <option value=\"no-repeat\">");t.b(t.v(t.d("i18n.themes.edit.repeat_options.none",c,p,0)));t.b("</option> <option value=\"repeat-x\">");t.b(t.v(t.d("i18n.themes.edit.repeat_options.horizontal",c,p,0)));t.b("</option> <option value=\"repeat-y\">");t.b(t.v(t.d("i18n.themes.edit.repeat_options.vertical",c,p,0)));t.b("</option> <option value=\"repeat\">");t.b(t.v(t.d("i18n.themes.edit.repeat_options.both",c,p,0)));t.b("</option> </select> </div> <div class=\"form-group\"> <label>");t.b(t.v(t.d("i18n.themes.edit.attach",c,p,0)));t.b("</label> <div> ");if(t.s(t.f("fixed",c,p,1),c,p,0,3000,3255,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <label class=\"checkbox-inline\"><input type=\"radio\" name=\"fixed\" value=\"scroll\" checked /> ");t.b(t.v(t.d("i18n.themes.edit.attach_tab",c,p,0)));t.b("</label> <label class=\"checkbox-inline\"><input type=\"radio\" name=\"fixed\" value=\"fixed\" /> ");t.b(t.v(t.d("i18n.themes.edit.attach_window",c,p,0)));t.b("</label> ");});c.pop();}t.b(" ");if(!t.s(t.f("fixed",c,p,1),c,p,1,0,0,"")){t.b(" <label class=\"checkbox-inline\"><input type=\"radio\" name=\"fixed\" value=\"scroll\" /> ");t.b(t.v(t.d("i18n.themes.edit.attach_tab",c,p,0)));t.b("</label> <label class=\"checkbox-inline\"><input type=\"radio\" name=\"fixed\" value=\"fixed\" checked /> ");t.b(t.v(t.d("i18n.themes.edit.attach_window",c,p,0)));t.b("</label> ");};t.b(" </div> </div> </form> <div class=\"preview\"></div> <div class=\"buttons\"> <button class=\"btn btn-success preview\">");t.b(t.v(t.d("i18n.themes.edit.preview",c,p,0)));t.b("</button> <button class=\"btn btn-primary save\">");t.b(t.v(t.d("i18n.themes.edit.save",c,p,0)));t.b("</button> </div>");return t.fl(); },partials: {}, subs: {  }}),"themes": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<h2 class=\"title\">");t.b(t.v(t.d("i18n.themes.title",c,p,0)));t.b("</h2> <ul class=\"nav\"> <li class=\"active\" data-id=\"all\">");t.b(t.v(t.d("i18n.themes.all",c,p,0)));t.b("</li> ");if(t.s(t.f("categories",c,p,1),c,p,0,135,171,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <li data-id=\"");t.b(t.v(t.f("id",c,p,0)));t.b("\">");t.b(t.v(t.f("name",c,p,0)));t.b("</li> ");});c.pop();}t.b(" <li data-id=\"custom\">");t.b(t.v(t.d("i18n.themes.custom",c,p,0)));t.b("</li> <li class=\"create\"> <button class=\"btn btn-primary\">");t.b(t.v(t.d("i18n.themes.create",c,p,0)));t.b("</button> </li> </ul> <div class=\"container\"> </div>");return t.fl(); },partials: {}, subs: {  }}),"themes.listing": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("themes",c,p,1),c,p,0,11,1519,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div data-id=\"");t.b(t.v(t.f("id",c,p,0)));t.b("\" class=\"theme");if(t.s(t.f("custom",c,p,1),c,p,0,57,64,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" custom");});c.pop();}t.b("\"> <div class=\"push lazy\" style=\"");if(t.s(t.f("color",c,p,1),c,p,0,118,146,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("background-color: ");t.b(t.v(t.f("color",c,p,0)));t.b(";");});c.pop();}if(t.s(t.f("thumb",c,p,1),c,p,0,166,201,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("background-image: url('");t.b(t.v(t.f("thumb",c,p,0)));t.b("');");});c.pop();}t.b("\"></div> <div class=\"caption\"> ");if(t.s(t.f("name",c,p,1),c,p,0,251,539,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <h2 title=\"");t.b(t.v(t.f("name",c,p,0)));t.b("\"> ");if(t.s(t.f("offline",c,p,1),c,p,0,286,353,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span class=\"cached\" title=\"");t.b(t.v(t.d("i18n.themes.cached",c,p,0)));t.b("\">&#xF0E7;</span>");});c.pop();}t.b(" ");if(t.s(t.f("type",c,p,1),c,p,0,375,428,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span class=\"type\" title=\"");t.b(t.v(t.f("desc",c,p,0)));t.b("\">");t.b(t.t(t.f("icon",c,p,0)));t.b("</span>");});c.pop();}t.b(" ");if(t.s(t.f("proOnly",c,p,1),c,p,0,450,511,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span class=\"pro\" title=\"");t.b(t.v(t.d("i18n.themes.pro_only",c,p,0)));t.b("\">Pro</span>");});c.pop();}t.b(" ");t.b(t.v(t.f("name",c,p,0)));t.b(" </h2> ");});c.pop();}t.b(" <div class=\"specs\"> ");if(t.s(t.f("stats",c,p,1),c,p,0,579,603,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <span>");t.b(t.v(t.f("stats",c,p,0)));t.b("</span> ");});c.pop();}t.b(" ");if(!t.s(t.f("stats",c,p,1),c,p,1,0,0,"")){t.b(" ");if(t.s(t.f("resolution",c,p,1),c,p,0,640,702,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span><b>");t.b(t.v(t.d("i18n.themes.resolution",c,p,0)));t.b(":</b> ");t.b(t.v(t.f("resolution",c,p,0)));t.b("</span>");});c.pop();}t.b(" ");};t.b(" ");if(t.s(t.f("source",c,p,1),c,p,0,740,1066,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" ");if(!t.s(t.f("stats",c,p,1),c,p,1,0,0,"")){t.b(" ");if(!t.s(t.f("resolution",c,p,1),c,p,1,0,0,"")){t.b(" ");if(t.s(t.f("categories",c,p,1),c,p,0,783,845,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span><b>");t.b(t.v(t.d("i18n.themes.categories",c,p,0)));t.b(":</b> ");t.b(t.v(t.f("categories",c,p,0)));t.b("</span>");});c.pop();}t.b(" ");};t.b(" ");};t.b(" ");if(t.s(t.f("url",c,p,1),c,p,0,896,986,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span><b>");t.b(t.v(t.d("i18n.themes.author",c,p,0)));t.b(":</b> <a href=\"");t.b(t.v(t.f("url",c,p,0)));t.b("\" target=\"_blank\">");t.b(t.v(t.f("name",c,p,0)));t.b("</a></span>");});c.pop();}t.b(" ");if(!t.s(t.f("url",c,p,1),c,p,1,0,0,"")){t.b("<span><b>");t.b(t.v(t.d("i18n.themes.author",c,p,0)));t.b(":</b> ");t.b(t.v(t.f("source",c,p,0)));t.b("</span>");};t.b(" ");});c.pop();}t.b(" ");if(!t.s(t.f("source",c,p,1),c,p,1,0,0,"")){t.b(" ");if(t.s(t.f("categories",c,p,1),c,p,0,1105,1167,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span><b>");t.b(t.v(t.d("i18n.themes.categories",c,p,0)));t.b(":</b> ");t.b(t.v(t.f("categories",c,p,0)));t.b("</span>");});c.pop();}t.b(" ");};t.b(" </div> ");if(t.s(t.f("custom",c,p,1),c,p,0,1213,1355,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <button class=\"btn btn-warning edit\">");t.b(t.v(t.d("i18n.themes.edit_btn",c,p,0)));t.b("</button> <button class=\"btn btn-danger delete\">");t.b(t.v(t.d("i18n.themes.delete",c,p,0)));t.b("</button> ");});c.pop();}t.b(" <button class=\"btn btn-success use\">");t.b(t.v(t.d("i18n.themes.use",c,p,0)));t.b("</button> <button class=\"btn btn-primary preview\">");t.b(t.v(t.d("i18n.themes.preview",c,p,0)));t.b("</button> </div> </div> ");});c.pop();}return t.fl(); },partials: {}, subs: {  }}),"toolbar": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(!t.s(t.f("isFull",c,p,1),c,p,1,0,0,"")){t.b(" <div class=\"search\"></div> <div class=\"add-widget-link\"> <span class=\"icon m-icon\">add_circle</span> </div> ");};t.b(" ");if(t.s(t.f("isFull",c,p,1),c,p,0,143,3089,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"logo\"></div> <div class=\"search\"></div> <div class=\"links\"> ");if(t.s(t.f("links",c,p,1),c,p,0,226,277,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<a href=\"");t.b(t.v(t.f("link",c,p,0)));t.b("\" class=\"custom-link\">");t.b(t.v(t.f("text",c,p,0)));t.b("</a>");});c.pop();}t.b(" ");if(t.s(t.f("plus",c,p,1),c,p,0,297,349,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<a href=\"https://plus.google.com/u/0/\">+");t.b(t.v(t.f("name",c,p,0)));t.b("</a>");});c.pop();}t.b(" ");if(t.s(t.f("gmail",c,p,1),c,p,0,369,440,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<a href=\"https://mail.google.com/mail/\">");t.b(t.v(t.d("i18n.toolbar.apps.gmail",c,p,0)));t.b("</a>");});c.pop();}t.b(" </div> ");if(t.s(t.f("announcements",c,p,1),c,p,0,476,540,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div class=\"announcements\" data-count=\"");t.b(t.v(t.f("announcements",c,p,0)));t.b("\"></div>");});c.pop();}t.b(" ");if(t.s(t.f("apps",c,p,1),c,p,0,568,2915,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"apps-toggle\"> <svg viewBox=\"0 0 21 21\"> <path fill=\"#EF5350\" d=\"M5,2.5C5,3.875,3.875,5,2.5,5S0,3.875,0,2.5S1.125,0,2.5,0S5,1.125,5,2.5z\" /> <path fill=\"#FFA726\" d=\"M13,2.5C13,3.875,11.875,5,10.5,5S8,3.875,8,2.5S9.125,0,10.5,0S13,1.125,13,2.5z\" /> <path fill=\"#EF5350\" d=\"M21,2.5C21,3.875,19.875,5,18.5,5S16,3.875,16,2.5S17.125,0,18.5,0S21,1.125,21,2.5z\" /> <path fill=\"#FFA726\" d=\"M21,10.5c0,1.375-1.125,2.5-2.5,2.5S16,11.875,16,10.5S17.125,8,18.5,8S21,9.125,21,10.5z\" /> <path fill=\"#42A5F5\" d=\"M21,18.5c0,1.375-1.125,2.5-2.5,2.5S16,19.875,16,18.5s1.125-2.5,2.5-2.5S21,17.125,21,18.5z\" /> <path fill=\"#FFA726\" d=\"M13,18.5c0,1.375-1.125,2.5-2.5,2.5S8,19.875,8,18.5S9.125,16,10.5,16S13,17.125,13,18.5z\" /> <path fill=\"#48C34D\" d=\"M5,18.5C5,19.875,3.875,21,2.5,21S0,19.875,0,18.5S1.125,16,2.5,16S5,17.125,5,18.5z\" /> <path fill=\"#48C34D\" d=\"M5,10.5C5,11.875,3.875,13,2.5,13S0,11.875,0,10.5S1.125,8,2.5,8S5,9.125,5,10.5z\" /> <path fill=\"#42A5F5\" d=\"M13,10.5c0,1.375-1.125,2.5-2.5,2.5S8,11.875,8,10.5S9.125,8,10.5,8S13,9.125,13,10.5z\" /> </svg> <div class=\"collapse\"> <nav class=\"apps\"> <div class=\"items\"> <a href=\"https://www.google.com/\"> <img data-src=\"images/icons/search.png\" /> <span>");t.b(t.v(t.d("i18n.toolbar.apps.search",c,p,0)));t.b("</span> </a> <a href=\"https://maps.google.com/\"> <img data-src=\"images/icons/maps.png\" /> <span>");t.b(t.v(t.d("i18n.toolbar.apps.maps",c,p,0)));t.b("</span> </a> <a href=\"https://www.youtube.com/\"> <img data-src=\"images/icons/youtube.png\" /> <span>");t.b(t.v(t.d("i18n.toolbar.apps.youtube",c,p,0)));t.b("</span> </a> <a href=\"https://play.google.com/\"> <img data-src=\"images/icons/play.png\" /> <span>");t.b(t.v(t.d("i18n.toolbar.apps.play",c,p,0)));t.b("</span> </a> <a href=\"https://news.google.com/\"> <img data-src=\"images/icons/news.png\" /> <span>");t.b(t.v(t.d("i18n.toolbar.apps.news",c,p,0)));t.b("</span> </a> <a href=\"https://mail.google.com/\"> <img data-src=\"images/icons/gmail.png\" /> <span>");t.b(t.v(t.d("i18n.toolbar.apps.gmail",c,p,0)));t.b("</span> </a> <a href=\"https://drive.google.com/\"> <img data-src=\"images/icons/drive.png\" /> <span>");t.b(t.v(t.d("i18n.toolbar.apps.drive",c,p,0)));t.b("</span> </a> <a href=\"https://www.google.com/calendar\"> <img data-src=\"images/icons/calendar.png\" /> <span>");t.b(t.v(t.d("i18n.toolbar.apps.calendar",c,p,0)));t.b("</span> </a> <a href=\"https://plus.google.com/\"> <img data-src=\"images/icons/plus.png\" /> <span>+");t.b(t.v(t.f("name",c,p,0)));t.b("</span> </a> </div> <a href=\"https://www.google.com/about/products/\" class=\"more\">");t.b(t.v(t.d("i18n.toolbar.apps.more",c,p,0)));t.b("</a> </nav> </div> </div> ");});c.pop();}t.b(" <div class=\"menu-toggle\"> <div class=\"img\"");if(t.s(t.f("profileimage",c,p,1),c,p,0,2984,3032,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" style=\"background-image: url(");t.b(t.v(t.f("profileimage",c,p,0)));t.b(")\"");});c.pop();}t.b("></div> <nav class=\"menu\"></nav> </div> ");});c.pop();}t.b(" ");return t.fl(); },partials: {}, subs: {  }}),"updated": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<div class=\"nav\"> <button type=\"button\" class=\"material fab m-icon prev\" data-direction=\"prev\">arrow_back</button> <button type=\"button\" class=\"material fab m-icon next\" data-direction=\"next\"></button> </div> <section class=\"slide intro active\" data-id=\"1\"> <img class=\"logo\" src=\"icon/300.png\" /> <h2 class=\"header\">ProductivityTab just got better</h2> <span class=\"subheader\">Click the button at the right to see what's new in V3</span> <span class=\"footer note\"><b>Note:</b> New <a href=\"https://productivitytab.co/terms-of-service\" target=\"_blank\">Terms</a> and <a href=\"https://productivitytab.co/privacy-policy\" target=\"_blank\">Privacy Policies</a> apply. Your continued use of ProductivityTab indicates acceptance of these.</span> </section> <section class=\"slide pro\" data-id=\"2\"> <div class=\"hero\" style=\"background-image: url(images/onboarding.png)\"></div> <div class=\"caption\"> <h2>Pro is here!</h2> <p>Buy Pro from the settings to get dark and transparent themes, maximizable widgets, live backgrounds, hourly weather forecasts, and more!</p> </div> </section> <section class=\"slide sign-in\" data-id=\"3\"> <div class=\"pending visible\"> <div class=\"caption\"> <h2>Sign in</h2> <p>ProductivityTab has a new, better sync system. Sign in with Google to save and sync your configuration.</p> <p>You can stay signed out if you want, but your page won't be saved online and you won't be able to access it from other computers.</p> </div> <div class=\"btn-container\"> <button type=\"button\" class=\"material large red sign-in\">Sign in with Google</button> </div> </div> <div class=\"complete\"> <h2>All set!</h2> <p>Click next to see what else has changed</p> </div> </section> <section class=\"slide other final\" data-id=\"3\"> <div class=\"caption\"> <h2>Other ways ProductivityTab has improved</h2> <p>The main settings have been completely reworked to be simpler and easier to use</p> <p>Over a dozen widgets have been completely redesigned and rebuilt</p> <p>The default theme is now a collection of nearly 3,000 randomly rotating images</p> <p>A number of smaller changes have been made to improve performance, stability, and fix bugs</p> <p>A new Dictionary widget has been added</p> <p>You can now click the button at the bottom right of the page to learn more about a background</p> <p>And more!</p> </div> <div class=\"footer\">Enjoy!</div> </section>");return t.fl(); },partials: {}, subs: {  }}),"whatsnew": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<p>Welcome to ProductivityTab version 1.45.14!</p> <section> <p>What's New in Version 1.45.14:</p> <ul> <li>FIXED. Facebook, Keep and iframe widgets \"unable to connect\" issues are fixed</li> <li>FIXED. Invisible dropdown controls in dark themes</li> <li>IMPROVEMENT. SiteLink widget image replacement is explained</li> </ul> </section>");return t.fl(); },partials: {}, subs: {  }}),"widget-settings": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<h2 class=\"title\">");t.b(t.v(t.d("i18n.widgets.settings.title",c,p,0)));t.b(" <button class=\"btn btn-primary save\">");t.b(t.v(t.d("i18n.widgets.settings.save",c,p,0)));t.b("</button></h2> <form></form>");return t.fl(); },partials: {}, subs: {  }}),"widget-settings.inputs": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("input-text",c,p,1),c,p,0,15,300,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <label for=\"widget-");t.b(t.v(t.f("name",c,p,0)));t.b("\"> ");t.b(t.v(t.f("label",c,p,0)));t.b(" ");if(t.s(t.f("help",c,p,1),c,p,0,65,139,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div class=\"help\" data-m-icon-before=\"help\" data-tooltip=\"");t.b(t.v(t.f("help",c,p,0)));t.b("\"></div>");});c.pop();}t.b(" </label> <input type=\"text\" class=\"form-control\" id=\"widget-");t.b(t.v(t.f("name",c,p,0)));t.b("\" name=\"");t.b(t.v(t.f("name",c,p,0)));t.b("\" placeholder=\"");t.b(t.v(t.f("placeholder",c,p,0)));t.b("\" value=\"");t.b(t.v(t.f("value",c,p,0)));t.b("\" ");t.b(t.v(t.f("proHelper",c,p,0)));t.b(" /> ");});c.pop();}t.b(" ");if(t.s(t.f("input-textarea",c,p,1),c,p,0,335,611,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <label for=\"widget-");t.b(t.v(t.f("name",c,p,0)));t.b("\"> ");t.b(t.v(t.f("label",c,p,0)));t.b(" ");if(t.s(t.f("help",c,p,1),c,p,0,385,459,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div class=\"help\" data-m-icon-before=\"help\" data-tooltip=\"");t.b(t.v(t.f("help",c,p,0)));t.b("\"></div>");});c.pop();}t.b(" </label> <textarea class=\"form-control\" id=\"widget-");t.b(t.v(t.f("name",c,p,0)));t.b("\" name=\"");t.b(t.v(t.f("name",c,p,0)));t.b("\" placeholder=\"");t.b(t.v(t.f("placeholder",c,p,0)));t.b("\" ");t.b(t.v(t.f("proHelper",c,p,0)));t.b(">");t.b(t.v(t.f("value",c,p,0)));t.b("</textarea> ");});c.pop();}t.b(" ");if(t.s(t.f("input-color",c,p,1),c,p,0,647,908,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <label for=\"widget-");t.b(t.v(t.f("name",c,p,0)));t.b("\"> ");t.b(t.v(t.f("label",c,p,0)));t.b(" ");if(t.s(t.f("help",c,p,1),c,p,0,697,771,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div class=\"help\" data-m-icon-before=\"help\" data-tooltip=\"");t.b(t.v(t.f("help",c,p,0)));t.b("\"></div>");});c.pop();}t.b(" </label> <input type=\"text\" class=\"form-control color\" id=\"widget-");t.b(t.v(t.f("name",c,p,0)));t.b("\" name=\"");t.b(t.v(t.f("name",c,p,0)));t.b("\" value=\"");t.b(t.v(t.f("value",c,p,0)));t.b("\" ");t.b(t.v(t.f("proHelper",c,p,0)));t.b(" /> ");});c.pop();}t.b(" ");if(t.s(t.f("input-select",c,p,1),c,p,0,942,1383,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <label for=\"widget-");t.b(t.v(t.f("name",c,p,0)));t.b("\"> ");t.b(t.v(t.f("label",c,p,0)));t.b(" ");if(t.s(t.f("help",c,p,1),c,p,0,992,1066,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div class=\"help\" data-m-icon-before=\"help\" data-tooltip=\"");t.b(t.v(t.f("help",c,p,0)));t.b("\"></div>");});c.pop();}t.b(" </label> <select class=\"form-control\" id=\"widget-");t.b(t.v(t.f("name",c,p,0)));t.b("\" name=\"");t.b(t.v(t.f("name",c,p,0)));t.b("\" ");t.b(t.v(t.f("multiple",c,p,0)));t.b(" ");t.b(t.v(t.f("proHelper",c,p,0)));t.b("> ");if(t.s(t.f("options",c,p,1),c,p,0,1191,1360,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" ");if(t.s(t.f("group",c,p,1),c,p,0,1202,1256,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <optgroup label=\"");t.b(t.t(t.f("nesting",c,p,0)));t.b(t.v(t.f("group",c,p,0)));t.b("\"></optgroup> ");});c.pop();}t.b(" ");if(!t.s(t.f("group",c,p,1),c,p,1,0,0,"")){t.b(" <option value=\"");t.b(t.v(t.f("value",c,p,0)));t.b("\" ");t.b(t.v(t.f("selected",c,p,0)));t.b(">");t.b(t.t(t.f("nesting",c,p,0)));t.b(t.v(t.f("label",c,p,0)));t.b("</option> ");};t.b(" ");});c.pop();}t.b(" </select> ");});c.pop();}t.b(" ");if(t.s(t.f("input-list",c,p,1),c,p,0,1416,2107,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <label for=\"widget-");t.b(t.v(t.f("name",c,p,0)));t.b("\"> ");t.b(t.v(t.f("label",c,p,0)));t.b(" ");if(t.s(t.f("help",c,p,1),c,p,0,1466,1540,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div class=\"help\" data-m-icon-before=\"help\" data-tooltip=\"");t.b(t.v(t.f("help",c,p,0)));t.b("\"></div>");});c.pop();}t.b(" </label> <div> <input type=\"text\" placeholder=\"");t.b(t.v(t.f("placeholder",c,p,0)));t.b("\" id=\"widget-");t.b(t.v(t.f("name",c,p,0)));t.b("\" ");t.b(t.v(t.f("proHelper",c,p,0)));t.b(" /> <ul class=\"suggestions\"></ul> <div class=\"items\"> ");if(t.s(t.f("items",c,p,1),c,p,0,1712,2082,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"item\"> ");if(t.s(t.f("color",c,p,1),c,p,0,1742,1834,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<input type=\"text\" class=\"color\" name=\"");t.b(t.v(t.f("name",c,p,0)));t.b("[][color]\" value=\"");t.b(t.v(t.f("color",c,p,0)));t.b("\" ");t.b(t.v(t.f("proHelper",c,p,0)));t.b(" />");});c.pop();}t.b(" <input type=\"text\" name=\"");t.b(t.v(t.f("name",c,p,0)));t.b("[]");if(t.s(t.f("color",c,p,1),c,p,0,1890,1896,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("[name]");});c.pop();}t.b("\" value=\"");t.b(t.v(t.f("value",c,p,0)));t.b("\" ");t.b(t.v(t.f("proHelper",c,p,0)));t.b(" /> <div class=\"tools\"> <span class=\"up\">&#xE6CF;</span> <span class=\"down\">&#xE6CE;</span> <span class=\"delete\">&#xE678;</span> </div> </div> ");});c.pop();}t.b(" </div> </div> ");});c.pop();}t.b(" ");if(t.s(t.f("input-list-item",c,p,1),c,p,0,2143,2513,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"item\"> ");if(t.s(t.f("color",c,p,1),c,p,0,2173,2265,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<input type=\"text\" class=\"color\" name=\"");t.b(t.v(t.f("name",c,p,0)));t.b("[][color]\" value=\"");t.b(t.v(t.f("color",c,p,0)));t.b("\" ");t.b(t.v(t.f("proHelper",c,p,0)));t.b(" />");});c.pop();}t.b(" <input type=\"text\" name=\"");t.b(t.v(t.f("name",c,p,0)));t.b("[]");if(t.s(t.f("color",c,p,1),c,p,0,2321,2327,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("[name]");});c.pop();}t.b("\" value=\"");t.b(t.v(t.f("value",c,p,0)));t.b("\" ");t.b(t.v(t.f("proHelper",c,p,0)));t.b(" /> <div class=\"tools\"> <span class=\"up\">&#xE6CF;</span> <span class=\"down\">&#xE6CE;</span> <span class=\"delete\">&#xE678;</span> </div> </div> ");});c.pop();}t.b(" ");if(t.s(t.f("input-size",c,p,1),c,p,0,2549,2775,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <label for=\"widget-size\">");t.b(t.v(t.d("i18n.widgets.settings.size",c,p,0)));t.b("</label> <select class=\"form-control\" id=\"widget-size\" name=\"size\" ");t.b(t.v(t.f("proHelper",c,p,0)));t.b("> ");if(t.s(t.f("sizes",c,p,1),c,p,0,2697,2754,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <option value=\"");t.b(t.v(t.f("size",c,p,0)));t.b("\" ");t.b(t.v(t.f("selected",c,p,0)));t.b(">");t.b(t.v(t.f("name",c,p,0)));t.b("</option> ");});c.pop();}t.b(" </select> ");});c.pop();}t.b(" ");if(t.s(t.f("input-radio",c,p,1),c,p,0,2807,3128,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <label> ");t.b(t.v(t.f("label",c,p,0)));t.b(" ");if(t.s(t.f("help",c,p,1),c,p,0,2835,2909,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div class=\"help\" data-m-icon-before=\"help\" data-tooltip=\"");t.b(t.v(t.f("help",c,p,0)));t.b("\"></div>");});c.pop();}t.b(" </label> <div> ");if(t.s(t.f("options",c,p,1),c,p,0,2946,3108,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <label class=\"checkbox-inline\"> <input type=\"radio\" name=\"");t.b(t.v(t.f("name",c,p,0)));t.b("\" value=\"");t.b(t.v(t.f("value",c,p,0)));t.b("\" ");t.b(t.v(t.f("proHelper",c,p,0)));if(!t.s(t.f("proHelper",c,p,1),c,p,1,0,0,"")){t.b(t.v(t.f("checked",c,p,0)));};t.b(" /> ");t.b(t.v(t.f("label",c,p,0)));t.b(" </label> ");});c.pop();}t.b(" </div> ");});c.pop();}t.b(" ");if(t.s(t.f("input-number",c,p,1),c,p,0,3162,3447,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <label for=\"widget-");t.b(t.v(t.f("name",c,p,0)));t.b("\"> ");t.b(t.v(t.f("label",c,p,0)));t.b(" ");if(t.s(t.f("help",c,p,1),c,p,0,3212,3286,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div class=\"help\" data-m-icon-before=\"help\" data-tooltip=\"");t.b(t.v(t.f("help",c,p,0)));t.b("\"></div>");});c.pop();}t.b(" </label> <input type=\"number\" id=\"widget-");t.b(t.v(t.f("name",c,p,0)));t.b("\" name=\"");t.b(t.v(t.f("name",c,p,0)));t.b("\" class=\"form-control\" min=\"");t.b(t.v(t.f("min",c,p,0)));t.b("\" max=\"");t.b(t.v(t.f("max",c,p,0)));t.b("\" value=\"");t.b(t.v(t.f("value",c,p,0)));t.b("\" ");t.b(t.v(t.f("proHelper",c,p,0)));t.b(" /> ");});c.pop();}t.b(" ");if(t.s(t.f("input-time",c,p,1),c,p,0,3480,3765,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <label for=\"widget-");t.b(t.v(t.f("name",c,p,0)));t.b("\"> ");t.b(t.v(t.f("label",c,p,0)));t.b(" ");if(t.s(t.f("help",c,p,1),c,p,0,3530,3604,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div class=\"help\" data-m-icon-before=\"help\" data-tooltip=\"");t.b(t.v(t.f("help",c,p,0)));t.b("\"></div>");});c.pop();}t.b(" </label> <input type=\"time\" class=\"form-control\" name=\"");t.b(t.v(t.f("name",c,p,0)));t.b("\" id=\"widget-");t.b(t.v(t.f("name",c,p,0)));t.b("\" value=\"");t.b(t.v(t.f("value",c,p,0)));t.b("\" placeholder=\"");t.b(t.v(t.f("placeholder",c,p,0)));t.b("\" ");t.b(t.v(t.f("proHelper",c,p,0)));t.b(" /> ");});c.pop();}return t.fl(); },partials: {}, subs: {  }}),"widgets.apps.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("The Apps widget displays your Chrome apps in a list or tile view.<br /> <br /> You can drag-and-drop widgets or pick a default display order in the settings.");return t.fl(); },partials: {}, subs: {  }}),"widgets.apps": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("title",c,p,1),c,p,0,10,43,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<h2 class=\"header\">");t.b(t.v(t.f("title",c,p,0)));t.b("</h2>");});c.pop();}t.b(" <div class=\"");if(t.s(t.f("tiles",c,p,1),c,p,0,76,81,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("tiles");});c.pop();}if(!t.s(t.f("tiles",c,p,1),c,p,1,0,0,"")){t.b("list");};t.b("\"> ");if(t.s(t.f("items",c,p,1),c,p,0,128,324,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <a class=\"app");if(!t.s(t.f("available",c,p,1),c,p,1,0,0,"")){t.b(" unavailable");};t.b("\" data-id=\"");t.b(t.v(t.f("id",c,p,0)));t.b("\"> <img class=\"thumb\" src=\"");t.b(t.v(t.f("thumb",c,p,0)));if(!t.s(t.f("available",c,p,1),c,p,1,0,0,"")){t.b("?grayscale=true");};t.b("\" /> <span class=\"title\">");t.b(t.v(t.f("name",c,p,0)));t.b("</span> </a> ");});c.pop();}t.b(" </div>");return t.fl(); },partials: {}, subs: {  }}),"widgets/auth-required": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<div class=\"notice\"> <h2>");t.b(t.v(t.f("name",c,p,0)));t.b("</h2> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 48 48\"> <path d=\"M38.71 20.07C37.35 13.19 31.28 8 24 8c-2.95 0-5.7.87-8.02 2.34l2.92 2.92C20.43 12.47 22.16 12 24 12c6.08 0 11 4.92 11 11v1h3c3.31 0 6 2.69 6 6 0 2.27-1.27 4.22-3.13 5.24l2.9 2.9C46.32 36.33 48 33.37 48 30c0-5.28-4.11-9.56-9.29-9.93zM6 10.55l5.5 5.48C5.12 16.3 0 21.55 0 28c0 6.63 5.37 12 12 12h23.45l4 4L42 41.46 8.55 8 6 10.55zM15.45 20l16 16H12c-4.42 0-8-3.58-8-8s3.58-8 8-8h3.45z\"></path> </svg> <p>");t.b(t.v(t.f("message",c,p,0)));if(!t.s(t.f("message",c,p,1),c,p,1,0,0,"")){t.b(t.v(t.d("i18n.widgets.auth.message",c,p,0)));};t.b("</p> <button type=\"button\" class=\"button material green\">");t.b(t.v(t.f("button",c,p,0)));if(!t.s(t.f("button",c,p,1),c,p,1,0,0,"")){t.b(t.v(t.d("i18n.widgets.auth.button",c,p,0)));};t.b("</button> </div>");return t.fl(); },partials: {}, subs: {  }}),"widgets.bookmarks.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("The Bookmarks widget contains an editable list of bookmarks in either a one or two column layout.<br /> <br /> Use the buttons at the right of each of the bookmarks to delete or reorder them.");return t.fl(); },partials: {}, subs: {  }}),"widgets.bookmarks.listing": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("url",c,p,1),c,p,0,8,302,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <a class=\"link drag\" href=\"");t.b(t.v(t.f("url",c,p,0)));if(t.s(t.f("newTab",c,p,1),c,p,0,54,70,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("\" target=\"_blank");});c.pop();}t.b("\"> <img class=\"favicon\" src=\"");t.b(t.v(t.f("favicon",c,p,0)));t.b("\" /> <span class=\"title\">");t.b(t.v(t.f("title",c,p,0)));t.b("</span> <div class=\"tools\"> <span class=\"edit\">&#xE606;</span> <span class=\"delete\">&#xE678;</span> <span class=\"move\">&#xE693;</span> </div> </a> ");});c.pop();}t.b(" ");if(!t.s(t.f("url",c,p,1),c,p,1,0,0,"")){t.b(" <div class=\"folder drag\"> <input type=\"text\" class=\"name\" value=\"");t.b(t.v(t.f("name",c,p,0)));t.b("\" disabled /> <div class=\"tools\"> <span class=\"edit\">&#xE606;</span> <span class=\"delete\">&#xE678;</span> <span class=\"move\">&#xE693;</span> </div> <div class=\"items\"> ");if(t.s(t.f("items",c,p,1),c,p,0,571,585,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" ");t.b(t.rp("<listing0",c,p,""));t.b(" ");});c.pop();}t.b(" </div> </div> ");};return t.fl(); },partials: {"<listing0":{name:"listing", partials: {}, subs: {  }}}, subs: {  }}),"widgets.bookmarks": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<div class=\"drop\"> <div class=\"text\">");t.b(t.v(t.d("i18n.drop_link",c,p,0)));t.b("</div> <div class=\"catch\" contenteditable></div> </div> <h2 class=\"header\">");t.b(t.v(t.f("title",c,p,0)));if(!t.s(t.f("title",c,p,1),c,p,1,0,0,"")){t.b("&nbsp;");};t.b("<div class=\"new\">");t.b(t.v(t.d("i18n.new_caption",c,p,0)));t.b(": <a data-type=\"bookmark\">");t.b(t.v(t.d("i18n.new_bookmark",c,p,0)));t.b("</a> <a data-type=\"folder\">");t.b(t.v(t.d("i18n.new_folder",c,p,0)));t.b("</a></div></h2> <div class=\"list");if(t.s(t.f("two",c,p,1),c,p,0,335,346,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" two-column");});c.pop();}t.b("\"> ");if(t.s(t.f("bookmarks",c,p,1),c,p,0,371,385,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" ");t.b(t.rp("<listing0",c,p,""));t.b(" ");});c.pop();}t.b(" </div>");return t.fl(); },partials: {"<listing0":{name:"listing", partials: {}, subs: {  }}}, subs: {  }}),"widgets.calc.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("This widget contains a calculator with basic functionality.");return t.fl(); },partials: {}, subs: {  }}),"widgets.calc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<input type=\"text\" placeholder=\"0\" class=\"display\" /> ");if(!t.s(t.f("tiny",c,p,1),c,p,1,0,0,"")){t.b(" <div class=\"buttons\"> ");if(t.s(t.f("medium",c,p,1),c,p,0,97,815,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <button data-id=\"clear\">C</button> <button data-id=\"oparen\">(</button> <button data-id=\"cparen\">)</button> <button data-id=\"divide\" class=\"larger\">&divide;</button> <button data-id=\"7\">7</button> <button data-id=\"8\">8</button> <button data-id=\"9\">9</button> <button data-id=\"multiply\" class=\"larger\">&times;</button> <button data-id=\"4\">4</button> <button data-id=\"5\">5</button> <button data-id=\"6\">6</button> <button data-id=\"minus\">&mdash;</button> <button data-id=\"1\">1</button> <button data-id=\"2\">2</button> <button data-id=\"3\">3</button> <button data-id=\"plus\" class=\"larger\">&plus;</button> <button data-id=\"0\">0</button> <button data-id=\"decimal\">.</button> <button data-id=\"equals\" class=\"larger\">=</button> ");});c.pop();}t.b(" ");if(t.s(t.f("small",c,p,1),c,p,0,837,1041,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <button data-id=\"clear\">C</button> <button data-id=\"multiply\" class=\"larger\">&times;</button> <button data-id=\"divide\" class=\"larger\">&divide;</button> <button data-id=\"equals\" class=\"larger\">=</button> ");});c.pop();}t.b(" </div> ");};return t.fl(); },partials: {}, subs: {  }}),"widgets.calendar.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("The Calendar widget displays a list of events from one or more of your Google Calendars.<br /> <br /> After installation, select the calendars you want shown from the settings.");return t.fl(); },partials: {}, subs: {  }}),"widgets.calendar": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("title",c,p,1),c,p,0,10,86,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <header> <a href=\"https://www.google.com/calendar\">");t.b(t.v(t.f("title",c,p,0)));t.b("</a> </header> ");});c.pop();}t.b(" ");if(t.s(t.f("noCalendars",c,p,1),c,p,0,113,168,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"notice\"><p>");t.b(t.v(t.d("i18n.nocalendars",c,p,0)));t.b("</p></div> ");});c.pop();}t.b(" ");if(!t.s(t.f("noCalendars",c,p,1),c,p,1,0,0,"")){t.b(" <div class=\"gcalendar\"></div> ");};t.b(" ");return t.fl(); },partials: {}, subs: {  }}),"widgets.chrome_bookmarks.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("This widget displays your Chrome bookmarks, optionally from a specific folder.<br /> <br /> You can add, remove, edit, and reorder bookmarks through Chrome's interface at <b>chrome://bookmarks</b>.");return t.fl(); },partials: {}, subs: {  }}),"widgets.chrome_bookmarks.listing": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("url",c,p,1),c,p,0,8,231,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <a class=\"link\" href=\"");t.b(t.v(t.f("url",c,p,0)));if(t.s(t.f("newTab",c,p,1),c,p,0,49,65,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("\" target=\"_blank");});c.pop();}if(!t.s(t.f("newTab",c,p,1),c,p,1,0,0,"")){t.b("\" target=\"_self");};t.b("\"> <img class=\"favicon\" src=\"");t.b(t.v(t.f("favicon",c,p,0)));t.b("\" /> <span class=\"title\" title=\"");t.b(t.v(t.f("title",c,p,0)));t.b("&#013;");t.b(t.v(t.f("url",c,p,0)));t.b("\">");t.b(t.v(t.f("title",c,p,0)));t.b("</span> </a> ");});c.pop();}t.b(" ");if(!t.s(t.f("url",c,p,1),c,p,1,0,0,"")){t.b(" <div class=\"folder\"> <span class=\"title\">");t.b(t.v(t.f("name",c,p,0)));t.b("</span> <span class=\"count\">");t.b(t.v(t.d("items.length",c,p,0)));t.b("</span> </div> <div class=\"folder-items\"> ");if(t.s(t.f("items",c,p,1),c,p,0,394,408,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" ");t.b(t.rp("<listing0",c,p,""));t.b(" ");});c.pop();}t.b(" </div> ");};return t.fl(); },partials: {"<listing0":{name:"listing", partials: {}, subs: {  }}}, subs: {  }}),"widgets.chrome_bookmarks": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("title",c,p,1),c,p,0,10,43,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<h2 class=\"header\">");t.b(t.v(t.f("title",c,p,0)));t.b("</h2>");});c.pop();}t.b(" <div class=\"list\"> ");if(t.s(t.f("bookmarks",c,p,1),c,p,0,87,101,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" ");t.b(t.rp("<listing0",c,p,""));t.b(" ");});c.pop();}t.b(" </div>");return t.fl(); },partials: {"<listing0":{name:"listing", partials: {}, subs: {  }}}, subs: {  }}),"widgets.clock.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("The Clock widget displays the current time and date and offers alarm, timer, and stopwatch functionality.<br /> <br /> After installation, pick your format preferences and alert sound in the settings.");return t.fl(); },partials: {}, subs: {  }}),"widgets.clock": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("analog",c,p,1),c,p,0,11,1019,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"clock\"> <!-- Hands --> <div class=\"hour holder\" style=\"-webkit-transform: rotate(");t.b(t.v(t.f("hPos",c,p,0)));t.b("deg);\"> <div class=\"hand\"><div></div></div> </div> <div class=\"minute holder\" style=\"-webkit-transform: rotate(");t.b(t.v(t.f("mPos",c,p,0)));t.b("deg);\"> <div class=\"hand\"><div></div></div> </div> <div class=\"second holder\" style=\"-webkit-transform: rotate(");t.b(t.v(t.f("sPos",c,p,0)));t.b("deg);\"> <div class=\"hand\"><div></div></div> </div> <!-- Hand Shadows --> <div class=\"shadow\"> <div class=\"hour holder\" style=\"-webkit-transform: rotate(");t.b(t.v(t.f("hPos",c,p,0)));t.b("deg);\"> <div class=\"hand\"><div></div></div> </div> <div class=\"minute holder\" style=\"-webkit-transform: rotate(");t.b(t.v(t.f("mPos",c,p,0)));t.b("deg);\"> <div class=\"hand\"><div></div></div> </div> <div class=\"second holder\" style=\"-webkit-transform: rotate(");t.b(t.v(t.f("sPos",c,p,0)));t.b("deg);\"> <div class=\"hand\"><div></div></div> </div> </div> <!-- Ticks --> <div class=\"ticks\"> <div></div><div></div><div></div> <div></div><div></div><div></div> <div></div><div></div><div></div> <div></div><div></div><div></div> </div> <div class=\"mticks\"></div> </div> ");});c.pop();}t.b(" ");if(!t.s(t.f("analog",c,p,1),c,p,1,0,0,"")){t.b(" ");if(t.s(t.f("small",c,p,1),c,p,0,1053,5011,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <header class=\"tabs\"> <div class=\"item\" data-id=\"alarm\" title=\"");t.b(t.v(t.d("i18n.alarm",c,p,0)));t.b("\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"><path d=\"M22 5.72l-4.6-3.86-1.29 1.53 4.6 3.86L22 5.72zM7.88 3.39L6.6 1.86 2 5.71l1.29 1.53 4.59-3.85zM12.5 8H11v6l4.75 2.85.75-1.23-4-2.37V8zM12 4c-4.97 0-9 4.03-9 9s4.02 9 9 9c4.97 0 9-4.03 9-9s-4.03-9-9-9zm0 16c-3.87 0-7-3.13-7-7s3.13-7 7-7 7 3.13 7 7-3.13 7-7 7z\"/></svg> </div> <div class=\"item tab-active\" data-id=\"clock\" title=\"");t.b(t.v(t.d("i18n.clock",c,p,0)));t.b("\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"><path fill-opacity=\".9\" d=\"M11.99 2C6.47 2 2 6.48 2 12s4.47 10 9.99 10C17.52 22 22 17.52 22 12S17.52 2 11.99 2zM12 20c-4.42 0-8-3.58-8-8s3.58-8 8-8 8 3.58 8 8-3.58 8-8 8zM12.5 7H11v6l5.25 3.15.75-1.23-4.5-2.67z\"/></svg> </div> <div class=\"item\" data-id=\"timer\" title=\"");t.b(t.v(t.d("i18n.timer",c,p,0)));t.b("\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"><path d=\"M6 2v6h.01L6 8.01 10 12l-4 4 .01.01H6V22h12v-5.99h-.01L18 16l-4-4 4-3.99-.01-.01H18V2H6zm10 14.5V20H8v-3.5l4-4 4 4zm-4-5l-4-4V4h8v3.5l-4 4z\"/></svg> </div> <div class=\"item\" data-id=\"stopwatch\" title=\"");t.b(t.v(t.d("i18n.stopwatch",c,p,0)));t.b("\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"><path d=\"M15 1H9v2h6V1zm-4 13h2V8h-2v6zm8.03-6.61l1.42-1.42c-.43-.51-.9-.99-1.41-1.41l-1.42 1.42C16.07 4.74 14.12 4 12 4c-4.97 0-9 4.03-9 9s4.02 9 9 9 9-4.03 9-9c0-2.12-.74-4.07-1.97-5.61zM12 20c-3.87 0-7-3.13-7-7s3.13-7 7-7 7 3.13 7 7-3.13 7-7 7z\"/></svg> </div> </header> <div class=\"section alarm ");if(t.s(t.d("alarm.set",c,p,1),c,p,0,2556,2563,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("running");});c.pop();}t.b("\"> <div class=\"time\">");t.b(t.v(t.d("alarm.html",c,p,0)));t.b("</div> <input type=\"time\" class=\"time\" value=\"");t.b(t.v(t.d("alarm.timeStr",c,p,0)));t.b("\" /> <div class=\"controls\"> <label class=\"audio\"> <input type=\"checkbox\" ");if(t.s(t.f("audio",c,p,1),c,p,0,2758,2765,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("checked");});c.pop();}t.b(" /> ");t.b(t.v(t.d("i18n.enable_audio",c,p,0)));t.b(" </label> <!-- <input type=\"date\" class=\"date\" min=\"2015-06-24\" value=\"2015-06-24\" /> --> <button type=\"button\" class=\"material blue set\">");if(t.s(t.d("alarm.set",c,p,1),c,p,0,2952,2966,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(t.v(t.d("i18n.unset",c,p,0)));});c.pop();}if(!t.s(t.d("alarm.set",c,p,1),c,p,1,0,0,"")){t.b(t.v(t.d("i18n.set",c,p,0)));};t.b("</button> </div> </div> <div class=\"alert alarm\"> <h3 class=\"type\">");t.b(t.v(t.d("i18n.alarm",c,p,0)));t.b("</h3> <h4 class=\"time\"></h4> <div class=\"btn-container\"> <button type=\"button\" class=\"material flat dismiss\">");t.b(t.v(t.d("i18n.dismiss",c,p,0)));t.b("</button> </div> </div> <div class=\"section clock tab-active\">");t.b(t.t(t.f("html",c,p,0)));t.b("</div> <div class=\"section timer ");if(t.s(t.d("timer.duration",c,p,1),c,p,0,3350,3357,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("running");});c.pop();}t.b("\"> <div class=\"time\">");t.b(t.v(t.d("timer.html",c,p,0)));t.b("</div> <input type=\"text\" class=\"time\" placeholder=\"0:00:00\" /> <div class=\"controls\"> <button type=\"button\" class=\"material toggle reset\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"> <path d=\"M12 5V1L7 6l5 5V7c3.31 0 6 2.69 6 6s-2.69 6-6 6-6-2.69-6-6H4c0 4.42 3.58 8 8 8s8-3.58 8-8-3.58-8-8-8z\"/> </svg> </button> <label class=\"audio\"> <input type=\"checkbox\" ");if(t.s(t.f("audio",c,p,1),c,p,0,3798,3805,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("checked");});c.pop();}t.b(" /> ");t.b(t.v(t.d("i18n.enable_audio",c,p,0)));t.b(" </label> <button type=\"button\" class=\"material fab blue start-stop ");if(t.s(t.d("timer.running",c,p,1),c,p,0,3926,3933,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("started");});c.pop();}t.b("\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 48 48\"> <path class=\"start\" d=\"M16 10v28l22-14z\"/> <path class=\"stop\" d=\"M12 12h24v24H12z\"/> </svg> </button> </div> </div> <div class=\"alert timer\"> <h3 class=\"type\">");t.b(t.v(t.d("i18n.timer",c,p,0)));t.b("</h3> <h4 class=\"time\"></h4> <div class=\"btn-container\"> <button type=\"button\" class=\"material flat dismiss\">");t.b(t.v(t.d("i18n.dismiss",c,p,0)));t.b("</button> </div> </div> <div class=\"section stopwatch\"> <div class=\"time\">");t.b(t.v(t.d("stopwatch.html",c,p,0)));if(!t.s(t.d("stopwatch.html",c,p,1),c,p,1,0,0,"")){t.b("0:00");};t.b("</div> <div class=\"controls\"> <button type=\"button\" class=\"material toggle reset\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"> <path d=\"M12 5V1L7 6l5 5V7c3.31 0 6 2.69 6 6s-2.69 6-6 6-6-2.69-6-6H4c0 4.42 3.58 8 8 8s8-3.58 8-8-3.58-8-8-8z\"/> </svg> </button> <button type=\"button\" class=\"material fab blue start-stop ");if(t.s(t.d("stopwatch.running",c,p,1),c,p,0,4802,4809,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("started");});c.pop();}t.b("\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 48 48\"> <path class=\"start\" d=\"M16 10v28l22-14z\"/> <path class=\"stop\" d=\"M12 12h24v24H12z\"/> </svg> </button> </div> </div> ");});c.pop();}t.b(" ");if(!t.s(t.f("small",c,p,1),c,p,1,0,0,"")){t.b(" ");if(t.s(t.f("title",c,p,1),c,p,0,5043,5076,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<h2 class=\"header\">");t.b(t.v(t.f("title",c,p,0)));t.b("</h2>");});c.pop();}t.b(" <div class=\"clock\">");t.b(t.t(t.f("html",c,p,0)));t.b("</div> ");};t.b(" ");};return t.fl(); },partials: {}, subs: {  }}),"widgets.directions.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Use this widget to instantly get directions to and from nearly anywhere, right from your homepage.");return t.fl(); },partials: {}, subs: {  }}),"widgets.directions": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<div class=\"methods\"> <button type=\"button\" class=\"material flat driving ");t.b(t.v(t.f("method_driving",c,p,0)));t.b("\" data-method=\"driving\" title=\"");t.b(t.v(t.d("i18n.driving",c,p,0)));t.b("\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"> <path d=\"M18.92 6.01C18.72 5.42 18.16 5 17.5 5h-11c-.66 0-1.21.42-1.42 1.01L3 12v8c0 .55.45 1 1 1h1c.55 0 1-.45 1-1v-1h12v1c0 .55.45 1 1 1h1c.55 0 1-.45 1-1v-8l-2.08-5.99zM6.5 16c-.83 0-1.5-.67-1.5-1.5S5.67 13 6.5 13s1.5.67 1.5 1.5S7.33 16 6.5 16zm11 0c-.83 0-1.5-.67-1.5-1.5s.67-1.5 1.5-1.5 1.5.67 1.5 1.5-.67 1.5-1.5 1.5zM5 11l1.5-4.5h11L19 11H5z\"/> </svg> </button> <button type=\"button\" class=\"material flat transit ");t.b(t.v(t.f("method_transit",c,p,0)));t.b("\" data-method=\"transit\" title=\"");t.b(t.v(t.d("i18n.transit",c,p,0)));t.b("\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"> <path d=\"M4 16c0 .88.39 1.67 1 2.22V20c0 .55.45 1 1 1h1c.55 0 1-.45 1-1v-1h8v1c0 .55.45 1 1 1h1c.55 0 1-.45 1-1v-1.78c.61-.55 1-1.34 1-2.22V6c0-3.5-3.58-4-8-4s-8 .5-8 4v10zm3.5 1c-.83 0-1.5-.67-1.5-1.5S6.67 14 7.5 14s1.5.67 1.5 1.5S8.33 17 7.5 17zm9 0c-.83 0-1.5-.67-1.5-1.5s.67-1.5 1.5-1.5 1.5.67 1.5 1.5-.67 1.5-1.5 1.5zm1.5-6H6V6h12v5z\"/> </svg> </button> <button type=\"button\" class=\"material flat walking ");t.b(t.v(t.f("method_walking",c,p,0)));t.b("\" data-method=\"walking\" title=\"");t.b(t.v(t.d("i18n.walking",c,p,0)));t.b("\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"> <path d=\"M13.5 5.5c1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2 .9 2 2 2zM9.8 8.9L7 23h2.1l1.8-8 2.1 2v6h2v-7.5l-2.1-2 .6-3C14.8 12 16.8 13 19 13v-2c-1.9 0-3.5-1-4.3-2.4l-1-1.6c-.4-.6-1-1-1.7-1-.3 0-.5.1-.8.1L6 8.3V13h2V9.6l1.8-.7\"/> </svg> </button> <button type=\"button\" class=\"material flat bicycling ");t.b(t.v(t.f("method_bicycling",c,p,0)));t.b("\" data-method=\"bicycling\" title=\"");t.b(t.v(t.d("i18n.cycling",c,p,0)));t.b("\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"> <path d=\"M15.5 5.5c1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2 .9 2 2 2zM5 12c-2.8 0-5 2.2-5 5s2.2 5 5 5 5-2.2 5-5-2.2-5-5-5zm0 8.5c-1.9 0-3.5-1.6-3.5-3.5s1.6-3.5 3.5-3.5 3.5 1.6 3.5 3.5-1.6 3.5-3.5 3.5zm5.8-10l2.4-2.4.8.8c1.3 1.3 3 2.1 5.1 2.1V9c-1.5 0-2.7-.6-3.6-1.5l-1.9-1.9c-.5-.4-1-.6-1.6-.6s-1.1.2-1.4.6L7.8 8.4c-.4.4-.6.9-.6 1.4 0 .6.2 1.1.6 1.4L11 14v5h2v-6.2l-2.2-2.3zM19 12c-2.8 0-5 2.2-5 5s2.2 5 5 5 5-2.2 5-5-2.2-5-5-5zm0 8.5c-1.9 0-3.5-1.6-3.5-3.5s1.6-3.5 3.5-3.5 3.5 1.6 3.5 3.5-1.6 3.5-3.5 3.5z\"/> </svg> </button> </div> <input type=\"text\" class=\"from\" placeholder=\"");t.b(t.v(t.d("i18n.from",c,p,0)));t.b("\" value=\"");t.b(t.v(t.f("from",c,p,0)));t.b("\" /> <input type=\"text\" class=\"to\" placeholder=\"");t.b(t.v(t.d("i18n.to",c,p,0)));t.b("\" value=\"");t.b(t.v(t.f("to",c,p,0)));t.b("\" /> <div class=\"notice loading\"> <p>");t.b(t.v(t.d("i18n.loading",c,p,0)));t.b("</p> </div> <div class=\"notice error\"> <p>");t.b(t.v(t.d("i18n.error",c,p,0)));t.b("</p> <p>");t.b(t.v(t.d("i18n.error2",c,p,0)));t.b("</p> </div> ");if(t.s(t.f("map",c,p,1),c,p,0,2544,2658,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <a href=\"");t.b(t.v(t.f("mapsLink",c,p,0)));t.b("\" title=\"");t.b(t.v(t.d("i18n.open_in_maps",c,p,0)));t.b("\" class=\"map-wrapper\"> <img src=\"");t.b(t.v(t.f("map",c,p,0)));t.b("\" class=\"map\" /> </a> ");});c.pop();}t.b(" <div class=\"results\"> ");if(t.s(t.f("routes",c,p,1),c,p,0,2700,3330,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"route\"> <div class=\"summary\"> <span class=\"time\">");t.b(t.v(t.f("time",c,p,0)));t.b("</span> (");t.b(t.v(t.f("distance",c,p,0)));t.b(") ");t.b(t.v(t.d("i18n.via",c,p,0)));t.b(" ");t.b(t.v(t.f("summary",c,p,0)));t.b(" <a href=\"");t.b(t.v(t.f("mapsLink",c,p,0)));t.b("\" title=\"");t.b(t.v(t.d("i18n.open_in_maps",c,p,0)));t.b("\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"> <path d=\"M19 19H5V5h7V3H5c-1.11 0-2 .9-2 2v14c0 1.1.89 2 2 2h14c1.1 0 2-.9 2-2v-7h-2v7zM14 3v2h3.59l-9.83 9.83 1.41 1.41L19 6.41V10h2V3h-7z\" /> </svg> </a> </div> <ul class=\"steps\"> ");if(t.s(t.f("steps",c,p,1),c,p,0,3125,3231,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <li> <span class=\"description\">");t.b(t.t(t.f("description",c,p,0)));t.b("</span> <span class=\"distance\">");t.b(t.v(t.f("distance",c,p,0)));t.b("</span> </li> ");});c.pop();}t.b(" ");if(t.s(t.f("copyrights",c,p,1),c,p,0,3257,3301,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <li class=\"copyrights\">");t.b(t.v(t.f("copyrights",c,p,0)));t.b("</li> ");});c.pop();}t.b(" </ul> </div> ");});c.pop();}t.b(" </div>");return t.fl(); },partials: {}, subs: {  }}),"widgets/error": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<div class=\"splash\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"> <path d=\"M11 15h2v2h-2zm0-8h2v6h-2zm.99-5C6.47 2 2 6.48 2 12s4.47 10 9.99 10C17.52 22 22 17.52 22 12S17.52 2 11.99 2zM12 20c-4.42 0-8-3.58-8-8s3.58-8 8-8 8 3.58 8 8-3.58 8-8 8z\"></path> </svg> </div> <div class=\"notice\"> <p>");t.b(t.v(t.f("explanation",c,p,0)));if(!t.s(t.f("explanation",c,p,1),c,p,1,0,0,"")){t.b(t.v(t.d("i18n.widgets.error.explanation",c,p,0)));};t.b("</p> <p>");t.b(t.v(t.f("advice",c,p,0)));if(!t.s(t.f("advice",c,p,1),c,p,1,0,0,"")){t.b(t.v(t.d("i18n.widgets.error.advice",c,p,0)));};t.b("</p> <footer> <button type=\"button\" class=\"button material flat support\">");t.b(t.v(t.d("i18n.widgets.error.support",c,p,0)));t.b("</button> <button type=\"button\" class=\"button material flat blue refresh\">");t.b(t.v(t.d("i18n.widgets.error.refresh",c,p,0)));t.b("</button> </footer> </div>");return t.fl(); },partials: {}, subs: {  }}),"widgets.facebook.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("This widget displays your Facebook home feed.<br /> <br /> Please note that since this widget loads a third-party site, it won't be available offline and could cause ProductivityTab to load slowly.");return t.fl(); },partials: {}, subs: {  }}),"widgets.facebook": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<iframe src=\"https://m.facebook.com/\" style=\"height:");t.b(t.v(t.f("height",c,p,0)));t.b("px\" seamless>For some strange reason it seems your browser doesn't support iFrames!</iframe>");return t.fl(); },partials: {}, subs: {  }}),"widgets.feedly.articles": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("articles",c,p,1),c,p,0,13,598,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <a class=\"item");if(!t.s(t.f("unread",c,p,1),c,p,1,0,0,"")){t.b(" read");};t.b("\" href=\"");t.b(t.v(t.f("link",c,p,0)));t.b("\" data-id=\"");t.b(t.v(t.f("id",c,p,0)));t.b("\"> ");if(t.s(t.f("image",c,p,1),c,p,0,101,194,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div class=\"img\" style=\"background-image: url('");t.b(t.v(t.f("image",c,p,0)));t.b("');\"><img src=\"/icon/16.png\" /></div>");});c.pop();}t.b(" <div class=\"content\"> <span class=\"title\" title=\"");t.b(t.v(t.f("title",c,p,0)));t.b("\">");t.b(t.v(t.f("title",c,p,0)));t.b("</span> <div class=\"desc\">");t.b(t.v(t.f("excerpt",c,p,0)));t.b(" ...</div> </div> <div class=\"specs\"> ");if(t.s(t.f("author",c,p,1),c,p,0,360,414,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span class=\"author\">");t.b(t.v(t.d("i18n.author",c,p,0)));t.b(" ");t.b(t.v(t.f("author",c,p,0)));t.b("</span>");});c.pop();}t.b(" <span class=\"recommendations\">");t.b(t.v(t.f("recommendations",c,p,0)));t.b("</span> <span class=\"source\">&nbsp;&nbsp;");t.b(t.v(t.f("source",c,p,0)));t.b("&nbsp;&nbsp;/&nbsp;</span> <span class=\"age\">");t.b(t.v(t.f("age",c,p,0)));t.b("</span> </div> </a> ");});c.pop();}return t.fl(); },partials: {}, subs: {  }}),"widgets.feedly.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("This widget displays a list of articles from any category or feed in your Feedly account, with images.<br /> <br /> Go into the settings after installation to choose a display format and set other preferences.");return t.fl(); },partials: {}, subs: {  }}),"widgets.feedly": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("title",c,p,1),c,p,0,10,43,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<h2 class=\"header\">");t.b(t.v(t.f("title",c,p,0)));t.b("</h2>");});c.pop();}t.b(" <div class=\"items ");t.b(t.v(t.f("class",c,p,0)));t.b("\" tabindex=\"-1\"> ");if(t.s(t.f("column2",c,p,1),c,p,0,110,196,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"column\"> ");t.b(t.t(t.f("articles",c,p,0)));t.b(" </div> <div class=\"column\"> ");t.b(t.t(t.f("column2",c,p,0)));t.b(" </div> ");});c.pop();}t.b(" ");if(!t.s(t.f("column2",c,p,1),c,p,1,0,0,"")){t.b(" ");t.b(t.t(t.f("articles",c,p,0)));t.b(" ");};t.b(" </div> ");if(t.s(t.f("link",c,p,1),c,p,0,266,338,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<a class=\"more\" href=\"https://www.feedly.com/\">");t.b(t.v(t.d("i18n.go_to_feedly",c,p,0)));t.b("</a>");});c.pop();}return t.fl(); },partials: {}, subs: {  }}),"widgets.html.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("This widget lets you display completely custom HTML.<br /> <br /> <b>Please note that if this widget is used incorrectly, it can make it impossible to access your homepage.  Only install use this widget if you know what you're doing.</b>");return t.fl(); },partials: {}, subs: {  }}),"widgets.html": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<span class=\"replace\"></span>");return t.fl(); },partials: {}, subs: {  }}),"widgets.linkedin.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Use this widget to keep up to date on changes in your LinkedIn.<br /> <br /> Please note that since this widget loads a third-party site, it won't be available offline and could cause ProductivityTab to load slowly.");return t.fl(); },partials: {}, subs: {  }}),"widgets.linkedin": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<iframe src=\"https://www.linkedin.com/\" style=\"height:");t.b(t.v(t.f("height",c,p,0)));t.b("px\" seamless>For some strange reason it seems your browser doesn't support iFrames!</iframe>");return t.fl(); },partials: {}, subs: {  }}),"widgets.notes.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("This widget contains a rich text sticky note.<br /> <br /> You can pick a color, font face, or font size in the settings.");return t.fl(); },partials: {}, subs: {  }}),"widgets.notes": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<style type=\"text/css\"> .note .content, .note .content * { ");if(t.s(t.f("size",c,p,1),c,p,0,68,100,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("font-size: ");t.b(t.v(t.f("size",c,p,0)));t.b("px!important;");});c.pop();}t.b(" ");if(t.s(t.f("face",c,p,1),c,p,0,119,151,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("font-family: ");t.b(t.v(t.f("face",c,p,0)));t.b("!important;");});c.pop();}t.b(" } </style> <div class=\"note ");t.b(t.v(t.f("color",c,p,0)));t.b("\"> <input type=\"text\" class=\"header\" maxlength=\"255\" value=\"");t.b(t.v(t.f("title",c,p,0)));t.b("\" /> <div class=\"content\" contenteditable>");t.b(t.t(t.f("content",c,p,0)));t.b("</div> </div>");return t.fl(); },partials: {}, subs: {  }}),"widgets.notifications.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("This widget displays your Google notifications, as shown on Google+ and Gmail.<br /> <br /> Please note that since this widget loads a third-party site, it won't be available offline and could cause ProductivityTab to load slowly.");return t.fl(); },partials: {}, subs: {  }}),"widgets.notifications": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<iframe src=\"https://www.google.com/ichrome/notifications#");t.b(t.v(t.f("config",c,p,0)));t.b("\" style=\"height: inherit\" sandbox=\"allow-same-origin allow-popups allow-forms allow-scripts\" seamless>For some strange reason it seems your browser doesn't support iFrames!</iframe>");return t.fl(); },partials: {}, subs: {  }}),"widgets.now.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("This widget displays cards from your Google Now.<br /> <br /> After installation, you'll need to grant it access to your account by clicking the Authorize button.");return t.fl(); },partials: {}, subs: {  }}),"widgets.now": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<div class=\"cards\"> ");if(t.s(t.f("cards",c,p,1),c,p,0,30,736,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" ");if(t.s(t.f("link",c,p,1),c,p,0,40,120,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <a class=\"card");if(t.s(t.f("btns",c,p,1),c,p,0,64,69,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" btns");});c.pop();}t.b("\" data-index=\"");t.b(t.v(t.f("index",c,p,0)));t.b("\" href=\"");t.b(t.v(t.f("link",c,p,0)));t.b("\"> ");});c.pop();}t.b(" ");if(!t.s(t.f("link",c,p,1),c,p,1,0,0,"")){t.b(" <div class=\"card");if(t.s(t.f("btns",c,p,1),c,p,0,165,170,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" btns");});c.pop();}t.b("\" data-index=\"");t.b(t.v(t.f("index",c,p,0)));t.b("\"> ");};t.b(" <div class=\"dismiss\">&#xE678;</div> ");if(t.s(t.f("icon",c,p,1),c,p,0,260,327,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div class=\"icon\" style=\"background-image: url('");t.b(t.v(t.f("icon",c,p,0)));t.b("');\"></div>");});c.pop();}t.b(" ");if(t.s(t.f("title",c,p,1),c,p,0,347,365,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<h2>");t.b(t.v(t.f("title",c,p,0)));t.b("</h2>");});c.pop();}t.b(" ");if(t.s(t.f("desc",c,p,1),c,p,0,385,413,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<p class=\"desc\">");t.b(t.v(t.f("desc",c,p,0)));t.b("</p>");});c.pop();}t.b(" ");if(t.s(t.f("image",c,p,1),c,p,0,433,501,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div class=\"image\" style=\"background-image: url('");t.b(t.v(t.f("image",c,p,0)));t.b("')\"></div>");});c.pop();}t.b(" ");if(!t.s(t.f("link",c,p,1),c,p,1,0,0,"")){t.b(" </div> ");};t.b(" ");if(t.s(t.f("link",c,p,1),c,p,0,548,554,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" </a> ");});c.pop();}t.b(" ");if(t.s(t.f("btns",c,p,1),c,p,0,573,726,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"buttons\"> ");if(t.s(t.f("buttons",c,p,1),c,p,0,608,706,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <a href=\"");t.b(t.v(t.f("link",c,p,0)));t.b("\" class=\"button\">");if(t.s(t.f("btnIcon",c,p,1),c,p,0,655,680,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<img src=\"");t.b(t.v(t.f("btnIcon",c,p,0)));t.b("\" />");});c.pop();}t.b(t.v(t.f("title",c,p,0)));t.b("</a> ");});c.pop();}t.b(" </div> ");});c.pop();}t.b(" ");});c.pop();}t.b(" ");if(!t.s(t.f("cards",c,p,1),c,p,1,0,0,"")){t.b(" ");if(t.s(t.f("authorize",c,p,1),c,p,0,772,922,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"card authorize\"> <h2>");t.b(t.v(t.d("i18n.authorize",c,p,0)));t.b("</h2> <button type=\"button\" class=\"btn btn-lg btn-primary\">");t.b(t.v(t.d("i18n.authorize_btn",c,p,0)));t.b("</button> </div> ");});c.pop();}t.b(" ");if(!t.s(t.f("authorize",c,p,1),c,p,1,0,0,"")){t.b(" <div class=\"card no-cards\"> <h2>");t.b(t.v(t.d("i18n.caught_up",c,p,0)));t.b("</h2> </div> ");};t.b(" ");};t.b(" </div>");return t.fl(); },partials: {}, subs: {  }}),"widgets/permissions-request": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<div class=\"splash\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"> <path d=\"M12 1L3 5v6c0 5.55 3.84 10.74 9 12 5.16-1.26 9-6.45 9-12V5l-9-4zm0 10.99h7c-.53 4.12-3.28 7.79-7 8.94V12H5V6.3l7-3.11v8.8z\"></path> </svg> </div> <div class=\"notice\"> <h2>");t.b(t.v(t.d("i18n.widgets.permissions_request.title",c,p,0)));t.b("</h2> <p>");t.b(t.v(t.d("i18n.widgets.permissions_request.desc",c,p,0)));t.b("</p> <footer> <button type=\"button\" class=\"button material flat blue\">");t.b(t.v(t.d("i18n.widgets.permissions_request.button",c,p,0)));t.b("</button> </footer> </div>");return t.fl(); },partials: {}, subs: {  }}),"widgets.plus.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("This widget displays your Google+ home stream.<br /> <br /> Please note that since this widget loads a third-party site, it won't be available offline and could cause ProductivityTab to load slowly.");return t.fl(); },partials: {}, subs: {  }}),"widgets.plus": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<iframe src=\"https://plus.google.com/app/basic#cardscontainer\" style=\"height:");t.b(t.v(t.f("height",c,p,0)));t.b("px\" sandbox=\"allow-same-origin allow-popups allow-forms allow-scripts\" seamless>For some strange reason it seems your browser doesn't support iFrames!</iframe>");return t.fl(); },partials: {}, subs: {  }}),"widgets.pocket.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");return t.fl(); },partials: {}, subs: {  }}),"widgets.pocket": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<header> <a href=\"https://www.getpocket.com/\">Pocket</a> </header> <div class=\"links\"> ");if(t.s(t.f("links",c,p,1),c,p,0,97,458,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <a class=\"link\" href=\"");t.b(t.v(t.f("url",c,p,0)));t.b("\"> <div class=\"image\" ");if(t.s(t.f("image",c,p,1),c,p,0,159,201,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("style=\"background-image: url('");t.b(t.v(t.f("image",c,p,0)));t.b("')\"");});c.pop();}t.b("></div> <div class=\"info\"> <h3 class=\"title\">");t.b(t.v(t.f("title",c,p,0)));t.b("</h3> <div class=\"details\"> ");if(t.s(t.f("author",c,p,1),c,p,0,304,356,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(t.v(t.d("i18n.by",c,p,0)));t.b(" <span class=\"author\">");t.b(t.v(t.f("author",c,p,0)));t.b("</span>, ");});c.pop();}t.b("<span class=\"site\">");t.b(t.v(t.f("domain",c,p,0)));t.b("</span> <span class=\"date\">");t.b(t.v(t.f("date",c,p,0)));t.b("</span> </div> </div> </a> ");});c.pop();}t.b(" </div> ");if(!t.s(t.f("links",c,p,1),c,p,1,0,0,"")){t.b(" ");if(t.s(t.f("noKey",c,p,1),c,p,0,497,1092,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"notice no-key\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 48 48\"> <path d=\"M38.71 20.07C37.35 13.19 31.28 8 24 8c-2.95 0-5.7.87-8.02 2.34l2.92 2.92C20.43 12.47 22.16 12 24 12c6.08 0 11 4.92 11 11v1h3c3.31 0 6 2.69 6 6 0 2.27-1.27 4.22-3.13 5.24l2.9 2.9C46.32 36.33 48 33.37 48 30c0-5.28-4.11-9.56-9.29-9.93zM6 10.55l5.5 5.48C5.12 16.3 0 21.55 0 28c0 6.63 5.37 12 12 12h23.45l4 4L42 41.46 8.55 8 6 10.55zM15.45 20l16 16H12c-4.42 0-8-3.58-8-8s3.58-8 8-8h3.45z\" /> </svg> <p>");t.b(t.v(t.d("i18n.no_key",c,p,0)));t.b("</p> <button type=\"button\" class=\"button material\">");t.b(t.v(t.d("i18n.grant_access",c,p,0)));t.b("</a> </div> ");});c.pop();}t.b(" ");if(!t.s(t.f("noKey",c,p,1),c,p,1,0,0,"")){t.b(" <div class=\"notice no-links\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 48 48\"> <path d=\"M37.98 10c0-2.21-1.77-4-3.98-4H20l-4.68 4.68L38 33.36 37.98 10zM7.3 7.76L4.76 10.3 10 15.55V38c0 2.21 1.79 4 4 4h20.02c.7 0 1.35-.2 1.92-.51l3.76 3.76 2.54-2.55L7.3 7.76z\" /> </svg> <p>");t.b(t.v(t.d("i18n.no_links",c,p,0)));t.b("</p> </div> ");};t.b(" ");};return t.fl(); },partials: {}, subs: {  }}),"widgets.pushbullet.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Use this widget to keep an eye on notifications and text message on your phone and other devices.");return t.fl(); },partials: {}, subs: {  }}),"widgets.pushbullet": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<header> <a href=\"https://www.pushbullet.com/\">Pushbullet</a> </header> ");if(t.s(t.f("hasPushes",c,p,1),c,p,0,86,887,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"items\"> ");if(t.s(t.f("pushes",c,p,1),c,p,0,118,868,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" ");if(t.s(t.f("link",c,p,1),c,p,0,128,176,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<a target=\"_blank\" href=\"");t.b(t.v(t.f("link",c,p,0)));t.b("\" class=\"item\">");});c.pop();}t.b(" ");if(!t.s(t.f("link",c,p,1),c,p,1,0,0,"")){t.b("<div class=\"item\">");};t.b(" <div class=\"thumb\" style=\"background-image: url(");t.b(t.v(t.d("sender.thumb",c,p,0)));t.b(");\"></div> ");if(t.s(t.f("sender",c,p,1),c,p,0,309,353,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <span class=\"title sender\">");t.b(t.v(t.f("name",c,p,0)));t.b("</span> ");});c.pop();}t.b(" ");if(t.s(t.f("date",c,p,1),c,p,0,374,410,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <span class=\"date\">");t.b(t.v(t.f("date",c,p,0)));t.b("</span> ");});c.pop();}t.b(" ");if(t.s(t.f("body",c,p,1),c,p,0,429,524,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <p class=\"body\">");if(t.s(t.f("title",c,p,1),c,p,0,456,501,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span class=\"title\">");t.b(t.v(t.f("title",c,p,0)));t.b("</span> &mdash; ");});c.pop();}t.b(t.v(t.f("body",c,p,0)));t.b("</p> ");});c.pop();}t.b(" ");if(!t.s(t.f("body",c,p,1),c,p,1,0,0,"")){t.b(" ");if(t.s(t.f("title",c,p,1),c,p,0,554,620,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<p class=\"body title\" title=\"");t.b(t.v(t.f("title",c,p,0)));t.b("\"><span>");t.b(t.v(t.f("title",c,p,0)));t.b("</span></p>");});c.pop();}t.b(" ");};t.b(" ");if(t.s(t.f("linkText",c,p,1),c,p,0,654,716,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <span class=\"body link\" title=\"");t.b(t.v(t.f("link",c,p,0)));t.b("\">");t.b(t.v(t.f("linkText",c,p,0)));t.b("</span> ");});c.pop();}t.b(" ");if(t.s(t.f("image",c,p,1),c,p,0,740,809,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"image\" style=\"background-image: url(");t.b(t.v(t.f("image",c,p,0)));t.b(");\"></div> ");});c.pop();}t.b(" ");if(t.s(t.f("link",c,p,1),c,p,0,829,833,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("</a>");});c.pop();}t.b(" ");if(!t.s(t.f("link",c,p,1),c,p,1,0,0,"")){t.b("</div>");};t.b(" ");});c.pop();}t.b(" </div> ");});c.pop();}t.b(" ");if(!t.s(t.f("hasPushes",c,p,1),c,p,1,0,0,"")){t.b(" ");if(t.s(t.f("noKey",c,p,1),c,p,0,927,1523,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"notice no-key\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 48 48\"> <path d=\"M38.71 20.07C37.35 13.19 31.28 8 24 8c-2.95 0-5.7.87-8.02 2.34l2.92 2.92C20.43 12.47 22.16 12 24 12c6.08 0 11 4.92 11 11v1h3c3.31 0 6 2.69 6 6 0 2.27-1.27 4.22-3.13 5.24l2.9 2.9C46.32 36.33 48 33.37 48 30c0-5.28-4.11-9.56-9.29-9.93zM6 10.55l5.5 5.48C5.12 16.3 0 21.55 0 28c0 6.63 5.37 12 12 12h23.45l4 4L42 41.46 8.55 8 6 10.55zM15.45 20l16 16H12c-4.42 0-8-3.58-8-8s3.58-8 8-8h3.45z\" /> </svg> <p>");t.b(t.v(t.d("i18n.no_key",c,p,0)));t.b("</p> <button type=\"button\" class=\"button material green\">");t.b(t.v(t.d("i18n.sign_in",c,p,0)));t.b("</a> </div> ");});c.pop();}t.b(" ");if(!t.s(t.f("noKey",c,p,1),c,p,1,0,0,"")){t.b(" <div class=\"notice no-pushes\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 48 48\"> <path d=\"M23 44c2.21 0 4-1.79 4-4h-8c0 2.21 1.79 4 4 4zm13-12V21c0-6.15-4.27-11.28-10-12.64V7c0-1.66-1.34-3-3-3s-3 1.34-3 3v1.36C14.27 9.72 10 14.85 10 21v11l-4 4v2h34v-2l-4-4zm-4 2H14V21c0-4.97 4.03-9 9-9s9 4.03 9 9v13z\" /> </svg> <p>");t.b(t.v(t.d("i18n.no_pushes",c,p,0)));t.b("</p> </div> ");};t.b(" ");};return t.fl(); },partials: {}, subs: {  }}),"widgets.quotes.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Use this widget to keep inspired with quotes picked every time you load the page or once daily.");return t.fl(); },partials: {}, subs: {  }}),"widgets.quotes": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("title",c,p,1),c,p,0,10,43,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<h2 class=\"header\">");t.b(t.v(t.f("title",c,p,0)));t.b("</h2>");});c.pop();}t.b(" <blockquote> ");if(t.s(t.f("link",c,p,1),c,p,0,76,95,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<a href=\"");t.b(t.v(t.f("link",c,p,0)));t.b("\">");});c.pop();}t.b(" <p ");if(t.s(t.f("noquotes",c,p,1),c,p,0,121,138,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("class=\"no-quotes\"");});c.pop();}t.b(">");t.b(t.v(t.f("body",c,p,0)));t.b("</p> <footer class=\"clearfix\"> <span class=\"refresh\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"> <path d=\"M17.65 6.35C16.2 4.9 14.21 4 12 4c-4.42 0-7.99 3.58-7.99 8s3.57 8 7.99 8c3.73 0 6.84-2.55 7.73-6h-2.08c-.82 2.33-3.04 4-5.65 4-3.31 0-6-2.69-6-6s2.69-6 6-6c1.66 0 3.14.69 4.22 1.78L13 11h7V4l-2.35 2.35z\"/> </svg> </span> <span class=\"tweet\"></span> ");if(t.s(t.f("source",c,p,1),c,p,0,544,575,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<cite>&mdash; ");t.b(t.v(t.f("source",c,p,0)));t.b("</cite>");});c.pop();}t.b(" </footer> ");if(t.s(t.f("link",c,p,1),c,p,0,606,610,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("</a>");});c.pop();}t.b(" </blockquote>");return t.fl(); },partials: {}, subs: {  }}),"widgets.reddit.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Use this widget to keep up with one of your subreddits.  After installation, enter the subreddit name in the settings.");return t.fl(); },partials: {}, subs: {  }}),"widgets.reddit": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("title",c,p,1),c,p,0,10,43,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<h2 class=\"header\">");t.b(t.v(t.f("title",c,p,0)));t.b("</h2>");});c.pop();}t.b(" <div class=\"items\"> ");if(t.s(t.f("links",c,p,1),c,p,0,84,1036,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <a class=\"item\" href=\"");t.b(t.v(t.f("link",c,p,0)));t.b("\"> ");if(t.s(t.f("image",c,p,1),c,p,0,128,195,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div class=\"img\" style=\"background-image: url('");t.b(t.v(t.f("image",c,p,0)));t.b("');\"></div>");});c.pop();}t.b(" <div class=\"content\"> <span class=\"title\">");t.b(t.v(t.f("title",c,p,0)));t.b("&nbsp;&#8203;<span class=\"nested-link domain\" data-href=\"http://www.reddit.com/domain/");t.b(t.v(t.f("domain",c,p,0)));t.b("\">");t.b(t.v(t.f("domain",c,p,0)));t.b("</span></span> <div class=\"specs\"> <span class=\"score");t.b(t.v(t.f("direction",c,p,0)));t.b("\" data-m-icon-before=\"arrow_upward\">");t.b(t.v(t.f("score",c,p,0)));t.b("</span> <span class=\"posted\" data-m-icon-before=\"access_time\">");t.b(t.v(t.f("created",c,p,0)));t.b("</span> <span class=\"comments nested-link\" data-href=\"http://www.reddit.com");t.b(t.v(t.f("permalink",c,p,0)));t.b("\" data-m-icon-before=\"comment\">");t.b(t.v(t.f("comments",c,p,0)));t.b("</span> ");if(t.s(t.f("subreddit",c,p,1),c,p,0,702,862,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span class=\"subreddit nested-link\" data-href=\"http://www.reddit.com/r/");t.b(t.v(t.f("subreddit",c,p,0)));t.b("\" title=\"");t.b(t.v(t.f("subreddit",c,p,0)));t.b("\" data-m-icon-before=\"group_work\">");t.b(t.v(t.f("subreddit",c,p,0)));t.b("</span>");});c.pop();}t.b(" <span class=\"user nested-link\" data-href=\"http://www.reddit.com/user/");t.b(t.v(t.f("user",c,p,0)));t.b("\" title=\"");t.b(t.v(t.f("user",c,p,0)));t.b("\" data-m-icon-before=\"person\">");t.b(t.v(t.f("user",c,p,0)));t.b("</span> </div> </div> </a> ");});c.pop();}t.b(" </div> <a class=\"more\" href=\"");t.b(t.v(t.f("link",c,p,0)));t.b("\">");t.b(t.v(t.d("i18n.more",c,p,0)));t.b("</a>");return t.fl(); },partials: {}, subs: {  }}),"widgets.search.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");return t.fl(); },partials: {}, subs: {  }}),"widgets.search": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<form action=\"");t.b(t.v(t.f("url",c,p,0)));t.b("\"> <input type=\"text\" name=\"");t.b(t.v(t.f("param",c,p,0)));t.b("\" class=\"searchbox\" placeholder=\"");t.b(t.v(t.f("placeholder",c,p,0)));t.b("\" /> ");if(t.s(t.f("small",c,p,1),c,p,0,121,175,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <button class=\"material blue submit\">Search</button> ");});c.pop();}t.b(" </form>");return t.fl(); },partials: {}, subs: {  }}),"widgets.sitelink.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Use this widget to display a link on your page.<br /> <br /> After installation, you can choose an image and title in the settings.  You can use this widget to create a speed-dial like page.");return t.fl(); },partials: {}, subs: {  }}),"widgets.sitelink": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<a href=\"");t.b(t.v(t.f("link",c,p,0)));t.b("\"> ");if(t.s(t.f("hasIcon",c,p,1),c,p,0,32,169,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"thumbnail ");t.b(t.v(t.f("style",c,p,0)));t.b("\" style=\"background-image: url(");t.b(t.v(t.f("image",c,p,0)));t.b("); background-color: ");t.b(t.v(t.f("color",c,p,0)));t.b(";\"> <img src=\"");t.b(t.v(t.f("image",c,p,0)));t.b("\" /> </div> ");});c.pop();}t.b(" ");if(t.s(t.f("title",c,p,1),c,p,0,192,225,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<h2 class=\"header\">");t.b(t.v(t.f("title",c,p,0)));t.b("</h2>");});c.pop();}t.b(" </a>");return t.fl(); },partials: {}, subs: {  }}),"widgets.stats.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Use this widget to keep an eye on your system with realtime statistics.");return t.fl(); },partials: {}, subs: {  }}),"widgets.stats": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<h2 class=\"header\">");t.b(t.v(t.d("i18n.name",c,p,0)));t.b("</h2> <div class=\"section cpu\"> <div class=\"label\"> <h3 class=\"title\">CPU</h3> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 48 48\" class=\"icon\"> <path d=\"M40 4.17H8c-2.21 0-4 1.79-4 4v32c0 2.21 1.79 4 4 4h32c2.21 0 4-1.79 4-4v-32c0-2.21-1.79-4-4-4zm0 36H8v-32h32v32zm-4-28H26c-2.21 0-4 1.79-4 4v4.55c-1.19.69-2 1.97-2 3.45 0 2.21 1.79 4 4 4s4-1.79 4-4c0-1.48-.81-2.75-2-3.45v-4.55h6v16H16v-16h4v-4h-8v24h24v-24z\"/> </svg> </div> <div class=\"status\"> <p class=\"name\">");t.b(t.v(t.d("cpu.name",c,p,0)));t.b("</p> <p class=\"summary\"><span class=\"usage\">");t.b(t.v(t.d("cpu.usage",c,p,0)));t.b("</span>% ");t.b(t.v(t.d("i18n.usage",c,p,0)));t.b("</p> ");if(t.s(t.d("cpu.cores",c,p,1),c,p,0,617,664,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <progress value=\"");t.b(t.v(t.d(".",c,p,0)));t.b("\" max=\"100\"></progress> ");});c.pop();}t.b(" </div> </div> <div class=\"section memory\"> <div class=\"label\"> <h3 class=\"title\">");t.b(t.v(t.d("i18n.memory",c,p,0)));t.b("</h3> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 48 48\" class=\"icon\"> <path d=\"M4 40h40v-8H4v8zm4-6h4v4H8v-4zM4 8v8h40V8H4zm8 6H8v-4h4v4zM4 28h40v-8H4v8zm4-6h4v4H8v-4z\"/> </svg> </div> <div class=\"status\"> <p class=\"summary\">");t.b(t.v(t.d("ram.usage",c,p,0)));t.b(" / ");t.b(t.v(t.d("ram.total",c,p,0)));t.b(" ");t.b(t.v(t.d("i18n.in_use",c,p,0)));t.b("</p> <progress value=\"");t.b(t.v(t.d("ram.usagePercent",c,p,0)));t.b("\" max=\"100\"></progress> </div> </div> <div class=\"section battery\"> <div class=\"label\"> <h3 class=\"title\">");t.b(t.v(t.d("i18n.battery",c,p,0)));t.b("</h3> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 48 48\" class=\"icon\"> <path d=\"M31.33 8H28V4h-8v4h-3.33C15.19 8 14 9.19 14 10.67v30.67c0 1.47 1.19 2.67 2.67 2.67h14.67c1.47 0 2.67-1.19 2.67-2.67V10.67C34 9.19 32.81 8 31.33 8z\"/> </svg> </div> <div class=\"status\"> <p class=\"summary\">");t.b(t.v(t.d("battery.status",c,p,0)));t.b(" (");t.b(t.v(t.d("battery.percent",c,p,0)));t.b("%");if(t.s(t.d("battery.remaining",c,p,1),c,p,0,1574,1616,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(", ");t.b(t.v(t.d("battery.remaining",c,p,0)));t.b(" ");t.b(t.v(t.d("i18n.remaining",c,p,0)));});c.pop();}t.b(")</p> <progress value=\"");t.b(t.v(t.d("battery.percent",c,p,0)));t.b("\" max=\"100\"></progress> </div> </div>");return t.fl(); },partials: {}, subs: {  }}),"widgets.tasks.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Keep focused by displaying your todo lists from your Google Tasks account.<br /> <br /> Click any item to edit, move, or delete it.  This widget does not save changes that are made while offline.");return t.fl(); },partials: {}, subs: {  }}),"widgets.tasks.item": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("edit",c,p,1),c,p,0,9,1064,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <input type=\"text\" class=\"title\" value=\"");t.b(t.v(t.f("title",c,p,0)));t.b("\" placeholder=\"");t.b(t.v(t.d("i18n.task_title",c,p,0)));t.b("\" /> <input type=\"text\" class=\"due-date\" value=\"");t.b(t.v(t.f("due",c,p,0)));t.b("\" placeholder=\"");t.b(t.v(t.d("i18n.due_date",c,p,0)));t.b("\" /> <textarea class=\"notes\" placeholder=\"");t.b(t.v(t.d("i18n.notes",c,p,0)));t.b("\">");t.b(t.v(t.f("notes",c,p,0)));t.b("</textarea> <button type=\"button\" class=\"btn icon delete\" title=\"");t.b(t.v(t.d("i18n.delete_task",c,p,0)));t.b("\"> <svg xmlns=\"http://www.w3.org/2000/svg\" width=\"24\" height=\"24\" viewBox=\"0 0 24 24\"> <path d=\"M6 19c0 1.1.9 2 2 2h8c1.1 0 2-.9 2-2V7H6v12zM19 4h-3.5l-1-1h-5l-1 1H5v2h14V4z\"></path> </svg> </button> <button type=\"button\" class=\"btn icon move-up\" title=\"");t.b(t.v(t.d("i18n.move_up",c,p,0)));t.b("\"> <svg xmlns=\"http://www.w3.org/2000/svg\" width=\"24\" height=\"24\" viewBox=\"0 0 24 24\"> <path d=\"M12 8l-6 6 1.41 1.41L12 10.83l4.59 4.58L18 14z\" /> </svg> </button> <button type=\"button\" class=\"btn icon move-down\" title=\"");t.b(t.v(t.d("i18n.move_down",c,p,0)));t.b("\"> <svg xmlns=\"http://www.w3.org/2000/svg\" width=\"24\" height=\"24\" viewBox=\"0 0 24 24\"> <path d=\"M16.59 8.59L12 13.17 7.41 8.59 6 10l6 6 6-6z\" /> </svg> </button> <button type=\"button\" class=\"btn done\">");t.b(t.v(t.d("i18n.done",c,p,0)));t.b("</button> ");});c.pop();}t.b(" ");if(!t.s(t.f("edit",c,p,1),c,p,1,0,0,"")){t.b(" <input type=\"checkbox\" class=\"check\"");if(t.s(t.f("done",c,p,1),c,p,0,1129,1137,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" checked");});c.pop();}t.b(" /> <span class=\"title\"> <span class=\"strikethrough\" title=\"");t.b(t.v(t.f("title",c,p,0)));t.b("\">");t.b(t.v(t.f("title",c,p,0)));t.b("</span> </span> ");if(t.s(t.f("due",c,p,1),c,p,0,1250,1515,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span class=\"due-date");if(t.s(t.f("duetoday",c,p,1),c,p,0,1284,1294,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" due-today");});c.pop();}if(t.s(t.f("overdue",c,p,1),c,p,0,1319,1327,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" overdue");});c.pop();}t.b("\" title=\"");if(t.s(t.f("duetoday",c,p,1),c,p,0,1361,1379,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(t.v(t.d("i18n.due_today",c,p,0)));});c.pop();}if(t.s(t.f("overdue",c,p,1),c,p,0,1404,1420,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(t.v(t.d("i18n.overdue",c,p,0)));});c.pop();}if(!t.s(t.f("duetoday",c,p,1),c,p,1,0,0,"")){if(!t.s(t.f("overdue",c,p,1),c,p,1,0,0,"")){t.b(t.v(t.d("i18n.due_date",c,p,0)));};};t.b("\">");t.b(t.v(t.f("due",c,p,0)));t.b("</span>");});c.pop();}t.b(" ");};return t.fl(); },partials: {}, subs: {  }}),"widgets.tasks": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<h2 class=\"header\">");t.b(t.v(t.f("title",c,p,0)));if(!t.s(t.f("authorize",c,p,1),c,p,1,0,0,"")){t.b("<button type=\"button\" class=\"btn add\">");t.b(t.v(t.d("i18n.add",c,p,0)));t.b("</button>");};t.b("</h2> <div class=\"items\"> ");if(t.s(t.f("items",c,p,1),c,p,0,151,360,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"item\" data-id=\"");t.b(t.v(t.f("id",c,p,0)));t.b("\" data-level=\"");t.b(t.v(t.f("parent",c,p,0)));t.b("\"> ");t.b(t.rp("<item0",c,p,""));t.b(" </div> ");if(t.s(t.f("children",c,p,1),c,p,0,242,346,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"item\" data-id=\"");t.b(t.v(t.f("id",c,p,0)));t.b("\" data-level=\"");t.b(t.v(t.f("parent",c,p,0)));t.b("\" style=\"margin-left: 15px\"> ");t.b(t.rp("<item1",c,p,""));t.b(" </div> ");});c.pop();}t.b(" ");});c.pop();}t.b(" ");if(!t.s(t.f("items",c,p,1),c,p,1,0,0,"")){t.b(" ");if(t.s(t.f("authorize",c,p,1),c,p,0,396,447,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"authorize\"> ");t.b(t.v(t.d("i18n.authorize",c,p,0)));t.b(" </div> ");});c.pop();}t.b(" ");};t.b(" </div>");return t.fl(); },partials: {"<item0":{name:"item", partials: {}, subs: {  }},"<item1":{name:"item", partials: {}, subs: {  }}}, subs: {  }}),"widgets.twitter.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Use this widget to keep track of what's going on on Twitter, and who's mentioned you.<br /> <br /> You'll need to grant access to your account after installation by clicking the Authorize button.");return t.fl(); },partials: {}, subs: {  }}),"widgets.twitter": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("title",c,p,1),c,p,0,10,43,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<h2 class=\"header\">");t.b(t.v(t.f("title",c,p,0)));t.b("</h2>");});c.pop();}t.b(" <div class=\"tweets\"> ");if(t.s(t.f("tweets",c,p,1),c,p,0,86,901,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"tweet nested-link\" data-href=\"https://twitter.com/");t.b(t.v(t.f("username",c,p,0)));t.b("/status/");t.b(t.v(t.f("id",c,p,0)));t.b("\"> <div class=\"topbar\"> <a href=\"https://twitter.com/");t.b(t.v(t.f("username",c,p,0)));t.b("\" class=\"user\"><b>");t.b(t.v(t.f("user",c,p,0)));t.b("</b> <span class=\"tweeter\">@");t.b(t.v(t.f("username",c,p,0)));t.b("</span></a> <span class=\"age\">");t.b(t.v(t.f("age",c,p,0)));t.b("</span> </div> <div class=\"content\"> <a href=\"https://twitter.com/");t.b(t.v(t.f("username",c,p,0)));t.b("\" class=\"user\"><img src=\"");t.b(t.v(t.f("image",c,p,0)));t.b("\" /></a> ");t.b(t.t(t.f("content",c,p,0)));t.b(" </div> <div class=\"tools\"> <a class=\"more\" href=\"https://twitter.com/");t.b(t.v(t.f("username",c,p,0)));t.b("/status/");t.b(t.v(t.f("id",c,p,0)));t.b("\">");t.b(t.v(t.d("i18n.more",c,p,0)));t.b("</a> <a class=\"reply\" href=\"https://twitter.com/intent/tweet?in_reply_to=");t.b(t.v(t.f("id",c,p,0)));t.b("\">");t.b(t.v(t.d("i18n.reply",c,p,0)));t.b("</a> <a class=\"retweet\" href=\"https://twitter.com/intent/retweet?tweet_id=");t.b(t.v(t.f("id",c,p,0)));t.b("\">");t.b(t.v(t.d("i18n.retweet",c,p,0)));t.b("</a> <a class=\"favorite\" href=\"https://twitter.com/intent/favorite?tweet_id=");t.b(t.v(t.f("id",c,p,0)));t.b("\">");t.b(t.v(t.d("i18n.favorite",c,p,0)));t.b("</a> </div> </div> ");});c.pop();}t.b(" ");if(!t.s(t.f("tweets",c,p,1),c,p,1,0,0,"")){t.b(" ");if(t.s(t.f("authorize",c,p,1),c,p,0,939,1079,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"authorize\"> ");t.b(t.v(t.d("i18n.authorize_msg",c,p,0)));t.b(" <button type=\"button\" class=\"btn btn-lg btn-primary\">");t.b(t.v(t.d("i18n.authorize_btn",c,p,0)));t.b("</button> </div> ");});c.pop();}t.b(" ");if(!t.s(t.f("authorize",c,p,1),c,p,1,0,0,"")){t.b(" <div class=\"no-tweets\"> ");t.b(t.v(t.d("i18n.no_tweets",c,p,0)));t.b(" </div> ");};t.b(" ");};t.b(" </div>");return t.fl(); },partials: {}, subs: {  }}),"widgets.wolfram.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Use this widget to display a Wolfram|Alpha search box on your page.");return t.fl(); },partials: {}, subs: {  }}),"widgets.wolfram": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<form action=\"http://www.wolframalpha.com/input/\" method=\"get\"> <img src=\"images/wolframlogo.png\" alt=\"Wolfram|Alpha logo\" /> <input type=\"text\" class=\"search\" name=\"i\" placeholder=\"Search Wolfram|Alpha...\" /> </form>");return t.fl(); },partials: {}, subs: {  }}),"widgets.youtube.desc": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Use this widget to keep track of what's popular on YouTube, or a channel's recent uploads.<br /> <br /> After installation, go into the settings to choose how you see videos.");return t.fl(); },partials: {}, subs: {  }}),"widgets.youtube": new Hogan.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("title",c,p,1),c,p,0,10,43,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<h2 class=\"header\">");t.b(t.v(t.f("title",c,p,0)));t.b("</h2>");});c.pop();}t.b(" <form class=\"searchbox\" action=\"https://www.youtube.com/results\" method=\"GET");if(t.s(t.f("newTab",c,p,1),c,p,0,141,157,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("\" target=\"_blank");});c.pop();}t.b("\"> <input type=\"text\" placeholder=\"");t.b(t.v(t.d("i18n.search",c,p,0)));t.b("\" name=\"search_query\" /> <button class=\"submit\">&#xE624;</button> </form> ");if(t.s(t.f("featured",c,p,1),c,p,0,305,584,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <a class=\"featured video\" href=\"");t.b(t.v(t.f("url",c,p,0)));t.b("\"> <div class=\"thumb\" style=\"background-image: url(");t.b(t.v(t.f("thumb",c,p,0)));t.b(");\" data-duration=\"");t.b(t.v(t.f("duration",c,p,0)));t.b("\"></div> <h2 title=\"");t.b(t.v(t.f("title",c,p,0)));t.b("\">");t.b(t.v(t.f("title",c,p,0)));t.b("</h2> <span class=\"author\">");t.b(t.v(t.f("uploader",c,p,0)));t.b("</span> <span class=\"views\">");t.b(t.v(t.f("views",c,p,0)));t.b(" ");t.b(t.v(t.d("i18n.num_views",c,p,0)));t.b("</span> </a> ");});c.pop();}t.b(" <div class=\"videos\"> ");if(t.s(t.f("videos",c,p,1),c,p,0,630,900,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <a class=\"video\" href=\"");t.b(t.v(t.f("url",c,p,0)));t.b("\"> <div class=\"thumb\" style=\"background-image: url(");t.b(t.v(t.f("thumb",c,p,0)));t.b(");\" data-duration=\"");t.b(t.v(t.f("duration",c,p,0)));t.b("\"></div> <h2 title=\"");t.b(t.v(t.f("title",c,p,0)));t.b("\">");t.b(t.v(t.f("title",c,p,0)));t.b("</h2> <span class=\"author\">");t.b(t.v(t.f("uploader",c,p,0)));t.b("</span> <span class=\"views\">");t.b(t.v(t.f("views",c,p,0)));t.b(" ");t.b(t.v(t.d("i18n.num_views",c,p,0)));t.b("</span> </a> ");});c.pop();}t.b(" </div>");return t.fl(); },partials: {}, subs: {  }}) }
	};
});
/**
 * Template renderer and cacher
 */
define('core/render',["lodash", "hogan", "core/status", "i18n/i18n", "core/templates"], function(_, Hogan, Status, Translate, templates) {
	var cache = templates.compiled || {},
		raw = templates.raw || {},
		i18n = Translate.getAll();

	var render = function(template, data, partials) {
		var compiled = render.getTemplate(template);

		if (!compiled) {
			return 'Template "' + template + '" not found!';
		}

		data = _.clone(data || {});

		if (!data.i18n) {
			data.i18n = i18n;
		}

		return compiled.render(data, partials);
	};


	/**
	 * Returns a compiled template
	 *
	 * @param   {String}  template  The name of the template to retrieve
	 */
	render.getTemplate = function(template) {
		if (!cache[template] && typeof raw[template] !== "undefined") {
			try {
				cache[template] = Hogan.compile(raw[template]);
			}
			catch (e) {
				Status.error("An error occurred while trying to render the " + template + " template!");
			}
		}

		return cache[template];
	};

	return render;
});
/**
 * This is the alert dialog view
 *
 * It follows the Material design guidelines so it only allows "boolean buttons" and basic content.
 *
 * The element is displayed immediately and destroyed once an option is chosen
 */
define('modals/alert',["jquery", "lodash", "backbone", "i18n/i18n", "core/render"], function($, _, Backbone, Translate, render) {
	var Alert = Backbone.View.extend({
		tagName: "dialog",

		events: {
			"click button": function(e) {
				var positive = e.currentTarget.getAttribute("data-action") === "positive";

				// If this is a confirmation, don't call the cb on failure
				if (this.cb && (!this.confirm || positive)) {
					this.cb(positive);
				}

				this.trigger("select", positive);

				this.hide();
			},

			"click a.extlink": function(e) {
				var type = e.currentTarget.getAttribute("data-id") || "";

				// If this is a confirmation, don't call the cb on failure
				if (this.extlink) {
					this.extlink(type);
				}
			}
		},

		hide: function() {
			this.el.open = false;

			setTimeout(function() {
				this.el.open = true;

				this.el.close();

				this.stopListening();

				this.$el.remove();

				this.trigger("destroy");
			}.bind(this), 300);

			return this;
		},

		show: function() {
			// This method is necessary for the transitions to animate
			this.el.showModal();

			this.$el.addClass("no-transition");

			this.el.open = false;

			setTimeout(function() {
				this.$el.removeClass("no-transition");

				this.el.open = true;
			}.bind(this), 0);

			// Chrome creates a new focus layer for dialogs, focusing the first
			// focusable element.  This disables that.
			this.$("a, button, :input, [tabindex]").first().blur();
		},

		initialize: function() {
			if (this.confirm) {
				if (!this.title && this.title !== false) {
					this.title = Translate("alert.confirm_title");
				}

				this.buttons = this.buttons || {};

				if (!this.buttons.negative) {
					this.buttons.negative = Translate("alert.confirm_cancel");
				}

				if (!this.buttons.positive) {
					this.buttons.positive = Translate("alert.confirm_continue");
				}
			}

			var data = {
				buttons: [],
				title: this.title,
				html: this.html || undefined,
				contents: this.contents || undefined
			};

			var btns = this.buttons || {};

			if (btns.negative) {
				data.buttons.push({
					action: "negative",
					label: btns.negative
				});
			}

			data.buttons.push({
				class: btns.positive ? "blue" : "",
				action: "positive",
				label: btns.positive
			});

			this.$el.addClass(this.classes).html(render("alert", data)).appendTo(document.body);

			this.show();
		}
	});

	var alertFn = function(options, cb) {
		if (typeof options !== "object" || Array.isArray(options)) {
			options = {
				contents: Array.isArray(options) ? options : [options]
			};
		}

		if (cb) {
			options.cb = cb;
		}

		return new (Alert.extend(options))();
	};

	alertFn.view = Alert;

	return alertFn;
});
/**
 * This creates a basic global API so all modules using the HTML5 FileSystem can have a centralized config
 */
/* global PERSISTENT */
define('storage/filesystem',[],function() {
	/**
	 * Requests and asynchronously returns a FileSystem instance.
	 *
	 * @api     public
	 * @param   {Function}  cb
	 * @param   {Function}  err  The error callback
	 */
	var get = function(cb, err) {
		window.webkitRequestFileSystem(PERSISTENT, 500 * 1024 * 1024, function(fs) { // This can't be cached because FileSystem objects get "stale"
			cb(fs);
		}, err || function() {});
	};


	/**
	 * Proxies the get method.  Returns a FileSystem instance.
	 *
	 * @api     public
	 * @param   {Function}  cb
	 * @param   {Function}  err  The error callback
	 */
	get.get = function(cb, err) { // Try to avoid circular references
		return get(cb, err);
	};


	/**
	 * Clears the FileSystem store
	 *
	 * @api     public
	 * @param   {Function}  cb    The callback
	 * @param   {Function}  oErr  The error callback
	 */
	get.clear = function(cb, oErr) {
		var err = function(err) {
			if (typeof oErr === "function") {
				oErr.apply(this, err);
			}
			else {
				cb(true, err);
			}
		};

		get(function(fs) {
			var reader = fs.root.createReader(),
				length = 0;

			(function read() { // Recursive and self executing, necessary as per the specs
				reader.readEntries(function(results) {
					if (results.length) {
						results.forEach(function(e) {
							length++;

							if (e.isDirectory) {
								e.removeRecursively(function() {
									length--;

									if (!length) {
										cb();
									}
								});
							}
							else {
								e.remove(function() {
									length--;

									if (!length) {
										cb();
									}
								});
							}
						});

						read();
					}
					else if (!length) {
						cb();
					}
				}, err);
			})();
		}, err);
	};

	return get;
});
/**
 * Handles authentication and API interactions.
 *
 * The system is OAuth based, although since it's exclusively for an internal use and
 * a public app many things have been removed. The flow is far simpler, the client
 * posts authorization (usually a Google login token) and the server responds with
 * access and refresh tokens.
 */
define('core/auth',["lodash", "jquery", "backbone", "browser/api", "fbanalytics", "i18n/i18n", "modals/alert", "storage/filesystem"], function(_, $, Backbone, Browser, FB, Translate, Alert, FileSystem) {
	var API_HOST = "https://api.ichro.me";

	var Auth = Backbone.Model.extend({
		isPro: false,
		adFree: false,
		isSignedIn: false,
		isTrial: false,
		trialExpiration: "0",

		initialize: function() {
			this.on("change:isPro", function() {
				this.isPro = this.get("isPro");
				this.isTrial = this.get("isTrial");
				this.trialExpiration = this.get("trialExpiration");
			}, this).on("change:adFree", function() {
				this.adFree = this.get("adFree");
			}, this).on("change:user", function() {
				this.isSignedIn = !!this.get("user");
			}, this);

			try {
				this.set(JSON.parse(Browser.storage.authData));
			}
			catch (e) {}

			// Listen for auth changes from the background and other pages
			window.addEventListener("storage", function(e) {
				if (!e || e.key !== "authData") {
					return;
				}

				// If we were just signed out, reload
				if (!e.newValue) {
					return location.reload();
				}

				var wasPro = this.isPro;

				this.clear({
					silent: true
				}).set(JSON.parse(e.newValue));

				if (this.isPro !== wasPro) {
					location.reload();
				}
			}.bind(this));

			this.on("change:token", this.updateAccessToken, this);

			this.on("change", function(model, options) {
				if (options && options.internal) {
					return;
				}

				Browser.storage.authData = JSON.stringify(this.toJSON());
			});
		},


		/**
		 * Signs the user out, revoking the current token and erasing local authorization data
		 *
		 * @param {Boolean}  [fromError]  If this sign out is due to an error (such as a token being revoked),
		 *                                in which case the user is silently signed out.
		 */
		signout: function(fromError) {
			var cb = function() {
				if (this.has("refreshToken")) {
					$.post(API_HOST + "/oauth2/v1/token/revoke?refresh_token=" + encodeURIComponent(this.get("refreshToken")));
				}

				this.clear();

				FileSystem.clear(function() {
					var version = Browser.storage.version;

					Browser.storage.clear();

					if (version) {
						Browser.storage.version = version;
					}

					window.onbeforeunload = null;

					location.reload();
				});
			}.bind(this);

			if (fromError) {
				return cb();
			}

			Alert({
				contents: [Translate("storage.signout_confirm")],
				confirm: true
			}, cb);
		},


		/**
		 * Initiates and handles the authorization flow
		 *
		 * @param   {Function}  cb
		 */
		authorize: function(cb) {
			var that = this;

			var messageHandler = function(event) {
				if (event.origin !== "https://api.ichro.me") {
					return;
				}

				if (!event.data || !event.data.token) {
					return;
				}

				FB.logEvent("COMPLETED_REGISTRATION");

				this.set({
					token: event.data.token,
					expiry: event.data.expiry * 1000,
					refreshToken: event.data.refreshToken
				});

				if (that.child) {
					that.child.close();
				}

				cb(null, !!event.data.isNewUser);
			}.bind(this);

			var error = function(text) {
				Alert({
					title: "Error",
					classes: "error",
					html: "<p>" + text + "</p>",
					buttons: {
						positive: "OK",
					}
				});
			};

			var url = API_HOST + "/oauth2/v1/getstart?extension=" + (Browser.app.newTab ? "newtab" : "main");

			this._autorizePromise = $.post(url, function(d) {
				if (typeof d !== "object") {
					d = JSON.parse(d);
				}

				if (!d.url) {
					error("Cannot start authentication flow");
					return;
				}

				window.addEventListener("message", messageHandler);

				var top = Math.round((screen.availHeight - 600) / 2);
				var left = Math.round((screen.availWidth - 560) / 2);
	
				var timer = setInterval(function() {   
					if(that.child && that.child.closed) {  
						clearInterval(timer);  
						window.removeEventListener("message", messageHandler);
					}  
				}, 200); 
	
				that.child = window.open(d.url, "_blank", "top=" + top + ",left=" + left + ",height=600,width=560");

				this._autorizePromise = null;
			}.bind(this)).fail(function(xhr) {
				error("Error start authentication flow. Error code: " + xhr.status.toString());

				// If something fails, the next request coming through should retry
				this._autorizePromise = null;
			}.bind(this));
		},


		/**
		 * Updates the current token
		 *
		 * @api     public
		 */
		updateAccessToken: function() {
			var token = this.get("token");

			if (!token) {
				return;
			}

			var payload;

			try {
				// Auth tokens are JSON Web Tokens, which aren't encrypted (in this case), just
				// verified with a HMAC hash. So, they're also used for data transmission.
				payload = JSON.parse(atob(token.split(".")[1]));
			}
			catch (e) {
				return;
			}


			this.isPro = payload.plan && payload.plan !== "free";

			this.isTrial = payload.plan && payload.plan === "trial";

			this.adFree = this.isPro || !!payload.adFree;

			this.set({
				isPro: this.isPro,
				user: payload.sub,
				adFree: this.adFree,
				expiry: payload.exp * 1000,
				plan: payload.plan || "free",
				subscription: payload.subscription,
				isTrial: this.isTrial,
				trialExpiration: payload.trial
			});

			return this;
		},


		_refreshPromise: null,


		refreshToken: function() {
			// If we're already refreshing, return
			if (this._refreshPromise) {
				return;
			}

			this._refreshPromise = $.post(API_HOST + "/oauth2/v1/token/refresh", "refresh_token=" + encodeURIComponent(this.get("refreshToken")), function(d) {
				if (typeof d !== "object") {
					d = JSON.parse(d);
				}

				if (!d.error && d.token) {
					var data = {
						token: d.token,
						expiry: d.expiry * 1000
					};

					// If we get a new refresh token, update that too
					if (d.refreshToken) {
						data.refreshToken = d.refreshToken;
					}

					this.set(data);

					this.trigger("refreshed");
				}

				this._refreshPromise = null;
			}.bind(this)).fail(function(xhr) {
				// An error likely means our token isn't valid, so we sign the user out
				if (xhr.status.toString()[0] === "4") {
					this.signout(true);
				}

				// If something fails, the next request coming through should retry
				this._refreshPromise = null;
			}.bind(this));
		},


		/**
		 * Proxies jQuery.ajax, adding the auth token (if available) in a header
		 * to each request.
		 *
		 * If the URL starts with a forward slash, it will be prefixed with the
		 * API server host. For example, /weather/33021 will be resolved to
		 * https://api.ichro.me/weather/33021
		 *
		 * @api    public
		 * @param  {Object} config The configuration to be passed to jQuery.ajax.
		 *                         If a beforeSend function is specified it will be
		 *                         called _after_ the auth token is added.
		 */
		ajax: function(config) {
			if (config.url && config.url[0] === "/") {
				if (this.has("expiry") && new Date().getTime() > this.get("expiry")) {
					this.refreshToken();
				}

				// If we're refreshing the token, wait till that's done
				if (this._refreshPromise) {
					return this._refreshPromise.then(this.ajax.bind(this, config));
				}

				config.url = API_HOST + config.url;

				if (this.has("token")) {
					config.headers = config.headers || {};

					config.headers.Authorization = "Bearer " + this.get("token");
				}
			}

			return $.ajax(config).fail(function(xhr) {
				if (this.has("token") && xhr.status === 401 && xhr.responseText.trim().toLowerCase().indexOf("invalid_token") !== -1) {
					this.refreshToken();
				}
			}.bind(this));
		}
	});

	return new Auth();
});
/**
 * Exports a global analytics API
 */
define('core/analytics',["lodash", "browser/api", "core/status", "core/auth", "fbanalytics"], function(_, Browser, Status, Auth, FB) {
	var sendQueue = [],
		sendTimeout = null,
		pageTime, totalLoad, toolbarStyle;

	window.addEventListener("beforeunload", function() {
		if (sendTimeout) {
			clearTimeout(sendTimeout);
		}

		flushQueue(true);
	});

	var flushQueue = function(isFinal) {
		sendTimeout = null;

		if (isFinal) {
			sendQueue.push([
				"session",
				new Date().getTime(), // The time this event was triggered
				pageTime, // The time the page took to load and parse
				totalLoad, // The time it took for the page to completely render
				new Date().getTime() - performance.timing.responseEnd, // The total time the user spent on this page
				Status.get("error").length, // The number of errors in the log
				toolbarStyle // The style of the toolbar
			]);
		}

		navigator.sendBeacon("https://stats.ichro.me/ingest?extension=" + Browser.app.id + "&version=" + Browser.app.version + "&lang=" + Browser.language, new Blob([JSON.stringify(sendQueue)], {
			type: "text/plain" // Fix for Chrome 59 which requires sendBeacon to use CORS-safe content-types
		}));

		sendQueue = [];
	};

	// GA setup
	(function() {
		// Uncompressed Google Analytics insertion code
		window.GoogleAnalyticsObject = "ga";

		window.ga = window.ga || function() {
			(window.ga.q = window.ga.q || []).push(arguments);
		};

		window.ga.l = new Date().getTime();


		var script = document.createElement("script"),
			firstScript = document.getElementsByTagName("script")[0];

		script.async = true;
		script.src = "https://www.google-analytics.com/analytics.js";

		firstScript.parentNode.insertBefore(script, firstScript);


		/* global ga */
		ga("create", "UA-41131844-2", "auto"); // This is temporarily set to a blank profile since the page is reloaded hundreds of times during development.

		ga("set", "checkProtocolTask", function() {}); // Fixes the incompatibility with Chrome extensions: https://code.google.com/p/analytics-issues/issues/detail?id=312#c2

		ga("set", "transport", "beacon");

		ga("require", "displayfeatures");

		ga("set", "dimension1", Auth.isPro ? "Pro" : Auth.adFree ? "Ad-free" : Auth.isSignedIn ? "Signed in" : "Anonymous");
	})();

	var track = function() {
		track.event.call(track, arguments);
	};

	Object.defineProperty(track, "ga", { get: function() {
		return ga;
	} });

	track.FB = FB;

	/*
		This wraps the Analytics event tracker.

		Usage: Track.event("GSShare", "Twitter");
	*/
	track.event = function(category, action, label, value, nin) {
		if (nin) { // All previous parameters have been defined
			ga("send", "event", category, action, label.toString(), value, {
				nonInteraction: 1
			});
		}
		else if (value) {
			ga("send", "event", category, action, label.toString(), value);
		}
		else if (label) {
			ga("send", "event", category, action, label.toString());
		}
		else {
			ga("send", "event", category, action);
		}
	};

	/*
		This wraps the Analytics pageview tracker.

		Usage: Track.pageview("/settings");
	*/
	track.pageview = function(title, path) {
		if (!path) {
			path = title;

			title = null;
		}

		if (path && title) {
			ga("send", "pageview", {
				page: path,
				title: title
			});
		}
		else {
			ga("send", "pageview", path || ("/v" + Browser.app.version + (Browser.app.newTab ? "/newtab" : "")));
		}
	};

	/*
		This sets a timer to the current time and returns a mark function.  It can't use named timers since they might overlap and reset each other.

		Usage: var mark = Track.time();
	*/
	track.time = function() {
		var time = new Date().getTime();

		/*
			This takes the value from a timer, subtracts it from the current time and tracks the result with the given variable and label parameters.

			It can be called multiple times as in the case of storage saving (see storage/sync.js).

			Usage: mark("Storage", "Load");
		*/
		return function(category, variable) {
			track.queue("timing", category, variable, new Date().getTime() - time);

			ga("send", "timing", category, variable || "Time", new Date().getTime() - time);
		};
	};


	/**
	 * Called when the page is completely rendered, keeps track of load times
	 *
	 * @api     public
	 * @param   {String}  [style]  The style of the toolbar
	 */
	track.pageDone = function(style) {
		if (style) {
			toolbarStyle = style;
		}

		var cTime = new Date().getTime();

		totalLoad = cTime - performance.timing.responseEnd;

		pageTime = (performance.timing.loadEventEnd || cTime) - performance.timing.responseEnd;

		Status.log("Window load took " + pageTime + "ms, actual load took " + totalLoad + "ms");

		console.log("Window load took " + pageTime + "ms, actual load took " + totalLoad + "ms");

		ga("send", "timing", "Page", "Onload", pageTime);

		ga("send", "timing", "Page", "Complete", totalLoad);

		track.queue(
			"sessionStart",
			pageTime, // The time the page took to load and parse
			totalLoad, // The time it took for the page to completely render
			toolbarStyle // The style of the toolbar
		);
	};


	var sizes = {
		tiny: 1,
		small: 2,
		medium: 3,
		large: 4,
		variable: 5
	};

	/**
	 * Queues an item in ProductivityTab's "native" analytics
	 *
	 * @api     public
	 */
	track.queue = function() {
		// Still need to wait for Chrome 45 to use arrow functions (e => !e)
		var params = _.dropRightWhile(arguments, function(e) { return !e; });

		// Compress the most common events
		if (params[0] === "widgets") {
			params[0] = "w";

			if (params[1] === "view") {
				params[1] = "v";
			}

			if (params[3] && sizes[params[3]]) {
				params[3] = sizes[params[3]];
			}
		}
		else if (params[0] === "timing") {
			params[0] = "t";

			if (params[1] === "Sync") {
				params[1] = "s";
			}

			if (params[2] && params[2] === "Load") {
				params[2] = "l";
			}
			else if (params[2] && params[2] === "Save") {
				params[2] = "s";
			}
		}

		sendQueue.push([].concat(params.shift(), new Date().getTime(), params));

		// A timeout is used so multiple events triggered on load are lumped into one request
		if (sendQueue.length >= 100) {
			clearTimeout(sendTimeout);

			flushQueue();
		}
		else if (!sendTimeout) {
			sendTimeout = setTimeout(flushQueue, 1000);
		}
	};


	// Track pageview with GA and internal counter
	track.pageview();

	Browser.storage.uses = parseInt(Browser.storage.uses || 0) + 1;

	return track;
});
/**
 * Handles sync interfacing with ichro.me and ID management
 */
define('storage/syncapi',["lodash", "browser/api", "i18n/i18n", "modals/alert", "core/analytics", "core/auth"], function(_, Browser, Translate, Alert, Track, Auth) {
	// The sync API URL
	var SYNC_URL = "/sync/v1";


	var pastDueAlerted = false;

	var handlePastDue = function() {
		if (pastDueAlerted) {
			return;
		}

		pastDueAlerted = true;

		Alert({
			title: Translate("storage.pastdue"),
			contents: [Translate("storage.pastdue_desc")]
		});
	};


	var syncAPI = {
		/**
		 * Retrieves data from the servers and returns the raw response.
		 *
		 * @api     public
		 * @param   {Number}    [params]  Any URL parameters to append to the request
		 * @param   {Function}  cb        Has a Node-style signature of (err, data). This will be called
		 *                                with no arguments if the user is not signed in. Possible errors
		 *                                are "Network error" and "Server error".
		 * @param   {Boolean}   [retry]   If this request is a retry
		 */
		get: function get(params, cb, retry) {
			if (typeof params === "function") {
				cb = params;
				params = null;
			}

			if (!Auth.isSignedIn) {
				return cb();
			}

			Auth.ajax({
				url: SYNC_URL,
				data: _.assign({
					version: Browser.app.version
				}, params),
				timeout: 10000,
				complete: function(xhr, status) {
					if ((xhr.status === 200 && xhr.responseJSON) || xhr.status === 304) {
						var d = xhr.responseJSON;

						if (d && d.accessToken) {
							var wasPro = Auth.isPro;

							Auth.set("token", d.accessToken);

							if (Auth.isPro !== wasPro) {
								location.reload();
							}
						}

						if (d && d.subscriptionPastDue) {
							handlePastDue();
						}

						if (!d || d.isModified === false) {
							return cb(null, {
								modified: false
							});
						}


						cb(null, d);
					}
					else if (retry && (xhr.status === 0 || status === "timeout")) {
						cb("Network error");
					}
					else if (retry) {
						cb("Server error");
					}
					else {
						get(params, cb, true);
					}
				}
			});
		},


		/**
		 * Syncs data up to the servers and returns the raw response.
		 *
		 * @api     public
		 * @param   {Object}    data         The data to sync to the server
		 * @param   {Function}  [cb]         Has a Node-style signature of (err, data). This will be called without
		 *                                   any arguments if the user isn't signed in. Possible errors are
		 *                                   "Network error", "No data", or "Server error".
		 * @param   {Boolean}   [useBeacon]  Whether or not to use a beacon to send the request
		 * @param   {Boolean}   [retry]      If this request is a retry
		 */
		sync: function sync(data, cb, useBeacon, retry) {
			if (typeof cb === "boolean") {
				useBeacon = cb;
				cb = _.noop;
			}
			else if (!cb) {
				cb = _.noop;
			}

			if (!Auth.isSignedIn) {
				return cb();
			}

			if (!data || typeof data !== "object") {
				return cb("No data");
			}

			var sData = JSON.stringify(_.assign({}, data, {
				version: Browser.app.version
			}));

			if (useBeacon) {
				if (Auth.has("token")) {
					sData.authToken = Auth.get("token");
				}

				return cb(navigator.sendBeacon(SYNC_URL, new Blob([sData], { type: "text/plain" })));
			}

			Auth.ajax({
				type: "PUT",
				url: SYNC_URL,
				data: sData,
				contentType: "application/json",
				timeout: 10000,
				complete: function(xhr, status) {
					if (xhr.status === 200 && xhr.responseJSON) {
						var d = xhr.responseJSON;

						if (d.accessToken) {
							var wasPro = Auth.isPro;

							Auth.set("token", d.accessToken);

							if (Auth.isPro !== wasPro) {
								location.reload();
							}
						}

						if (d.subscriptionPastDue) {
							handlePastDue();
						}

						cb(null, d);
					}
					else if (retry && (xhr.status === 0 || status === "timeout")) {
						cb("Network error");
					}
					else if (retry) {
						cb("Server error");
					}
					else {
						sync(data, cb, false, true);
					}
				}
			});
		},


		/**
		 * Prompts the user to sign in and then syncs with the server
		 *
		 * @api     public
		 * @param   {Storage}  storage     The ProductivityTab storage interface.  This will be used to
		 *                                 save the response profile
		 * @param   {Boolean}  [sendData]  Whether or not to send data to the server, overwriting
		 *                                 the configurations on other computers.  Defaults to false
		 * @param   {Function} [cb]        The callback
		 */
		authorize: function(storage, sendData, cb) {
			cb = cb || _.noop;

			Auth.authorize(function(err, isNewUser) {
				if (err) {
					cb(err);

					Track.event("Sync", "Authorize", "Error");

					return;
				}

				var data = {};

				if (sendData) {
					data = {
						tabs: storage.tabsSync,
						themes: storage.themes,
						settings: storage.settings
					};
				}

				syncAPI.sync(data, function(err, d) {
					if (err || !d) {
						Track.event("Sync", "Authorize", "Error");

						cb(null, isNewUser);

						return;
					}

					Track.event("Sync", "Authorize", "Success");

					_.assign(storage, _.pick(d, "user", "tabs", "themes", "settings"));

					// This results in two requests going to the server, but it's the
					// simplest way to get all the metadata set up properly.
					storage.sync();

					cb(null, isNewUser);
				});
			});
		}
	};

	return syncAPI;
});
/**
 * Handles settings deprecation
 */
define('storage/deprecate',["lodash"], function(_) {
	var Deprecate = {
		settings: function(settings) {
			// The new layout specification format sets the columns property to a number,
			// unless the layout is grid-based in which case it's removed.
			if (typeof settings.columns === "string" && !settings.hasOwnProperty("layout")) {
				var parsed = {
					type: settings.columns.split("-")[1] || settings.columns,
					number: parseInt(settings.columns.split("-")[0]) || 1
				};

				settings.columns = parsed.number;
				settings.layout = parsed.type === "medley" ? "grid" : "columns";
				settings.columnWidth = parsed.type === "medley" ? "fixed" : parsed.type;
			}


			if (typeof settings.toolbar === "boolean") {
				if (settings.toolbar) {
					settings.toolbar = "full2";
				}
				else {
					settings.toolbar = "button";
				}
			}


			// Renames
			_.each({
				def: "defaultTab",
				stab: "searchInNewTab",
				ltab: "openLinksInNewTab",
				"custom-css": "customCSS"
			}, function(updated, prev) {
				// Actual old property removal is handled below
				if (settings.hasOwnProperty(prev)) {
					settings[updated] = settings[prev];
				}
			});


			// deprecated settings removal
			settings = _.omit(settings,
				"wcolor", // Widget BG color
				"hcolor", // Toolbar BG color
				"alignment", // Column alignment
				"logo-url", // Custom Logo URL
				"animation", // Loading animation control

				// Old versions of renamed settings
				"def", // Default tab
				"stab", // Search results tab
				"ltab", // Link target
				"custom-css", // Custom CSS
				"search-url", // Search URL
				"searchURL" // Later search URL
			);


			return settings;
		},

		tabs: function(tabs) {
			_.each(tabs, function(tab, i) {
				if (tab.theme) {
					delete tabs[i].theme;
				}

				if (typeof tab.medley !== "undefined") {
					tab.isGrid = tab.medley;

					delete tab.medley;
				}
			});

			return tabs;
		}
	};

	return Deprecate;
});
/**
 * This stores the storage defaults.  It's mainly used for comparisons, unextends and resetting ProductivityTab.
 */
define('storage/defaults',["i18n/i18n"], function(Translate) {
	return {
		tabs: [{
			columns: [
				[
					{ 
						id: 54,
						size: "medium"
					},
					{ 
						id: 1,
						size: "variable"
					}, 
				], [
					{ 
						id: 38,
						size: "tiny"
					}, 
					{ 
						id: 38,
						size: "tiny",
						config: {
							color: "rgb(255, 255, 255)",
							title: "Leave a Review?",
							link: "https://chrome.google.com/webstore/detail/ichrome-new-tab-ultimate/###productivitytab###/related?hl=en",
							image: "images/sitelink_logo.png"
						}
					}, 
					{ 
						id: 4,
						size: "variable"
					}
				], [
					{ 
						id: 13,
						size: "variable"
					},
					{ 
						id: 8,
						size: "variable",
						config: {
							feeds: [
								{
									url:  "https://lifehacker.com/rss",
									name: "Lifehacker"
								}
							]
						}
					}
				]
			],
			id: 1,
			name: Translate("defaults.tab")
		}],

		user: {
			fname: Translate("defaults.me"),
			image: "images/profile.png"
		},

		// Settings. Check deprecate.js when adding or removing any settings
		settings: {
			openLinksInNewTab: false,

			links: [],
			ok: false,
			apps: true,
			plus: true,
			voice: true,
			gmail: true,
			toolbar: "button",
			captureFocus: true,
			searchInNewTab: false,
			searchEngine: "default",
			adPlacement: "footer_leaderboard",

			editing: true,
			customCSS: "",
			style: "light",
			theme: "default",

			columns: 3,
			defaultTab: 1,
			layout: "columns",
			columnWidth: "fixed"
		},
		themes: [],

		// Keep the default theme spec in sync with the background page's fallback
		cached: {
			0: {
				id: 0,
				type: "feed",
				offline: true,
				name: "Default theme",
				format: "{{res.url}}",
				image: "images/defaulttheme.jpg",
				url: "https://api.ichro.me/themes/v1/default/getImage"
			}
		},
		tab: {
			name: Translate("defaults.tab")
		}
	};
});
/**
 * This module handles theme changes from incoming sync data
 */
define('storage/updatethemes',["jquery", "lodash", "browser/api"], function($, _, Browser) {
	// The cacher depends on storage, so we need to load it at run time
	var Cacher;

	/**
	 * Checks for theme changes, saving any themes that aren't present in the local cache.
	 *
	 * @api     private
	 * @param   {Storage}   storage
	 * @param   {Object}    d        The incoming sync object
	 * @param   {Function}  cb
	 */
	var updateThemes = function(storage, d, cb) {
		var oldData = _.pick(storage, "user", "tabs", "themes", "settings");

		var newData = _.pick(d, "user", "tabs", "themes", "settings");

		var themesChanged = newData.themes && (JSON.stringify(oldData.themes) !== JSON.stringify(newData.themes));

		var save = function() {
			var queue = [];

			if (newData.settings && newData.settings.theme && parseInt(newData.settings.theme) && !storage.cached[newData.settings.theme]) {
				queue.push(newData.settings.theme);
			}

			var next = function() {
				if (queue.length) {
					var theme = mThemes[queue.pop()];

					return new Cacher(theme, {
						events: {
							complete: next
						}
					});
				}

				var save = function() {
					newData.cached = storage.cached;

					cb(newData);
				};

				if (themesChanged) {
					// Any combination of changes could've happened, delete and recache everything

					var cacheNew = function() {
						if (newData.themes.length) {
							queue = _.map(newData.themes, function(e, i) {
								if (!e.image || (e.image.indexOf("#OrigURL:") === -1 && e.image.indexOf("http") !== 0)) {
									return function() {
										if (queue.length) {
											return queue.pop()();
										}

										save();
									};
								}

								if (e.image.indexOf("#OrigURL:") !== -1) {
									e.image = e.image.split("#OrigURL:")[1];
								}

								return function() {
									Cacher.Custom.cache(e, i, function() {
										if (queue.length) {
											return queue.pop()();
										}

										save();
									});
								};
							});

							queue.pop()();
						}
						else {
							save();
						}
					};


					if (oldData.themes.length) {
						queue = _.map(oldData.themes , function(e, i) {
							return function() {
								Cacher.Custom.deleteImage(i, function() {
									if (queue.length) {
										return queue.pop()();
									}

									cacheNew();
								});
							};
						});

						queue.pop()();
					}
					else {
						cacheNew();
					}
				}
				else {
					save();
				}
			};

			var mThemes;

			if (queue.length) {
				$.get("https://api.ichro.me/themes?extension=" + Browser.app.id + "&version=" + Browser.app.version + "&lang=" + Browser.language, function(d) {
					if (d && d.themes) {
						mThemes = _.indexBy(_.map(d.themes, function(e) {
							e.oType = e.type;

							return e;
						}), "id");

						next();
					}
				});
			}
			else {
				next();
			}
		};

		if (themesChanged || (JSON.stringify(newData) !== JSON.stringify(oldData))) {
			save();
		}
	};


	/**
	 * Wraps the method and ensures that the themes cacher is always available
	 *
	 * @api     public
	 */
	return function() {
		if (Cacher) {
			updateThemes.apply(this, arguments);
		}
		else {
			var that = this,
				args = arguments;

			require(["themes/cacher"], function(cacher) {
				Cacher = cacher;

				updateThemes.apply(that, args);
			});
		}
	};
});
/**
 * Converts a non-JSON.stringify()able tabs object to JSON.  This is used for syncing and comparing tab objects.
 */
define('storage/tojson',["lodash", "storage/defaults"], function(_, defaults) {
	var toJSON = function(tabs, settings) {
		var stabs = _.map(tabs, function(tab) {
			tab = _.omit(tab, function(e, k) {
				return defaults.tab[k] && e === defaults.tab[k] ||
					k === "isGrid" && e === (settings.layout === "grid") ||
					k === "fixed" && e === (settings.columnWidth === "fixed");
			});

			tab.columns = _.map(tab.columns || [], function(column) {
				return _.map(column, function(widget) {
					widget = _.pick(widget, ["id", "loc", "size", "config", "syncData"]);

					if (widget.config) {
						if (Object.keys(widget.config).length === (widget.config.size ? 1 : 0)) {
							delete widget.config;
						}
						else {
							widget.config = _.clone(widget.config);

							delete widget.config.size;
						}
					}

					return widget;
				});
			});

			return tab;
		});

		return JSON.stringify(stabs);
	};

	return toJSON;
});
define('lib/unextend',[],function() {
	/**
	 * Given the same input as $.extend, undoes the $.extend operation
	 *
	 * @param   {Object}  obj1
	 * @param   {Object}  obj2
	 * @return  {Object}        The unextended object
	 */
	var unextend = function(obj1, obj2) {
		var newObj = {};

		for (var k in obj2) {
			if (!obj2.hasOwnProperty(k)) {
				continue;
			}

			var e = obj2[k],
				c = obj1[k];

			if (typeof c === "undefined") {
				newObj[k] = e;
			}
			else if (e === null) {
				newObj[k] = e;
			}
			else if (typeof e === "object" && typeof e.length === "number" && JSON.stringify(e) !== JSON.stringify(c)) {
				newObj[k] = e;
			}
			else if (typeof e === "object" && typeof e.length === "undefined" && JSON.stringify(e) !== JSON.stringify(c)) {
				newObj[k] = unextend(c, e);
			}
			else if (e.toString() !== c.toString()) {
				newObj[k] = e;
			}
		}

		return newObj;
	};

	return unextend;
});
/**
 * Loads storage and returns a Promise that can be used to listen for updates
 */
define('storage/storage',[
	"jquery", "lodash", "backbone", "browser/api", "core/status", "core/analytics", "storage/filesystem",
	"core/auth", "storage/syncapi", "storage/deprecate", "storage/defaults", "storage/updatethemes", "storage/tojson", "lib/unextend"
], function($, _, Backbone, Browser, Status, Track, FileSystem, Auth, API, Deprecate, defaults, updateThemes, getJSON, unextend) {
		var deferred = $.Deferred();

		// This lets events get attached and fired on storage itself. It'll primarily be used as storage.on("updated", ...) and storage.trigger("updated")
		var promise = deferred.promise(_.extend({}, Backbone.Events));

		/**
		 * Wraps Backbone's Events.trigger method so every event handler is passed
		 * the storage and promise objects along with any extra data.
		 *
		 * @api     public
		 * @param   {String}    name  The name of the event to trigger
		 * @param   {Anything}  data  Any data to pass to the handlers
		 */
		promise.trigger = function(name, data) {
			if (storage && storage.tabs) { // Don't trigger events if storage isn't loaded
				Backbone.Events.trigger.call(promise, name, storage, promise, data);
			}
		};

		// Trigger the done event on done
		promise.done(function() {
			promise.trigger("done");

			window.onbeforeunload = function() {
				if (timeout) {
					save(true, _.noop, true);
				}
			};
		});


		/**
		 * Wraps Backbone's Events.on method, triggering the `done` event if storage is
		 * already available.
		 *
		 * @api     public
		 * @param   {String}    events  A space separated list of events to bind this handler to
		 * @param   {Function}  cb      The handler to bind to the events
		 * @param   {Anything}  ctx     The context the handler should be bound to
		 */
		promise.on = function(events, cb, ctx) {
			// If the promise is resolved and a done event is being attached, trigger it
			if (promise.state() === "resolved" && events.split(" ").indexOf("done") !== -1) {
				if (ctx) {
					cb.call(ctx, storage, promise);
				}
				else {
					cb.call(promise, storage, promise);
				}

				// Remove the event so it doesn't get called from the promise.done() function
				events = events.replace(/(?:^| )done(?:$| )/, "");

				if (!events) {
					return;
				}
			}

			Backbone.Events.on.call(promise, events, cb, ctx);
		};

		var saving = false;

		// When storage is updated it should be synced
		promise.on("updated", function() {
			if (!saving) {
				storage.sync();
			}
			else {
				saving = false;
			}
		});


		/**
		 * Resets Browser.storage and FileSystem, but not the sync token and user data,
		 * to their original states.
		 *
		 * @api     public
		 * @param   {Function}  cb
		 */
		promise.reset = function(cb) {
			FileSystem.clear(function() {
				// A reset shouldn't affect these since we'll still want to sync when this is over
				var uses = Browser.storage.uses,
					version = Browser.storage.version,
					authData = Browser.storage.authData;

				Browser.storage.clear();

				if (uses) {
					Browser.storage.uses = uses;
				}

				if (version) {
					Browser.storage.version = version;
				}

				if (authData) {
					Browser.storage.authData = authData;
				}

				Browser.storage.firstRun = true; // Show the installation guide when the page is reloaded

				// Overwrite with the default configuration
				_.assign(storage, _.pick(defaults, "tabs", "settings", "themes", "cached"));

				storage.tabsSync = JSON.parse(getJSON(storage.tabs, storage.settings));

				// Force a save and sync
				save(true, function() {
					if (cb) {
						cb();
					}
				});
			});
		};


		/**
		 * Checks for and loads any changes from the sync server
		 *
		 * @api     private
		 * @param   {Boolean}  fromInterval  Whether or not this call is from an interval, used for tracking.
		 */
		var loadSync = function(fromInterval) {
			if (!Auth.isSignedIn) {
				return;
			}

			var mark = Track.time();

			API.get({
				modifiedSince: storage.modified,
				fromInterval: fromInterval ? 1 : undefined
			}, function(err, data) {
				mark("Sync", "Load");

				if (!err && data) {
					if (data.modified === false) {
						return;
					}

					updateThemes(storage, data, function(processed) {
						storage.modified = new Date(data.modified).getTime();

						_.assign(storage, processed);

						storage.tabsSync = JSON.parse(getJSON(storage.tabs, storage.settings));

						lastSynced = JSON.stringify(_.pick(storage, "user", "tabsSync", "settings", "themes"));

						lastSaved = JSON.stringify(_.pick(storage, "user", "tabs", "settings", "themes", "cached"));

						save(false, _.noop);

						// Temporary flag to prevent a recursive loop from the updated call
						saving = true;

						promise.trigger("updated");
					});
				}
				else if (err && err === "No token") {
					save(true, _.noop);
				}
				else {
					Status.log("Error in storage fetch: " + err);
				}
			});
		};

		// Refresh every 15 minutes
		setInterval(function() {
			loadSync(true);
		}, 9E5);


		// These are used to check if anything was changed and to stop a default configuration from being synced
		var timeout = null,
			lastSaved = "",
			lastSynced = "",
			dString = JSON.stringify(_.pick(defaults, "user", "tabs", "settings", "themes", "cached"));

		var cacheTheme = function() {
			// We can't use the theme utils here since they require storage
			var image;

			if (storage.settings.theme === "custom") {
				image = storage.settings.backgroundImage;
			}
			else {
				image = (storage.cached[storage.settings.theme] || storage.themes[(storage.settings.theme + "").replace("custom", "")] || storage.cached[0]).image;
			}

			if (!image || image.slice(-4) === ".mp4") {
				delete Browser.storage.themeImg;

				return;
			}

			Browser.storage.themeImg = image;
		};


		/**
		 * Saves and optionally syncs storage
		 *
		 * @api     private
		 * @param   {Boolean}      sync       Whether or not to sync storage
		 * @param   {Function}     cb
		 * @param   {Boolean}      useBeacon  If a beacon should be used for this sync
		 * @return  {null|Beacon}             If useBeacon was specified, the beacon is returned
		 */
		var save = function(sync, cb, useBeacon) {
			Status.log("Starting storage save");

			timeout = null;

			// Local save
			var local = _.pick(storage, "user", "cached", "themes", "settings", "modified");

			local.tabs = _.map(storage.tabs, function(tab) {
				return unextend({
					isGrid: storage.settings.layout === "grid",
					fixed: storage.settings.columnWidth === "fixed"
				}, unextend(defaults.tab, tab));
			});

			Browser.storage.config = JSON.stringify(local);

			// Cache the default theme image
			cacheTheme(storage);


			// Sync save
			if (Auth.isSignedIn && sync) {
				if (useBeacon) {
					Status.log("Sending sync beacon");

					return cb(API.sync({
						tabs: storage.tabsSync,
						themes: storage.themes,
						settings: storage.settings
					}, true));
				}

				Status.log("Starting sync save");

				var mark = Track.time();

				API.sync({
					tabs: storage.tabsSync,
					themes: storage.themes,
					settings: storage.settings
				}, function(err, d) {
					if (!err && d) {
						var modified = new Date(d.modified).getTime();

						storage.modified = local.modified = modified;

						if (d.user) {
							storage.user = local.user = d.user;
						}

						Browser.storage.config = JSON.stringify(local);
					}

					mark("Sync", "Save");

					cb();
				});
			}
			else {
				cb();
			}
		};

		var storage = {
			/**
			 * Schedules a storage save
			 *
			 * @api     public
			 * @param   {Boolean}   [now]        If the save should be triggered immediately
			 * @param   {Function}  [cb]         A function to be called when the save is actually triggered.
			 *
			 * @param   {Anything}  [data]       Any data that should be passed to the update event that
			 *                                   will be triggered.  Useful to avoid double-renders.
			 *
			 * @param   {Boolean}   [forceSync]  Whether or not a sync save, instead of just a local one,
			 *                                   should be forced, regardless of changes since the last sync.
			 */
			sync: function(now, cb, data, forceSync) {
				if (typeof now === "function") {
					cb = now;
					now = undefined;
				}
				else if (typeof now === "object") {
					data = now;
					cb = undefined;
					now = undefined;
				}
				else if (typeof cb === "object") {
					data = cb;
					cb = undefined;
				}

				data = data || {};
				now = now || false;
				cb = cb || function() {};
				forceSync = forceSync || false;

				var stringified = JSON.stringify(_.pick(storage, "user", "tabs", "settings", "themes", "cached"));

				// Don't sync if the settings haven't changed or are the defaults unless this is a onbeforeunload or similar sync
				if (now || (stringified !== lastSaved && stringified !== dString)) {
					lastSaved = stringified;

					Status.log("Sync called");

					clearTimeout(timeout);

					timeout = null;

					storage.tabsSync = JSON.parse(getJSON(storage.tabs, storage.settings));

					var syncString = JSON.stringify(_.pick(storage, "user", "tabsSync", "settings", "themes"));

					var sync = forceSync || (syncString !== lastSynced);
					if (!storage.isSync) {
						storage.isSync = sync;
					}

					if (sync) {
						lastSynced = syncString;

						// Until we have a timestamp from the server
						storage.modified = new Date().getTime();
					}

					if (!now) {
						timeout = setTimeout(function() {
							save(storage.isSync, cb);
							storage.isSync = false;
						}, 2000);
					}
					else {
						save(storage.isSync, cb);
						storage.isSync = false;
					}


					// Temporary flag to prevent a recursive loop from the updated call
					saving = true;

					// If sync was called something was most likely changed, therefore requiring the caller to trigger updated is redundant.
					// Also, UI changes should happen instantly, so this is called synchronously but after the sync synchronous code is run.
					if (now !== "final") {
						promise.trigger("updated", data);
					}
				}
				else {
					cb();
				}
			},
			isSync : false
		};

		var parseData = function(data) {
			var d;

			if (typeof data === "string") {
				d = JSON.parse(data || Browser.storage.config || "{}");
			}
			else {
				d = data || {};
			}

			storage.user = d.user || defaults.user;
			storage.themes = d.themes || defaults.themes;
			storage.cached = d.cached || defaults.cached;
			storage.tabs = Deprecate.tabs(d.tabs || defaults.tabs);

			if (!storage.cached[0]) {
				storage.cached[0] = defaults.cached[0];
			}

			storage.modified = d.modified || 0;

			if (d.settings) {
				storage.settings = _.defaultsDeep(Deprecate.settings(d.settings), defaults.settings);
			}
			else {
				storage.settings = _.cloneDeep(defaults.settings);
			}

			storage.tabsSync = JSON.parse(getJSON(storage.tabs, storage.settings));

			// Set the last saved and synced values to the just loaded data
			lastSaved = JSON.stringify(_.pick(storage, "user", "tabs", "settings", "themes", "cached"));
			lastSynced = JSON.stringify(_.pick(storage, "user", "tabsSync", "settings", "themes"));

			// Backup once a day, before any changes are made
			if (new Date().getTime() - (Browser.storage.lastBackup || "0") > 864E5) {
				var backups = JSON.parse(Browser.storage.backups || "[]");

				backups.unshift({
					date: new Date().getTime(),
					data: {
						tabs: storage.tabsSync,
						themes: storage.themes,
						settings: storage.settings
					}
				});

				Browser.storage.backups = JSON.stringify(backups.slice(0, 4));
				Browser.storage.lastBackup = new Date().getTime();

				backups = null;
			}


			// Load any updates from the sync server, sending the request before the page is rendered
			loadSync();

			deferred.resolve(storage);
		};

		if (Browser.storage.config) {
			parseData(Browser.storage.config);
		}
		else if (Browser.chromeLocal) {
			Browser.chromeLocal.get(["tabs", "settings", "themes", "cached"], function(d) {
				if (typeof d.tabs === "string") {
					try {
						d.tabs = JSON.parse(d.tabs);
					}
					catch(e) {
						delete d.tabs;
					}
				}

				Browser.storage.config = JSON.stringify(d);

				Browser.chromeLocal.remove(["tabs", "settings", "themes", "cached"]);
				Browser.syncStorage.remove(["tabs", "settings", "themes", "cached"]);

				parseData(d);
			});
		}
		else {
			parseData();
		}


		// Listen for storage changes from the background and other pages
		window.addEventListener("storage", function(e) {
			if (!e || e.key !== "config" || !e.newValue) {
				return;
			}

			var changed,
				oldData = JSON.parse(e.oldValue),
				newData = JSON.parse(e.newValue);

			_.each(newData, function(e, k) {
				// Note that this uses oldData.settings in both cases. We don't
				// want settings changed to be misinterpreted as tab changes.
				if (k === "tabs" && getJSON(oldData.tabs, oldData.settings) !== getJSON(newData.tabs, oldData.settings)) {
					changed = true;

					storage.tabs = e;
				}
				else if (["user", "themes", "settings", "cached"].indexOf(k) !== -1 && JSON.stringify(e) !== JSON.stringify(oldData[k])) {
					changed = true;

					storage[k] = e;
				}
			});

			if (!changed) {
				return;
			}

			console.log("Detected localStorage change, updating");

			storage.modified = new Date(e).getTime();

			storage.tabsSync = JSON.parse(getJSON(storage.tabs, storage.settings));

			lastSaved = JSON.stringify(_.pick(storage, "user", "tabs", "settings", "themes", "cached"));
			lastSynced = JSON.stringify(_.pick(storage, "user", "tabsSync", "settings", "themes"));

			promise.trigger("updated");
		});

		return promise;
	}
);
define('widgets/views/main',["lodash", "backbone", "core/auth", "core/analytics", "storage/storage", "widgets/framefix"], function(_, Backbone, Auth, Track, Storage, frameFix) {
	var isDark = false;

	Storage.on("done updated", function(storage) {
		isDark = Auth.isPro && storage.settings.style && storage.settings.style !== "light";
	});

	return Backbone.View.extend({
		get isDark() {
			return isDark;
		},

		/**
		 * Returns a Hogan template that should be used to render this view.
		 *
		 * This is in a function so it can be easily overridden by variations of
		 * the main view and widgets
		 */
		getTemplate: function() {
			return this.widget.templates["default"];
		},

		Auth: Auth,

		constructor: function(options) {
			this.widget = options.widget;

			var manifest = this.widget.manifest;

			// Set core properties
			this.id = manifest.id;
			this.name = manifest.name;
			this.model = options.model;
			this.template = this.getTemplate();
			this.cid = _.uniqueId("widgetView");
			this.isPreview = options.instance.isPreview;

			// Binding the translate method once, now, avoids unnecessary calls later
			this.translate = _.bind(this.widget.translate, this.widget);

			if (options.errorHandler) {
				this.on("error", options.errorHandler);
			}


			// Create the content element
			this.el = document.createElement("div");

			this.el.setAttribute("class", "content");

			this.setElement(this.el);

			this.initialize();
		},


		initialize: function() {
			this.listenTo(this.model, "change", _.ary(this.render, 0));

			this.render();
		},


		/**
		 * Passes errors to the parent instance via an event
		 */
		error: function(explanation, advice) {
			this.trigger("error", explanation, advice);
		},


		/**
		 * Destroys this view
		 *
		 * @api     public
		 */
		destroy: function() {
			if (this.onBeforeDestroy) {
				// onBeforeDestroy can cancel destruction
				if (!this.onBeforeDestroy()) {
					return;
				}
			}

			this.trigger("before:destroy");

			this.remove();

			this.stopListening();

			if (this.onDestroy) {
				this.onDestroy();
			}

			this.trigger("destroy");
		},


		/**
		 * Renders the main template
		 *
		 * @param  {Object}  [data={}]  An object of data to pass to Hogan
		 * @param  {Object}  [partials] Any partials that the template should be rendered with
		 */
		render: function(data, partials) {
			if (this.isFrame && !frameFix(this.render, this, arguments)) {
				return;
			}

			// We only do a shallow clone, if widgets need a deep clone they
			// still have to do it themselves
			data = _.extend({
				isDark: isDark,
				isPro: Auth.isPro,
				i18n: this.widget.strings
			}, data || this.model.data);

			data[this.model.get("size")] = true;

			try {
				// We use a system similar to Marionette's, except that onBeforeRender
				// can return a new data object
				if (this.onBeforeRender) {
					var ret = this.onBeforeRender(data, this.isPreview);

					if (typeof ret === "object") {
						data = ret;
					}
				}

				this.trigger("before:render", data, this.isPreview);
			}
			catch (e) {
				Track.queue("widgets", "error", this.nicename, this.size, "beforeRender", e.stack);

				return this.error();
			}

			// We need to use $.html even though it's slower than innerHTML
			// because it cleans up jQuery events and data
			this.$el.html(this.template.render(data, partials));

			try {
				if (this.onRender) {
					this.onRender(data, this.isPreview);
				}

				this.trigger("render", data, this.isPreview);
			}
			catch (e) {
				Track.queue("widgets", "error", this.nicename, this.size, "render", e.stack);

				this.error();
			}

			return this;
		}
	});
});
define('lib/gcloader',["backbone"], function(Backbone) {
    var loader = {
        callbacks: [],

        load: function(callback, context) {
            if (window.gcapiloaded) {
                if (callback) {
                    callback.call(context);
                }
                return;
            }

            if (callback) {
                this.callbacks.push({
                    callback: callback,
                    context: context
                });
            }

            if (window.gcapiloading) {
                return;
            }

            window.gcapiloading = true;

            var w = window;
            var d = document;            
            var s = 'script';
            var js=d.createElement(s);
            var fs=d.getElementsByTagName(s)[0];
            js.src='https://www.gstatic.com/charts/loader.js';
            fs.parentNode.insertBefore(js,fs);
            js.onload = function() { 
                var that = this;
                //google.charts.load('current', {packages: ['corechart', 'annotationchart']});
                google.charts.load('current', {packages: ['corechart']});
                google.charts.setOnLoadCallback(function() {
                    window.gcapiloaded = true;
                    that.callbacks.forEach(function(item) {
                        item.callback.call(item.context);
                    });
                });
            }.bind(this);
        },
    
        isLoaded: function() {
            return window.gcapiloaded || false;
        }
    };

    return loader;
});
define('w/analytics/view',["lodash", "widgets/views/main", "lib/gcloader"], function(_, WidgetView, GCLoader) {
	/*global google */
	return WidgetView.extend({
		events: {
			"click header .select .options li": function(e) {
				this.model.set("range", e.currentTarget.getAttribute("data-id"));

				this.render({
					loading: true
				});
			}
		},

		initialize: function() {
			WidgetView.prototype.initialize.call(this);

			GCLoader.load(this.render, this);
			this.listenTo(this.model, "data:loaded", this.render);
		},

		onBeforeRender: function(data, isPreview) {
			if (this.model.config.title) {
				data.title = this.model.config.title;
			}

			if (!this.model.config.profile && !isPreview) {
				data.noProfile = true;
			}

			data.cid = this.cid;

			if (isPreview) {
				data.common = {
					visits: 5605,
					pageviews: 15033,
					bounceRate: 12.57,
					completions: 4853,
					pagesVisit: 8.54
				};
			}

			var activeView = this.model.get("range");

			data.views = _.map({
				today: "Today",
				yesterday: "Yesterday",
				pastweek: "Past Week"
			}, function(e, k) {
				if (k === activeView) {
					data.activeView = e;
				}

				return {
					id: k,
					name: e,
					active: k === activeView
				};
			}, this);

			return data;
		},

		onRender: function(data) {
			if (!GCLoader.isLoaded() || data.empty) {
				return;
			}

			var chartData, options, chart;
			if (data.weekly) {
				chartData = google.visualization.arrayToDataTable(data.weekly.items);
				options = {
					title: 'This Week vs Last Week',
					hAxis: { slantedText: true },
					vAxis: {textPosition: 'in', title: 'By Sessions',  titleTextStyle: {color: '#333'}, minValue: 0},
					animation: {
						startup: true,
						duration: 1000,
						easing: 'out',
					},
					legend: {
						position: 'bottom'
					},
					chartArea: { width: '92%' },
				};
		  
				chart = new google.visualization.AreaChart(document.getElementById('weekly_charts' + this.cid));
				chart.draw(chartData, options);
			}

			if (data.yearly) {
				chartData = google.visualization.arrayToDataTable(data.yearly.items);
				options = {
					title: 'This Year vs Last Year',
					hAxis: { slantedText: true },
					vAxis: { textPosition: 'in', title: 'By Sessions',  titleTextStyle: { color: '#333' }, minValue: 0 },
					animation: {
						startup: true,
						duration: 1000,
						easing: 'out',
					},
					legend: {
						position: 'bottom'
					},
					chartArea: { width: '92%' }
				};
		  
				chart = new google.visualization.AreaChart(document.getElementById('yearly_charts' + this.cid));
				chart.draw(chartData, options);
			}
			

			if (data.channels) {
				chartData = google.visualization.arrayToDataTable(data.channels.items);
				options = {
					title: 'Traffic Channels',
					width: "100%",
					height: 400,
					chartArea: { width: '85%' },
					legend: { position: 'bottom' },
					bar: { groupWidth: '75%' },
					isStacked: true,
					hAxis: { slantedText: true },
					vAxis: { textPosition: 'in', title: 'By Sessions',  titleTextStyle: { color: '#333' }, minValue: 0 },
					animation: {
						startup: true,
						duration: 1000,
						easing: 'out',
					}
				};			
	
				chart = new google.visualization.ColumnChart(document.getElementById("channels_charts" + this.cid));
				chart.draw(chartData, options);
			}

		}
	});
});
define('text',{});
define('widgetTemplate',{load: function(id){throw new Error("Dynamic load not allowed: " + id);}});

define("widgetTemplate!w/analytics/templates/desc.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Use this widget to keep track of how your analytics are doing today.<br /> <br /> After installation, you'll need to select a profile from the widget settings.");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/analytics/templates/main.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("empty",c,p,1),c,p,0,10,41,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <h3>");t.b(t.v(t.d("i18n.empty_title",c,p,0)));t.b("</h3> ");});c.pop();}t.b(" ");if(!t.s(t.f("empty",c,p,1),c,p,1,0,0,"")){t.b(" ");if(t.s(t.f("noProfile",c,p,1),c,p,0,77,698,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"no-profile\"> <h2>");t.b(t.v(t.d("i18n.noprofile_title",c,p,0)));t.b("</h2> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"> <path d=\"M10 6.35V4.26c-.8.21-1.55.54-2.23.96l1.46 1.46c.25-.12.5-.24.77-.33zm-7.14-.94l2.36 2.36C4.45 8.99 4 10.44 4 12c0 2.21.91 4.2 2.36 5.64L4 20h6v-6l-2.24 2.24C6.68 15.15 6 13.66 6 12c0-1 .25-1.94.68-2.77l8.08 8.08c-.25.13-.5.25-.77.34v2.09c.8-.21 1.55-.54 2.23-.96l2.36 2.36 1.27-1.27L4.14 4.14 2.86 5.41zM20 4h-6v6l2.24-2.24C17.32 8.85 18 10.34 18 12c0 1-.25 1.94-.68 2.77l1.46 1.46C19.55 15.01 20 13.56 20 12c0-2.21-.91-4.2-2.36-5.64L20 4z\"></path> </svg> <p>");t.b(t.t(t.d("i18n.noprofile",c,p,0)));t.b("</p> </div> ");});c.pop();}t.b(" ");if(!t.s(t.f("noProfile",c,p,1),c,p,1,0,0,"")){t.b(" <header ");if(t.s(t.f("tiny",c,p,1),c,p,0,745,782,"{{ }}")){t.rs(c,p,function(c,p,t){if(t.s(t.f("title",c,p,1),c,p,0,755,772,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("class=\"has-title\"");});c.pop();}});c.pop();}t.b("> <a href=\"https://www.google.com/analytics/web/\" class=\"title\">");t.b(t.v(t.f("title",c,p,0)));t.b("</a> ");if(t.s(t.f("medium",c,p,1),c,p,0,880,1091,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"select\" tabindex=\"-1\"> <span class=\"selected\">");t.b(t.v(t.f("activeView",c,p,0)));t.b("</span> <ul class=\"options\"> ");if(t.s(t.f("views",c,p,1),c,p,0,992,1067,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <li data-id=\"");t.b(t.v(t.f("id",c,p,0)));t.b("\"");if(t.s(t.f("active",c,p,1),c,p,0,1024,1041,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" class=\"selected\"");});c.pop();}t.b(">");t.b(t.v(t.f("name",c,p,0)));t.b("</li> ");});c.pop();}t.b(" </ul> </div> ");});c.pop();}t.b(" </header> ");if(t.s(t.f("loading",c,p,1),c,p,0,1125,1359,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"loading\"> <svg class=\"spinner\" width=\"65px\" height=\"65px\" viewBox=\"0 0 66 66\" xmlns=\"http://www.w3.org/2000/svg\"> <circle fill=\"none\" stroke-width=\"6\" stroke-linecap=\"round\" cx=\"33\" cy=\"33\" r=\"30\"></circle> </svg> </div> ");});c.pop();}t.b(" ");if(!t.s(t.f("loading",c,p,1),c,p,1,0,0,"")){t.b(" ");if(t.s(t.f("common",c,p,1),c,p,0,1396,2128,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"sessions\"> <span class=\"value\"");if(t.s(t.f("tiny",c,p,1),c,p,0,1448,1723,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" data-tooltip=\"&lt;b&gt;");t.b(t.v(t.d("i18n.pageviews",c,p,0)));t.b("&lt;/b&gt;: ");t.b(t.v(t.f("pageviews",c,p,0)));t.b("&lt;br /&gt;&lt;b&gt;");t.b(t.v(t.d("i18n.pagesvisit",c,p,0)));t.b("&lt;/b&gt;: ");t.b(t.v(t.f("pagesVisit",c,p,0)));t.b("&lt;br /&gt;&lt;b&gt;");t.b(t.v(t.d("i18n.bouncerate",c,p,0)));t.b("&lt;/b&gt;: ");t.b(t.v(t.f("bounceRate",c,p,0)));t.b("&lt;br /&gt;&lt;b&gt;");t.b(t.v(t.d("i18n.completions",c,p,0)));t.b("&lt;/b&gt;: ");t.b(t.v(t.d("common.completions",c,p,0)));t.b("\"");});c.pop();}t.b(">");t.b(t.v(t.d("common.visits",c,p,0)));t.b("</span> <span class=\"label\">");t.b(t.v(t.d("i18n.sessions",c,p,0)));t.b("</span> </div> ");if(t.s(t.f("medium",c,p,1),c,p,0,1821,2116,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"details\"> <div data-label=\"");t.b(t.v(t.d("i18n.pageviews",c,p,0)));t.b("\">");t.b(t.v(t.d("common.pageviews",c,p,0)));t.b("</div> <div data-label=\"");t.b(t.v(t.d("i18n.pagesvisit",c,p,0)));t.b("\">");t.b(t.v(t.d("common.pagesVisit",c,p,0)));t.b("</div> <div data-label=\"");t.b(t.v(t.d("i18n.bouncerate",c,p,0)));t.b("\">");t.b(t.v(t.d("common.bounceRate",c,p,0)));t.b("%</div> <div data-label=\"");t.b(t.v(t.d("i18n.completions",c,p,0)));t.b("\">");t.b(t.v(t.d("common.completions",c,p,0)));t.b("</div> </div> ");});c.pop();}t.b(" ");});c.pop();}t.b(" ");if(t.s(t.f("weekly",c,p,1),c,p,0,2151,2220,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <hr class=\"margin-bottom: 0\"> <div id=\"weekly_charts");t.b(t.v(t.f("cid",c,p,0)));t.b("\"></div> ");});c.pop();}t.b(" ");if(t.s(t.f("yearly",c,p,1),c,p,0,2243,2312,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <hr class=\"margin-bottom: 0\"> <div id=\"yearly_charts");t.b(t.v(t.f("cid",c,p,0)));t.b("\"></div> ");});c.pop();}t.b(" ");if(t.s(t.f("top10",c,p,1),c,p,0,2334,2575,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <hr> <div class=\"topvisited\"> <h6>Top visited pages</h6> <table> <thead> <tr> <th>Page</th> <th>Pageviews</th> </tr> </thead> <tbody> ");if(t.s(t.d("top10.items",c,p,1),c,p,0,2485,2533,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <tr> <td>");t.b(t.v(t.f("url",c,p,0)));t.b("</td> <td>");t.b(t.v(t.f("count",c,p,0)));t.b("</td> </tr> ");});c.pop();}t.b(" </tbody> </table> </div> ");});c.pop();}t.b(" ");if(t.s(t.f("channels",c,p,1),c,p,0,2599,2670,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <hr class=\"margin-bottom: 0\"> <div id=\"channels_charts");t.b(t.v(t.f("cid",c,p,0)));t.b("\"></div> ");});c.pop();}t.b(" ");};t.b(" ");};t.b(" ");};t.b(" ");return t.fl(); },partials: {}, subs: {  }})});
/**
 * This is a slightly modified version of the OAuth library that stores authorization
 * data in a widget's synced configuration instead of Browser.storage.
 *
 * This allows for multiple accounts across different widgets and obviates the need
 * to sign in on each computer (since keys are synced).
 */
define('widgets/oauth',["lodash", "oauth"], function(_, OAuth) {
	/**
	 * Creates a new Widget OAuth instance
	 *
	 * @constructor
	 * @param  {Backbone.WidgetModel}  model  The widget's model
	 * @return {WidgetOAuth}                  A new widget OAuth instance
	 */
	var WidgetOAuth = function(model) {
		this.model = model;

		var config = _.clone(_.result(this.model, "oAuth"));

		if (!config) {
			return;
		}

		config.name = config.name || this.model.name;

		if (OAuth.call(this, config) === "Invalid config") {
			throw new Error("Invalid OAuth configuration");
		}
	};

	WidgetOAuth.prototype = _.clone(OAuth.prototype);


	/**
	 * Returns any stored OAuth data from the model's synced configuration
	 * and updates this.data
	 *
	 * @api     private
	 * @return  {Object}  The data retreived from the model's data
	 */
	WidgetOAuth.prototype.loadStorage = function() {
		this.data = this.model && this.model.config && this.model.config.oauth;

		// If the model doesn't have an OAuth configuration stored, try loading
		// it from Browser.storage
		if (!this.data) {
			try {
				OAuth.prototype.loadStorage.call(this);
			}
			catch (e) {}
		}

		this.data = this.data || {};

		return this.data;
	};


	/**
	 * Saves this.data to the model's synced configuration
	 *
	 * @api     private
	 */
	WidgetOAuth.prototype.saveStorage = function() {
		if (this.data && this.model && Object.keys(this.data).length) {
			if (!this.model.config) {
				this.model.config = {};
			}

			this.model.config.oauth = this.data;

			this.model.saveConfig();
		}
	};


	/**
	 * Used to bind functions to `this.model` when passed to the OAuth
	 * library
	 *
	 * @api     private
	 * @param   {Function}  fn   The function to bind
	 * @return  {Function}       The bound function
	 */
	WidgetOAuth.prototype._bind = function(fn) {
		var ctx = this.model;

		return function(a, b) {
			fn.call(ctx, a, b);
		};
	};


	// We proxy these methods so models don't have to bind to `this`
	WidgetOAuth.prototype.getToken = function(cb, silent) {
		return OAuth.prototype.getToken.call(this, this._bind(cb), silent);
	};

	WidgetOAuth.prototype.refreshToken = function(cb, silent) {
		return OAuth.prototype.refreshToken.call(this, this._bind(cb), silent);
	};

	WidgetOAuth.prototype.startAuthFlow = function(cb, silent) {
		return OAuth.prototype.startAuthFlow.call(this, this._bind(cb), silent);
	};

	WidgetOAuth.prototype.ajax = function(params) {
		if (params.success) {
			params.success = this._bind(params.success);
		}

		return OAuth.prototype.ajax.call(this, params);
	};


	return WidgetOAuth;
});
/**
 * The widget model
 */
define('widgets/model',["lodash", "backbone", "core/auth", "core/analytics", "widgets/oauth"], function(_, Backbone, Auth, Track, WidgetOAuth) {
	var WidgetModel = Backbone.Model.extend({
		idAttribute: "cid",

		Auth: Auth,

		constructor: function(attrs, options) {
			// We can't call the default constructor since we need to run
			// _.defaults() on the config and data properties. So, the contents
			// of the constructor are included here
			attrs = attrs || {};
			options = options || {};

			// Set core properties
			this.attributes = {};
			this.widget = options.widget;
			this.id = this.widget.manifest.id;
			this.cid = _.uniqueId("widgetModel");
			this.name = this.widget.manifest.name;
			this.isPreview = options.instance.isPreview;

			this.translate = _.bind(this.widget.translate, this.widget);


			var defaults = _.result(this, "defaults");

			attrs = _.defaults({}, attrs, defaults);

			if (defaults.config) {
				attrs.config = _.defaults(attrs.config, defaults.config);
			}

			this.set(attrs, options);

			this.changed = {};

			// Convenience properties to access the data and config attributes.
			//
			// Since these are objects modifications made to them will not trigger
			// a change event, and therefore won't persist changes unless the
			// events are fired manually. Since we'll need to make a convenience
			// method to handle that anyway, there's no good reason to require
			// this.get("config") calls everywhere.
			this.data = this.attributes.data;
			this.config = this.attributes.config;
			this.syncData = this.attributes.syncData;

			this.on("change:data change:syncData change:config", function() {
				this.data = this.attributes.data;
				this.config = this.attributes.config;
				this.syncData = this.attributes.syncData;
			}, this);


			if (typeof this.oAuth !== "undefined") {
				this.oAuth = new WidgetOAuth(this);
			}


			this.initialize();
		},


		initialize: function() {
			if (this.refresh) {
				this.on("change", function(model, options) {
					if (options && options.widgetChange === true) {
						return;
					}

					this.refresh();
				}, this);
			}
		},


		/**
		 * Passes errors to the parent instance via an event
		 */
		error: function(explanation, advice) {
			this.trigger("error", explanation, advice);
		},


		/**
		 * Destroys this model
		 *
		 * @api     public
		 */
		destroy: function() {
			if (this.onBeforeDestroy) {
				// onBeforeDestroy can cancel destruction
				if (!this.onBeforeDestroy()) {
					return;
				}
			}

			this.trigger("before:destroy");

			this.stopListening();

			if (this.onDestroy) {
				this.onDestroy();
			}

			this.trigger("destroy");
		},


		/**
		 * Fires change events on the data attribute and persists its value to localStorage
		 *
		 * @api     public
		 * @param   {Object}  [data]  Optional. An object that the existing data
		 *                            property should be overwritten with
		 */
		saveData: function(data) {
			if (data) {
				this.data = data;
			}

			this.set("data", this.data, {
				silent: true
			});

			// This is the simplest way to ensure that the appropriate
			// change events get triggered.
			//
			// The parent widget instance listens for change events, so we
			// don't need to do anything beyond that
			this.trigger("change:data", this, this.data, { widgetChange: true });
			this.trigger("change", this, { widgetChange: true });
		},


		/**
		 * See above, but for syncData
		 */
		saveSyncData: function(data) {
			if (data) {
				this.syncData = data;
			}

			this.set("syncData", this.syncData, {
				silent: true
			});

			this.trigger("change:syncData", this, this.syncData, { widgetChange: true });
			this.trigger("change", this, { widgetChange: true });
		},


		/**
		 * Fires change events on the config attribute and persists its value to localStorage.
		 *
		 * This does the same thing as the saveData function, just for the config attribute
		 *
		 * @api     public
		 * @param   {Object}  [config]  Optional. An object that the existing config
		 *                              property should be overwritten with
		 */
		saveConfig: function(config) {
			if (config) {
				this.config = config;
			}

			this.set("config", this.config, {
				silent: true
			});

			// This is the simplest way to ensure that the appropriate
			// change events get triggered.
			//
			// The parent widget instance listens for change events, so we
			// don't need to do anything beyond that
			this.trigger("change:config", this, this.config, { widgetChange: true });
			this.trigger("change", this, { widgetChange: true });
		}
	});

	return WidgetModel;
});
define('w/analytics/model',["lodash", "jquery", "moment", "widgets/model"], function(_, $, moment, WidgetModel) {
	return WidgetModel.extend({
		refreshInterval: 300000,

		defaults: {
			config: {
				title: "Google Analytics™",
				size: "medium",
				profile: false,
				yearyear: "0",
				weekweek: "0",
				topvisited: "0",
				channels: "0"				
			},

			data: {
				common: {
					visits: 0,
					pageviews: 0,
					bounceRate: 0,
					completions: 0,
					pagesVisit: 0
				}
			},

			range: "today"
		},

		oAuth: {
			id: "559765430405-5rvu6sms3mc111781cfgp1atb097rrph.apps.googleusercontent.com",
			secret: "tMLIjQ6-ZpbR3dLMpYFci4MW",
			scope: "https://www.googleapis.com/auth/analytics.readonly"
		},

		getProfiles: function(cb) {
			var done = 0,
				errors = 0,
				profiles = [],
				accounts = {},
				properties = {},
				data = {},
				compile = function() {
					if (errors !== 0) {
						return cb("Error");
					}

					if (++done < 3) {
						return;
					}

					profiles.forEach(function(e) {
						data[e.account] = data[e.account] || {label: accounts[e.account]};
						data[e.account][e.property] = data[e.account][e.property] || {label: properties[e.property].name};

						data[e.account][e.property][e.id] = decodeURIComponent(e.name);
					});

					cb(data);
				};

			this.oAuth.getToken(function(token) {
				$.ajax({
					type: "GET",
					dataType: "json",
					url: "https://www.googleapis.com/analytics/v3/management/accounts",
					beforeSend: function(xhr) {
						xhr.setRequestHeader("Authorization", "Bearer " + token);
					},
					success: function(d) {
						if (!d || !d.items) {
							return errors++;
						}

						d.items.forEach(function(e) {
							accounts[e.id] = e.name;
						});

						compile();
					}
				});

				$.ajax({
					type: "GET",
					dataType: "json",
					url: "https://www.googleapis.com/analytics/v3/management/accounts/~all/webproperties",
					beforeSend: function(xhr) {
						xhr.setRequestHeader("Authorization", "Bearer " + token);
					},
					success: function(d) {
						if (!d || !d.items) {
							return errors++;
						}

						d.items.forEach(function(e) {
							properties[e.id] = {
								name: e.name,
								account: e.accountId
							};
						});

						compile();
					}
				});

				$.ajax({
					type: "GET",
					dataType: "json",
					url: "https://www.googleapis.com/analytics/v3/management/accounts/~all/webproperties/~all/profiles",
					beforeSend: function(xhr) {
						xhr.setRequestHeader("Authorization", "Bearer " + token);
					},
					success: function(d) {
						if (!d || !d.items) {
							return errors++;
						}

						d.items.forEach(function(e) {
							profiles.push({
								id: e.id,
								name: e.name,
								account: e.accountId,
								property: e.webPropertyId
							});
						});

						compile();
					}
				});
			});
		},

		refresh: function() {
			if (!this.config.profile) {
				return false;
			}

			var that = this;

			var start, end;

			switch (this.get("range")) {
				case "yesterday":
					start = end = "yesterday";
				break;

				case "pastweek":
					start = "7daysAgo";
					end = "today";
				break;

				default:
					start = end = "today";
				break;
			}

			var commonReq = {
				"viewId": this.config.profile,
				"dateRanges":[{
					"startDate": start,
					"endDate": end
				  }],
				"metrics": [
					{ "expression": "ga:visits" },
					{ "expression": "ga:pageviews" },
					{ "expression": "ga:visitBounceRate" },
					{ "expression": "ga:goal1Completions" }
				],
				"pageSize": "1"
			};

			var trafficChannelReq = null;
			var isSingleDay = start === end;
			if (isSingleDay) {
				trafficChannelReq = {
					"viewId": this.config.profile,
					"dateRanges": [
					{
					  "startDate": start,
					  "endDate": end
					}],
					"metrics": [{
					  "expression":"ga:sessions"
					}],
					"dimensions": [{
						"name":"ga:nthHour"
					},{
						"name":"ga:channelGrouping"
					}],
					"orderBys": [{
						"fieldName": "ga:nthHour",
						"sortOrder": "ASCENDING"
					},{
						"fieldName": "ga:channelGrouping",
						"sortOrder": "ASCENDING"
					}]
				};
			}else{
				trafficChannelReq = {
					"viewId": this.config.profile,
					"dateRanges": [
					{
					  "startDate": start,
					  "endDate": end,
					}],
					"metrics": [{
					  "expression":"ga:sessions"
					}],
					"dimensions": [{
						"name":"ga:date"
					},{
						"name":"ga:channelGrouping"
					}],
					"orderBys": [{
						"fieldName": "ga:date",
						"sortOrder": "ASCENDING"
					},{
						"fieldName": "ga:channelGrouping",
						"sortOrder": "ASCENDING"
					}]
				};
			}


			var top10Req = {
				"viewId": this.config.profile,
				"dateRanges": [
				{
					"startDate": start,
					"endDate": end
				  }],
				"metrics": [
				{
				  "expression":"ga:pageviews"
				}],
				"dimensions": [{
				  "name":"ga:pagePath"
				}],
				"pageSize": "20",
				"orderBys": [{
					"fieldName": "ga:pageviews",
					"sortOrder": "DESCENDING"
				}],
			};

			var startOfWeek = moment().add(-1, "days").startOf('week');
			var weeklyReq = {
				"viewId": this.config.profile,
				"dateRanges": [{
					"startDate": startOfWeek.clone().add(-7, 'days').format("YYYY-MM-DD"),
					"endDate": startOfWeek.clone().add(-1, 'days').format("YYYY-MM-DD")
				},{
					"startDate": startOfWeek.clone().format("YYYY-MM-DD"),
					"endDate": startOfWeek.clone().add(6, 'days').format("YYYY-MM-DD")
				}],
				"metrics": [
				{
				  "expression":"ga:sessions"
				}],
				"dimensions": [{
				  "name":"ga:dayOfWeek"
				}],
				"orderBys": [{
					"fieldName": "ga:dayOfWeek",
					"sortOrder": "ASCENDING"
				}],
			};

			var thisYear = moment([moment().year(), 0, 1]);
			var thisYearEnd = thisYear.clone().add(1, 'years').subtract(1, 'days');
			var prevYear = thisYear.clone().subtract(1, 'years');
			var prevYearEnd = thisYearEnd.clone().subtract(1, 'years');
			var yearlyReq = {
				"viewId": this.config.profile,
				"dateRanges": [{
					"startDate": prevYear.format("YYYY-MM-DD"),
					"endDate": prevYearEnd.format("YYYY-MM-DD")
				},{
					"startDate": thisYear.format("YYYY-MM-DD"),
					"endDate": thisYearEnd.format("YYYY-MM-DD")
				}],
				"metrics": [
				{
				  "expression":"ga:users"
				}],
				"dimensions": [{
				  "name":"ga:nthMonth"
				}],
				"orderBys": [{
					"fieldName": "ga:nthMonth",
					"sortOrder": "ASCENDING"
				}],
			};

			var data = {};
			data.isTopVisited = this.config.topvisited === "1";
			data.isChannels = this.config.channels === "1";
			data.isYearly = this.config.yearyear === "1";
			data.isWeekly = this.config.weekweek === "1";

			var requests = [commonReq];
			if (data.isTopVisited) {
				requests.push(top10Req);
			}
			if (data.isChannels) {
				requests.push(trafficChannelReq);
			}

			this.oAuth.ajax({
				type: "POST",
				dataType: "json",
				beforeSend: function (xhr) {
					xhr.setRequestHeader("Content-Type", "application/json");
			   	},
				data: JSON.stringify({
					"reportRequests": requests
				}),
				url: "https://analyticsreporting.googleapis.com/v4/reports:batchGet",
				success: function(d) {
					if (d && d.reports && d.reports.length === requests.length) {
						var respCommon = d.reports[0];
						if (respCommon.data && respCommon.data.rows && respCommon.data.rows.length === 1) {
							var row = respCommon.data.rows[0];
							if (row.metrics && row.metrics.length === 1) {
								var metric = row.metrics[0];
								if (metric.values && metric.values.length === 4) {
									var result = metric.values;

									data.common = _.mapValues({
										visits: result[0],
										pageviews: result[1],
										bounceRate: parseInt(result[2] * 100) / 100,
										completions: result[3],
										pagesVisit: parseInt((result[1] / result[0]) * 100) / 100
									}, function(e) {
										return parseInt(e).toLocaleString();
									});
								}
							}
						}

						if (data.isTopVisited) {
							var respTopPages = d.reports[1];
							if (respTopPages.data && respTopPages.data.rows) {
								var items = respTopPages.data.rows.map(function(row) {
									if (!row.dimensions || row.dimensions.length === 0) { return null; }
									if (!row.metrics || row.metrics.length === 0) { return null; }
									var metric = row.metrics[0];
									if (!metric.values || metric.values.length === 0) { return null; }
									return {
										url: row.dimensions[0],
										count: metric.values[0]
									};
								}).filter(function(item) {
									return item !== null;
								});

								data.top10 = {
									items: items
								};
							}
						}						

						if (data.isChannels) {
							var respChannelsTraffic = d.reports[data.isTopVisited ? 2 : 1];
							if (respChannelsTraffic.data && respChannelsTraffic.data.rows) {
								var allItems = respChannelsTraffic.data.rows.map(function(row) {
									if (!row.dimensions || row.dimensions.length !== 2) { return; }
									if (!row.metrics || row.metrics.length === 0) { return; }
									var metric = row.metrics[0];
									if (!metric.values || metric.values.length === 0) { return; }
									return {
										yyyymmdd: parseInt(row.dimensions[0]),
										channel: row.dimensions[1],
										value: Number(metric.values[0])
									};
								});

								var channels = _.uniq(allItems.map(function(el) {
									return el.channel;
								}));

								var chartData = [];
								var header = ["Channels"].concat(channels, [{ role: 'annotation' }]);
								chartData.push(header);

								var groups = _.groupBy(allItems, "yyyymmdd");
								for (var date in groups) {
									var dateChannels = groups[date];
									var chartRow = [];
									if (isSingleDay) {
										chartRow.push(date);
									}else{
										chartRow.push(moment(date + "", 'YYYYMMDD').format("MMM DD"));
									}

									channels.forEach(function(channel) {
										var foundItem = dateChannels.find(function(el) {
											return el.channel === channel;
										});

										chartRow.push(foundItem ? foundItem.value : 0);
									});

									chartRow.push('');
									chartData.push(chartRow);
								}

								data.channels = {
									items: chartData
								};
							}
						}
					}
				},
				complete: function() {
					var yearlyComplete = function() {
						var weeklyComplete = function() {
							if (that.get("range") === "today") {
								that.saveData(data);
							}
							else {
								that.trigger("data:loaded", data);
							}
						};
						
						if (data.isYearly) {
							this.oAuth.ajax({
								type: "POST",
								dataType: "json",
								beforeSend: function (xhr) {
									xhr.setRequestHeader("Content-Type", "application/json");
								   },
								data: JSON.stringify({
									"reportRequests": [ yearlyReq ]
								}),
								url: "https://analyticsreporting.googleapis.com/v4/reports:batchGet",
								success: function(d) {
									if (d && d.reports && d.reports.length === 1) {
										var chartData = [['Year', 'Last Year', 'This Year']];
										var restWeekly = d.reports[0];
										if (restWeekly.data && restWeekly.data.rows) {
											restWeekly.data.rows.forEach(function(row) {
												if (!row.dimensions || row.dimensions.length === 0) { return; }
												if (!row.metrics || row.metrics.length !== 2) { return; }
												var metric0 = row.metrics[0];
												var metric1 = row.metrics[1];
												if (!metric0.values || metric0.values.length === 0) { return; }
												if (!metric1.values || metric1.values.length === 0) { return; }
												chartData.push([
													moment((parseInt(row.dimensions[0]) + 1) + "", "M").format("MMM"), 
													metric0.values[0] === "0" ? null : Number(metric0.values[0]), 
													metric1.values[0] === "0" ? null : Number(metric1.values[0])
												]);
											});
		
											data.yearly = {
												items: chartData
											};
										}
									}
		
									//this.trigger("data:loaded", data);
								},
								complete: function() {
									weeklyComplete();
								}
							});
						}else{
							weeklyComplete();
						}
					}.bind(this);

					if (data.isWeekly) {
						this.oAuth.ajax({
							type: "POST",
							dataType: "json",
							beforeSend: function (xhr) {
								xhr.setRequestHeader("Content-Type", "application/json");
							   },
							data: JSON.stringify({
								"reportRequests": [ weeklyReq ]
							}),
							url: "https://analyticsreporting.googleapis.com/v4/reports:batchGet",
							success: function(d) {
								if (d && d.reports && d.reports.length === 1) {
									var chartData = [['Week', 'Last Week', 'This Week']];
									var restWeekly = d.reports[0];
									if (restWeekly.data && restWeekly.data.rows) {
										restWeekly.data.rows.forEach(function(row) {
											if (!row.dimensions || row.dimensions.length === 0) { return; }
											if (!row.metrics || row.metrics.length !== 2) { return; }
											var metric0 = row.metrics[0];
											var metric1 = row.metrics[1];
											if (!metric0.values || metric0.values.length === 0) { return; }
											if (!metric1.values || metric1.values.length === 0) { return; }
											chartData.push([
												moment().isoWeekday(Number(row.dimensions[0])).format("ddd"), 
												metric0.values[0] === "0" ? null : Number(metric0.values[0]), 
												metric1.values[0] === "0" ? null : Number(metric1.values[0])
											]);
										});
	
										data.weekly = {
											items: chartData
										};
									}
								}
	
								//this.trigger("data:loaded", data);
							},
							complete: function() {
								yearlyComplete();

							}.bind(this)
						});
					}else{
						yearlyComplete();
					}
		
				}.bind(this)
			});

			
		}
	});
});
define('w/classroom/view',["widgets/views/main"], function(WidgetView) {
	return WidgetView.extend({
		isFrame: true,

		onBeforeRender: function(data) {
			data.url = "https://classroom.google.com/u/" + (this.model.config.user || 0) + (this.model.config.mode === "teacher" ? "/ta/not-reviewed/all" : "/a/not-turned-in/all");

			return data;
		},

		onRender: function() {
			this.el.style.height = "450px";
		}
	});
});
define('w/classroom/maximized',["./view"], function(MainView) {
	return MainView.extend({
		onRender: null
	});
});

define("widgetTemplate!w/classroom/templates/desc.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Use this widget to keep up with your assignments and class changes in Google Classroom.<br /> <br /> Please note that this widget isn't available when you're offline.");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/classroom/templates/main.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<iframe src=\"");t.b(t.v(t.f("url",c,p,0)));t.b("\" sandbox=\"allow-same-origin allow-popups allow-forms allow-scripts\" seamless></iframe>");return t.fl(); },partials: {}, subs: {  }})});
define('w/classroom/model',["widgets/model"], function(WidgetModel) {
	return WidgetModel.extend({
		defaults: {
			config: {
				user: "0",
				mode: "student",
				size: "variable"
			}
		}
	});
});
define('w/currency/view',["lodash", "widgets/views/main"], function(_, WidgetView) {
	var currencies = {
		AED: "United Arab Emirates Dirham",
		AFN: "Afghan Afghani",
		ALL: "Albanian Lek",
		AMD: "Armenian Dram",
		ANG: "Netherlands Antillean Guilder",
		AOA: "Angolan Kwanza",
		ARS: "Argentine Peso",
		AUD: "Australian Dollar",
		AWG: "Aruban Florin",
		AZN: "Azerbaijani Manat",
		BAM: "Bosnia-Herzegovina Convertible Mark",
		BBD: "Barbadian Dollar",
		BDT: "Bangladeshi Taka",
		BGN: "Bulgarian Lev",
		BHD: "Bahraini Dinar",
		BIF: "Burundian Franc",
		BMD: "Bermudan Dollar",
		BND: "Brunei Dollar",
		BOB: "Bolivian Boliviano",
		BRL: "Brazilian Real",
		BSD: "Bahamian Dollar",
		BTC: "Bitcoin",
		BTN: "Bhutanese Ngultrum",
		BWP: "Botswanan Pula",
		BYN: "Belarusian Ruble",
		BZD: "Belize Dollar",
		CAD: "Canadian Dollar",
		CDF: "Congolese Franc",
		CHF: "Swiss Franc",
		CLF: "Chilean Unit of Account (UF)",
		CLP: "Chilean Peso",
		CNH: "Chinese Yuan (Offshore)",
		CNY: "Chinese Yuan",
		COP: "Colombian Peso",
		CRC: "Costa Rican Colón",
		CUC: "Cuban Convertible Peso",
		CUP: "Cuban Peso",
		CVE: "Cape Verdean Escudo",
		CZK: "Czech Republic Koruna",
		DJF: "Djiboutian Franc",
		DKK: "Danish Krone",
		DOP: "Dominican Peso",
		DZD: "Algerian Dinar",
		EGP: "Egyptian Pound",
		ERN: "Eritrean Nakfa",
		ETB: "Ethiopian Birr",
		EUR: "Euro",
		FJD: "Fijian Dollar",
		FKP: "Falkland Islands Pound",
		GBP: "British Pound Sterling",
		GEL: "Georgian Lari",
		GGP: "Guernsey Pound",
		GHS: "Ghanaian Cedi",
		GIP: "Gibraltar Pound",
		GMD: "Gambian Dalasi",
		GNF: "Guinean Franc",
		GTQ: "Guatemalan Quetzal",
		GYD: "Guyanaese Dollar",
		HKD: "Hong Kong Dollar",
		HNL: "Honduran Lempira",
		HRK: "Croatian Kuna",
		HTG: "Haitian Gourde",
		HUF: "Hungarian Forint",
		IDR: "Indonesian Rupiah",
		ILS: "Israeli New Sheqel",
		IMP: "Manx pound",
		INR: "Indian Rupee",
		IQD: "Iraqi Dinar",
		IRR: "Iranian Rial",
		ISK: "Icelandic Króna",
		JEP: "Jersey Pound",
		JMD: "Jamaican Dollar",
		JOD: "Jordanian Dinar",
		JPY: "Japanese Yen",
		KES: "Kenyan Shilling",
		KGS: "Kyrgystani Som",
		KHR: "Cambodian Riel",
		KMF: "Comorian Franc",
		KPW: "North Korean Won",
		KRW: "South Korean Won",
		KWD: "Kuwaiti Dinar",
		KYD: "Cayman Islands Dollar",
		KZT: "Kazakhstani Tenge",
		LAK: "Laotian Kip",
		LBP: "Lebanese Pound",
		LKR: "Sri Lankan Rupee",
		LRD: "Liberian Dollar",
		LSL: "Lesotho Loti",
		LYD: "Libyan Dinar",
		MAD: "Moroccan Dirham",
		MDL: "Moldovan Leu",
		MGA: "Malagasy Ariary",
		MKD: "Macedonian Denar",
		MMK: "Myanma Kyat",
		MNT: "Mongolian Tugrik",
		MOP: "Macanese Pataca",
		MRO: "Mauritanian Ouguiya (pre-2018)",
		MRU: "Mauritanian Ouguiya",
		MUR: "Mauritian Rupee",
		MVR: "Maldivian Rufiyaa",
		MWK: "Malawian Kwacha",
		MXN: "Mexican Peso",
		MYR: "Malaysian Ringgit",
		MZN: "Mozambican Metical",
		NAD: "Namibian Dollar",
		NGN: "Nigerian Naira",
		NIO: "Nicaraguan Córdoba",
		NOK: "Norwegian Krone",
		NPR: "Nepalese Rupee",
		NZD: "New Zealand Dollar",
		OMR: "Omani Rial",
		PAB: "Panamanian Balboa",
		PEN: "Peruvian Nuevo Sol",
		PGK: "Papua New Guinean Kina",
		PHP: "Philippine Peso",
		PKR: "Pakistani Rupee",
		PLN: "Polish Zloty",
		PYG: "Paraguayan Guarani",
		QAR: "Qatari Rial",
		RON: "Romanian Leu",
		RSD: "Serbian Dinar",
		RUB: "Russian Ruble",
		RWF: "Rwandan Franc",
		SAR: "Saudi Riyal",
		SBD: "Solomon Islands Dollar",
		SCR: "Seychellois Rupee",
		SDG: "Sudanese Pound",
		SEK: "Swedish Krona",
		SGD: "Singapore Dollar",
		SHP: "Saint Helena Pound",
		SLL: "Sierra Leonean Leone",
		SOS: "Somali Shilling",
		SRD: "Surinamese Dollar",
		SSP: "South Sudanese Pound",
		STD: "São Tomé and Príncipe Dobra (pre-2018)",
		STN: "São Tomé and Príncipe Dobra",
		SVC: "Salvadoran Colón",
		SYP: "Syrian Pound",
		SZL: "Swazi Lilangeni",
		THB: "Thai Baht",
		TJS: "Tajikistani Somoni",
		TMT: "Turkmenistani Manat",
		TND: "Tunisian Dinar",
		TOP: "Tongan Pa'anga",
		TRY: "Turkish Lira",
		TTD: "Trinidad and Tobago Dollar",
		TWD: "New Taiwan Dollar",
		TZS: "Tanzanian Shilling",
		UAH: "Ukrainian Hryvnia",
		UGX: "Ugandan Shilling",
		USD: "United States Dollar",
		UYU: "Uruguayan Peso",
		UZS: "Uzbekistan Som",
		VEF: "Venezuelan Bolívar Fuerte (Old)",
		VES: "Venezuelan Bolívar Soberano",
		VND: "Vietnamese Dong",
		VUV: "Vanuatu Vatu",
		WST: "Samoan Tala",
		XAF: "CFA Franc BEAC",
		XAG: "Silver Ounce",
		XAU: "Gold Ounce",
		XCD: "East Caribbean Dollar",
		XDR: "Special Drawing Rights",
		XOF: "CFA Franc BCEAO",
		XPD: "Palladium Ounce",
		XPF: "CFP Franc",
		XPT: "Platinum Ounce",
		YER: "Yemeni Rial",
		ZAR: "South African Rand",
		ZMW: "Zambian Kwacha",
		ZWL: "Zimbabwean Dollar"
	};

	return WidgetView.extend({
		events: {
			"change select": "convert",
			"input input.fromval": "convert",

			"input input.toval": function() {
				this.convert(true);
			},

			"keyup input": function(e) {
				if (e.which === 17) {
					this._ctrlDown = false;
				}
			},

			"keydown input": function(e) {
				var w = e.which;

				if (w === 17) {
					this._ctrlDown = true;
				}

				if (w === 13) {
					e.preventDefault();

					this.convert();
				}
				else if (!(this._ctrlDown || (
					(w > 47 && w < 58) ||
					(w > 36 && w < 41) ||
					(w > 95 && w < 106) ||
					w === 8 || w === 9 ||
					w === 46 || w === 17 ||
					w === 65 || w === 190
				))) {
					e.preventDefault();
				}
			},

			"click button.swap": function() {
				var temp = this.$("select.from").val();

				this.$("select.from").val(this.$("select.to").val());
				this.$("select.to").val(temp);

				temp = this.$(".fromval").val();

				this.$(".fromval").val(this.$(".toval").val());
				this.$(".toval").val(temp);
			}
		},

		convert: function(reverse) {
			var to = this.$("select.to").val(),
				from = this.$("select.from").val();

			this.model.saveSyncData({
				to: to,
				from: from,

				recentTo: _(this.model.syncData.recentTo || []).unshift(to).uniq().take(15).value(),
				recentFrom: _(this.model.syncData.recentFrom || []).unshift(from).uniq().take(15).value()
			});


			if (reverse === true) {
				this.model.getConversion(this.$(".toval").val(), to, from, function(converted) {
					this.$(".fromval").val(converted);
				}, this);
			}
			else {
				this.model.getConversion(this.$(".fromval").val(), from, to, function(converted) {
					this.$(".toval").val(converted);
				}, this);
			}
		},

		initialize: function() {
			this.render();

			this.model.getConversion(1, this.model.syncData.from, this.model.syncData.to, function(converted) {
				this.$("input.toval").val(converted);
			}, this);
		},

		render: function(data, partials) {
			return WidgetView.prototype.render.call(this, data || this.model.syncData, partials);
		},

		onBeforeRender: function(data) {
			var mapRecents = function(recents) {
				return _.map(recents || ["USD"], function(code) {
					return {
						name: currencies[code],
						code: code,
						selected: code === "USD"
					};
				});
			};

			data.recentTo = mapRecents(data.recentTo);
			data.recentFrom = mapRecents(data.recentFrom);

			data.currencies = _.map(currencies, function(name, code) {
				return {
					name: name,
					code: code
				};
			});

			return data;
		}
	});
});

define("widgetTemplate!w/currency/templates/desc.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("This widget lets you convert to and from any of 169 currencies, including Bitcoin.  It'll also remember which ones you used last.");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/currency/templates/main.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<div class=\"selectbar\"> <select class=\"from\"> <optgroup label=\"");t.b(t.v(t.d("i18n.recently_used",c,p,0)));t.b("\"> ");if(t.s(t.f("recentFrom",c,p,1),c,p,0,103,147,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <option value=\"");t.b(t.v(t.f("code",c,p,0)));t.b("\">");t.b(t.v(t.f("name",c,p,0)));t.b("</option> ");});c.pop();}t.b(" </optgroup> ");if(t.s(t.f("currencies",c,p,1),c,p,0,190,269,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <option value=\"");t.b(t.v(t.f("code",c,p,0)));t.b("\" ");if(t.s(t.f("selected",c,p,1),c,p,0,229,237,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("selected");});c.pop();}t.b(">");t.b(t.v(t.f("name",c,p,0)));t.b("</option> ");});c.pop();}t.b(" </select> <button type=\"button\" class=\"material toggle m-icon swap\">swap_horiz</button> <select class=\"to\"> <optgroup label=\"");t.b(t.v(t.d("i18n.recently_used",c,p,0)));t.b("\"> ");if(t.s(t.f("recentTo",c,p,1),c,p,0,448,492,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <option value=\"");t.b(t.v(t.f("code",c,p,0)));t.b("\">");t.b(t.v(t.f("name",c,p,0)));t.b("</option> ");});c.pop();}t.b(" </optgroup> ");if(t.s(t.f("currencies",c,p,1),c,p,0,533,612,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <option value=\"");t.b(t.v(t.f("code",c,p,0)));t.b("\" ");if(t.s(t.f("selected",c,p,1),c,p,0,572,580,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("selected");});c.pop();}t.b(">");t.b(t.v(t.f("name",c,p,0)));t.b("</option> ");});c.pop();}t.b(" </select> </div> <div class=\"inputs\"> <input type=\"number\" class=\"fromval\" value=\"1\" /> <span class=\"equals\">=</span> <input type=\"number\" class=\"toval\" value=\"1\" /> </div>");return t.fl(); },partials: {}, subs: {  }})});
define('w/currency/model',["lodash", "jquery", "widgets/model"], function(_, $, WidgetModel) {
	return WidgetModel.extend({
		defaults: {
			syncData: {
				from: "USD",
				to: "EUR",
				recentFrom: ["USD"],
				recentTo: ["EUR"]
			}
		},

		rates: null,

		initialize: function() {
			if (typeof this.data === "object" && this.data.from) {
				this.set("syncData", this.data);

				this.unset("data");
			}
		},

		getConversion: function(value, from, to, cb, ctx) {
			ctx = ctx || this;

			if (from === to) {
				return cb.call(ctx, value * 1);
			}

			if (this.rates) {
				cb.call(ctx, Math.round((value / this.rates[from]) * this.rates[to] * 10000) / 10000);
			}
			else {
				$.getJSON("https://api.ichro.me/currency/v1/rates", function(d) {
					if (d) {
						this.rates = d;

						cb.call(ctx, Math.round((value / this.rates[from]) * this.rates[to] * 10000) / 10000);
					}
				}.bind(this));
			}
		}
	});
});
define('w/dictionary/view',["lodash", "jquery", "browser/api", "widgets/views/main"], function(_, $, Browser, WidgetView) {
	return WidgetView.extend({
		events: {
			"click button.more": function(e) {
				this._isExpanded = !this._isExpanded;

				this.$(".forms, ol li .synonyms, ol li .antonyms, ol li:nth-child(n + 2), .usage:nth-of-type(n + 3), .usage ~ .web-definitions")[this._isExpanded ? "slideDown" : "slideUp"](300);

				e.currentTarget.textContent = this.translate(this._isExpanded ? "less" : "more");
			},

			"click button.audio": function(e) {
				if (this._audio && !this._audio.paused) {
					this._audio.pause();
				}
				else {
					if (!this._audio) {
						this._audio = new Audio();
						this._audio.autoplay = true;
					}

					this._audio.currentTime = 0;
					this._audio.src = e.currentTarget.getAttribute("data-url");

					this._audio.play();
				}
			},

			"click span.has-def": function(e) {
				this.lookupTerm(e.currentTarget.textContent.trim());
			},

			"keydown header input": function(e) {
				if (e.which === 13) {
					this.lookupTerm(e.currentTarget.value.trim());
				}
			}
		},

		lookupTerm: function(term) {
			this.render({
				loading: true
			});

			this.model.getDefinition(term, null, function(err, d) {
				if (!err && d) {
					this.render({
						definition: d
					});
				}
				else {
					this.render({
						error: true
					});
				}
			}.bind(this));
		},

		onRender: function() {
			// If we're already expanded, keep it that way
			if (this._isExpanded) {
				this.$(".forms, ol li .synonyms, ol li .antonyms, .usage:nth-of-type(n + 3), .usage ~ .web-definitions").css("display", "block");

				this.$("ol li:nth-child(n + 2)").css("display", "list-item");

				this.$("button.more").text(this.translate("less"));
			}
		}
	});
});
define('widgets/views/settings',["widgets/views/main"], function(WidgetView) {
	return WidgetView.extend({
		getTemplate: function() {
			return this.widget.templates.settings;
		},

		render: function(data, partials) {
			return WidgetView.prototype.render.call(this, data || this.model.config, partials);
		}
	});
});
/*!
  SerializeJSON jQuery plugin.
  https://github.com/marioizquierdo/jquery.serializeJSON
  version 2.1.0 (May, 2014)

  MODIFIED FOR AMD USAGE

  Copyright (c) 2014 Mario Izquierdo
  Dual licensed under the MIT (http://www.opensource.org/licenses/mit-license.php)
  and GPL (http://www.opensource.org/licenses/gpl-license.php) licenses.
*/
(function(factory) {

  // Set up Backbone appropriately for the environment. Start with AMD.
  if (typeof define === 'function' && define.amd) {
    define('jquery.serializejson',['jquery'], function($) {
      // Export global even in AMD case in case this script is loaded with
      // others that may still expect a global Backbone.
      factory($);
    });

  // As a browser global.
  } else {
    factory(window.jQuery || window.Zepto || window.$);
  }

}(function ($) {
  "use strict";

  // jQuery('form').serializeJSON()
  $.fn.serializeJSON = function (options) {
    var serializedObject, formAsArray, keys, value, f, opts;
    f = $.serializeJSON;
    formAsArray = this.serializeArray(); // array of objects {name, value}
    opts = f.optsWithDefaults(options); // calculate values for options {parseNumbers, parseBoolens, parseNulls}

    serializedObject = {};
    $.each(formAsArray, function (i, input) {
      keys = f.splitInputNameIntoKeysArray(input.name); // "some[deep][key]" => ['some', 'deep', 'key']
      value = f.parseValue(input.value, opts); // string, number, boolean or null
      if (opts.parseWithFunction) value = opts.parseWithFunction(value); // allow for custom parsing
      f.deepSet(serializedObject, keys, value, opts);
    });
    return serializedObject;
  };

  // Use $.serializeJSON as namespace for the auxiliar functions
  // and to define defaults
  $.serializeJSON = {

    defaultOptions: {
      parseNumbers: false, // convert values like "1", "-2.33" to 1, -2.33
      parseBooleans: false, // convert "true", "false" to true, false
      parseNulls: false, // convert "null" to null
      parseAll: false, // all of the above
      parseWithFunction: null, // to use custom parser, use a function like: function (val) => parsed_val
      useIntKeysAsArrayIndex: false // name="foo[2]" value="v" => {foo: [null, null, "v"]}, instead of {foo: ["2": "v"]}
    },

    // Merge options with defaults to get {parseNumbers, parseBoolens, parseNulls, useIntKeysAsArrayIndex}
    optsWithDefaults: function(options) {
      var f, parseAll;
      if (options == null) options = {}; // arg default value = {}
      f = $.serializeJSON;
      parseAll = f.optWithDefaults('parseAll', options);
      return {
        parseNumbers:  parseAll || f.optWithDefaults('parseNumbers',  options),
        parseBooleans: parseAll || f.optWithDefaults('parseBooleans', options),
        parseNulls:    parseAll || f.optWithDefaults('parseNulls',    options),
        parseWithFunction:         f.optWithDefaults('parseWithFunction', options),
        useIntKeysAsArrayIndex:    f.optWithDefaults('useIntKeysAsArrayIndex', options)
      }
    },

    optWithDefaults: function(key, options) {
      return (options[key] !== false) && (options[key] || $.serializeJSON.defaultOptions[key]);
    },

    // Convert the string to a number, boolean or null, depending on the enable option and the string format.
    parseValue: function(str, opts) {
      var value, f;
      f = $.serializeJSON;
      if (opts.parseNumbers  && f.isNumeric(str)) return Number(str); // number
      if (opts.parseBooleans && (str === "true" || str === "false")) return str === "true"; // boolean
      if (opts.parseNulls    && str == "null") return null; // null
      return str; // otherwise, keep same string
    },

    isObject:          function(obj) { return obj === Object(obj); }, // is this variable an object?
    isUndefined:       function(obj) { return obj === void 0; }, // safe check for undefined values
    isValidArrayIndex: function(val) { return /^[0-9]+$/.test(String(val)); }, // 1,2,3,4 ... are valid array indexes
    isNumeric:         function(obj) { return obj - parseFloat(obj) >= 0; }, // taken from jQuery.isNumeric implementation. Not using jQuery.isNumeric to support old jQuery and Zepto versions

    // Split the input name in programatically readable keys
    // "foo"              => ['foo']
    // "[foo]"            => ['foo']
    // "foo[inn][bar]"    => ['foo', 'inn', 'bar']
    // "foo[inn][arr][0]" => ['foo', 'inn', 'arr', '0']
    // "arr[][val]"       => ['arr', '', 'val']
    splitInputNameIntoKeysArray: function (name) {
      var keys, last, f;
      f = $.serializeJSON;
      if (f.isUndefined(name)) { throw new Error("ArgumentError: param 'name' expected to be a string, found undefined"); }
      keys = $.map(name.split('['), function (key) {
        last = key[key.length - 1];
        return last === ']' ? key.substring(0, key.length - 1) : key;
      });
      if (keys[0] === '') { keys.shift(); } // "[foo][inn]" should be same as "foo[inn]"
      return keys;
    },

    // Set a value in an object or array, using multiple keys to set in a nested object or array:
    //
    // deepSet(obj, ['foo'], v)               // obj['foo'] = v
    // deepSet(obj, ['foo', 'inn'], v)        // obj['foo']['inn'] = v // Create the inner obj['foo'] object, if needed
    // deepSet(obj, ['foo', 'inn', '123'], v) // obj['foo']['arr']['123'] = v //
    //
    // deepSet(obj, ['0'], v)                                   // obj['0'] = v
    // deepSet(arr, ['0'], v, {useIntKeysAsArrayIndex: true})   // arr[0] = v
    // deepSet(arr, [''], v)                                    // arr.push(v)
    // deepSet(obj, ['arr', ''], v)                             // obj['arr'].push(v)
    //
    // arr = [];
    // deepSet(arr, ['', v]          // arr => [v]
    // deepSet(arr, ['', 'foo'], v)  // arr => [v, {foo: v}]
    // deepSet(arr, ['', 'bar'], v)  // arr => [v, {foo: v, bar: v}]
    // deepSet(arr, ['', 'bar'], v)  // arr => [v, {foo: v, bar: v}, {bar: v}]
    //
    deepSet: function (o, keys, value, opts) {
      var key, nextKey, tail, lastIdx, lastVal, f;
      if (opts == null) opts = {};
      f = $.serializeJSON;
      if (f.isUndefined(o)) { throw new Error("ArgumentError: param 'o' expected to be an object or array, found undefined"); }
      if (!keys || keys.length === 0) { throw new Error("ArgumentError: param 'keys' expected to be an array with least one element"); }

      key = keys[0];

      // Only one key, then it's not a deepSet, just assign the value.
      if (keys.length === 1) {
        if (key === '') {
          o.push(value); // '' is used to push values into the array (assume o is an array)
        } else {
          o[key] = value; // other keys can be used as object keys or array indexes
        }

      // With more keys is a deepSet. Apply recursively.
      } else {

        nextKey = keys[1];

        // '' is used to push values into the array,
        // with nextKey, set the value into the same object, in object[nextKey].
        // Covers the case of ['', 'foo'] and ['', 'var'] to push the object {foo, var}, and the case of nested arrays.
        if (key === '') {
          lastIdx = o.length - 1; // asume o is array
          lastVal = o[lastIdx];
          if (f.isObject(lastVal) && (f.isUndefined(lastVal[nextKey]) || keys.length > 2)) { // if nextKey is not present in the last object element, or there are more keys to deep set
            key = lastIdx; // then set the new value in the same object element
          } else {
            key = lastIdx + 1; // otherwise, point to set the next index in the array
          }
        }

        // o[key] defaults to object or array, depending if nextKey is an array index (int or '') or an object key (string)
        if (f.isUndefined(o[key])) {
          if (nextKey === '') { // '' is used to push values into the array.
            o[key] = [];
          } else if (opts.useIntKeysAsArrayIndex && f.isValidArrayIndex(nextKey)) { // if 1, 2, 3 ... then use an array, where nextKey is the index
            o[key] = [];
          } else { // for anything else, use an object, where nextKey is going to be the attribute name
            o[key] = {};
          }
        }

        // Recursively set the inner object
        tail = keys.slice(1);
        f.deepSet(o[key], tail, value, opts);
      }
    }

  };

}));
define('w/dictionary/settings',["lodash", "jquery", "widgets/views/settings", "jquery.serializejson"], function(_, $, WidgetView) {
	return WidgetView.extend({
		events: {
			"click header button.save": "serialize",

			"keydown label.input > input": function(e) {
				if (e.which === 13) {
					this.serialize();
				}
			}
		},


		/**
		 * Serializes and saves the contents of the settings form
		 */
		serialize: function() {
			var config = _.assign({}, this.model.config, this.$("form").serializeJSON());
			this.model.set({
				config: config,
				state: "default"
			});
		},


		initialize: function() {
			this.render();
		},

		onBeforeRender: function(config) {
			return config;
		},

		onRender: function(config) {
			this.$(".lang").val(config.lang);
		}
	});
});

define("widgetTemplate!w/dictionary/templates/desc.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/dictionary/templates/main.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<header data-m-icon-before=\"search\"> <input type=\"search\" placeholder=\"");t.b(t.v(t.d("i18n.search_placeholder",c,p,0)));t.b("\" /> </header> ");if(t.s(t.f("loading",c,p,1),c,p,0,125,359,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"loading\"> <svg class=\"spinner\" width=\"65px\" height=\"65px\" viewBox=\"0 0 66 66\" xmlns=\"http://www.w3.org/2000/svg\"> <circle fill=\"none\" stroke-width=\"6\" stroke-linecap=\"round\" cx=\"33\" cy=\"33\" r=\"30\"></circle> </svg> </div> ");});c.pop();}t.b(" ");if(!t.s(t.f("loading",c,p,1),c,p,1,0,0,"")){t.b(" ");if(t.s(t.f("definition",c,p,1),c,p,0,400,1355,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"definition\"> ");if(t.s(t.f("first",c,p,1),c,p,0,436,512,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<button type=\"button\" class=\"material flat blue more\">");t.b(t.v(t.d("i18n.more",c,p,0)));t.b("</button>");});c.pop();}t.b(" <h2 class=\"term\">");t.b(t.v(t.f("word",c,p,0)));t.b("</h2> ");if(t.s(t.f("phonetics",c,p,1),c,p,0,568,727,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <h3 class=\"pronunciation\"> <span>");t.b(t.v(t.f("text",c,p,0)));t.b("</span> ");if(t.s(t.f("audio",c,p,1),c,p,0,628,710,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<button type=\"button\" class=\"audio m-icon\" data-url=\"");t.b(t.v(t.f("audio",c,p,0)));t.b("\">volume_up</button>");});c.pop();}t.b(" </h3> ");});c.pop();}t.b(" ");if(t.s(t.f("meanings",c,p,1),c,p,0,755,1334,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"usage\"> <div class=\"form\">");t.b(t.v(t.f("partOfSpeech",c,p,0)));t.b("</div> <ol class=\"definitions\"> ");if(t.s(t.f("definitions",c,p,1),c,p,0,858,1304,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <li> <p class=\"definition\">");t.b(t.t(t.f("definition",c,p,0)));t.b("</p> ");if(t.s(t.f("example",c,p,1),c,p,0,919,955,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<q class=\"example\">");t.b(t.t(t.f("example",c,p,0)));t.b("</q>");});c.pop();}t.b(" ");if(t.s(t.d("synonyms.0",c,p,1),c,p,0,983,1117,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"synonyms\"> <i class=\"title\">");t.b(t.v(t.d("i18n.synonyms",c,p,0)));t.b(":</i> ");if(t.s(t.f("synonyms",c,p,1),c,p,0,1060,1096,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <span class=\"has-def\">");t.b(t.v(t.d(".",c,p,0)));t.b("</span> ");});c.pop();}t.b(" </div> ");});c.pop();}t.b(" ");if(t.s(t.d("antonyms.0",c,p,1),c,p,0,1148,1282,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"antonyms\"> <i class=\"title\">");t.b(t.v(t.d("i18n.antonyms",c,p,0)));t.b(":</i> ");if(t.s(t.f("antonyms",c,p,1),c,p,0,1225,1261,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <span class=\"has-def\">");t.b(t.v(t.d(".",c,p,0)));t.b("</span> ");});c.pop();}t.b(" </div> ");});c.pop();}t.b(" </li> ");});c.pop();}t.b(" </ol> </div> ");});c.pop();}t.b(" </div> ");});c.pop();}t.b(" ");if(!t.s(t.f("definition",c,p,1),c,p,1,0,0,"")){t.b(" <div class=\"splash no-definition\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"> <path d=\"M12 2C6.48 2 2 6.48 2 12s4.48 10 10 10 10-4.48 10-10S17.52 2 12 2zm0 18c-4.42 0-8-3.58-8-8 0-1.85.63-3.55 1.69-4.9L16.9 18.31C15.55 19.37 13.85 20 12 20zm6.31-3.1L7.1 5.69C8.45 4.63 10.15 4 12 4c4.42 0 8 3.58 8 8 0 1.85-.63 3.55-1.69 4.9z\"></path> </svg> <p>");t.b(t.v(t.d("i18n.no_definitions",c,p,0)));t.b("</p> </div> ");};t.b(" ");};return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/dictionary/templates/settings.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<header> <span class=\"title\">");t.b(t.v(t.d("i18n.settings.page_title",c,p,0)));t.b("</span> <button type=\"button\" class=\"material flat blue save\">");t.b(t.v(t.d("i18n.settings.save",c,p,0)));t.b("</button> </header> <form class=\"material-form ");t.b(t.v(t.f("source",c,p,0)));t.b("\"> <div class=\"msn-wrapper\"> <label class=\"input\"> <span>");t.b(t.v(t.d("i18n.settings.lang",c,p,0)));t.b("</span> <select class=\"lang\" name=\"lang\"> <option value=\"en\">English</option> <option value=\"hi\">Hindi</option> <option value=\"es\">Spanish</option> <option value=\"fr\">French</option> <option value=\"ja\">Japanese</option> <option value=\"ru\">Russian</option> <option value=\"de\">German</option> <option value=\"it\">Italian</option> <option value=\"ko\">Korean</option> <option value=\"pt-BR\">Brazilian Portuguese</option> <option value=\"ar\">Arabic</option> <option value=\"tr\">Turkish</option> </select> </label> </div> </form>");return t.fl(); },partials: {}, subs: {  }})});
define('w/dictionary/model',["jquery", "lodash", "browser/api", "widgets/model"], function($, _, Browser, WidgetModel) {
	return WidgetModel.extend({
		defaults: {
			config: {
				title: "i18n.name",
				lang: "en",
			},

			data: {
				defaultWord: "test",
				definition: [
					{
						"word": "test",
						"first": 1,
						"phonetics": [
							{
								"text": "/tɛst/",
								"audio": "https://lex-audio.useremarkable.com/mp3/test_us_1.mp3"
							}
						],
						"meanings": [
							{
								"partOfSpeech": "noun",
								"definitions": [
									{
										"definition": "A procedure intended to establish the quality, performance, or reliability of something, especially before it is taken into widespread use.",
										"example": "no sparking was visible during the tests",
										"synonyms": [
											"trial",
											"experiment",
											"pilot study",
											"try-out"
										]
									},
									{
										"definition": "A movable hearth in a reverberating furnace, used for separating gold or silver from lead.",
										"example": "When fully prepared, the test is allowed to dry, and is then placed in a  furnace, constructed in all respects like a common reverberator)' furnace,  except that a space is left open in the bed of it to receive the test, and that  the width of the arch is much reduced."
									}
								]
							},
							{
								"partOfSpeech": "transitive verb",
								"definitions": [
									{
										"definition": "Take measures to check the quality, performance, or reliability of (something), especially before putting it into widespread use or practice.",
										"example": "this range has not been tested on animals",
										"synonyms": [
											"try out",
											"trial",
											"carry out trials on",
											"put to the test",
											"put through its paces",
											"experiment with",
											"pilot"
										]
									}
								]
							}
						]
					},
					{
						"word": "test",
						"phonetics": [
							{
								"text": "/tɛst/",
								"audio": "https://lex-audio.useremarkable.com/mp3/test_us_1.mp3"
							}
						],
						"meanings": [
							{
								"partOfSpeech": "noun",
								"definitions": [
									{
										"definition": "The shell or integument of some invertebrates and protozoans, especially the chalky shell of a foraminiferan or the tough outer layer of a tunicate.",
										"example": "The tests of the shells are recrystallized, but the original ornamentation is preserved in very good detail."
									}
								]
							}
						]
					}
				]
			}
		},

		getDefinition: function(term, lang, cb) {
			lang = lang || this.config.lang || Browser.language || "en";
			$.ajax({
				type: "GET",
				dataType: "json",
				url: "https://api.dictionaryapi.dev/api/v2/entries/" + lang + "/" + encodeURIComponent(term),
				success: function(d) {
					if (!d || !Array.isArray(d) || !d[0].word) {
						return cb.call(this, true);
					}

					d[0].first = 1;
					cb.call(this, null, d);
				}.bind(this),
			}).fail(function() {
				cb.call(this, true);
			});
		},

		getWordOfDay: function(cb) {
			$.getJSON("https://cloud.feedly.com/v3/streams/contents?count=1&streamId=feed%2Fhttp%3A%2F%2Fwww.thefreedictionary.com%2F_%2FWoD%2Frss.aspx", function(d) {
				if (d && d.items && d.items[0] && d.items[0].title) {
					cb.call(this, null, d.items[0].title.trim());
				}
				else {
					cb.call(this, true);
				}
			}.bind(this)).fail(cb.bind(this, true, null));
		},

		/**
		 * We override this so we only refresh once on init
		 */
		initialize: function() {
			this.getWordOfDay(function(err, word) {
				if (!err && word) {
					this.getDefinition(word, "en", function(err, definition) {
						if (!err && definition) {
							this.saveData({
								defaultWord: word,
								definition: definition
							});
						}
					});
				}
			});
		}
	});
});
define('w/drive/view',["lodash", "widgets/views/main", "moment"], function(_, WidgetView, moment) {
	return WidgetView.extend({
		onBeforeRender: function(data) {
			data.files = _.map(data.files, function(e) {
				// A clone inside the loop is faster than a deep clone of the
				// entire data object
				e = _.clone(e);

				var date = moment(e.date);

				if (moment().diff(date, "days") > 7) {
					e.modified = date.format("MMMM Do YYYY") + " " + this.translate("modified_by") + " " + e.user;
				}
				else {
					e.modified = date.calendar() + " " + this.translate("modified_by") + " " + e.user;
				}

				return e;
			}, this);

			if (this.model.config.title) {
				data.title = this.model.config.title;
			}

			return data;
		}
	});
});

define("widgetTemplate!w/drive/templates/desc.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("The Drive widget displays recently changed files from your Google Drive account.<br /> <br /> You'll need to grant it access to your account after installation by clicking the Authorize button.");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/drive/templates/main.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("title",c,p,1),c,p,0,10,43,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<h2 class=\"header\">");t.b(t.v(t.f("title",c,p,0)));t.b("</h2>");});c.pop();}t.b(" <div class=\"files\"> ");if(t.s(t.f("files",c,p,1),c,p,0,84,305,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <a class=\"file\" href=\"");t.b(t.v(t.f("link",c,p,0)));t.b("\"> <div class=\"icon\" style=\"");if(t.s(t.f("icon",c,p,1),c,p,0,152,184,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("background-image: url(");t.b(t.v(t.f("icon",c,p,0)));t.b(");");});c.pop();}t.b("\"></div> <div class=\"info\"> <h2 class=\"name\">");t.b(t.v(t.f("name",c,p,0)));t.b("</h2> <div class=\"modified\">");t.b(t.v(t.f("modified",c,p,0)));t.b("</div> </div> </a> ");});c.pop();}t.b(" ");if(!t.s(t.f("files",c,p,1),c,p,1,0,0,"")){t.b(" ");if(t.s(t.f("authorize",c,p,1),c,p,0,341,477,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"authorize\"> ");t.b(t.v(t.d("i18n.authorize",c,p,0)));t.b(" <button type=\"button\" class=\"btn btn-lg btn-primary\">");t.b(t.v(t.d("i18n.authorize_btn",c,p,0)));t.b("</button> </div> ");});c.pop();}t.b(" ");};t.b(" </div>");return t.fl(); },partials: {}, subs: {  }})});
define('w/drive/model',["lodash", "widgets/model"], function(_, WidgetModel) {
	return WidgetModel.extend({
		refreshInterval: 300000,

		defaults: {
			config: {
				title: "i18n.name",
				size: "variable",
				files: 8
			},

			data: {
				files: [
					{
						name: "Recent trips",
						icon: "https://ssl.gstatic.com/docs/doclist/images/icon_11_collection_email.png",
						link: "https://drive.google.com/",
						user: "John Doe",
						date: 1396978331809
					},
					{
						name: "Getaway camping plans",
						icon: "https://ssl.gstatic.com/docs/doclist/images/icon_11_spreadsheet_email.png",
						link: "https://drive.google.com/",
						user: "John Doe",
						date: 1396961351031
					},
					{
						name: "20120716-213442_3-urban0_high_resolution.jpg",
						icon: "https://lh4.googleusercontent.com/HG7nuq3CpdLbTRIebHh0DrW7zwNco8aY9CIOTB4SDwBjNj7mrOxU_JNEsl2rIJqc8A=s75-c",
						link: "https://drive.google.com/",
						user: "Avi Kohn",
						date: 1396912248952
					},
					{
						name: "Engagement party menu ideas",
						icon: "https://ssl.gstatic.com/docs/doclist/images/icon_11_document_email.png",
						link: "https://drive.google.com/",
						user: "John Doe",
						date: 1395760856920
					},
					{
						name: "notifiersalpha",
						icon: "https://ssl.gstatic.com/docs/doclist/images/icon_11_document_email.png",
						link: "https://drive.google.com/",
						user: "John Doe",
						date: 1395760558164
					},
					{
						name: "Catering_agreement.pdf",
						icon: "https://ssl.gstatic.com/docs/doclist/images/icon_11_pdf_email.png",
						link: "https://drive.google.com/",
						user: "John Doe",
						date: 1395760364357
					},
					{
						name: "Grocery List.xlsx",
						icon: "https://ssl.gstatic.com/docs/doclist/images/icon_11_excel_email.png",
						link: "https://drive.google.com/",
						user: "John Doe",
						date: 1394551564697
					},
					{
						name: "H20120827-185744_3-urban2_high_resolution.jpg",
						icon: "https://lh6.googleusercontent.com/HFuWO2XkEPYSXvvMRDhXA5sD8k9Gamuas2aeMz4H-YxycnzGp3d62mOWPAJ1U5zc5w=s75-c",
						link: "https://drive.google.com/",
						user: "John Doe",
						date: 1394219609054
					}
				]
			}
		},

		oAuth: {
			id: "559765430405-jtbjv5ivuc17nenpsl4dfk9r53a3q0hg.apps.googleusercontent.com",
			secret: "uzvC025Z3R12syGZ52hFDyHx",
			scope: "https://www.googleapis.com/auth/drive.readonly"
		},

		refresh: function() {
			this.oAuth.ajax({
				type: "GET",
				data: {
					maxResults: this.config.files || 8,
					fields: "items(alternateLink,iconLink,mimeType,thumbnailLink,lastModifyingUserName,modifiedDate,title)"
				},
				url: "https://www.googleapis.com/drive/v2/files",
				success: function(d) {
					var files = [];

					if (d && d.items) {
						d.items.forEach(function(e) {
							var file = {
								name: e.title,
								icon: e.iconLink,
								link: e.alternateLink,
								user: e.lastModifyingUserName,
								date: new Date(e.modifiedDate).getTime()
							};

							if (e.thumbnailLink && e.mimeType && (e.mimeType.indexOf("image") === 0 || e.mimeType.indexOf("video") === 0)) {
								file.icon = e.thumbnailLink.replace(/=s220$/, "=s75-c"); // Replace the 220px picture with a 75px square one
							}
							else if (e.iconLink) {
								file.icon = e.iconLink.replace("_list.png", "_email.png").replace("icon_10", "icon_11"); // Replace the 16px icon with a 32px icon and version 10 icons with V11
							}

							files.push(file);
						});


						// When called with an argument, saveData sets this.data in addition to persisting
						// its value
						this.saveData({
							files: files
						});
					}
				}
			});
		}
	});
});
define('w/gmail/view',["widgets/views/main"], function(WidgetView) {
	return WidgetView.extend({
		isFrame: true,

		onBeforeRender: function(data) {
			if ( (this.model.config.type || "new") === "old" ) {
				data.url = "https://mail.google.com/mail/mu/mp/?authuser=" + (this.model.config.user || 0);	
			} else{
				data.url = "https://mail.google.com/mail/u/" + (this.model.config.user || 0) + "/x/" + (new Date().getTime())  + "/?f=1";
			}

			return data;
		},

		onRender: function() {
			this.el.style.height = (this.model.config.height || 400) + "px";
		}
	});
});
define('w/gmail/maximized',["./view"], function(MainView) {
	return MainView.extend({
		onRender: null
	});
});

define("widgetTemplate!w/gmail/templates/desc.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("The Gmail widget displays your Gmail inbox in an iFrame where you can manage your email.<br /> <br /> This widget won't work offline unless you install the Gmail extension for Chrome.");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/gmail/templates/main.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<iframe src=\"");t.b(t.v(t.f("url",c,p,0)));t.b("\" sandbox=\"allow-same-origin allow-popups allow-forms allow-scripts\" seamless></iframe>");return t.fl(); },partials: {}, subs: {  }})});
define('w/gmail/model',["widgets/model"], function(WidgetModel) {
	return WidgetModel.extend({
		defaults: {
			config: {
				user: "0",
				height: 400,
				size: "variable",
				type: "new"
			}
		}
	});
});
define('w/iframe/view',["widgets/views/main", "lib/parseurl"], function(WidgetView, parseUrl) {
	return WidgetView.extend({
		isFrame: true,

		onBeforeRender: function(data) {
			data.url = parseUrl(this.model.config.url);

			return data;
		},

		onRender: function() {
			this.el.style.height = (this.model.config.height || 400) + "px";

			this.$el.toggleClass("has-padding", this.model.config.padding === "true");
		}
	});
});
define('w/iframe/maximized',["./view"], function(MainView) {
	return MainView.extend({
		onRender: function() {
			this.$el.toggleClass("has-padding", this.model.config.padding === "true");
		}
	});
});

define("widgetTemplate!w/iframe/templates/desc.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("The iFrame widget displays another webpage, or even an entire other website, inside a widget.  You can use this to embed things like the Gmail offline app or a mobile website.<br /> <br /> Go into the settings after installation to enter a URL to display.");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/iframe/templates/main.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<iframe src=\"");t.b(t.v(t.f("url",c,p,0)));t.b("\" sandbox=\"allow-same-origin allow-popups allow-forms allow-scripts\" seamless></iframe>");return t.fl(); },partials: {}, subs: {  }})});
define('w/iframe/model',["widgets/model"], function(WidgetModel) {
	return WidgetModel.extend({
		defaults: {
			config: {
				height: 400,
				padding: "false",
				size: "variable",
				url: "https://en.m.wikipedia.org/"
			}
		}
	});
});
define('w/keep/view',["widgets/views/main", "browser/api"], function(WidgetView, Browser) {
	return WidgetView.extend({
		isFrame: true,

		onBeforeRender: function(data) {
			data.url = "https://keep.google.com/u/" + (this.model.config.user || 0);

			var randomMessage = 'idkeep' + Math.random();
			data.randomMessage = randomMessage;

			function injectToFrame(tabId, frameId) {
				try {
					Browser.tabs.insertCSS(tabId, {
						frameId,
						file: "/inject/css/keep.css", 
						allFrames: true
					});
				}
				catch(e) {}
			}

			function frameMessageListener(msg, sender) {
				if (msg !== randomMessage) { return; }
				var tabId = sender.tab.id;
				var frameId = sender.frameId;
				var f = document.getElementById(randomMessage);

				Browser.runtime.onMessage.removeListener(frameMessageListener);
				// This will cause the script to be run on the first load.
				// If the frame redirects elsewhere, then the injection can seemingly fail.
				f.addEventListener('load', function onload() {
					f.removeEventListener('load', onload);
					injectToFrame(tabId, frameId);
				});
				f.src = data.url;

				for (var i = 0; i < 7; i++) {
					setTimeout(function() {
						injectToFrame(tabId, frameId);
					}, 500 + 200 * i);
				}

				setInterval(function() {
					injectToFrame(tabId, frameId);
				}, 30000);
			}

			Browser.runtime.onMessage.addListener(frameMessageListener);

			return data;
		},

		onRender: function() {
			this.el.style.height = (this.model.config.height || 400) + "px";
		}
	});
});
define('w/keep/maximized',["./view"], function(MainView) {
	return MainView.extend({
		onRender: null
	});
});

define("widgetTemplate!w/keep/templates/desc.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Use this widget to display your Google Keep.<br /> <br /> Please note that this widget won't work offline unless you install the Google Keep Chrome extension.");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/keep/templates/main.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<iframe id=\"");t.b(t.v(t.f("randomMessage",c,p,0)));t.b("\" src=\"/inject/framehelper.html#");t.b(t.v(t.f("randomMessage",c,p,0)));t.b("\" sandbox=\"allow-same-origin allow-popups allow-forms allow-scripts\" seamless></iframe>");return t.fl(); },partials: {}, subs: {  }})});
define('w/keep/model',["widgets/model"], function(WidgetModel) {
	return WidgetModel.extend({
		refreshInterval: 6000000,
		defaults: {
			config: {
				user: "0",
				height: 400,
				size: "variable"
			}
		}
	});
});
define('w/news/view',["lodash", "moment", "widgets/views/main"], function(_, moment, WidgetView) {
	return WidgetView.extend({
		events: {
			"click .tabs button": "scrollTabs",

			"click .tabs li[data-id]": function(e) {
				var tab = e.currentTarget.getAttribute("data-id");

				// If the tab hasn't changed the model won't refresh on its own
				if (tab === this.model.get("activeTab")) {
					this.model.refresh();
				}

				this.model.set("activeTab", tab);

				this.render({
					loading: true
				});
			}
		},

		scrollTabs: function(e) {
			var direction = e.currentTarget.getAttribute("data-direction");

			var tabs = this.$("ul.tabs"),
				finalLeft = tabs[0].scrollLeft,
				offsetWidth = tabs[0].offsetWidth;


			// Scroll by the element width, minus what the buttons cover with padding
			if (direction === "left") {
				finalLeft -= offsetWidth - 85;

				// This stops the tabs from scrolling to just before when the buttons
				// would be hidden
				if (finalLeft < 45) {
					finalLeft = 0;
				}
			}
			else if (direction === "right") {
				finalLeft += offsetWidth - 85;

				if (finalLeft + offsetWidth + 85 > tabs[0].scrollWidth) {
					finalLeft = tabs[0].scrollWidth - offsetWidth;
				}
			}


			tabs.animate({
				scrollLeft: finalLeft
			}, 300);

			// Update the state of the navigation buttons immediately
			// so they can transparently animate out of view while we're scrolling
			this.updateTabs(finalLeft);
		},

		initialize: function() {
			this.listenTo(this.model, "change:config change:size change:data", _.ary(this.render, 0));

			this.listenTo(this.model, "entries:loaded", _.ary(this.render, 1));

			this.render();
		},


		/**
		 * Shows or hides the scroll buttons in the tabs list
		 *
		 * @param  {Number}  [scrollLeft]    A current or near-future scrollLeft position
		 */
		updateTabs: function(scrollLeft) {
			var tabs = this.$("ul.tabs");

			if (!tabs.length) {
				return;
			}

			var scrollWidth = tabs[0].scrollWidth,
				offsetWidth = tabs[0].offsetWidth;

			scrollLeft = typeof scrollLeft === "number" ? scrollLeft : tabs[0].scrollLeft;

			if (scrollWidth - offsetWidth > 15) {
				tabs.toggleClass("scrollable-left", scrollLeft > 0);

				tabs.toggleClass("scrollable-right", scrollLeft + offsetWidth < scrollWidth - 10);
			}

			// Set a transition now so later changes in position transition the
			// buttons in
			setTimeout(function() {
				tabs.css("transition", "margin .15s ease");
			}, 0);
		},


		onBeforeRender: function(data) {
			if (!data.loading) {
				data.items = _.map(data.items, function(e) {
					e = _.clone(e);

					e.date = moment(e.date).fromNow();

					return e;
				});
			}

			if (this.model.config.title) {
				data.title = this.model.config.title;
				if (this.model.isBbc()) {
					if (data.title !== "BBC News") {
						data.title += ", BBC News";
					}
				}
			}

			if (this.model.config.link) {
				data.link = this.model.config.link;
			}

			var topics = this.model.getStoredTopics();
			var topic = this.model.getTopic();
			if (this.Auth.isPro && topics) {
				var activeTab = this.model.get("activeTab");

				var defaultTab = [];

				var tabs = _.compact(_.map(topics, function(e) {
					e = {
						id: e[0],
						name: e[1],
						active: e[0] === activeTab
					};

					if (e.id === topic) {
						defaultTab = [e];

						return;
					}

					return e;
				}, this));

				data.tabs = defaultTab.concat(tabs);
			}


			// Preserve the scrolled state of the tabs
			if (this.$("ul.tabs").length) {
				this.tabsLeft = this.$("ul.tabs")[0].scrollLeft;
			}


			return data;
		},

		onRender: function(data) {
			if (this.tabsLeft && this.$("ul.tabs").length) {
				this.updateTabs(this.tabsLeft);

				this.$("ul.tabs")[0].scrollLeft = this.tabsLeft;

				delete this.tabsLeft;
			}
			else {
				this.updateTabs();
			}


			if (data.images) {
				this.$("img").on("error", function() {
					this.style.height = "20px";
				});
			}
		}
	});
});
define('w/news/settings',["lodash", "jquery", "widgets/views/settings", "jquery.serializejson"], function(_, $, WidgetView) {
	return WidgetView.extend({
		events: {
			"click header button.save": "serialize",

			"keydown label.input > input": function(e) {
				if (e.which === 13) {
					this.serialize();
				}
			}
		},


		/**
		 * Serializes and saves the contents of the settings form
		 */
		serialize: function() {
			var config = _.assign({}, this.model.config, this.$("form").serializeJSON());

			// Trigger a topic reload
			this.model.topicsLoaded = false;

			var topic = this.model.getTopic(config);
			this.model.set({
				config: config,
				state: "default",
				activeTab: topic
			});
		},


		initialize: function() {
			this.listenTo(this.model, "change:config change:data", _.ary(this.render, 0));

			this.render();
		},


		onBeforeRender: function(config) {
			config.topics = this.model.data.topics;
			config.bbctopics = this.model.bbctopics;

			return config;
		},


		onRender: function(config) {
			var topic = this.$(".topic").val(config.topic),
				edition = this.$(".edition").val(config.edition),
				source = this.$(".source").val(config.source);

			source.on("change", function() {
				var form = this.$("form");
				form.removeClass("msn");
				form.removeClass("bbc");
				form.addClass(source.val());
			}.bind(this));

			edition.on("change", function() {
				if (edition.val() !== config.edition) {
					this.model.getTopics(function(topics) {
						var currTopic = topic.val();

						var hEscape = function(str) {
							str = String(str || "");

							if (/[&<>\{\"\']/.test(str)) {
								return str
									.replace(/&/g, "&amp;")
									.replace(/</g, "&lt;")
									.replace(/>/g, "&gt;")
									.replace(/\'/g, "&#39;")
									.replace(/\"/g, "&quot;")
									.replace(/\{/g, "&#123;");
							}
							else {
								return str;
							}
						};

						topic.html(_.map(topics, function(e) {
							return '<option value="' + hEscape(e[0]) + '"' + (e[0] === currTopic ? " selected" : "") + '>' + hEscape(e[1]) + '</option>';
						}).join(""));
					}, source.var(), edition.val());
				}
			}.bind(this));
		}
	});
});
define('w/news/maximized',["lodash", "./view", "moment"], function(_, MainView, moment) {
	return MainView.extend({
		events: _.assign({
			"click header button.layout": function(e) {
				if (this.layout === "cards") {
					this.layout = "list";
				}
				else {
					this.layout = "cards";
				}

				e.currentTarget.setAttribute("data-state", this.layout);

				if (this.lastItems) {
					this.render({
						items: this.lastItems
					});
				}
				else {
					this.render({
						loading: true
					});

					this.model.refresh();
				}
			}
		}, MainView.prototype.events),


		/**
		 * Since we extend from the main widget view and not the maximized view,
		 * we need to reset the template
		 */
		getTemplate: function() {
			return this.widget.templates.maximized;
		},


		initialize: function() {
			// We don't listen for config changes since the model will run a fetch
			// when those happen, and we can't render without articles anyway
			this.listenTo(this.model, "entries:loaded", _.ary(this.render, 1));

			this.layout = "cards";

			this.render({
				loading: true
			});
		},

		resizeImage: function(featured, e) {
			if (!e || !e.image) {
				return;
			}

			// The 18px is 10px padding + an 8px scrollbar
			var containerWidth = window.innerWidth - 18;

			var width;
			if (featured === 1) {
				// Bing identifies the subject in images, resizing them to focus appropriately
				//
				// We calculate the final size at 2x and request a scaled image
				//
				// The calculation here is a 60% flex-basis + a flex-grow of 3 (takes 0.75 of
				// available space) times the remaining 10% of the container width (after the
				// two flex-basis's) minus 20px combined margin from both featured articles
				width = Math.round(((0.6 * containerWidth) + (0.75 * ((0.1 * containerWidth) - 20))) * 2);
			}
			else if (featured === 2) {
				// Same thing here, just with a flex-grow of 1 and 30% basis
				width = Math.round(((0.3 * containerWidth) + (0.25 * ((0.1 * containerWidth) - 20))) * 2);
			}
			else {
				width = Math.round(((containerWidth / 5) - 10) * 2);
			}

			if (this.model.isBbc()) {
				if (width > 2048) {
					width = 2048;
				} else if (width > 1024) {
					width = 1024;
				} else if (width > 999) {
					width = 999;
				}

				e.image = e.image.replace("/320/", "/" + width + "/");

				return;
			}
			
			if (featured === 1) {
				// Bing identifies the subject in images, resizing them to focus appropriately
				//
				// We calculate the final size at 2x and request a scaled image
				//
				// The calculation here is a 60% flex-basis + a flex-grow of 3 (takes 0.75 of
				// available space) times the remaining 10% of the container width (after the
				// two flex-basis's) minus 20px combined margin from both featured articles
				e.image = e.image.replace(".img", "_m5_w" + width + "_h800");
			}
			else if (featured === 2) {
				// Same thing here, just with a flex-grow of 1 and 30% basis
				e.image = e.image.replace(".img", "_m5_w" + width + "_h800");
			}
			else {
				e.image = e.image.replace(".img", "_m5_w" + width + "_h350");
			}
		},

		onBeforeRender: function(data) {
			data.layout = this.layout;

			data.list = this.layout === "list";

			if (!data.loading) {
				// Saved for layout changes
				if (data.items) {
					this.lastItems = data.items;
				}

				data.featured = [];

				var featured = data.layout === "cards" ? 0 : 999999;

				data.items = _.compact(_.map(data.items, function(e) {
					e = _.clone(e);

					e.date = moment(e.date).fromNow();

					++featured;
					// The first two articles with images are selected as featured
					if (featured < 3) {
						this.resizeImage(featured, e);
						data.featured.push(e);

						return null;
					}

					this.resizeImage(featured, e);
					return e;
				}, this));
			}


			if (this.model.config.title) {
				data.title = this.model.config.title;
				if (this.model.isBbc()) {
					if (data.title !== "BBC News") {
						data.title += ", BBC News";
					}
				}
			}

			var topics = this.model.getStoredTopics();
			var topic = this.model.getTopic();
			if (topics) {
				var activeTab = this.model.get("activeTab");

				var defaultTab = [];

				var tabs = _.compact(_.map(topics, function(e) {
					e = {
						id: e[0],
						name: e[1],
						active: e[0] === activeTab
					};

					if (e.id === topic) {
						defaultTab = [e];

						return;
					}

					return e;
				}, this));

				data.tabs = defaultTab.concat(tabs);
			}

			// Preserve the scrolled state of the tabs
			if (this.$("ul.tabs").length) {
				this.tabsLeft = this.$("ul.tabs")[0].scrollLeft;
			}

			return data;
		}
	});
});

define("widgetTemplate!w/news/templates/desc.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Use this widget to keep up-to-date on the latest news.<br /> <br /> After installation, pick an source, edition and topic in the settings.");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/news/templates/main.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<header> ");if(t.s(t.f("title",c,p,1),c,p,0,19,140,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" ");if(t.s(t.f("link",c,p,1),c,p,0,29,75,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<a href=\"");t.b(t.v(t.f("link",c,p,0)));t.b("\" class=\"title\">");t.b(t.v(t.f("title",c,p,0)));t.b("</a>");});c.pop();}t.b(" ");if(!t.s(t.f("link",c,p,1),c,p,1,0,0,"")){t.b("<span class=\"title\">");t.b(t.v(t.f("title",c,p,0)));t.b("</span>");};t.b(" ");});c.pop();}t.b(" ");if(t.s(t.d("tabs.1",c,p,1),c,p,0,162,473,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <ul class=\"tabs\"> <button type=\"button\" class=\"material flat scroll-left\" data-direction=\"left\">&#xE6CD;</button> ");if(t.s(t.f("tabs",c,p,1),c,p,0,286,359,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <li data-id=\"");t.b(t.v(t.f("id",c,p,0)));t.b("\"");if(t.s(t.f("active",c,p,1),c,p,0,318,333,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" class=\"active\"");});c.pop();}t.b(">");t.b(t.v(t.f("name",c,p,0)));t.b("</li> ");});c.pop();}t.b(" <button type=\"button\" class=\"material flat scroll-right\" data-direction=\"right\">&#xE6D0;</button> </ul> ");});c.pop();}t.b(" </header> ");if(t.s(t.f("loading",c,p,1),c,p,0,507,741,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"loading\"> <svg class=\"spinner\" width=\"65px\" height=\"65px\" viewBox=\"0 0 66 66\" xmlns=\"http://www.w3.org/2000/svg\"> <circle fill=\"none\" stroke-width=\"6\" stroke-linecap=\"round\" cx=\"33\" cy=\"33\" r=\"30\"></circle> </svg> </div> ");});c.pop();}t.b(" ");if(!t.s(t.f("loading",c,p,1),c,p,1,0,0,"")){t.b(" <div class=\"items\"> ");if(t.s(t.f("items",c,p,1),c,p,0,797,1136,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <a href=\"");t.b(t.v(t.f("url",c,p,0)));t.b("\" class=\"item\"> ");if(t.s(t.f("image",c,p,1),c,p,0,840,909,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div class=\"image\" style=\"background-image: url('");t.b(t.v(t.f("image",c,p,0)));t.b("');\"></div>");});c.pop();}t.b(" <div class=\"content");if(t.s(t.f("desc",c,p,1),c,p,0,948,953,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" desc");});c.pop();}t.b("\"> <h3 class=\"title\"> ");t.b(t.v(t.f("title",c,p,0)));t.b(" ");if(t.s(t.f("source",c,p,1),c,p,0,1005,1051,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span class=\"source\">&mdash; ");t.b(t.v(t.f("source",c,p,0)));t.b("</span>");});c.pop();}t.b(" </h3> ");t.b(t.t(t.f("desc",c,p,0)));t.b(" ");if(t.s(t.f("pixel",c,p,1),c,p,0,1090,1113,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<img src=\"");t.b(t.v(t.f("pixel",c,p,0)));t.b("\" />");});c.pop();}t.b(" </div> </a> ");});c.pop();}t.b(" </div> ");};return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/news/templates/settings.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<header> <span class=\"title\">");t.b(t.v(t.d("i18n.settings.page_title",c,p,0)));t.b("</span> <button type=\"button\" class=\"material flat blue save\">");t.b(t.v(t.d("i18n.settings.save",c,p,0)));t.b("</button> </header> <form class=\"material-form ");t.b(t.v(t.f("source",c,p,0)));t.b("\"> <label class=\"input\"> <span>");t.b(t.v(t.d("i18n.settings.title",c,p,0)));t.b("</span> <input type=\"text\" name=\"title\" placeholder=\"");t.b(t.v(t.d("i18n.settings.title_placeholder",c,p,0)));t.b("\" value=\"");t.b(t.v(t.f("title",c,p,0)));t.b("\" /> </label> <label class=\"input\"> <span>");t.b(t.v(t.d("i18n.settings.source",c,p,0)));t.b("</span> <select class=\"source\" name=\"source\"> <option value=\"msn\">MSN</option> <option value=\"bbc\">BBC</option> </select> </label> <label class=\"input\"> <span>");t.b(t.v(t.d("i18n.settings.articles",c,p,0)));t.b("</span> <input type=\"number\" name=\"number\" min=\"1\" max=\"20\" value=\"");t.b(t.v(t.f("number",c,p,0)));t.b("\" /> </label> <div class=\"msn-wrapper\"> <label class=\"input\"> <span>");t.b(t.v(t.d("i18n.settings.edition",c,p,0)));t.b("</span> <select class=\"edition\" name=\"edition\"> <option value=\"ar-ae\">(الإمارات العربية المتحدة (العربية</option> <option value=\"ar-eg\">(مصر (العربية</option> <option value=\"ar-sa\">(السعودية (العربية</option> <option value=\"da-dk\">Danmark (Dansk)</option> <option value=\"de-at\">Österreich (Deutsch)</option> <option value=\"de-ch\">Schweiz (Deutsch)</option> <option value=\"de-de\">Deutschland (Deutsch)</option> <option value=\"el-gr\">Ελλάδα (ελληνικά)</option> <option value=\"en-ae\">U.A.E. (English)</option> <option value=\"en-au\">Australia (English)</option> <option value=\"en-ca\">Canada (English)</option> <option value=\"en-gb\">United Kingdom (English)</option> <option value=\"en-ie\">Ireland (English)</option> <option value=\"en-in\">India (English)</option> <option value=\"en-my\">Malaysia (English)</option> <option value=\"en-nz\">New Zealand (English)</option> <option value=\"en-ph\">Philippines (English)</option> <option value=\"en-sg\">Singapore (English)</option> <option value=\"en-us\" selected>United States (English)</option> <option value=\"en-za\">South Africa (English)</option> <option value=\"es-ar\">Argentina (español)</option> <option value=\"es-cl\">Chile (español)</option> <option value=\"es-co\">Colombia (español)</option> <option value=\"es-es\">España (español)</option> <option value=\"es-mx\">México (español)</option> <option value=\"es-pe\">Perú (español)</option> <option value=\"es-us\">United States (español)</option> <option value=\"es-ve\">Venezuela (español)</option> <option value=\"es-xl\">América Latina (español)</option> <option value=\"fi-fi\">Suomi (Suomi)</option> <option value=\"fr-be\">Belgique (Français)</option> <option value=\"fr-ca\">Canada (Français)</option> <option value=\"fr-ch\">Suisse (Français)</option> <option value=\"fr-fr\">France (Français)</option> <option value=\"he-il\">(ישראל (עברית</option> <option value=\"id-id\">Indonesia (Bahasa Indonesia)</option> <option value=\"it-it\">Italia (Italiano)</option> <option value=\"ja-jp\">日本 (日本語)</option> <option value=\"ko-kr\">한국 (한국어)</option> <option value=\"nb-no\">Norge (Norsk, bokmål)</option> <option value=\"nl-be\">België (Nederlands)</option> <option value=\"nl-nl\">Nederland (Nederlands)</option> <option value=\"pl-pl\">Polska (polski)</option> <option value=\"pt-br\">Brasil (Português)</option> <option value=\"pt-pt\">Portugal (Português)</option> <option value=\"ru-ru\">Россия (Pусский)</option> <option value=\"sv-se\">Sverige (Svenska)</option> <option value=\"th-th\">ไทย (ไทย)</option> <option value=\"tr-tr\">Türkiye (Türkçe)</option> <option value=\"vi-vn\">Việt Nam (Tiếng Việt)</option> <option value=\"zh-cn\">中华人民共和国 (中文)</option> <option value=\"zh-hk\">香港特別行政區 (中文)</option> <option value=\"zh-tw\">台灣 (中文)</option> </select> </label> <label class=\"input\"> <span>");t.b(t.v(t.d("i18n.settings.default_topic",c,p,0)));t.b("</span> <select class=\"topic\" name=\"topic\"> ");if(t.s(t.f("topics",c,p,1),c,p,0,3600,3638,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <option value=\"");t.b(t.v(t.f("0",c,p,0)));t.b("\">");t.b(t.v(t.f("1",c,p,0)));t.b("</option> ");});c.pop();}t.b(" </select> </label> </div> <div class=\"bbc-wrapper\"> <label class=\"input\"> <span>");t.b(t.v(t.d("i18n.settings.default_topic",c,p,0)));t.b("</span> <select class=\"bbctopic\" name=\"bbctopic\"> ");if(t.s(t.f("bbctopics",c,p,1),c,p,0,3825,3864,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <option  value=\"");t.b(t.v(t.f("0",c,p,0)));t.b("\">");t.b(t.v(t.f("1",c,p,0)));t.b("</option> ");});c.pop();}t.b(" </select> </label> </div> </form>");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/news/templates/maximized.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<header> ");if(t.s(t.f("title",c,p,1),c,p,0,19,140,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" ");if(t.s(t.f("link",c,p,1),c,p,0,29,75,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<a href=\"");t.b(t.v(t.f("link",c,p,0)));t.b("\" class=\"title\">");t.b(t.v(t.f("title",c,p,0)));t.b("</a>");});c.pop();}t.b(" ");if(!t.s(t.f("link",c,p,1),c,p,1,0,0,"")){t.b("<span class=\"title\">");t.b(t.v(t.f("title",c,p,0)));t.b("</span>");};t.b(" ");});c.pop();}t.b(" <button type=\"button\" class=\"material flat toggle layout\" data-state=\"");t.b(t.v(t.f("layout",c,p,0)));if(!t.s(t.f("layout",c,p,1),c,p,1,0,0,"")){t.b("cards");};t.b("\"> <svg viewBox=\"0 0 24 24\" class=\"list\"> <path d=\"M4 15h16v-2H4v2zm0 4h16v-2H4v2zm0-8h16V9H4v2zm0-6v2h16V5H4z\"></path> </svg> <svg viewBox=\"0 0 24 24\" class=\"cards\"> <path d=\"M4 11h5V5H4v6zm0 7h5v-6H4v6zm6 0h5v-6h-5v6zm6 0h5v-6h-5v6zm-6-7h5V5h-5v6zm6-6v6h5V5h-5z\"></path> </svg> </button> ");if(t.s(t.d("tabs.1",c,p,1),c,p,0,559,870,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <ul class=\"tabs\"> <button type=\"button\" class=\"material flat scroll-left\" data-direction=\"left\">&#xE6CD;</button> ");if(t.s(t.f("tabs",c,p,1),c,p,0,683,756,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <li data-id=\"");t.b(t.v(t.f("id",c,p,0)));t.b("\"");if(t.s(t.f("active",c,p,1),c,p,0,715,730,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" class=\"active\"");});c.pop();}t.b(">");t.b(t.v(t.f("name",c,p,0)));t.b("</li> ");});c.pop();}t.b(" <button type=\"button\" class=\"material flat scroll-right\" data-direction=\"right\">&#xE6D0;</button> </ul> ");});c.pop();}t.b(" </header> ");if(t.s(t.f("loading",c,p,1),c,p,0,904,1138,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"loading\"> <svg class=\"spinner\" width=\"65px\" height=\"65px\" viewBox=\"0 0 66 66\" xmlns=\"http://www.w3.org/2000/svg\"> <circle fill=\"none\" stroke-width=\"6\" stroke-linecap=\"round\" cx=\"33\" cy=\"33\" r=\"30\"></circle> </svg> </div> ");});c.pop();}t.b(" ");if(!t.s(t.f("loading",c,p,1),c,p,1,0,0,"")){t.b(" <div class=\"items ");t.b(t.v(t.f("layout",c,p,0)));if(!t.s(t.f("layout",c,p,1),c,p,1,0,0,"")){t.b("cards");};t.b("\"> ");if(t.s(t.f("featured",c,p,1),c,p,0,1235,1573,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <a href=\"");t.b(t.v(t.f("url",c,p,0)));t.b("\" class=\"item featured\" style=\"background-image: linear-gradient(rgba(0, 0, 0, 0), rgba(0, 0, 0, .5)), url('");t.b(t.v(t.f("image",c,p,0)));t.b("');\"> <h3 class=\"title\">");t.b(t.v(t.f("title",c,p,0)));t.b("</h3> <div class=\"desc\">");t.b(t.t(t.f("desc",c,p,0)));t.b("</div> <div class=\"details\"> ");if(t.s(t.f("source",c,p,1),c,p,0,1476,1514,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span class=\"source\">");t.b(t.v(t.f("source",c,p,0)));t.b("</span>");});c.pop();}t.b(" <span class=\"date\">");t.b(t.v(t.f("date",c,p,0)));t.b("</span> </div> </a> ");});c.pop();}t.b(" ");if(t.s(t.f("items",c,p,1),c,p,0,1597,2189,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <a href=\"");t.b(t.v(t.f("url",c,p,0)));t.b("\" class=\"item\"> ");if(t.s(t.f("list",c,p,1),c,p,0,1639,1828,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <span class=\"source\">");t.b(t.v(t.f("source",c,p,0)));t.b("</span> <span class=\"desc\"> <b class=\"title\">");t.b(t.v(t.f("title",c,p,0)));t.b("</b> ");t.b(t.t(t.f("desc",c,p,0)));t.b(" ");if(t.s(t.f("pixel",c,p,1),c,p,0,1751,1774,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<img src=\"");t.b(t.v(t.f("pixel",c,p,0)));t.b("\" />");});c.pop();}t.b(" </span> <span class=\"date\">");t.b(t.v(t.f("date",c,p,0)));t.b("</span> ");});c.pop();}t.b(" ");if(!t.s(t.f("list",c,p,1),c,p,1,0,0,"")){t.b(" ");if(t.s(t.f("image",c,p,1),c,p,0,1858,1927,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div class=\"image\" style=\"background-image: url('");t.b(t.v(t.f("image",c,p,0)));t.b("');\"></div>");});c.pop();}t.b(" <h3 class=\"title\">");t.b(t.v(t.f("title",c,p,0)));t.b("</h3> <div class=\"desc\">");t.b(t.t(t.f("desc",c,p,0)));if(t.s(t.f("pixel",c,p,1),c,p,0,2009,2032,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<img src=\"");t.b(t.v(t.f("pixel",c,p,0)));t.b("\" />");});c.pop();}t.b("</div> <div class=\"details\"> ");if(t.s(t.f("source",c,p,1),c,p,0,2082,2120,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span class=\"source\">");t.b(t.v(t.f("source",c,p,0)));t.b("</span>");});c.pop();}t.b(" <span class=\"date\">");t.b(t.v(t.f("date",c,p,0)));t.b("</span> </div> ");};t.b(" </a> ");});c.pop();}t.b(" </div> ");};return t.fl(); },partials: {}, subs: {  }})});
define('lib/feedlyproxy',["backbone", "lodash", "jquery", "lib/parseurl", "browser/api", "lib/cryptojs"], function(Backbone, _, $, parseUrl, Browser, CryptoJS) {
    if (window.feedlyProxySingleton) {
        return window.feedlyProxySingleton;
    };

    function createFeedlyProxy() {
        var that = this;

        this.timeQueueSize = 60;

        var load = function() {
            var queue = null;
            try {
                queue = JSON.parse(Browser.storage.rssqueue || "null");
            }
            catch(e) {};

            if (!queue) {
                queue = {
                    buffer: null,
                    pointer: 0,
                    expectedAt: 0
                };
            }

            if (!queue.buffer || queue.buffer.length != that.timeQueueSize) {
                queue.buffer = new Array(that.timeQueueSize).fill(0);
                queue.pointer = 0;
            }

            return queue;
        }.bind(this);

        var save = function(queue) {
            Browser.storage.rssqueue = JSON.stringify(queue);
        };

        var queueObject = function(queue, length) {
            return {
                delayMs: function() {
                    var last = this.get();
                    if (!last || last === 0) {
                        return 0;
                    };
        
                    var result = new Date().getTime() - last;
                    return result < 0 ? 0 : result;
                },
        
                get: function() {
                    return queue.buffer[queue.pointer === 0 ? (length - 1) : (queue.pointer - 1)];
                },
                
                push: function() {
                    queue.buffer[queue.pointer] = new Date().getTime();
                    queue.pointer = (length + queue.pointer + 1) % length;
                }, 

                calculateDelay: function(isUrgent) {
                    var now = new Date().getTime();
                    var delay = this.delayMs();
                    if (queue.expectedAt === 0) {
                        queue.expectedAt = now;
                        return delay;
                    }
        
                    var nextTime = now + delay;
                    if (nextTime > queue.expectedAt) {
                        queue.expectedAt = nextTime;
                        return delay;
                    }
        
                    var minIntervalMs = 1000;
                    if (!isUrgent) {
                        //Dynamically calculate the recommended delay depending on requests number during last hour
                        var oneHourAgo = now - 3600000;
                        var lastHourRequests = 0;
                        queue.buffer.forEach(function(i) { 
                            if  (i > oneHourAgo) {
                                lastHourRequests++;
                            }
                        });

                        if (lastHourRequests > length) {
                            minIntervalMs = 10 * 60 * 1000;
                        } else if (lastHourRequests > length * 0.9) {
                            minIntervalMs = 5 * 60 * 1000;
                        } else if (lastHourRequests > length * 0.75) {
                            minIntervalMs = 1 * 60 * 1000;
                        } else if (lastHourRequests > length * 0.5) {
                            minIntervalMs = 30 * 1000;
                        } else if (lastHourRequests > length * 0.3) {
                            minIntervalMs = 5 * 1000;
                        } else if (lastHourRequests > length * 0.1) {
                            minIntervalMs = 2 * 1000;
                        } 
                    }
        
                    nextTime = queue.expectedAt + minIntervalMs;
                    queue.expectedAt = nextTime;
                    delay = queue.expectedAt - now;
                    return delay < 0 ? 0 : delay;
                }
            };
        }

        var makeFilename = function(url) {
			return CryptoJS.SHA1(url).toString(CryptoJS.enc.Base64);
        };

        this.getCached = function(url) {
            var data = JSON.parse(Browser.storage.rssc || "{}");
            var now = new Date().getTime();            
            var shouldSave = false;
            for (prop in data) {
                var expireAt = data[prop];
                if (expireAt < now) {
                    Browser.storage.removeItem("rssu" + prop);
                    delete data[prop];          
                    shouldSave = true;
                }
            }
    
            if (shouldSave) {
                Browser.storage.rssc = JSON.stringify(data);
            }

            var hash = makeFilename(url);

            if (data[hash]) {
                return JSON.parse(Browser.storage.getItem("rssu" + hash) || "null");
            }

            return null;
        };

        var saveCached = function(items, url, time) {
            var data = JSON.parse(Browser.storage.rssc || "{}");
            var hash = makeFilename(url);
            data[hash] = time;
            Browser.storage.rssc = JSON.stringify(data);
            Browser.storage.setItem("rssu" + hash, JSON.stringify(items));
        };         

        this.onsent = function(data, url, time) {
            var queueData = load();
            queueObject(queueData, that.timeQueueSize).push();
            save(queueData);

            saveCached(data, url, time);
        };

        this.getDelay = function(isUrgent) {
            var queueData = load();
            var delay = queueObject(queueData, that.timeQueueSize).calculateDelay(isUrgent);
            save(queueData);
            return delay;
        };
        
        return this;
    };

    window.feedlyProxySingleton = createFeedlyProxy();
    return window.feedlyProxySingleton;
});
/**
 * Implements a cross-browser core API
 */
define('core/settings',[], function() {
	return {
		apidomain: "https://api.ichro.me",
		isHomepage: false
	};
});
define('w/news/model',["lodash", "jquery", "widgets/model", "lib/feedlyproxy", "core/settings"], function(_, $, WidgetModel, feedlyProxy, settings) {
	return WidgetModel.extend({
		widgetClassname: "tabbed-corner",

		pro_tooltip: "news",

		refreshInterval: 300000,
		bbctopics: [
			["top", "Top"],
			["world", "World", "world"],
			["wus", "USA & Canada", "world/us_and_canada"],
			["wuk", "UK", "uk"],
			["weu", "Europe", "world/europe"],
			["waf", "Africa", "world/africa"],
			["was", "Asia", "world/asia"],
			["wla", "Latin America", "world/latin_america"],
			["wme", "Middle East", "world/middle_east"],
			["business", "Business", "business"],
			["politics", "Politics", "politics"],
			["health", "Health", "health"],
			["edu", "Education & Family", "education"],
			["scienv", "Science & Environment", "science_and_environment"],
			["tech", "Technology", "technology"],
			["arts", "Entertainment & Arts", "entertainment_and_arts"],
			["topus", "Top / USA & Canada", "", "?edition=uk"],
			["topukus", "Top / UK", "", "?edition=us"],
			["topint", "Top / Rest world", "", "?edition=int"]
		],

		defaults: {
			config: {
				size: "variable",
				title: "i18n.name",
				source: "msn",
				number: 5,
				edition: "en-us",
				topic: "$allStories",
				bbctopic: "top",
				link: "https://news.google.com"
			},

			data: {
				topics: [
					["$allStories", "All"],
					["rt_US", "Top Stories", "cms-amp-AA9tmo2"],
					["rt_usanatnews", "US", "cms-amp-AA9tmo3"],
					["rt_World", "World", "cms-amp-AAaeSyj"],
					["rt_Crime", "Crime", "cms-amp-AAavKVW"],
					["rt_Offbeat", "Offbeat", "cms-amp-AAavKWc"],
					["rt_ScienceAndTechnology", "Technology", "cms-amp-AAavzN1"],
					["rt_Politics", "Politics", "cms-amp-AAaviQH"],
					["rt_Opinion", "Opinion", "cms-amp-AA9tmod"],
					["rt_WeekendReads", "Weekend Reads", "cms-amp-AA9tmoc"],
					["rt_Entertainment", "Entertainment", "cms-amp-AAaviU8"],
					["rt_Business", "Money", "cms-amp-AAaf38w"],
					["rt_Sports", "Sports", "cms-amp-AAavGal"]
				],
				items: [
					{
						"title": "EXCLUSIVE-Chemical weapons used in Syrian fighting - watchdog",
						"desc": "Chemical weapons experts have determined that mustard gas was used during fighting in Syria in August, according to a report by an international watchdog seen by Reuters.",
						"date": 1446747372000,
						"image": "https://img-s-msn-com.akamaized.net/tenant/amp/entityid/BBmSQjO_m5_h190_w200.jpg",
						"url": "https://a.msn.com/r/2/BBmSxTl",
						"source": "Reuters"
					},
					{
						"title": "The tragic case of the boy who was missing for 13 years — and didn’t know it",
						"desc": "Julian Hernandez was abducted in Alabama by his father in 2002, police said. He was found in Ohio, living under assumed name.",
						"date": 1446746400000,
						"image": "https://img-s-msn-com.akamaized.net/tenant/amp/entityid/BBmSxnS_m5_h190_w200.jpg",
						"url": "https://a.msn.com/r/2/BBmSx48",
						"source": "The Washington Post"
					},
					{
						"title": "Rumsfeld: Bush 41 'getting up in years'",
						"desc": "The former Defense secretary is pushing back on criticism from the elder Bush.",
						"date": 1446752880000,
						"image": "https://img-s-msn-com.akamaized.net/tenant/amp/entityid/BBmSvmg_m5_h190_w200.jpg",
						"url": "https://a.msn.com/r/2/BBmSFha",
						"source": "The Hill"
					},
					{
						"title": "Russia, Egypt reject British PM's terrorist bomb speculation",
						"desc": "British Prime Minister David Cameron said Thursday there is a \"strong possibility\" a terrorist bomb brought down a Russian plane over the Sinai even as Russia and Egypt dismissed such talk as premature speculation.",
						"date": 1446746400000,
						"image": "https://img-s-msn-com.akamaized.net/tenant/amp/entityid/BBmSnRb_m5_h190_w200.jpg",
						"url": "https://a.msn.com/r/2/BBmPoS9",
						"source": "USA Today"
					},
					{
						"title": "Detective: 'Hero' cop sought hit-man to cover up thefts",
						"desc": "Months before an Illinois police officer staged his suicide to look like murder, prompting an expensive manhunt that put his community under siege, he tried to find a hit man to kill a village administrator.",
						"date": 1446750000000,
						"image": "https://img-s-msn-com.akamaized.net/tenant/amp/entityid/BBmS7SA_m5_h190_w200.jpg",
						"url": "https://a.msn.com/r/2/BBmScSG",
						"source": "Associated Press"
					}
				]
			}
		},


		/**
		 * Initialize
		 */
		initialize: function() {
			if (this.config.custom) {
				delete this.config.custom;
			}

			// Migrate pre-V2 settings to the new format
			if (["us", "uk", "ca", "fr_ca", "en_il", "fr", "au", "pt-BR_br"].indexOf(this.config.edition) !== -1) {
				var conversions = {
					us: "en-us",
					uk: "en-gb",
					ca: "en-ca",
					fr_ca: "fr-ca",
					en_il: "he-il",
					fr: "fr-fr",
					au: "en-au",
					"pt-BR_br": "pt-br"
				};

				this.config.edition = conversions[this.config.edition] || "en-us";
			}


			if (!this.config.number || this.config.number > 20) {
				this.config.number = 20;
			}

			this.authHeader = this.Auth.adFree ? "API_KEY db72b4be78c04a3a97b2b11ea8ab1e4a" : "API_KEY 8b04677e27d5498a90e306eedbf19fb3";

			this.set("activeTab", this.getTopic());

			this.on("change", function(model, options) {
				if (options && options.widgetChange === true) {
					return;
				}

				this.refresh();
			}, this);
		},

		getTopic: function(config) {
			config = config || this.config;
			if (this.isBbc(config.source)) {
				return config.bbctopic;
			}

			return config.topic;
		},

		getTopics: function(cb, source, edition) {
			if (this.isBbc(source)) {
				return this.getBbcTopics(cb);
			}

			edition = edition || this.config.edition;
			return this.getMsnTopics(cb, edition);
		},

		getStoredTopics: function() {
			if (this.isBbc()) {
				return this.bbctopics;
			}

			return this.data.topics;
		},

		isBbc: function(source) {
			source = source || this.config.source;
			return source === "bbc";
		},

		/**
		 * Loads the list of topics for the current MSN news edition.
		 *
		 * @param   {Function}  cb         The callback
		 * @param   {String}    [edition]  The edition to get topics for, defaults to the current edition
		 */
		getMsnTopics: function(cb, edition) {
			edition = edition || this.config.edition;

			$.getJSON("https://cdn.content.prod.cms.msn.com/none/sources/alias/compositestreambyname/today?market=" + edition + "&tenant=amp&vertical=news", function(d) {
				var topics = _.map(d && d._links && d._links.sources, function(d) {
					return [d.categoryKey, d.sourceName, d.href];
				});

				topics = topics.filter(function(d) { return d && d.length > 0 && d[0] !== "rt_AppSpotlightCard"; });
				topics.unshift(["$allStories", this.translate("all_stories")]);

				cb.call(this, topics || []);
			}.bind(this));
		},


		/**
		 * Loads the list of topics for the current BBC news edition.
		 *
		 * @param   {Function}  cb         The callback
		 */
		getBbcTopics: function(cb) {
			var topics = this.bbctopics;
			cb.call(this, topics);
		},

		/**
		 * Parses and normalizes articles
		 *
		 * @param   {Array}   docs       The items to parse
		 * @return  {Object}             An array of parsed, normalized entries
		 */
		parseArticles: function(docs, maximized) {
			// Bing returns a relational data structure, we need to index the items
			// for fast lookups
			var images = {},
				sources = {},
				articles = [];

			_.each(docs, function(e) {
				var self = (e._links && e._links.self && e._links.self[0]) || {};

				if (self.type === "image") {
					images[self.href] = e;
				}
				else if (self.type === "provider") {
					sources[self.href] = e;
				}
				else if (self.type === "article" || self.type === "video" || self.type === "slideshow") {
					articles.push(e);
				}
			});


			var textDiv = document.createElement("div");

			articles = _.map(articles, function(e) {
				var image = _.find(e._links && e._links.references, { type: "image" });

				image = image && images[image.href] && images[image.href].href;

				textDiv.innerHTML = e.abstract || "";

				return {
					title: e.title || "",
					desc: textDiv.textContent.trim(),
					date: new Date(e.displayPublishedDateTime).getTime(),
					image: maximized ? image : (image || "").replace(".img", "_m5_h190_w200.jpg"),
					url: (((e._links && e._links.self && e._links.self[0]) || {}).href || "").replace("cms-amp-", "http://a.msn.com/r/2/"),
					source: e._links && e._links.provider && e._links.provider[0] && sources[e._links.provider[0].href] && sources[e._links.provider[0].href].displayName
				};
			});

			return articles;
		},


		/**
		 * Parses and normalizes CodeFuel MSN articles
		 *
		 * @param   {Array}   docs       The items to parse
		 * @return  {Object}             An array of parsed, normalized entries
		 */
		parseArticlesCodeFuel: function(docs, maximized) {
			return _.map(docs, function(e) {
				return {
					title: e.Title || "",
					desc: e.Description || "",
					date: new Date(e.DatePublished).getTime(),
					pixel: e.PixelUrl,
					image: maximized ? e.ThumbnailUrl : (e.ThumbnailUrl || "").replace(".img", "_m5_h190_w200.jpg"),
					url: e.TargetedUrl,
					source: e.Provider
				};
			});
		},


		refresh: function() {
			if (this.isBbc()) {
				this.refreshBbc();
				return;
			}

			if (this.config.edition === "en-us") {
				this.refreshMsnCodeFuel();
				return;
			}

			this.refreshMsn();
		},

		knowDomains: [
			"www.reuters.com",
			"a.msn.com",
			"img-s-msn-com.akamaized.net",
			"img.s-msn.com"
		],

		fixlinks: function(items) {
			var fix = function(url) {
				if (!_.isEmpty(url)) {
					for (var i = 0; i < this.knowDomains.length; i++) {
						var domain = this.knowDomains[i];

						if (url.indexOf("http://" + domain) === 0) {
							return url.slice(0, 4) + "s" + url.slice(4);
						}
					}
				}

				return url;
			}.bind(this);

			if (!_.isEmpty(items))  {
				_.each(items, function(item) {
					item.url = fix(item.url);
					item.image = fix(item.image);
				});
			}
		},

		refreshMsnCodeFuel: function() {
			// We load the list of topics once when the page loads since it might
			// have changed since we last loaded it
			if (!this.topicsLoaded) {
				this.getTopics(function(topics) {
					this.topicsLoaded = true;

					this.data.topics = topics;

					this.refresh();
				});

				return;
			}

			// We save the active tab in case it changes before the request is finished
			var activeTab = this.get("activeTab");

			if (!this.Auth.isPro && activeTab !== this.config.topic) {
				return this.set("activeTab", this.config.topic);
			}

			var maximized = this.get("state") === "maximized";

			var topic = _.find(this.data.topics, [activeTab]);
			var query;
			if (topic && topic.length > 1) {
				query = topic[0] === "$allStories" ? "News" : topic[1];
			}
			query = query || "News";

			$.getJSON("https://feed.cf-se.com/v2/News?gd=" + (settings.isHomepage ? "SY1002609" : "SY1002608") + "&format=json&source=80&q=" + encodeURIComponent(query) + "&numnews=" + (maximized ? 45 : this.config.number) + "&_=" + new Date().getTime(), {
			}, function(d) {
				// If the active tab has changed (i.e. the user has switched tabs
				// twice before the request finished), we don't want to emit any entries
				if (this.get("activeTab") === activeTab && d && d.NewsResults && d.NewsResults.Items) {
					var items = this.parseArticlesCodeFuel(d.NewsResults.Items, maximized);
					
					// Only save data if this is the default tab and we aren't
					// maximized (and therefore didn't fetch more articles)
					if (activeTab === this.config.topic && !maximized) {
						this.data.items = items;

						this.saveData();
					}
					else {
						// We only trigger the entries:loaded event if this is not the
						// first tab so the view doesn't render twice
						this.trigger("entries:loaded", {
							items: items
						});
					}
				}
			}.bind(this));
		},

		refreshMsn: function() {
			// We load the list of topics once when the page loads since it might
			// have changed since we last loaded it
			if (!this.topicsLoaded) {
				this.getTopics(function(topics) {
					this.topicsLoaded = true;

					this.data.topics = topics;

					this.refresh();
				});

				return;
			}

			// We save the active tab in case it changes before the request is finished
			var activeTab = this.get("activeTab");

			if (!this.Auth.isPro && activeTab !== this.config.topic) {
				return this.set("activeTab", this.config.topic);
			}

			var maximized = this.get("state") === "maximized";

			var topic = _.find(this.data.topics, [activeTab]);
			var query;
			if (topic && topic.length > 1) {
				query = topic[0] === "$allStories" ? "alias/compositestreambyname/today" : "id/" + topic[2];
			}
			if (!query) {
				query = "alias/compositestreambyname/today";
			}

			$.getJSON("https://cdn.content.prod.cms.msn.com/common/abstract/" + query, {
				count: maximized ? 45 : this.config.number,
				market: this.config.edition,
				tenant: "amp",
				vertical: "news",
				_: new Date().getTime() //to avoid caching
			}, function(d) {
				// If the active tab has changed (i.e. the user has switched tabs
				// twice before the request finished), we don't want to emit any entries
				if (
					this.get("activeTab") === activeTab &&
					d && d._embedded && d._embedded.documents
				) {
					var items = this.parseArticles(d._embedded.documents, maximized);
					this.fixlinks(items);

					// Only save data if this is the default tab and we aren't
					// maximized (and therefore didn't fetch more articles)
					if (activeTab === this.config.topic && !maximized) {
						this.data.items = items;

						this.saveData();
					}
					else {
						// We only trigger the entries:loaded event if this is not the
						// first tab so the view doesn't render twice
						this.trigger("entries:loaded", {
							items: items
						});
					}
				}
			}.bind(this));
		},

		refreshBbc: function(isReload) {
			// We save the active tab in case it changes before the request is finished
			var activeTab = this.get("activeTab");

			if (!this.Auth.isPro && activeTab !== this.config.bbctopic) {
				return this.set("activeTab", this.config.bbctopic);
			}

			var maximized = this.get("state") === "maximized";

			var topic = _.find(this.bbctopics, [activeTab]);

			var url = "http://feeds.bbci.co.uk/news/"; //Important! The "https://" here do not return image, for unknown reason
			if (topic && topic.length > 2) {
				url += topic[2] + "/";
			}
			url += "rss.xml";
			if (topic && topic.length > 3) {
				url += topic[3];
			}

			var process = function(d) {
				// If the active tab has changed (i.e. the user has switched tabs
				// twice before the request finished), we don't want to emit any entries
				if (
					this.get("activeTab") === activeTab && d && d.items
				) {
					var items = _.map(d.items, this.parseFeedlyEntry, this);
					this.fixlinks(items);

					// Only save data if this is the default tab and we aren't
					// maximized (and therefore didn't fetch more articles)
					if (activeTab === this.config.bbctopic && !maximized) {
						this.data.items = items;

						this.saveData();
					}
					else {
						// We only trigger the entries:loaded event if this is not the
						// first tab so the view doesn't render twice
						this.trigger("entries:loaded", {
							items: items
						});
					}
				}
			}.bind(this);

			var getSingle = function() {
				var cached = feedlyProxy.getCached(url);
				if (cached && !isReload) {
					setTimeout(function() {
						process(cached);
					}, 0);
					return;
				}

				var cacheTimeout = 3 * 60000;

				$.getJSON("https://cloud.feedly.com/v3/streams/contents?streamId=feed%2F" + encodeURIComponent(url), {
					bnd: new Date().getTime(),
					count: maximized ? 45 : this.config.number
				}, function(d) {
					feedlyProxy.onsent(d, url, new Date().getTime() + cacheTimeout);
					process(d);
				}.bind(this)).fail(function() {
					this.trigger("entries:loaded", {
						errors: 1
					});
				});
			}.bind(this);

			var delayMs = feedlyProxy.getDelay(isReload || false);
			if (delayMs >= 0) {
				getSingle();
				return;
			}

			setTimeout(function() {
				getSingle();
			}.bind(this), delayMs);
		},


		/**
		 * Parses a feed entry, removing tracking tokens, ads, and sharing buttons
		 *
		 * @param   {Object}   e           The item to parse
		 * @param   {Boolean}  [extended]  If extended data should be parsed
		 * @return  {Object}               A parsed, normalized entry
		 */
		parseFeedlyEntry: function(e, extended) {
			extended = extended === true;

			var html = $("<div>" + ((e.summary && e.summary.content) || (e.content && e.content.content) || "")
				.replace(/ src="\/\//g, " data-src=\"https://")
				.replace(/ src="/g, " data-src=\"")
				.replace(/ src='\/\//g, " data-src='https://")
				.replace(/ src='/g, " data-src='") +
			"</div>");

			// Cleanup tracking images, feedburner ads, etc.
			_.each(html[0].querySelectorAll('.mf-viral, .feedflare, img[width="1"], img[height="1"], img[data-src^="http://da.feedsportal.com"]'), function(e) {
				if (e && e.parentNode) {
					e.parentNode.removeChild(e);
				}
			});

			var item = {
				date: e.published,
				title: (e.title || "").trim(),
				url: ((_.find(e.alternate, { type: "text/html" }) || {}).href || "").trim()
			};


			if (extended) {
				item.author = e.author;
				item.source = e.origin && e.origin.title;
			}


			if (e.visual && e.visual.url && e.visual.url !== "none") {
				item.image = e.visual.url;
			}
			else if (html.find("img[data-src]").length) {
				item.image = html.find("img[data-src]").first().attr("data-src");
			}
			else if (html.find("iframe[data-chomp-id]").length) {
				item.image = "http://img.youtube.com/vi/" + html.find("iframe[data-chomp-id]").attr("data-chomp-id") + "/1.jpg";
			}
			else if (e.enclosure && e.enclosure.length > 0 && e.enclosure[0].width && e.enclosure[0].height && e.enclosure[0].href) {
				item.image = e.enclosure[0].href;
			}

			// Find any element that isn't allowed and replace it with its contents
			_.each(html[0].querySelectorAll("*:not(a):not(b):not(i):not(strong):not(u)"), function(e) {
				if (e.children.length) {
					$(e).children().unwrap();
				}
				else {
					$(e).replaceWith(e.innerHTML);
				}
			});

			// Then remove anything that's left
			_.each(html[0].querySelectorAll("*:not(a):not(b):not(i):not(strong):not(u)"), function(e) {
				if (e && e.parentNode) {
					e.parentNode.removeChild(e);
				}
			});


			// If the first element in the description is empty or the article's
			// title repeated, remove it
			var fChild = html.children().first(),
				text = (fChild.text() || "").trim();

			if (!text || text.toLowerCase() === item.title.toLowerCase()) {
				fChild.remove();
			}


			// If the description is blank (maybe it only had an image that's now
			// been removed), remove it
			if (!html[0].innerHTML.trim().length) {
				delete item.desc;
			}

			// Otherwise, make every link nested so it can still be clicked
			else {
				_.each(html[0].querySelectorAll("a"), function(e) {
					var span = document.createElement("span");

					span.setAttribute("class", "nested-link");
					span.setAttribute("data-target", "blank");
					span.setAttribute("class", "nested-link");

					span.textContent = e.textContent.replace(/\n/g, "  ").trim();


					var href = e.getAttribute("href") || "https://www.google.com/";

					if (href.trim().indexOf("//") === 0) {
						href =  "http:" + href.trim();
					}
					else if (href.trim().indexOf("http") !== 0) {
						href =  "http://" + href.trim();
					}
					else {
						href = href.trim();
					}

					span.setAttribute("data-href", href);


					$(e).replaceWith(span);
				});

				item.desc = html[0].innerHTML.trim();
			}

			return item;
		}


	});
});
define('w/quicklinks/view',["widgets/views/main"], function(WidgetView) {
	return WidgetView.extend({
		onBeforeRender: function(data) {
			if (this.model.config.title) {
				data.title = this.model.config.title;
			}

			if (this.model.config.view) {
				data.view = this.model.config.view;
			}

			return data;
		}
	});
});

define("widgetTemplate!w/quicklinks/templates/desc.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("This widget displays a list of popular websites.");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/quicklinks/templates/main.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("title",c,p,1),c,p,0,10,43,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<h2 class=\"header\">");t.b(t.v(t.f("title",c,p,0)));t.b("</h2>");});c.pop();}t.b(" <ul class=\"items ");t.b(t.v(t.f("view",c,p,0)));t.b("\"> ");if(t.s(t.f("sites",c,p,1),c,p,0,92,207,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <li> <a class=\"item\" href=\"");t.b(t.v(t.f("url",c,p,0)));t.b("\"> <img src=\"images/quicklinks/");t.b(t.v(t.f("icon",c,p,0)));t.b(".png\" /> <div>");t.b(t.v(t.f("title",c,p,0)));t.b("</div> </a> </li> ");});c.pop();}t.b(" </div>");return t.fl(); },partials: {}, subs: {  }})});
define('w/quicklinks/model',["lodash", "widgets/model"], function(_, WidgetModel) {
	return WidgetModel.extend({
		widgetClassname: "tabbed",

		defaults: {
			config: {
				view: "icons",
				title: "i18n.name"
			},
			data: {
				sites: [{
					title: "Wikipedia",
					url: "https://www.wikipedia.org/",
					icon: "wikipedia"				
				}, {
					title: "Amazon",
					url: "https://amzn.to/2NQaf8A",
					icon: "amazon"
				}, {
					title: "Facebook",
					url: "https://www.facebook.com/",
					icon: "facebook"
				}, {
					title: "Pizza",
					url: "https://11170765.mb.trafficsafe.net/ads?sid=11170765&said={said}&autoRedirect=1&q=pizzahut",
					icon: "pizzahut"
				}, {
					title: "Travel",
					url: "https://11170767.mb.trafficsafe.net/ads?sid=11170767&said={said}&autoRedirect=1&q=hotwire",
					icon: "hotwire"
				}, {
					title: "Google",
					url: "https://www.google.com/",
					icon: "google"
				}, {
					title: "TurboTax",
					url: "https://11170766.mb.trafficsafe.net/ads?sid=11170766&said={said}&autoRedirect=1&q=turbotax",
					icon: "turbotax"
				}, {
					title: "Youtube",
					url: "https://www.youtube.com/",
					icon: "youtube"
				}]
			}
		}
	});
});
define('w/recentlyclosed/view',["lodash", "jquery", "browser/api", "widgets/views/main"], function(_, $, Browser, WidgetView) {
	return WidgetView.extend({
		events: {
			"click .item": function(e) {
				e.preventDefault();

				Browser.sessions.restore(e.currentTarget.getAttribute("data-id"), function() {
					if (this.model.config.target === "_self") {
						Browser.tabs.getCurrent(function(tab) {
							if (tab) {
								Browser.tabs.remove(tab.id);
							}
						});
					}
				}.bind(this));
			}
		},

		onBeforeRender: function(data) {
			if (this.model.config.title) {
				data.title = this.model.config.title;
			}
		}
	});
});

define("widgetTemplate!w/recentlyclosed/templates/desc.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Use this widget to display a list of your recently closed tabs.");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/recentlyclosed/templates/main.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("title",c,p,1),c,p,0,10,43,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<h2 class=\"header\">");t.b(t.v(t.f("title",c,p,0)));t.b("</h2>");});c.pop();}t.b(" <div class=\"items\"> ");if(t.s(t.f("tabs",c,p,1),c,p,0,83,191,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <a class=\"item\" href=\"");t.b(t.v(t.f("url",c,p,0)));t.b("\" data-id=\"");t.b(t.v(t.f("id",c,p,0)));t.b("\" style=\"background-image: url('");t.b(t.v(t.f("favicon",c,p,0)));t.b("')\">");t.b(t.v(t.f("title",c,p,0)));t.b("</a> ");});c.pop();}t.b(" </div>");return t.fl(); },partials: {}, subs: {  }})});
define('w/recentlyclosed/model',["jquery", "lodash", "browser/api", "widgets/model"], function($, _, Browser, WidgetModel) {
	return WidgetModel.extend({
		defaults: {
			config: {
				tabs: 5,
				target: "_self",
				size: "variable",
				title: "i18n.name"
			},
			data: {
				tabs: [{
					title: "Google",
					url: "https://www.google.com/",
					favicon: "https://www.google.com/s2/favicons?domain=www.google.com&sz=32"
				}, {
					title: "Facebook",
					url: "https://www.facebook.com/",
					favicon: "https://www.google.com/s2/favicons?domain=www.facebook.com&sz=16"
				}, {
					title: "Youtube",
					url: "https://www.youtube.com/",
					favicon: "https://www.google.com/s2/favicons?domain=www.youtube.com&sz=32"
				}, {
					title: "Amazon",
					url: "https://www.amazon.com/",
					favicon: "https://www.google.com/s2/favicons?domain=www.amazon.com&sz=32"
				}, {
					title: "Wikipedia",
					url: "https://www.wikipedia.org/",
					favicon: "https://www.google.com/s2/favicons?domain=www.wikipedia.org&sz=32"
				}]
			}
		},

		initialize: function() {
			WidgetModel.prototype.initialize.call(this);

			if (!this.isPreview) {
				Browser.sessions.onChanged.addListener(_.ary(this.refresh.bind(this), 0));
			}
		},

		refresh: function() {
			Browser.sessions.getRecentlyClosed(function(sessions) {
				this.saveData({
					tabs: _(sessions).map(function(e) {
						var ret = {};

						if (e.tab) {
							ret.id = e.tab.sessionId;

							ret.url = e.tab.url;
							ret.title = e.tab.title;
						}
						else if (e.window && e.window.tabs.length) {
							ret.id = e.window.sessionId;

							ret.url = e.window.tabs[0].url;
							ret.title = e.window.tabs[0].title + (e.window.tabs.length > 1 ? ", " + (e.window.tabs.length - 1) + " " + this.translate("more") : "");
						}

						if (ret.id) {
							ret.favicon = Browser.getFavicon(ret.url);

							return ret;
						}
						else {
							return null;
						}
					}, this).compact().take(parseInt(this.config.tabs || 5)).value()
				});
			}.bind(this));
		}
	});
});
define('w/rss/view',["lodash", "widgets/views/main", "lib/parseurl"], function(_, WidgetView, parseUrl) {
	return WidgetView.extend({
		events: {
			"click .tabs button": "scrollTabs",

			"click .tabs li[data-id]": function(e) {
				var tab = e.currentTarget.getAttribute("data-id");

				this.render({
					loading: true
				});

				// If the tab hasn't changed the model won't refresh on its own
				if (tab === this.model.get("activeTab")) {
					this.model.refresh();
				}

				this.model.set("activeTab", tab);
			}
		},

		scrollTabs: function(e) {
			var direction = e.currentTarget.getAttribute("data-direction");

			var tabs = this.$("ul.tabs"),
				finalLeft = tabs[0].scrollLeft,
				offsetWidth = tabs[0].offsetWidth;


			// Scroll by the element width, minus what the buttons cover with padding
			if (direction === "left") {
				finalLeft -= offsetWidth - 85;

				// This stops the tabs from scrolling to just before when the buttons
				// would be hidden
				if (finalLeft < 45) {
					finalLeft = 0;
				}
			}
			else if (direction === "right") {
				finalLeft += offsetWidth - 85;

				if (finalLeft + offsetWidth + 85 > tabs[0].scrollWidth) {
					finalLeft = tabs[0].scrollWidth - offsetWidth;
				}
			}


			tabs.animate({
				scrollLeft: finalLeft
			}, 300);

			// Update the state of the navigation buttons immediately
			// so they can transparently animate out of view while we're scrolling
			this.updateTabs(finalLeft);
		},

		initialize: function() {
			this.listenTo(this.model, "change:config change:size change:data", _.ary(this.render, 0));

			this.listenTo(this.model, "entries:loaded", _.ary(this.render, 1));

			this.listenTo(this.model, "wrefresh", function() {
				this.render({
					loading: true
				});

				this.model.refresh(true);
			}.bind(this));

			this.render();
		},


		/**
		 * Shows or hides the scroll buttons in the tabs list
		 *
		 * @param  {Number}  [scrollLeft]    A current or near-future scrollLeft position
		 */
		updateTabs: function(scrollLeft) {
			var tabs = this.$("ul.tabs");

			if (!tabs.length) {
				return;
			}

			var scrollWidth = tabs[0].scrollWidth,
				offsetWidth = tabs[0].offsetWidth;

			scrollLeft = typeof scrollLeft === "number" ? scrollLeft : tabs[0].scrollLeft;

			if (scrollWidth - offsetWidth > 15) {
				tabs.toggleClass("scrollable-left", scrollLeft > 0);

				tabs.toggleClass("scrollable-right", scrollLeft + offsetWidth < scrollWidth - 10);
			}

			// Set a transition now so later changes in position transition the
			// buttons in
			setTimeout(function() {
				tabs.css("transition", "margin .15s ease");
			}, 0);
		},


		onBeforeRender: function(data) {
			if (!data.loading) {
				data.items = _.map(data.items.slice(0, this.model.config.number || 5), function(e) {
					e = _.clone(e);

					if (this.model.config.desc === "false" && e.desc) {
						delete e.desc;
					}

					if (this.model.config.images === "false" && e.image) {
						delete e.image;
					}

					return e;
				}, this);
			}


			if (this.model.config.title) {
				data.title = this.model.config.title;
			}

			if (this.model.config.link) {
				data.link = parseUrl(this.model.config.link);
			}

			if (this.model.config.view && this.model.config.view === "images") {
				data.images = true;
			}


			if (this.Auth.isPro && this.model.config.feeds && this.model.config.feeds.length > 1) {
				var activeTab = this.model.get("activeTab") || 0;

				data.tabs = _.map(this.model.config.feeds, function(e, i) {
					return {
						id: i,
						name: e.name,

						// The == is intentional here, IDs are not necessarily numerical
						active: i == activeTab // jshint ignore:line
					};
				});
			}


			// Preserve the scrolled state of the tabs
			if (this.$("ul.tabs").length) {
				this.tabsLeft = this.$("ul.tabs")[0].scrollLeft;
			}


			return data;
		},

		onRender: function(data) {
			if (this.tabsLeft && this.$("ul.tabs").length) {
				this.updateTabs(this.tabsLeft);

				this.$("ul.tabs")[0].scrollLeft = this.tabsLeft;

				delete this.tabsLeft;
			}
			else {
				this.updateTabs();
			}


			if (data.images) {
				this.$("img").on("error", function() {
					this.style.height = "20px";
				});
			}
		}
	});
});
define('w/rss/settings',["lodash", "jquery", "widgets/views/settings", "lib/parseurl", "jquery.serializejson"], function(_, $, WidgetView, parseUrl) {
	return WidgetView.extend({
		events: {
			"click header button.save": function() {
				var add = this.$("form").find(".feeds input.add");
				var url = add.val();
				if (!_.isEmpty(url)) {
					this.addUrl(url, function() {
						this.serialize();
					}.bind(this));

					return;
				}

				this.serialize();
			},

			"keydown label.input > input": function(e) {
				if (e.which === 13) {
					this.serialize();
				}
			},

			"click .feeds li .delete": function(e) {
				e.currentTarget.parentNode.parentNode.removeChild(e.currentTarget.parentNode);
			},

			"keydown .feeds input.add": function(e) {
				if (e.which === 13) {
					var url = e.currentTarget.value;
					e.currentTarget.value = "";
					this.addUrl(url);
				}
			}
		},

		addUrl: function(urlText, callback) {
			var url = parseUrl(urlText);

			var itm = $('<li>' +
				'<button type="button" class="material toggle delete"><svg viewBox="0 0 24 24"><path d="M6 19c0 1.1.9 2 2 2h8c1.1 0 2-.9 2-2V7H6v12zM19 4h-' +
				'3.5l-1-1h-5l-1 1H5v2h14V4z"></path></svg></button>' +

				'<input type="text" name="feeds[][name]" class="name" placeholder="' + this.translate("settings.feed_name_placeholder") + '" />' +

				'<input type="text" name="feeds[][url]" class="url" placeholder="' + this.translate("settings.feed_url_placeholder") + '" />' +
				'</li>');

			itm.children(".name").val((new URL(url)).host.replace(/^www\./, "").replace(/\.com$/, ""));

			itm.children(".url").val(url);

			$.getJSON("https://cloud.feedly.com/v3/feeds/feed%2F" + encodeURIComponent(url), function(d) {
				if (d && d.title) {
					itm.children(".name").val(d.title);
				}
			})
			.always(function() {
				if (typeof callback !== 'undefined') {
					callback();
				}
			});

			this.$(".feeds ul").append(itm).scrollTop(this.$(".feeds ul")[0].scrollHeight);

			itm.children(".name").focus();
		},

		/**
		 * Serializes and saves the contents of the settings form
		 */
		serialize: function() {
			var newValue = this.$("form").serializeJSON();
			if (isNaN(newValue.cache)) {
				newValue.cache = 5;
			}
			if (newValue.cache < 5) {
				newValue.cache = 5;
			}

			this.model.set({
				state: "default",
				config: _.assign({}, this.model.config, newValue)
			});
		},


		initialize: function() {
			this.listenTo(this.model, "change:config change:data", _.ary(this.render, 0));

			this.render();
		}
	});
});
define('w/rss/maximized',["lodash", "./view", "moment", "lib/parseurl"], function(_, MainView, moment, parseUrl) {
	return MainView.extend({
		events: _.assign({
			"click header button.layout": function(e) {
				if (this.layout === "cards") {
					this.layout = "list";
				}
				else {
					this.layout = "cards";
				}

				e.currentTarget.setAttribute("data-state", this.layout);

				if (this.lastItems) {
					this.render({
						items: this.lastItems
					});
				}
				else {
					this.render({
						loading: true
					});

					this.model.refresh();
				}
			}
		}, MainView.prototype.events),


		/**
		 * Since we extend from the main widget view and not the maximized view,
		 * we need to reset the template
		 */
		getTemplate: function() {
			return this.widget.templates.maximized;
		},


		initialize: function() {
			// We don't listen for config changes since the model will run a fetch
			// when those happen, and we can't render without articles anyway
			this.listenTo(this.model, "entries:loaded", _.ary(this.render, 1));

			this.layout = "cards";

			this.listenTo(this.model, "wrefresh", function() {
				this.render({
					loading: true
				});

				this.model.refresh(true);
			}.bind(this));


			this.render({
				loading: true
			});

			this.model.refresh();
		},


		onBeforeRender: function(data) {
			data.layout = this.layout;

			data.list = this.layout === "list";

			if (!data.loading) {
				// Saved for layout changes
				if (data.items) {
					this.lastItems = data.items;
				}

				data.featured = [];

				var featured = 0;

				data.items = _.compact(_.map(data.items, function(e) {
					e = _.clone(e);

					e.date = moment(e.date).fromNow();

					if (this.model.config.desc === "false") {
						delete e.desc;
					}

					if (this.model.config.images === "false") {
						delete e.image;
					}

					// The first two articles with images are selected as featured
					if (e.image && data.layout === "cards" && featured < 2) {
						featured++;

						data.featured.push(e);

						return null;
					}

					return e;
				}, this));
			}


			if (this.model.config.title) {
				data.title = this.model.config.title;
			}

			if (this.model.config.link) {
				data.link = parseUrl(this.model.config.link);
			}

			if (this.model.config.view && this.model.config.view === "images") {
				data.images = true;
			}


			var activeTab = this.model.get("activeTab");

			data.tabs = _.map(this.model.config.feeds, function(e, i) {
				return {
					id: i,
					name: e.name,
					active: i == activeTab // jshint ignore:line
				};
			});

			// Maximized views can show articles from all feeds
			if (data.tabs.length > 1) {
				data.tabs.unshift({
					id: "all",
					active: activeTab === "all",
					name: this.translate("all_articles")
				});
			}


			// Preserve the scrolled state of the tabs
			if (this.$("ul.tabs").length) {
				this.tabsLeft = this.$("ul.tabs")[0].scrollLeft;
			}


			return data;
		}
	});
});

define("widgetTemplate!w/rss/templates/desc.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Use this widget to display an RSS or Atom feed.  It'll display items with titles, images, and descriptions.<br /> <br /> After installation, go into the settings and enter your feed URL.  You can also customize what's shown.");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/rss/templates/main.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<header class=\"");if(t.s(t.f("errors",c,p,1),c,p,0,26,32,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("errors");});c.pop();}t.b("\"> ");if(t.s(t.f("title",c,p,1),c,p,0,56,177,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" ");if(t.s(t.f("link",c,p,1),c,p,0,66,112,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<a href=\"");t.b(t.v(t.f("link",c,p,0)));t.b("\" class=\"title\">");t.b(t.v(t.f("title",c,p,0)));t.b("</a>");});c.pop();}t.b(" ");if(!t.s(t.f("link",c,p,1),c,p,1,0,0,"")){t.b("<span class=\"title\">");t.b(t.v(t.f("title",c,p,0)));t.b("</span>");};t.b(" ");});c.pop();}t.b(" ");if(t.s(t.d("tabs.1",c,p,1),c,p,0,199,510,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <ul class=\"tabs\"> <button type=\"button\" class=\"material flat scroll-left\" data-direction=\"left\">&#xE6CD;</button> ");if(t.s(t.f("tabs",c,p,1),c,p,0,323,396,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <li data-id=\"");t.b(t.v(t.f("id",c,p,0)));t.b("\"");if(t.s(t.f("active",c,p,1),c,p,0,355,370,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" class=\"active\"");});c.pop();}t.b(">");t.b(t.v(t.f("name",c,p,0)));t.b("</li> ");});c.pop();}t.b(" <button type=\"button\" class=\"material flat scroll-right\" data-direction=\"right\">&#xE6D0;</button> </ul> ");});c.pop();}t.b(" </header> ");if(t.s(t.f("loading",c,p,1),c,p,0,544,778,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"loading\"> <svg class=\"spinner\" width=\"65px\" height=\"65px\" viewBox=\"0 0 66 66\" xmlns=\"http://www.w3.org/2000/svg\"> <circle fill=\"none\" stroke-width=\"6\" stroke-linecap=\"round\" cx=\"33\" cy=\"33\" r=\"30\"></circle> </svg> </div> ");});c.pop();}t.b(" ");if(!t.s(t.f("loading",c,p,1),c,p,1,0,0,"")){t.b(" <div class=\"items ");if(t.s(t.f("images",c,p,1),c,p,0,833,840,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" images");});c.pop();}t.b("\"> ");if(t.s(t.f("items",c,p,1),c,p,0,864,1175,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <a href=\"");t.b(t.v(t.f("url",c,p,0)));t.b("\" class=\"item\"> ");if(t.s(t.f("image",c,p,1),c,p,0,907,1063,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" ");if(t.s(t.f("images",c,p,1),c,p,0,919,959,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<img src=\"");t.b(t.v(t.f("image",c,p,0)));t.b("\" alt=\"Loading...\" />");});c.pop();}t.b(" ");if(!t.s(t.f("images",c,p,1),c,p,1,0,0,"")){t.b("<div class=\"image\" style=\"background-image: url('");t.b(t.v(t.f("image",c,p,0)));t.b("');\"></div>");};t.b(" ");});c.pop();}t.b(" <div class=\"content");if(t.s(t.f("desc",c,p,1),c,p,0,1102,1107,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" desc");});c.pop();}t.b("\"> <h3 class=\"title\">");t.b(t.v(t.f("title",c,p,0)));t.b("</h3> ");t.b(t.t(t.f("desc",c,p,0)));t.b(" </div> </a> ");});c.pop();}t.b(" </div> ");};return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/rss/templates/settings.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<header> <span class=\"title\">");t.b(t.v(t.d("i18n.settings.page_title",c,p,0)));t.b("</span> <button type=\"button\" class=\"material flat blue save\">");t.b(t.v(t.d("i18n.settings.save",c,p,0)));t.b("</button> </header> <form class=\"material-form\"> <label class=\"input\"> <span>");t.b(t.v(t.d("i18n.settings.title",c,p,0)));t.b("</span> <input type=\"text\" name=\"title\" placeholder=\"");t.b(t.v(t.d("i18n.settings.title_placeholder",c,p,0)));t.b("\" value=\"");t.b(t.v(t.f("title",c,p,0)));t.b("\" /> </label> <label class=\"input\"> <span>");t.b(t.v(t.d("i18n.settings.link",c,p,0)));t.b("</span> <input type=\"text\" name=\"link\" placeholder=\"");t.b(t.v(t.d("i18n.settings.link_placeholder",c,p,0)));t.b("\" value=\"");t.b(t.v(t.f("link",c,p,0)));t.b("\" /> </label> <label class=\"input\"> <span>");t.b(t.v(t.d("i18n.settings.articles",c,p,0)));t.b("</span> <input type=\"number\" name=\"number\" min=\"1\" max=\"20\" value=\"");t.b(t.v(t.f("number",c,p,0)));t.b("\" /> </label> <label class=\"input\"> <span>");t.b(t.v(t.d("i18n.settings.cache_time",c,p,0)));t.b("</span> <input type=\"number\" name=\"cache\" min=\"5\" max=\"9999999\" value=\"");t.b(t.v(t.f("cache",c,p,0)));t.b("\" /> </label> <fieldset class=\"feeds\"> <legend> ");t.b(t.v(t.d("i18n.settings.feeds",c,p,0)));t.b(" <span class=\"help\">");t.b(t.v(t.d("i18n.settings.feeds_help",c,p,0)));t.b("</span> </legend> ");if(t.s(t.f("isPro",c,p,1),c,p,0,956,1041,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <input type=\"text\" class=\"add\" placeholder=\"");t.b(t.v(t.d("i18n.settings.feeds_placeholder",c,p,0)));t.b("\" /> ");});c.pop();}t.b(" ");if(!t.s(t.f("isPro",c,p,1),c,p,1,0,0,"")){t.b(" <p class=\"help pro-only\">");t.b(t.v(t.d("i18n.settings.feeds_pro_only",c,p,0)));t.b("</p> ");};t.b(" <ul> ");if(t.s(t.f("feeds",c,p,1),c,p,0,1151,1606,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <li> <button type=\"button\" class=\"material toggle delete\"> <svg viewBox=\"0 0 24 24\"> <path d=\"M6 19c0 1.1.9 2 2 2h8c1.1 0 2-.9 2-2V7H6v12zM19 4h-3.5l-1-1h-5l-1 1H5v2h14V4z\"></path> </svg> </button> <input type=\"text\" name=\"feeds[][name]\" class=\"name\" placeholder=\"");t.b(t.v(t.d("i18n.settings.feed_name_placeholder",c,p,0)));t.b("\" value=\"");t.b(t.v(t.f("name",c,p,0)));t.b("\" /> <input type=\"text\" name=\"feeds[][url]\" class=\"url\" placeholder=\"");t.b(t.v(t.d("i18n.settings.feed_url_placeholder",c,p,0)));t.b("\" value=\"");t.b(t.v(t.f("url",c,p,0)));t.b("\" /> </li> ");});c.pop();}t.b(" </ul> </fieldset> </form>");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/rss/templates/maximized.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<header class=\"");if(t.s(t.f("errors",c,p,1),c,p,0,26,32,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("errors");});c.pop();}t.b("\"> ");if(t.s(t.f("title",c,p,1),c,p,0,56,177,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" ");if(t.s(t.f("link",c,p,1),c,p,0,66,112,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<a href=\"");t.b(t.v(t.f("link",c,p,0)));t.b("\" class=\"title\">");t.b(t.v(t.f("title",c,p,0)));t.b("</a>");});c.pop();}t.b(" ");if(!t.s(t.f("link",c,p,1),c,p,1,0,0,"")){t.b("<span class=\"title\">");t.b(t.v(t.f("title",c,p,0)));t.b("</span>");};t.b(" ");});c.pop();}t.b(" <button type=\"button\" class=\"material flat toggle layout\" data-state=\"");t.b(t.v(t.f("layout",c,p,0)));if(!t.s(t.f("layout",c,p,1),c,p,1,0,0,"")){t.b("cards");};t.b("\"> <svg viewBox=\"0 0 24 24\" class=\"list\"> <path d=\"M4 15h16v-2H4v2zm0 4h16v-2H4v2zm0-8h16V9H4v2zm0-6v2h16V5H4z\"></path> </svg> <svg viewBox=\"0 0 24 24\" class=\"cards\"> <path d=\"M4 11h5V5H4v6zm0 7h5v-6H4v6zm6 0h5v-6h-5v6zm6 0h5v-6h-5v6zm-6-7h5V5h-5v6zm6-6v6h5V5h-5z\"></path> </svg> </button> <ul class=\"tabs\"> <button type=\"button\" class=\"material flat scroll-left\" data-direction=\"left\">&#xE6CD;</button> ");if(t.s(t.f("tabs",c,p,1),c,p,0,708,781,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <li data-id=\"");t.b(t.v(t.f("id",c,p,0)));t.b("\"");if(t.s(t.f("active",c,p,1),c,p,0,740,755,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" class=\"active\"");});c.pop();}t.b(">");t.b(t.v(t.f("name",c,p,0)));t.b("</li> ");});c.pop();}t.b(" <button type=\"button\" class=\"material flat scroll-right\" data-direction=\"right\">&#xE6D0;</button> </ul> </header> ");if(t.s(t.f("loading",c,p,1),c,p,0,917,1151,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"loading\"> <svg class=\"spinner\" width=\"65px\" height=\"65px\" viewBox=\"0 0 66 66\" xmlns=\"http://www.w3.org/2000/svg\"> <circle fill=\"none\" stroke-width=\"6\" stroke-linecap=\"round\" cx=\"33\" cy=\"33\" r=\"30\"></circle> </svg> </div> ");});c.pop();}t.b(" ");if(!t.s(t.f("loading",c,p,1),c,p,1,0,0,"")){t.b(" <div class=\"items ");t.b(t.v(t.f("layout",c,p,0)));if(!t.s(t.f("layout",c,p,1),c,p,1,0,0,"")){t.b("cards");};t.b("\"> ");if(t.s(t.f("featured",c,p,1),c,p,0,1248,1638,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <a href=\"");t.b(t.v(t.f("url",c,p,0)));t.b("\" class=\"item featured\" style=\"background-image: linear-gradient(rgba(0, 0, 0, 0), rgba(0, 0, 0, .5)), url('");t.b(t.v(t.f("image",c,p,0)));t.b("');\"> <h3 class=\"title\">");t.b(t.v(t.f("title",c,p,0)));t.b("</h3> <div class=\"desc\">");t.b(t.t(t.f("desc",c,p,0)));t.b("</div> <div class=\"details\"> ");if(t.s(t.f("author",c,p,1),c,p,0,1489,1541,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(t.v(t.d("i18n.by",c,p,0)));t.b(" <span class=\"author\">");t.b(t.v(t.f("author",c,p,0)));t.b("</span>, ");});c.pop();}t.b("<span class=\"source\">");t.b(t.v(t.f("source",c,p,0)));t.b("</span> <span class=\"date\">");t.b(t.v(t.f("date",c,p,0)));t.b("</span> </div> </a> ");});c.pop();}t.b(" ");if(t.s(t.f("items",c,p,1),c,p,0,1662,2241,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <a href=\"");t.b(t.v(t.f("url",c,p,0)));t.b("\" class=\"item\"> ");if(t.s(t.f("list",c,p,1),c,p,0,1704,1871,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" ");if(t.s(t.f("source",c,p,1),c,p,0,1716,1754,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span class=\"source\">");t.b(t.v(t.f("source",c,p,0)));t.b("</span>");});c.pop();}t.b(" <span class=\"desc\"> <b class=\"title\">");t.b(t.v(t.f("title",c,p,0)));t.b("</b> ");t.b(t.t(t.f("desc",c,p,0)));t.b(" </span> <span class=\"date\">");t.b(t.v(t.f("date",c,p,0)));t.b("</span> ");});c.pop();}t.b(" ");if(!t.s(t.f("list",c,p,1),c,p,1,0,0,"")){t.b(" ");if(t.s(t.f("image",c,p,1),c,p,0,1901,1970,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div class=\"image\" style=\"background-image: url('");t.b(t.v(t.f("image",c,p,0)));t.b("');\"></div>");});c.pop();}t.b(" <h3 class=\"title\">");t.b(t.v(t.f("title",c,p,0)));t.b("</h3> <div class=\"desc\">");t.b(t.t(t.f("desc",c,p,0)));t.b("</div> <div class=\"details\"> ");if(t.s(t.f("author",c,p,1),c,p,0,2082,2134,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(t.v(t.d("i18n.by",c,p,0)));t.b(" <span class=\"author\">");t.b(t.v(t.f("author",c,p,0)));t.b("</span>, ");});c.pop();}t.b("<span class=\"source\">");t.b(t.v(t.f("source",c,p,0)));t.b("</span> <span class=\"date\">");t.b(t.v(t.f("date",c,p,0)));t.b("</span> </div> ");};t.b(" </a> ");});c.pop();}t.b(" </div> ");};return t.fl(); },partials: {}, subs: {  }})});
define('w/rss/model',["lodash", "jquery", "widgets/model", "lib/parseurl", "lib/feedlyproxy"], function(_, $, WidgetModel, parseUrl, feedlyProxy) {
	return WidgetModel.extend({
		widgetClassname: "tabbed-corner refreshable",

		refreshInterval: 60000,

		pro_tooltip: "rss",

		defaults: {
			config: {
				title: "Lifehacker",
				link: "",
				number: 5,
				cache: 5,
				view: "default",
				images: "true",
				desc: "true",
				size: "variable",
				feeds: [
					{
						url:  "https://lifehacker.com/rss",
						name: "Lifehacker"
					}
				]
			},

			data: {
				items: [
					{
						title: "Pandora for iOS has gained a nifty feature today: the app can act as an alarm clock so you can wake",
						url: "http://feeds.gawker.com/~r/lifehacker/full/~3/p-3zc3sNwyQ/pandora-for-ios-has-gained-a-nifty-feature-today-the-a-1479529870",
						desc: "Pandora for iOS has gained a nifty feature today: the app can act as an alarm clock so you can wake up to some music. Read more on the Pandora blog.Read more..."
					},
					{
						title: "Surfly Shares Your Browsing Session Without Downloading Anything",
						url: "http://feeds.gawker.com/~r/lifehacker/full/~3/TD7FbdZCHHk/surfly-shares-your-browsing-session-without-downloading-1479358895",
						image: "http://img.gawkerassets.com/img/198vaoqj1h8yspng/ku-medium.png",
						desc: "Sometimes, it's just easier to show someone what you're doing instead of explaining yourself. Over the web, that can be difficult, but Surfly makes it a bit easier.Read more..."
					},
					{
						title: "Design Your Home Bar with Ergonomics (and Guests) In Mind",
						url: "http://feeds.gawker.com/~r/lifehacker/full/~3/fT1J5LvVCBg/design-your-home-bar-with-ergonomics-and-guests-in-mi-1479090750",
						image: "http://img.gawkerassets.com/img/198s8jxvaur33jpg/small.jpg",
						desc: "If you're putting together a home bar, you're probably thinking about the essentials you'll need, but not necessarily how it's laid out and where in the room. Kevin Liu at Serious Eats suggests you think about positioning too—the right layout will ke"
					},
					{
						title: "Gawker Paris Hilton's Brother Bloodied in Attack Ordered By Lindsay Lohan | io9 Scientists listened",
						url: "http://feeds.gawker.com/~r/lifehacker/full/~3/QMRqfH-YUcA/@whitsongordon",
						desc: "Gawker Paris Hilton's Brother Bloodied in Attack Ordered By Lindsay Lohan | io9 Scientists listened to the heartbeat of a prisoner as he was executed | Jalopnik Comedian Dares To Make Fun Of Danica Patrick, Awkwardness Ensues | Jezebel No One Learns "
					},
					{
						title: "4 Unconventional Ways the Internet Can Help You Land Job",
						url: "http://feeds.gawker.com/~r/lifehacker/full/~3/B6gKevxTg3k/4-unconventional-ways-the-internet-can-help-you-land-jo-1479206108",
						image: "http://img.gawkerassets.com/img/198uydw1d3z7djpg/small.jpg",
						desc: "With thousands of new people entering the job market daily, you need to tap every available resource to stand out. The internet can help you hack into the minds of potential employers, if you know where to look.Read more..."
					}
				]
			}
		},


		/**
		 * Initialize
		 *
		 * The RSS widget supports a list of feeds (for Pro users), but only
		 * caches entries from the first and default one.
		 */
		initialize: function() {
			if (this.config.view) {
				delete this.config.view;
			}

			// Migrate pre-V2 feeds to the new format
			if (!this.config.feeds && this.config.url) {
				this.config.feeds = [{
					url: this.config.url,
					name: this.config.title
				}];

				delete this.config.url;

				this.saveConfig();
			}
			else {
				//Migrate to new default settings
				var isUpdated = false;
				if (this.config.feeds) {
					this.config.feeds.forEach(function(e) {
						if (e.url === "http://feeds.gawker.com/lifehacker/full") {
							e.url = "https://lifehacker.com/rss";
							isUpdated = true;
						}
					});
				}

				if (this.config.url) {
					delete this.config.url;
					isUpdated = true;
				}

				if (isUpdated) {
					this.saveConfig();
				}
			}

			this.set("activeTab", 0);

			this.on("change", function(model, options) {
				if (options && options.widgetChange === true) {
					return;
				}

				this.refresh();
			}, this);
		},


		/**
		 * Parses a feed entry, removing tracking tokens, ads, and sharing buttons
		 *
		 * @param   {Object}   e           The item to parse
		 * @param   {Boolean}  [extended]  If extended data should be parsed
		 * @return  {Object}               A parsed, normalized entry
		 */
		parseEntry: function(e, extended) {
			extended = extended === true;

			var html = $("<div>" + ((e.summary && e.summary.content) || (e.content && e.content.content) || "")
				.replace(/ src="\/\//g, " data-src=\"https://")
				.replace(/ src="/g, " data-src=\"")
				.replace(/ src='\/\//g, " data-src='https://")
				.replace(/ src='/g, " data-src='") +
			"</div>");

			// Cleanup tracking images, feedburner ads, etc.
			_.each(html[0].querySelectorAll('.mf-viral, .feedflare, img[width="1"], img[height="1"], img[data-src^="http://da.feedsportal.com"]'), function(e) {
				if (e && e.parentNode) {
					e.parentNode.removeChild(e);
				}
			});


			var item = {
				date: e.published,
				title: (e.title || "").trim(),
				url: ((_.find(e.alternate, { type: "text/html" }) || {}).href || "").trim()
			};


			if (extended) {
				item.author = e.author;
				item.source = e.origin && e.origin.title;
			}


			if (e.visual && e.visual.url && e.visual.url !== "none") {
				item.image = e.visual.url;
			}
			else if (html.find("img[data-src]").length) {
				item.image = html.find("img[data-src]").first().attr("data-src");
			}
			else if (html.find("iframe[data-chomp-id]").length) {
				item.image = "http://img.youtube.com/vi/" + html.find("iframe[data-chomp-id]").attr("data-chomp-id") + "/1.jpg";
			}
			else if (e.enclosure && e.enclosure.length > 0 && e.enclosure[0].width && e.enclosure[0].height && e.enclosure[0].href) {
				item.image = e.enclosure[0].href;
			}


			// Find any element that isn't allowed and replace it with its contents
			_.each(html[0].querySelectorAll("*:not(a):not(b):not(i):not(strong):not(u)"), function(e) {
				if (e.children.length) {
					$(e).children().unwrap();
				}
				else {
					$(e).replaceWith(e.innerHTML);
				}
			});

			// Then remove anything that's left
			_.each(html[0].querySelectorAll("*:not(a):not(b):not(i):not(strong):not(u)"), function(e) {
				if (e && e.parentNode) {
					e.parentNode.removeChild(e);
				}
			});


			// If the first element in the description is empty or the article's
			// title repeated, remove it
			var fChild = html.children().first(),
				text = (fChild.text() || "").trim();

			if (!text || text.toLowerCase() === item.title.toLowerCase()) {
				fChild.remove();
			}


			// If the description is blank (maybe it only had an image that's now
			// been removed), remove it
			if (!html[0].innerHTML.trim().length) {
				delete item.desc;
			}

			// Otherwise, make every link nested so it can still be clicked
			else {
				_.each(html[0].querySelectorAll("a"), function(e) {
					var span = document.createElement("span");

					span.setAttribute("class", "nested-link");
					span.setAttribute("data-target", "blank");
					span.setAttribute("class", "nested-link");

					span.textContent = e.textContent.replace(/\n/g, "  ").trim();


					var href = e.getAttribute("href") || "http://www.google.com/";

					if (href.trim().indexOf("//") === 0) {
						href =  "http:" + href.trim();
					}
					else if (href.trim().indexOf("http") !== 0) {
						href =  "http://" + href.trim();
					}
					else {
						href = href.trim();
					}

					span.setAttribute("data-href", href);


					$(e).replaceWith(span);
				});

				item.desc = html[0].innerHTML.trim();
			}

			return item;
		},


		/**
		 * Fetches all articles from all feeds, emitting the 45 newest
		 */
		getAll: function(isReload) {
			var feeds = _.uniq(_.map(this.config.feeds, function(e) {
				return parseUrl(e.url || "https://lifehacker.com/rss");
			}));

			if (!feeds.length) {
				feeds = [this.config.url || "https://lifehacker.com/rss"];
			}

			//var numPerFeed = Math.round((45 / feeds.length) * 2);
			var numPerFeed = 45;

			function loadFeed(feed) {
				return function() {
					return $.getJSON("https://cloud.feedly.com/v3/streams/contents?count=" + numPerFeed + "&nc=" + (new Date().getTime()) + "&streamId=feed%2F" + encodeURIComponent(feed));
				};
			}

			var processResult = function (results, errors) {
				if (this.get("activeTab") !== "all") {
					return;
				}

				var entries = _(results)
					.map(function(d) {
						return (d && d.items) || [];
					})
					.flatten()
					.sortByOrder("published", "desc")
					.take(45)
					.map(_.bind(this.parseEntry, this, _, true))
					.value();

				this.trigger("entries:loaded", {
					items: entries,
					errors: errors
				});
			}.bind(this);

			var delay = function(timeout){
				var $d = $.Deferred(),
					t = timeout || 0;
				  
				setTimeout(function (){
				  $d.resolve(timeout);
				}, t);

				return function() {
					return $d.promise();
				};
			};

			var errorCount = 0;
			var result = [];
			var cacheTimeout = (this.config.cache === '' ? 5 : this.config.cache) * 60000;
			feeds.reduce(function(prevFeed, feed) {
				var key = feed + "?count=" + numPerFeed;
				var cached = feedlyProxy.getCached(key);
				if (cached && !isReload) {
					return prevFeed
						.then(function() {
							result.push(cached);
						})
						.done(function (){
							if (feed === feeds[feeds.length - 1]) { 
								processResult(result, errorCount); //Last feed received or failed
							}
						});
				}

				return prevFeed
					.then(loadFeed(feed))
					.then(function(data) {
						feedlyProxy.onsent(data, feed, new Date().getTime() + cacheTimeout);
						result.push(data);
					})
					.fail(function() {
						errorCount++;
					})
					.done(function (){
						if (feed === feeds[feeds.length - 1]) { 
							processResult(result, errorCount); //Last feed received or failed
						}
					})
					.then(delay(1000));
			}, $.when());
		},


		refresh: function(isReload) {
			// We save the active feed in case it changes before the request is finished
			var activeTab = this.get("activeTab");

			if (!this.Auth.isPro && activeTab !== 0) {
				return this.set("activeTab", 0);
			}

			if (this.config.feeds && activeTab >= this.config.feeds.length) {
				//The active tab is deleted in the settings
				return this.set("activeTab", 0);
			}

			if (activeTab === "all") {
				return this.getAll(isReload);
			}

			var feed = (this.config.feeds && this.config.feeds[activeTab].url) || this.config.url || "https://lifehacker.com/rss";

			var maximized = this.get("state") === "maximized";

			var count = maximized || this.config.number === '' ? 45 : this.config.number;				
			var feedUrl = "https://cloud.feedly.com/v3/streams/contents?count=" + count + "&nc=" + (new Date().getTime()) + "&streamId=feed%2F" + encodeURIComponent(parseUrl(feed));

			var delayMs = feedlyProxy.getDelay(isReload || false);
			if (delayMs >= 0) {
				var key = feed + "?count=" + count;
				this.getSingle(feedUrl, key, isReload);
				return;
			}

			setTimeout(function() {
				this.getSingle(feedUrl, feed, isReload);
			}.bind(this), delayMs);
		},

		getSingle: function(url, feed, isReload) {
			var activeTab = this.get("activeTab");
			var maximized = this.get("state") === "maximized";

			var process = function(d) {
				// If the active feed has changed (i.e. the user has switched tabs
				// twice before the request finished), we don't want to emit any entries
				if (d && d.items && this.get("activeTab") === activeTab) {
					var items = _.map(d.items, this.parseEntry, this);

					// Only save data if this is the first feed and we aren't
					// maximized (and therefore didn't fetch more articles)
					if (!activeTab && !maximized) {
						this.saveData({
							items: items
						});
					}
					else {
						// We only trigger the entries:loaded event if this is not the
						// first feed so the view doesn't render twice
						this.trigger("entries:loaded", {
							items: items,
							errors: 0
						});
					}
				}
			}.bind(this);

			var cached = feedlyProxy.getCached(feed);
			if (cached && !isReload) {
				setTimeout(function() {
					process(cached);
				}, 0);
				return;
			}

			var cacheTimeout = (this.config.cache === '' ? 5 : this.config.cache) * 60000;

			// Switch to /v3/mixes/contents to get the most popular entries instead of the newest
			$.getJSON(url, function(d) {
				feedlyProxy.onsent(d, feed, new Date().getTime() + cacheTimeout);
				process(d);
			}.bind(this)).fail(function() {
				this.trigger("entries:loaded", {
					errors: 1
				});
			});
		}
	});
});
define('w/sports/view',["lodash", "jquery", "moment", "widgets/views/main"], function(_, $, moment, WidgetView) {
	return WidgetView.extend({
		events: {
			"click .game .summary": function(e) {
				$(e.currentTarget).next(".extended").toggleClass("visible");
			},

			"click header .tabs li": function(e) {
				this.model._state = e.currentTarget.getAttribute("data-id");

				if (this.model._state === "news" && !this.Auth.isPro) {
					this.render();
				}
				else {
					this.render({
						loading: true
					});

					this.model.refresh();
				}
			},

			"click header .select .options li": function(e) {
				delete this.model._state;

				this.model.setActiveView(e.currentTarget.getAttribute("data-id"));

				this.render({
					loading: true
				});

				this.model.refresh();
			}
		},

		initialize: function() {
			this.listenTo(this.model, "change", _.ary(this.render, 0));

			// Here we want the data object to be passed
			this.listenTo(this.model, "news:loaded games:loaded", this.render);

			this.render();
		},

		onBeforeRender: function(data) {
			var activeView = this.model._activeView || (this.model.config.teams && this.model.config.teams.length ? "favorites" : "top");

			data.news = this.model._state === "news";

			if (data.news && !this.Auth.isPro) {
				data.proSplash = true;

				delete data.games;
			}

			if (data.games) {
				var open = [];

				if (this._rendered) {
					open = _.map(this.$(".extended.visible").toArray(), function(e) {
						return parseInt(e.getAttribute("data-id"));
					});

					this._scrollTop = this.$(".games").scrollTop();
				}

				this._rendered = true;


				data.allView = activeView === "top";

				data.sections = _(data.games).map(function(game) {
					// If this is a V1-format game, skip
					if (game.home_first) {
						return;
					}

					game = _.clone(game);

					// These are loser instead of winner so upcoming games are darker and higher contrast
					game.home_loser = (typeof game.home.isWinner === "boolean" ? !game.home.isWinner : (game.home.score && game.home.score < game.away.score)) ? "loser" : "";
					game.away_loser = (typeof game.away.isWinner === "boolean" ? !game.away.isWinner : (game.away.score && game.away.score < game.home.score)) ? "loser" : "";

					game.groupDate = new Date(game.date).toDateString();


					if (open.indexOf(game.id) !== -1) {
						game.extendedVisible = "visible";
					}


					var mDate = moment(game.date);

					game.longDate = mDate.format("dddd, MMMM Do" + (mDate.year() !== new Date().getFullYear() ? " YYYY" : "") + ", LT");

					if (game.date > new Date().getTime()) {
						game.pre = true;

						game.shortDate = mDate.format("LT");

						if (game.broadcasts) {
							game.broadcasts = game.broadcasts.join(", ");
						}
					}

					return game;
				}).compact().groupBy(data.allView ? "league" : "groupDate").map(function(e, k) {
					var title;

					if (data.allView) {
						title = k;
					}
					else {
						var date = new Date(k);

						title = moment(new Date(k)).format("dddd, MMMM Do" + (date.getFullYear() !== new Date().getFullYear() ? " YYYY" : ""));
					}

					return {
						title: title,
						games: e
					};
				}).value();

				if (data.allView) {
					data.sections = _.sortBy(data.sections, function(e) {
						return e.title.indexOf("NCAA") === 0 ? 1 : -1;
					});
				}
			}

			data.views = _.map({
				"favorites": this.translate("favorites"),
				"top": this.translate("top_games"),
				"football/nfl": "NFL",
				"football/college-football": "NCAA Football",
				"baseball/mlb": "MLB",
				"baseball/college-baseball": "NCAA Men's Baseball",
				"hockey/nhl": "NHL",
				"basketball/nba": "NBA",
				"basketball/mens-college-basketball": "NCAA Basketball",
				"basketball/wnba": "WNBA",
				"basketball/womens-college-basketball": "NCAA Women's Basketball",
				"tennis/atp": "Men's Tennis",
				"tennis/wta": "Women's Tennis",
				"soccer/eng.1": "Barclays Premier League",
				"soccer/uefa.uefa": "UEFA Champions League",
				"soccer/esp.1": "Spanish Primera División",
				"soccer/usa.1": "Major League Soccer",
				"soccer/mex.1": "Mexican Liga MX",
				"soccer/ita.1": "Italian Serie A",
				"soccer/ger.1": "German Bundesliga",
				"soccer/fifa.wwc": "Women's World Cup",
				"soccer/fifa.world": "FIFA World Cup",
				"mma/ufc": "Ultimate Fighting Championship",
			}, function(e, k) {
				if (k === activeView) {
					data.activeView = e;
				}

				return {
					id: k,
					name: e,
					active: k === activeView
				};
			}, this);

			return data;
		},

		onRender: function() {
			if (this._scrollTop) {
				this.$(".games").scrollTop(this._scrollTop);
			}
		}
	});
});
define('w/sports/settings',["lodash", "jquery", "widgets/views/settings", "jquery.serializejson"], function(_, $, WidgetView) {
	return WidgetView.extend({
		events: {
			"click header button.save": "serialize",

			"click .list li .delete": function(e) {
				e.currentTarget.parentNode.parentNode.removeChild(e.currentTarget.parentNode);
			},

			"keydown .add input": function(e) {
				if (e.which === 13) {
					e.preventDefault();

					this.addTeam();
				}
				else if (e.which === 38 || e.which === 40) {
					e.preventDefault();

					var active = this.$("ul.suggestions li.active").removeClass("active");

					active = active[e.which === 38 ? "prev" : "next"]();

					if (!active.length) {
						active = this.$("ul.suggestions li")[e.which === 38 ? "last" : "first"]();
					}

					e.currentTarget.value = active.addClass("active").find("h3").text();
				}
			},

			"mousedown .suggestions li": function(e) {
				$(e.currentTarget).addClass("active").siblings().removeClass("active");

				this.addTeam();
			},

			"input .add input": function(e) {
				this.updateSuggestions(e, "input");
			},

			"focusin .add": function(e) {
				this.updateSuggestions(e, "focusin");
			},

			"focusout .add": function(e) {
				this.updateSuggestions(e, "focusout");
			}
		},


		addTeam: function() {
			var tElm = this.$(".suggestions .active:first");

			if (!tElm.length) {
				tElm = this.$(".suggestions li:first");
			}

			this.$(".add").focusout().children("input").val("");

			var itm = tElm.clone().append('<button type="button" class="material toggle delete">' +
				'<svg viewBox="0 0 24 24">' +
					'<path d="M6 19c0 1.1.9 2 2 2h8c1.1 0 2-.9 2-2V7H6v12zM19 4h-3.5l-1-1h-5l-1 1H5v2h14V4z"></path>' +
				'</svg>' +
			'</button>');

			this.$(".list").append(itm).scrollTop(this.$(".list")[0].scrollHeight);
		},


		updateSuggestions: function(e, type) {
			var val = this.$(".add input").val(),
				sElm = this.$("ul.suggestions");

			if (val.trim() !== "" && type !== "focusout") {
				sElm.addClass("visible");

				this.Auth.ajax({
					url: "/sports/v1/teams/" + encodeURIComponent(val),
					success: function(d) {
						if (!d || !Array.isArray(d) || !d.length) {
							return sElm.removeClass("visible");
						}

						// Dynamic element creation... a bit messy but safer than plain HTML and
						// not too bad performance-wise
						sElm.empty().append(_.map(d, function(e, i) {
							return $(document.createElement("li")).addClass(i === 0 ? "active" : "").attr("data-value", JSON.stringify(e)).append(
								$(document.createElement("img")).addClass("logo").attr("src", this.isDark ? e.logoDark : e.logo),
								$(document.createElement("div")).addClass("name").append(
									$(document.createElement("h3")).text(e.name),
									$(document.createElement("span")).addClass("league").text(e.league)
								)
							);
						}, this));
					}.bind(this)
				});
			}
			else {
				sElm.removeClass("visible");
			}
		},


		/**
		 * Serializes and saves the contents of the settings form
		 */
		serialize: function() {
			delete this.model._state;
			delete this.model._activeView;

			this.model.config.teams = _(this.$(".list li").toArray()).map(function(e) {
				try {
					return JSON.parse(e.getAttribute("data-value"));
				}
				catch (err) {}

				return;
			}).compact().uniq("id").value();

			this.model.set({
				state: "default"
			});

			this.model.saveConfig();
		},


		initialize: function() {
			this.listenTo(this.model, "change:config", _.ary(this.render, 0));

			this.render();
		},


		onBeforeRender: function(config) {
			config.teams = _.map(config.teams, function(e) {
				e = _.clone(e);

				e.json = JSON.stringify(e);

				return e;
			});
		}
	});
});

define("widgetTemplate!w/sports/templates/desc.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Keep track of recent and live sports scores, schedules, and news with this widget.<br /> <br /> After installing this widget, go to the settings to enter your favorite teams.");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/sports/templates/main.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<header> <div class=\"select\" tabindex=\"-1\"> <span class=\"selected\">");t.b(t.v(t.f("activeView",c,p,0)));t.b("</span> <ul class=\"options\"> ");if(t.s(t.f("views",c,p,1),c,p,0,120,195,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <li data-id=\"");t.b(t.v(t.f("id",c,p,0)));t.b("\"");if(t.s(t.f("active",c,p,1),c,p,0,152,169,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" class=\"selected\"");});c.pop();}t.b(">");t.b(t.v(t.f("name",c,p,0)));t.b("</li> ");});c.pop();}t.b(" </ul> </div> <ul class=\"tabs\"> <li data-id=\"scores\"");if(!t.s(t.f("news",c,p,1),c,p,1,0,0,"")){t.b(" class=\"active\"");};t.b(">");t.b(t.v(t.d("i18n.scores",c,p,0)));t.b("</li> <li data-id=\"news\"");if(t.s(t.f("news",c,p,1),c,p,0,339,354,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" class=\"active\"");});c.pop();}t.b(">");t.b(t.v(t.d("i18n.news",c,p,0)));t.b("</li> </ul> </header> ");if(t.s(t.f("loading",c,p,1),c,p,0,411,645,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"loading\"> <svg class=\"spinner\" width=\"65px\" height=\"65px\" viewBox=\"0 0 66 66\" xmlns=\"http://www.w3.org/2000/svg\"> <circle fill=\"none\" stroke-width=\"6\" stroke-linecap=\"round\" cx=\"33\" cy=\"33\" r=\"30\"></circle> </svg> </div> ");});c.pop();}t.b(" ");if(t.s(t.f("proSplash",c,p,1),c,p,0,672,799,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"splash pro-only\"> <span class=\"badge\">Pro</span> <p> ");t.b(t.v(t.d("i18n.pro_splash1",c,p,0)));t.b(" <br /> ");t.b(t.v(t.d("i18n.pro_splash2",c,p,0)));t.b(" </p> </div> ");});c.pop();}t.b(" ");if(t.s(t.f("news",c,p,1),c,p,0,823,1171,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"news\"> ");if(t.s(t.f("articles",c,p,1),c,p,0,856,1150,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <a href=\"");t.b(t.v(t.f("link",c,p,0)));t.b("\" class=\"item\"> ");if(t.s(t.f("image",c,p,1),c,p,0,900,969,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div class=\"image\" style=\"background-image: url('");t.b(t.v(t.f("image",c,p,0)));t.b("');\"></div>");});c.pop();}t.b(" <div class=\"content");if(t.s(t.f("desc",c,p,1),c,p,0,1008,1013,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" desc");});c.pop();}t.b("\"> <h3 class=\"title\"> ");t.b(t.v(t.f("title",c,p,0)));t.b(" ");if(t.s(t.f("source",c,p,1),c,p,0,1065,1111,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span class=\"source\">&mdash; ");t.b(t.v(t.f("source",c,p,0)));t.b("</span>");});c.pop();}t.b(" </h3> ");t.b(t.v(t.f("desc",c,p,0)));t.b(" </div> </a> ");});c.pop();}t.b(" </div> ");});c.pop();}t.b(" ");if(!t.s(t.f("news",c,p,1),c,p,1,0,0,"")){t.b(" ");if(!t.s(t.f("loading",c,p,1),c,p,1,0,0,"")){if(!t.s(t.f("games",c,p,1),c,p,1,0,0,"")){t.b(" <div class=\"splash no-games\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"> <path d=\"M12 2C6.48 2 2 6.48 2 12s4.48 10 10 10 10-4.48 10-10S17.52 2 12 2zm0 18c-4.42 0-8-3.58-8-8 0-1.85.63-3.55 1.69-4.9L16.9 18.31C15.55 19.37 13.85 20 12 20zm6.31-3.1L7.1 5.69C8.45 4.63 10.15 4 12 4c4.42 0 8 3.58 8 8 0 1.85-.63 3.55-1.69 4.9z\"></path> </svg> <p>");t.b(t.v(t.d("i18n.no_games",c,p,0)));t.b("</p> </div> ");};};t.b(" <div class=\"games\"> ");if(t.s(t.f("sections",c,p,1),c,p,0,1657,4784,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <section> ");if(t.s(t.f("title",c,p,1),c,p,0,1678,1696,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<h3>");t.b(t.v(t.f("title",c,p,0)));t.b("</h3>");});c.pop();}t.b(" ");if(t.s(t.f("games",c,p,1),c,p,0,1717,4762,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"game ");t.b(t.v(t.f("sport",c,p,0)));t.b("\"> <div class=\"summary\"> <div class=\"teams\"> <div class=\"away ");t.b(t.v(t.f("away_loser",c,p,0)));t.b("\"> <img class=\"icon\" src=\"");if(t.s(t.f("isDark",c,p,1),c,p,0,1857,1874,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(t.v(t.d("away.logoDark",c,p,0)));});c.pop();}if(!t.s(t.f("isDark",c,p,1),c,p,1,0,0,"")){t.b(t.v(t.d("away.logo",c,p,0)));};t.b("\" /> <span class=\"name\" title=\"");t.b(t.v(t.d("away.location",c,p,0)));t.b(" ");t.b(t.v(t.d("away.name",c,p,0)));t.b("\">");t.b(t.v(t.d("away.location",c,p,0)));t.b(" ");t.b(t.v(t.d("away.name",c,p,0)));t.b("</span> <span class=\"score\">");t.b(t.v(t.d("away.score",c,p,0)));if(t.s(t.f("pre",c,p,1),c,p,0,2065,2080,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(t.v(t.d("away.record",c,p,0)));});c.pop();}t.b("</span> </div> <div class=\"home ");t.b(t.v(t.f("home_loser",c,p,0)));t.b("\"> <img class=\"icon\" src=\"");if(t.s(t.f("isDark",c,p,1),c,p,0,2171,2188,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(t.v(t.d("home.logoDark",c,p,0)));});c.pop();}if(!t.s(t.f("isDark",c,p,1),c,p,1,0,0,"")){t.b(t.v(t.d("home.logo",c,p,0)));};t.b("\" /> <span class=\"name\" title=\"");t.b(t.v(t.d("home.location",c,p,0)));t.b(" ");t.b(t.v(t.d("home.name",c,p,0)));t.b("\">");t.b(t.v(t.d("home.location",c,p,0)));t.b(" ");t.b(t.v(t.d("home.name",c,p,0)));t.b("</span> <span class=\"score\">");t.b(t.v(t.d("home.score",c,p,0)));if(t.s(t.f("pre",c,p,1),c,p,0,2379,2394,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(t.v(t.d("home.record",c,p,0)));});c.pop();}t.b("</span> </div> </div> <div class=\"status\"> ");if(t.s(t.f("pre",c,p,1),c,p,0,2453,2539,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <span>");t.b(t.v(t.f("shortDate",c,p,0)));t.b("</span> ");if(t.s(t.f("broadcasts",c,p,1),c,p,0,2496,2523,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span>");t.b(t.v(t.f("broadcasts",c,p,0)));t.b("</span>");});c.pop();}t.b(" ");});c.pop();}t.b(" ");if(!t.s(t.f("pre",c,p,1),c,p,1,0,0,"")){t.b(" <span>");t.b(t.v(t.f("label",c,p,0)));t.b("</span> ");};t.b(" </div> </div> <div class=\"extended ");t.b(t.v(t.f("extendedVisible",c,p,0)));t.b("\" data-id=\"");t.b(t.v(t.f("id",c,p,0)));t.b("\"> ");if(t.s(t.f("note",c,p,1),c,p,0,2672,2706,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span class=\"note\">");t.b(t.v(t.f("note",c,p,0)));t.b("</span>");});c.pop();}t.b(" <span class=\"date\">");t.b(t.v(t.f("longDate",c,p,0)));t.b("</span> <span class=\"venue\">");t.b(t.v(t.f("venue",c,p,0)));t.b("</span> <div class=\"overview\"> ");if(t.s(t.f("away",c,p,1),c,p,0,2824,3095,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"team away\" style=\"background-image: url('");if(t.s(t.f("isDark",c,p,1),c,p,0,2889,2901,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(t.v(t.f("logoDark",c,p,0)));});c.pop();}if(!t.s(t.f("isDark",c,p,1),c,p,1,0,0,"")){t.b(t.v(t.f("logo",c,p,0)));};t.b("')\"> <span class=\"location\">");t.b(t.v(t.f("location",c,p,0)));t.b("</span> <span class=\"name\">");t.b(t.v(t.f("name",c,p,0)));t.b("</span> ");if(t.s(t.f("record",c,p,1),c,p,0,3036,3076,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span class=\"record\">(");t.b(t.v(t.f("record",c,p,0)));t.b(")</span>");});c.pop();}t.b(" </div> ");});c.pop();}t.b(" <div class=\"status\"> ");if(t.s(t.f("pre",c,p,1),c,p,0,3134,3262,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <span class=\"time\">");t.b(t.v(t.f("shortDate",c,p,0)));t.b("</span> <span class=\"broadcasts\">&nbsp;");if(t.s(t.f("broadcasts",c,p,1),c,p,0,3221,3239,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("TV: ");t.b(t.v(t.f("broadcasts",c,p,0)));});c.pop();}t.b("</span> ");});c.pop();}t.b(" ");if(!t.s(t.f("pre",c,p,1),c,p,1,0,0,"")){t.b(" <span class=\"score\">");t.b(t.v(t.d("away.score",c,p,0)));t.b(" - ");t.b(t.v(t.d("home.score",c,p,0)));t.b("</span> <span class=\"status\">");t.b(t.v(t.f("label",c,p,0)));t.b("</span> ");};t.b(" </div> ");if(t.s(t.f("home",c,p,1),c,p,0,3402,3673,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"team home\" style=\"background-image: url('");if(t.s(t.f("isDark",c,p,1),c,p,0,3467,3479,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(t.v(t.f("logoDark",c,p,0)));});c.pop();}if(!t.s(t.f("isDark",c,p,1),c,p,1,0,0,"")){t.b(t.v(t.f("logo",c,p,0)));};t.b("')\"> <span class=\"location\">");t.b(t.v(t.f("location",c,p,0)));t.b("</span> <span class=\"name\">");t.b(t.v(t.f("name",c,p,0)));t.b("</span> ");if(t.s(t.f("record",c,p,1),c,p,0,3614,3654,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span class=\"record\">(");t.b(t.v(t.f("record",c,p,0)));t.b(")</span>");});c.pop();}t.b(" </div> ");});c.pop();}t.b(" </div> ");if(t.s(t.f("lastPlay",c,p,1),c,p,0,3703,3869,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"lastplay\"> <h4> ");t.b(t.v(t.d("i18n.last_play",c,p,0)));t.b(" ");if(t.s(t.f("secondaryPlayText",c,p,1),c,p,0,3773,3807,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span>");t.b(t.v(t.f("secondaryPlayText",c,p,0)));t.b("</span>");});c.pop();}t.b(" </h4> <span>");t.b(t.v(t.f("lastPlay",c,p,0)));t.b("</span> </div> ");});c.pop();}t.b(" ");if(t.s(t.d("linescoreKey.0",c,p,1),c,p,0,3902,4327,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <table class=\"linescores\"> <thead> <tr> <td></td> ");if(t.s(t.f("linescoreKey",c,p,1),c,p,0,3970,3984,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<td>");t.b(t.v(t.d(".",c,p,0)));t.b("</td>");});c.pop();}t.b(" </tr> </thead> <tbody> <tr> <td class=\"team\" title=\"");t.b(t.v(t.d("away.location",c,p,0)));t.b(" ");t.b(t.v(t.d("away.name",c,p,0)));t.b("\">");t.b(t.v(t.d("away.name",c,p,0)));t.b("</td> ");if(t.s(t.d("away.linescores",c,p,1),c,p,0,4126,4140,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<td>");t.b(t.v(t.d(".",c,p,0)));t.b("</td>");});c.pop();}t.b(" </tr> <tr> <td class=\"team\" title=\"");t.b(t.v(t.d("home.location",c,p,0)));t.b(" ");t.b(t.v(t.d("home.name",c,p,0)));t.b("\">");t.b(t.v(t.d("home.name",c,p,0)));t.b("</td> ");if(t.s(t.d("home.linescores",c,p,1),c,p,0,4268,4282,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<td>");t.b(t.v(t.d(".",c,p,0)));t.b("</td>");});c.pop();}t.b(" </tr> </tbody> </table> ");});c.pop();}t.b(" <div class=\"links\"> ");if(t.s(t.f("pre",c,p,1),c,p,0,4375,4510,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" ");if(t.s(t.f("preview",c,p,1),c,p,0,4388,4430,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<a href=\"");t.b(t.v(t.f("preview",c,p,0)));t.b("\">");t.b(t.v(t.d("i18n.preview",c,p,0)));t.b("</a>");});c.pop();}t.b(" ");if(t.s(t.f("tickets",c,p,1),c,p,0,4455,4497,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<a href=\"");t.b(t.v(t.f("tickets",c,p,0)));t.b("\">");t.b(t.v(t.d("i18n.tickets",c,p,0)));t.b("</a>");});c.pop();}t.b(" ");});c.pop();}t.b(" ");if(!t.s(t.f("pre",c,p,1),c,p,1,0,0,"")){t.b(" ");if(t.s(t.f("live",c,p,1),c,p,0,4537,4573,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<a href=\"");t.b(t.v(t.f("live",c,p,0)));t.b("\">");t.b(t.v(t.d("i18n.live",c,p,0)));t.b("</a>");});c.pop();}t.b(" ");if(!t.s(t.f("live",c,p,1),c,p,1,0,0,"")){if(t.s(t.f("recap",c,p,1),c,p,0,4602,4640,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<a href=\"");t.b(t.v(t.f("recap",c,p,0)));t.b("\">");t.b(t.v(t.d("i18n.recap",c,p,0)));t.b("</a>");});c.pop();}};t.b(" ");if(t.s(t.f("boxscore",c,p,1),c,p,0,4673,4718,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<a href=\"");t.b(t.v(t.f("boxscore",c,p,0)));t.b("\">");t.b(t.v(t.d("i18n.box_score",c,p,0)));t.b("</a>");});c.pop();}t.b(" ");};t.b(" </div> </div> </div> ");});c.pop();}t.b(" </section> ");});c.pop();}t.b(" </div> ");};return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/sports/templates/settings.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<header> <span class=\"title\">");t.b(t.v(t.d("i18n.settings.page_title",c,p,0)));t.b("</span> <button type=\"button\" class=\"material flat blue save\">");t.b(t.v(t.d("i18n.settings.save",c,p,0)));t.b("</button> </header> <form class=\"material-form\"> <div class=\"add\" tabindex=\"-1\"> <input type=\"text\" placeholder=\"");t.b(t.v(t.d("i18n.settings.teams_placeholder",c,p,0)));t.b("\" /> <ul class=\"suggestions\"></ul> </div> <ul class=\"list\"> ");if(t.s(t.f("teams",c,p,1),c,p,0,359,774,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <li data-value=\"");t.b(t.v(t.f("json",c,p,0)));t.b("\"> <img class=\"logo\" src=\"");if(t.s(t.f("isDark",c,p,1),c,p,0,421,433,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(t.v(t.f("logoDark",c,p,0)));});c.pop();}if(!t.s(t.f("isDark",c,p,1),c,p,1,0,0,"")){t.b(t.v(t.f("logo",c,p,0)));};t.b("\" /> <div class=\"name\"> <h3>");t.b(t.v(t.f("location",c,p,0)));t.b(" ");t.b(t.v(t.f("name",c,p,0)));t.b("</h3> <span class=\"league\">");t.b(t.v(t.f("league",c,p,0)));t.b("</span> </div> <button type=\"button\" class=\"material toggle delete\"> <svg viewBox=\"0 0 24 24\"> <path d=\"M6 19c0 1.1.9 2 2 2h8c1.1 0 2-.9 2-2V7H6v12zM19 4h-3.5l-1-1h-5l-1 1H5v2h14V4z\"></path> </svg> </button> </li> ");});c.pop();}t.b(" </ul> </form>");return t.fl(); },partials: {}, subs: {  }})});
define('w/sports/model',["jquery", "lodash", "widgets/model"], function($, _, WidgetModel) {
	return WidgetModel.extend({
		refreshInterval: 180000,

		pro_tooltip: "sport",

		defaults: {
			config: {
				size: "variable",
				teams: []
			},
			data: {
				games: [
					{
						id: 400854243,
						sport: "basketball",
						league: "NCAA Basketball",
						clock: "0:00",
						period: 2,
						status: "post",
						label: "Final",
						date: 1448809200000,
						odds: 0,
						broadcasts: [],
						recap: "https://espn.go.com/ncb/recap?gameId=400854243",
						boxscore: "https://espn.go.com/ncb/boxscore?gameId=400854243",
						linescoreKey: ["1", "2", "Total"],
						home: {
							id: 2294,
							name: "Hawkeyes",
							logo: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/ncaa/500/2294.png&w=70&h=70&transparent=true",
							isWinner: true,
							logoDark: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/ncaa/500-dark/2294.png&w=70&h=70&transparent=true",
							record: "4-2",
							score: 84,
							location: "Iowa",
							linescores: [40, 44, 84]
						},
						away: {
							id: 2724,
							name: "Shockers",
							logo: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/ncaa/500/2724.png&w=70&h=70&transparent=true",
							isWinner: false,
							logoDark: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/ncaa/500-dark/2724.png&w=70&h=70&transparent=true",
							record: "2-4",
							score: 61,
							location: "Wichita St",
							linescores: [21, 40, 61]
						},
						venue: "HP Field House, Orlando, Florida"
					},
					{
						id: 400816818,
						sport: "basketball",
						league: "NCAA Basketball",
						clock: "11:43",
						period: 1,
						status: "in",
						label: "11:43 - 1st",
						date: 1448818200000,
						odds: 0,
						broadcasts: ["ESPNU"],
						boxscore: "https://espn.go.com/ncb/boxscore?gameId=400816818",
						live: "https://espn.go.com/ncb/gamecast?gameId=400816818",
						linescoreKey: ["1", "Total"],
						home: {
							id: 150,
							name: "Blue Devils",
							logo: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/ncaa/500/150.png&w=70&h=70&transparent=true",
							logoDark: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/ncaa/500-dark/150.png&w=70&h=70&transparent=true",
							record: "5-1",
							score: 18,
							location: "Duke",
							linescores: [18, 18]
						},
						away: {
							id: 328,
							name: "Aggies",
							logo: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/ncaa/500/328.png&w=70&h=70&transparent=true",
							logoDark: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/ncaa/500-dark/328.png&w=70&h=70&transparent=true",
							record: "4-0",
							score: 12,
							location: "Utah State",
							linescores: [12, 12]
						},
						venue: "Cameron Indoor Stadium, Durham, North Carolina"
					},
					{
						id: 400791516,
						sport: "football",
						league: "NFL",
						clock: "15:00",
						period: 1,
						status: "pre",
						label: "1:00 PM",
						date: 1448820000000,
						odds: 0,
						broadcasts: ["FOX"],
						preview: "https://espn.go.com/nfl/preview?gameId=400791516",
						tickets: "https://www.stubhub.com/cincinnati-bengals-cincinnati-paul-brown-stadium-11-29-2015-9298647",
						home: {
							id: 4,
							name: "Bengals",
							logo: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/nfl/500/scoreboard/cin.png&w=70&h=70&transparent=true",
							logoDark: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/nfl/500-dark/scoreboard/cin.png&w=70&h=70&transparent=true",
							record: "8-2",
							location: "Cincinnati"
						},
						away: {
							id: 14,
							name: "Rams",
							logo: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/nfl/500/scoreboard/stl.png&w=70&h=70&transparent=true",
							logoDark: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/nfl/500-dark/scoreboard/stl.png&w=70&h=70&transparent=true",
							record: "4-6",
							location: "St. Louis"
						},
						venue: "Paul Brown Stadium, Cincinnati, OH"
					},
					{
						id: 400791514,
						sport: "football",
						league: "NFL",
						clock: "15:00",
						period: 1,
						status: "pre",
						label: "1:00 PM",
						date: 1448820000000,
						odds: 0,
						broadcasts: ["FOX"],
						preview: "https://espn.go.com/nfl/preview?gameId=400791514",
						tickets: "https://www.stubhub.com/atlanta-falcons-atlanta-georgia-dome-11-29-2015-9298672",
						home: {
							id: 1,
							name: "Falcons",
							logo: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/nfl/500/scoreboard/atl.png&w=70&h=70&transparent=true",
							logoDark: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/nfl/500-dark/scoreboard/atl.png&w=70&h=70&transparent=true",
							record: "6-4",
							location: "Atlanta"
						},
						away: {
							id: 16,
							name: "Vikings",
							logo: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/nfl/500/scoreboard/min.png&w=70&h=70&transparent=true",
							logoDark: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/nfl/500-dark/scoreboard/min.png&w=70&h=70&transparent=true",
							record: "7-3",
							location: "Minnesota"
						},
						venue: "Georgia Dome, Atlanta, GA"
					},
					{
						id: 400791506,
						sport: "football",
						league: "NFL",
						clock: "15:00",
						period: 1,
						status: "pre",
						label: "1:00 PM",
						date: 1448820000000,
						odds: 0,
						broadcasts: ["FOX"],
						preview: "https://espn.go.com/nfl/preview?gameId=400791506",
						tickets: "https://www.stubhub.com/washington-redskins-landover-fedexfield-11-29-2015-9298625",
						home: {
							id: 28,
							name: "Redskins",
							logo: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/nfl/500/scoreboard/wsh.png&w=70&h=70&transparent=true",
							logoDark: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/nfl/500-dark/scoreboard/wsh.png&w=70&h=70&transparent=true",
							record: "4-6",
							location: "Washington"
						},
						away: {
							id: 19,
							name: "Giants",
							logo: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/nfl/500/scoreboard/nyg.png&w=70&h=70&transparent=true",
							logoDark: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/nfl/500-dark/scoreboard/nyg.png&w=70&h=70&transparent=true",
							record: "5-5",
							location: "New York"
						},
						venue: "FedEx Field, Landover, MD"
					},
					{
						id: 400791522,
						sport: "football",
						league: "NFL",
						clock: "15:00",
						period: 1,
						status: "pre",
						label: "1:00 PM",
						date: 1448820000000,
						odds: 0,
						broadcasts: ["CBS"],
						preview: "https://espn.go.com/nfl/preview?gameId=400791522",
						tickets: "https://www.stubhub.com/new-york-jets-east-rutherford-metlife-stadium-11-29-2015-9298555",
						home: {
							id: 20,
							name: "Jets",
							logo: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/nfl/500/scoreboard/nyj.png&w=70&h=70&transparent=true",
							logoDark: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/nfl/500-dark/scoreboard/nyj.png&w=70&h=70&transparent=true",
							record: "5-5",
							location: "New York"
						},
						away: {
							id: 15,
							name: "Dolphins",
							logo: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/nfl/500/scoreboard/mia.png&w=70&h=70&transparent=true",
							logoDark: "https://a.espncdn.com/combiner/i?img=/i/teamlogos/nfl/500-dark/scoreboard/mia.png&w=70&h=70&transparent=true",
							record: "4-6",
							location: "Miami"
						},
						venue: "MetLife Stadium, East Rutherford, NJ"
					}
				]
			}
		},

		initialize: function() {
			if (this.config.title || this.config.league || this.config.number || this.config.unavailable || this.get("size") === "tiny") {
				delete this.config.title;
				delete this.config.league;
				delete this.config.number;
				delete this.config.unavailable;

				if (this.config.teams && this.config.teams[0] && typeof this.config.teams[0] !== "object") {
					delete this.config.teams;
				}

				this.set("size", "variable");
			}

			this._activeView = this.config.last;

			WidgetModel.prototype.initialize.call(this);
		},

		setActiveView: function(view) {
			this._activeView = view;
			this.config.last = view;
			this.saveData();
		},

		getNews: function() {
			this.Auth.ajax({
				url: "/sports/v1/news" + (!this._activeView || this._activeView === "favorites" || this._activeView === "all" ? "" : "/" + this._activeView),
				success: function(d) {
					this.trigger("news:loaded", {
						articles: d
					});
				}.bind(this)
			});
		},

		refresh: function() {
			if (this._state === "news") {
				if (!this.Auth.isPro) {
					return;
				}

				return this.getNews();
			}

			var url = "/sports/v1/",
				requestedView = this._activeView;

			if (!this._activeView || this._activeView === "favorites") {
				if (this.config.teams && this.config.teams.length) {
					url += "favorites/" + _.pluck(this.config.teams, "id").join(",");
				}
				else {
					url += "top";
				}
			}
			else if (this._activeView === "all") {
				url += "top";
			}
			else {
				url += this._activeView;
			}

			this.Auth.ajax({
				url: url,
				success: function(d) {
					if (this._activeView !== requestedView) {
						return;
					}

					// If any games are in progress refresh every 30 seconds instead of every 2.5 minutes
					if (_.some(d, { status: "in" })) {
						if (this.refreshInterval !== 30000) {
							this.refreshInterval = 30000;

							this.trigger("refreshInterval:change");
						}
					}
					else if (this.refreshInterval !== 180000) {
						this.refreshInterval = 180000;

						this.trigger("refreshInterval:change");
					}

					if (this._activeView && this._activeView !== "favorites") {
						this.trigger("games:loaded", {
							games: d
						});
					}
					else {
						this.saveData({
							games: d
						});
					}
				}.bind(this)
			});
		}
	});
});
define('w/stocks/view',["lodash", "jquery", "widgets/views/main"], function(_, $, WidgetView) {
	return WidgetView.extend({
		events: {
			"click .list .stock": function(e) {
				var stock = this.model.data.stocks[$(e.currentTarget).index()];

				this.model.activeTicker = stock.ticker;

				this.model.set("state", "detail");
			}
		},

		onBeforeRender: function(data) {
			if (this.model.config.title) {
				data.title = this.model.config.title;
			}

			return data;
		}
	});
});
/**
 * Chart.js
 * http://chartjs.org/
 * Version: 2.0.0-beta
 *
 * Copyright 2015 Nick Downie
 * Released under the MIT license
 * https://github.com/nnnick/Chart.js/blob/master/LICENSE.md
 *
 * Patched with proper AMD support
 */
// jshint ignore:start
define('w/stocks/lib/chart',["moment"], function(moment){
	!function t(e,i,a){function s(n,r){if(!i[n]){if(!e[n]){var h="function"==typeof require&&require;if(!r&&h)return h(n,!0);if(o)return o(n,!0);var l=new Error("Cannot find module '"+n+"'");throw l.code="MODULE_NOT_FOUND",l}var c=i[n]={exports:{}};e[n][0].call(c.exports,function(t){var i=e[n][1][t];return s(i?i:t)},c,c.exports,t,e,i,a)}return i[n].exports}for(var o="function"==typeof require&&require,n=0;n<a.length;n++)s(a[n]);return s}({1:[function(t,e){!function(){var i=t("color-convert"),a=t("color-string"),s=function(t){if(t instanceof s)return t;if(!(this instanceof s))return new s(t);if(this.values={rgb:[0,0,0],hsl:[0,0,0],hsv:[0,0,0],hwb:[0,0,0],cmyk:[0,0,0,0],alpha:1},"string"==typeof t){var e=a.getRgba(t);if(e)this.setValues("rgb",e);else if(e=a.getHsla(t))this.setValues("hsl",e);else{if(!(e=a.getHwb(t)))throw new Error('Unable to parse color from string "'+t+'"');this.setValues("hwb",e)}}else if("object"==typeof t){var e=t;if(void 0!==e.r||void 0!==e.red)this.setValues("rgb",e);else if(void 0!==e.l||void 0!==e.lightness)this.setValues("hsl",e);else if(void 0!==e.v||void 0!==e.value)this.setValues("hsv",e);else if(void 0!==e.w||void 0!==e.whiteness)this.setValues("hwb",e);else{if(void 0===e.c&&void 0===e.cyan)throw new Error("Unable to parse color from object "+JSON.stringify(t));this.setValues("cmyk",e)}}};s.prototype={rgb:function(){return this.setSpace("rgb",arguments)},hsl:function(){return this.setSpace("hsl",arguments)},hsv:function(){return this.setSpace("hsv",arguments)},hwb:function(){return this.setSpace("hwb",arguments)},cmyk:function(){return this.setSpace("cmyk",arguments)},rgbArray:function(){return this.values.rgb},hslArray:function(){return this.values.hsl},hsvArray:function(){return this.values.hsv},hwbArray:function(){return 1!==this.values.alpha?this.values.hwb.concat([this.values.alpha]):this.values.hwb},cmykArray:function(){return this.values.cmyk},rgbaArray:function(){var t=this.values.rgb;return t.concat([this.values.alpha])},hslaArray:function(){var t=this.values.hsl;return t.concat([this.values.alpha])},alpha:function(t){return void 0===t?this.values.alpha:(this.setValues("alpha",t),this)},red:function(t){return this.setChannel("rgb",0,t)},green:function(t){return this.setChannel("rgb",1,t)},blue:function(t){return this.setChannel("rgb",2,t)},hue:function(t){return this.setChannel("hsl",0,t)},saturation:function(t){return this.setChannel("hsl",1,t)},lightness:function(t){return this.setChannel("hsl",2,t)},saturationv:function(t){return this.setChannel("hsv",1,t)},whiteness:function(t){return this.setChannel("hwb",1,t)},blackness:function(t){return this.setChannel("hwb",2,t)},value:function(t){return this.setChannel("hsv",2,t)},cyan:function(t){return this.setChannel("cmyk",0,t)},magenta:function(t){return this.setChannel("cmyk",1,t)},yellow:function(t){return this.setChannel("cmyk",2,t)},black:function(t){return this.setChannel("cmyk",3,t)},hexString:function(){return a.hexString(this.values.rgb)},rgbString:function(){return a.rgbString(this.values.rgb,this.values.alpha)},rgbaString:function(){return a.rgbaString(this.values.rgb,this.values.alpha)},percentString:function(){return a.percentString(this.values.rgb,this.values.alpha)},hslString:function(){return a.hslString(this.values.hsl,this.values.alpha)},hslaString:function(){return a.hslaString(this.values.hsl,this.values.alpha)},hwbString:function(){return a.hwbString(this.values.hwb,this.values.alpha)},keyword:function(){return a.keyword(this.values.rgb,this.values.alpha)},rgbNumber:function(){return this.values.rgb[0]<<16|this.values.rgb[1]<<8|this.values.rgb[2]},luminosity:function(){for(var t=this.values.rgb,e=[],i=0;i<t.length;i++){var a=t[i]/255;e[i]=.03928>=a?a/12.92:Math.pow((a+.055)/1.055,2.4)}return.2126*e[0]+.7152*e[1]+.0722*e[2]},contrast:function(t){var e=this.luminosity(),i=t.luminosity();return e>i?(e+.05)/(i+.05):(i+.05)/(e+.05)},level:function(t){var e=this.contrast(t);return e>=7.1?"AAA":e>=4.5?"AA":""},dark:function(){var t=this.values.rgb,e=(299*t[0]+587*t[1]+114*t[2])/1e3;return 128>e},light:function(){return!this.dark()},negate:function(){for(var t=[],e=0;3>e;e++)t[e]=255-this.values.rgb[e];return this.setValues("rgb",t),this},lighten:function(t){return this.values.hsl[2]+=this.values.hsl[2]*t,this.setValues("hsl",this.values.hsl),this},darken:function(t){return this.values.hsl[2]-=this.values.hsl[2]*t,this.setValues("hsl",this.values.hsl),this},saturate:function(t){return this.values.hsl[1]+=this.values.hsl[1]*t,this.setValues("hsl",this.values.hsl),this},desaturate:function(t){return this.values.hsl[1]-=this.values.hsl[1]*t,this.setValues("hsl",this.values.hsl),this},whiten:function(t){return this.values.hwb[1]+=this.values.hwb[1]*t,this.setValues("hwb",this.values.hwb),this},blacken:function(t){return this.values.hwb[2]+=this.values.hwb[2]*t,this.setValues("hwb",this.values.hwb),this},greyscale:function(){var t=this.values.rgb,e=.3*t[0]+.59*t[1]+.11*t[2];return this.setValues("rgb",[e,e,e]),this},clearer:function(t){return this.setValues("alpha",this.values.alpha-this.values.alpha*t),this},opaquer:function(t){return this.setValues("alpha",this.values.alpha+this.values.alpha*t),this},rotate:function(t){var e=this.values.hsl[0];return e=(e+t)%360,e=0>e?360+e:e,this.values.hsl[0]=e,this.setValues("hsl",this.values.hsl),this},mix:function(t,e){e=1-(null==e?.5:e);for(var i=2*e-1,a=this.alpha()-t.alpha(),s=((i*a==-1?i:(i+a)/(1+i*a))+1)/2,o=1-s,n=this.rgbArray(),r=t.rgbArray(),h=0;h<n.length;h++)n[h]=n[h]*s+r[h]*o;this.setValues("rgb",n);var l=this.alpha()*e+t.alpha()*(1-e);return this.setValues("alpha",l),this},toJSON:function(){return this.rgb()},clone:function(){return new s(this.rgb())}},s.prototype.getValues=function(t){for(var e={},i=0;i<t.length;i++)e[t.charAt(i)]=this.values[t][i];return 1!=this.values.alpha&&(e.a=this.values.alpha),e},s.prototype.setValues=function(t,e){var a={rgb:["red","green","blue"],hsl:["hue","saturation","lightness"],hsv:["hue","saturation","value"],hwb:["hue","whiteness","blackness"],cmyk:["cyan","magenta","yellow","black"]},s={rgb:[255,255,255],hsl:[360,100,100],hsv:[360,100,100],hwb:[360,100,100],cmyk:[100,100,100,100]},o=1;if("alpha"==t)o=e;else if(e.length)this.values[t]=e.slice(0,t.length),o=e[t.length];else if(void 0!==e[t.charAt(0)]){for(var n=0;n<t.length;n++)this.values[t][n]=e[t.charAt(n)];o=e.a}else if(void 0!==e[a[t][0]]){for(var r=a[t],n=0;n<t.length;n++)this.values[t][n]=e[r[n]];o=e.alpha}if(this.values.alpha=Math.max(0,Math.min(1,void 0!==o?o:this.values.alpha)),"alpha"!=t){for(var n=0;n<t.length;n++){var h=Math.max(0,Math.min(s[t][n],this.values[t][n]));this.values[t][n]=Math.round(h)}for(var l in a){l!=t&&(this.values[l]=i[t][l](this.values[t]));for(var n=0;n<l.length;n++){var h=Math.max(0,Math.min(s[l][n],this.values[l][n]));this.values[l][n]=Math.round(h)}}return!0}},s.prototype.setSpace=function(t,e){var i=e[0];return void 0===i?this.getValues(t):("number"==typeof i&&(i=Array.prototype.slice.call(e)),this.setValues(t,i),this)},s.prototype.setChannel=function(t,e,i){return void 0===i?this.values[t][e]:(this.values[t][e]=i,this.setValues(t,this.values[t]),this)},window.Color=e.exports=s}()},{"color-convert":3,"color-string":4}],2:[function(t,e){function i(t){var e,i,a,s=t[0]/255,o=t[1]/255,n=t[2]/255,r=Math.min(s,o,n),h=Math.max(s,o,n),l=h-r;return h==r?e=0:s==h?e=(o-n)/l:o==h?e=2+(n-s)/l:n==h&&(e=4+(s-o)/l),e=Math.min(60*e,360),0>e&&(e+=360),a=(r+h)/2,i=h==r?0:.5>=a?l/(h+r):l/(2-h-r),[e,100*i,100*a]}function a(t){var e,i,a,s=t[0],o=t[1],n=t[2],r=Math.min(s,o,n),h=Math.max(s,o,n),l=h-r;return i=0==h?0:l/h*1e3/10,h==r?e=0:s==h?e=(o-n)/l:o==h?e=2+(n-s)/l:n==h&&(e=4+(s-o)/l),e=Math.min(60*e,360),0>e&&(e+=360),a=h/255*1e3/10,[e,i,a]}function s(t){var e=t[0],a=t[1],s=t[2],o=i(t)[0],n=1/255*Math.min(e,Math.min(a,s)),s=1-1/255*Math.max(e,Math.max(a,s));return[o,100*n,100*s]}function o(t){var e,i,a,s,o=t[0]/255,n=t[1]/255,r=t[2]/255;return s=Math.min(1-o,1-n,1-r),e=(1-o-s)/(1-s)||0,i=(1-n-s)/(1-s)||0,a=(1-r-s)/(1-s)||0,[100*e,100*i,100*a,100*s]}function n(t){return Q[JSON.stringify(t)]}function h(t){var e=t[0]/255,i=t[1]/255,a=t[2]/255;e=e>.04045?Math.pow((e+.055)/1.055,2.4):e/12.92,i=i>.04045?Math.pow((i+.055)/1.055,2.4):i/12.92,a=a>.04045?Math.pow((a+.055)/1.055,2.4):a/12.92;var s=.4124*e+.3576*i+.1805*a,o=.2126*e+.7152*i+.0722*a,n=.0193*e+.1192*i+.9505*a;return[100*s,100*o,100*n]}function l(t){var e,i,a,s=h(t),o=s[0],n=s[1],r=s[2];return o/=95.047,n/=100,r/=108.883,o=o>.008856?Math.pow(o,1/3):7.787*o+16/116,n=n>.008856?Math.pow(n,1/3):7.787*n+16/116,r=r>.008856?Math.pow(r,1/3):7.787*r+16/116,e=116*n-16,i=500*(o-n),a=200*(n-r),[e,i,a]}function c(t){return z(l(t))}function d(t){var e,i,a,s,o,n=t[0]/360,r=t[1]/100,h=t[2]/100;if(0==r)return o=255*h,[o,o,o];i=.5>h?h*(1+r):h+r-h*r,e=2*h-i,s=[0,0,0];for(var l=0;3>l;l++)a=n+1/3*-(l-1),0>a&&a++,a>1&&a--,o=1>6*a?e+6*(i-e)*a:1>2*a?i:2>3*a?e+(i-e)*(2/3-a)*6:e,s[l]=255*o;return s}function u(t){var e,i,a=t[0],s=t[1]/100,o=t[2]/100;return o*=2,s*=1>=o?o:2-o,i=(o+s)/2,e=2*s/(o+s),[a,100*e,100*i]}function m(t){return s(d(t))}function p(t){return o(d(t))}function f(t){return n(d(t))}function v(t){var e=t[0]/60,i=t[1]/100,a=t[2]/100,s=Math.floor(e)%6,o=e-Math.floor(e),n=255*a*(1-i),r=255*a*(1-i*o),h=255*a*(1-i*(1-o)),a=255*a;switch(s){case 0:return[a,h,n];case 1:return[r,a,n];case 2:return[n,a,h];case 3:return[n,r,a];case 4:return[h,n,a];case 5:return[a,n,r]}}function x(t){var e,i,a=t[0],s=t[1]/100,o=t[2]/100;return i=(2-s)*o,e=s*o,e/=1>=i?i:2-i,e=e||0,i/=2,[a,100*e,100*i]}function y(t){return s(v(t))}function k(t){return o(v(t))}function D(t){return n(v(t))}function w(t){var e,i,a,s,o=t[0]/360,n=t[1]/100,h=t[2]/100,l=n+h;switch(l>1&&(n/=l,h/=l),e=Math.floor(6*o),i=1-h,a=6*o-e,0!=(1&e)&&(a=1-a),s=n+a*(i-n),e){default:case 6:case 0:r=i,g=s,b=n;break;case 1:r=s,g=i,b=n;break;case 2:r=n,g=i,b=s;break;case 3:r=n,g=s,b=i;break;case 4:r=s,g=n,b=i;break;case 5:r=i,g=n,b=s}return[255*r,255*g,255*b]}function C(t){return i(w(t))}function S(t){return a(w(t))}function _(t){return o(w(t))}function A(t){return n(w(t))}function I(t){var e,i,a,s=t[0]/100,o=t[1]/100,n=t[2]/100,r=t[3]/100;return e=1-Math.min(1,s*(1-r)+r),i=1-Math.min(1,o*(1-r)+r),a=1-Math.min(1,n*(1-r)+r),[255*e,255*i,255*a]}function M(t){return i(I(t))}function P(t){return a(I(t))}function F(t){return s(I(t))}function R(t){return n(I(t))}function V(t){var e,i,a,s=t[0]/100,o=t[1]/100,n=t[2]/100;return e=3.2406*s+-1.5372*o+n*-.4986,i=s*-.9689+1.8758*o+.0415*n,a=.0557*s+o*-.204+1.057*n,e=e>.0031308?1.055*Math.pow(e,1/2.4)-.055:e=12.92*e,i=i>.0031308?1.055*Math.pow(i,1/2.4)-.055:i=12.92*i,a=a>.0031308?1.055*Math.pow(a,1/2.4)-.055:a=12.92*a,e=Math.min(Math.max(0,e),1),i=Math.min(Math.max(0,i),1),a=Math.min(Math.max(0,a),1),[255*e,255*i,255*a]}function T(t){var e,i,a,s=t[0],o=t[1],n=t[2];return s/=95.047,o/=100,n/=108.883,s=s>.008856?Math.pow(s,1/3):7.787*s+16/116,o=o>.008856?Math.pow(o,1/3):7.787*o+16/116,n=n>.008856?Math.pow(n,1/3):7.787*n+16/116,e=116*o-16,i=500*(s-o),a=200*(o-n),[e,i,a]}function L(t){return z(T(t))}function W(t){var e,i,a,s,o=t[0],n=t[1],r=t[2];return 8>=o?(i=100*o/903.3,s=7.787*(i/100)+16/116):(i=100*Math.pow((o+16)/116,3),s=Math.pow(i/100,1/3)),e=.008856>=e/95.047?e=95.047*(n/500+s-16/116)/7.787:95.047*Math.pow(n/500+s,3),a=.008859>=a/108.883?a=108.883*(s-r/200-16/116)/7.787:108.883*Math.pow(s-r/200,3),[e,i,a]}function z(t){var e,i,a,s=t[0],o=t[1],n=t[2];return e=Math.atan2(n,o),i=360*e/2/Math.PI,0>i&&(i+=360),a=Math.sqrt(o*o+n*n),[s,a,i]}function B(t){return V(W(t))}function O(t){var e,i,a,s=t[0],o=t[1],n=t[2];return a=n/360*2*Math.PI,e=o*Math.cos(a),i=o*Math.sin(a),[s,e,i]}function E(t){return W(O(t))}function N(t){return B(O(t))}function H(t){return Z[t]}function q(t){return i(H(t))}function j(t){return a(H(t))}function Y(t){return s(H(t))}function U(t){return o(H(t))}function X(t){return l(H(t))}function J(t){return h(H(t))}e.exports={rgb2hsl:i,rgb2hsv:a,rgb2hwb:s,rgb2cmyk:o,rgb2keyword:n,rgb2xyz:h,rgb2lab:l,rgb2lch:c,hsl2rgb:d,hsl2hsv:u,hsl2hwb:m,hsl2cmyk:p,hsl2keyword:f,hsv2rgb:v,hsv2hsl:x,hsv2hwb:y,hsv2cmyk:k,hsv2keyword:D,hwb2rgb:w,hwb2hsl:C,hwb2hsv:S,hwb2cmyk:_,hwb2keyword:A,cmyk2rgb:I,cmyk2hsl:M,cmyk2hsv:P,cmyk2hwb:F,cmyk2keyword:R,keyword2rgb:H,keyword2hsl:q,keyword2hsv:j,keyword2hwb:Y,keyword2cmyk:U,keyword2lab:X,keyword2xyz:J,xyz2rgb:V,xyz2lab:T,xyz2lch:L,lab2xyz:W,lab2rgb:B,lab2lch:z,lch2lab:O,lch2xyz:E,lch2rgb:N};var Z={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]},Q={};for(var G in Z)Q[JSON.stringify(Z[G])]=G},{}],3:[function(t,e){var i=t("./conversions"),a=function(){return new h};for(var s in i){a[s+"Raw"]=function(t){return function(e){return"number"==typeof e&&(e=Array.prototype.slice.call(arguments)),i[t](e)}}(s);var o=/(\w+)2(\w+)/.exec(s),n=o[1],r=o[2];a[n]=a[n]||{},a[n][r]=a[s]=function(t){return function(e){"number"==typeof e&&(e=Array.prototype.slice.call(arguments));var a=i[t](e);if("string"==typeof a||void 0===a)return a;for(var s=0;s<a.length;s++)a[s]=Math.round(a[s]);return a}}(s)}var h=function(){this.convs={}};h.prototype.routeSpace=function(t,e){var i=e[0];return void 0===i?this.getValues(t):("number"==typeof i&&(i=Array.prototype.slice.call(e)),this.setValues(t,i))},h.prototype.setValues=function(t,e){return this.space=t,this.convs={},this.convs[t]=e,this},h.prototype.getValues=function(t){var e=this.convs[t];if(!e){var i=this.space,s=this.convs[i];e=a[i][t](s),this.convs[t]=e}return e},["rgb","hsl","hsv","cmyk","keyword"].forEach(function(t){h.prototype[t]=function(){return this.routeSpace(t,arguments)}}),e.exports=a},{"./conversions":2}],4:[function(t,e){function i(t){if(t){var e=/^#([a-fA-F0-9]{3})$/,i=/^#([a-fA-F0-9]{6})$/,a=/^rgba?\(\s*([+-]?\d+)\s*,\s*([+-]?\d+)\s*,\s*([+-]?\d+)\s*(?:,\s*([+-]?[\d\.]+)\s*)?\)$/,s=/^rgba?\(\s*([+-]?[\d\.]+)\%\s*,\s*([+-]?[\d\.]+)\%\s*,\s*([+-]?[\d\.]+)\%\s*(?:,\s*([+-]?[\d\.]+)\s*)?\)$/,o=/(\w+)/,n=[0,0,0],r=1,h=t.match(e);if(h){h=h[1];for(var l=0;l<n.length;l++)n[l]=parseInt(h[l]+h[l],16)}else if(h=t.match(i)){h=h[1];for(var l=0;l<n.length;l++)n[l]=parseInt(h.slice(2*l,2*l+2),16)}else if(h=t.match(a)){for(var l=0;l<n.length;l++)n[l]=parseInt(h[l+1]);r=parseFloat(h[4])}else if(h=t.match(s)){for(var l=0;l<n.length;l++)n[l]=Math.round(2.55*parseFloat(h[l+1]));r=parseFloat(h[4])}else if(h=t.match(o)){if("transparent"==h[1])return[0,0,0,0];if(n=x[h[1]],!n)return}for(var l=0;l<n.length;l++)n[l]=b(n[l],0,255);return r=r||0==r?b(r,0,1):1,n[3]=r,n}}function a(t){if(t){var e=/^hsla?\(\s*([+-]?\d+)(?:deg)?\s*,\s*([+-]?[\d\.]+)%\s*,\s*([+-]?[\d\.]+)%\s*(?:,\s*([+-]?[\d\.]+)\s*)?\)/,i=t.match(e);if(i){var a=parseFloat(i[4]),s=b(parseInt(i[1]),0,360),o=b(parseFloat(i[2]),0,100),n=b(parseFloat(i[3]),0,100),r=b(isNaN(a)?1:a,0,1);return[s,o,n,r]}}}function s(t){if(t){var e=/^hwb\(\s*([+-]?\d+)(?:deg)?\s*,\s*([+-]?[\d\.]+)%\s*,\s*([+-]?[\d\.]+)%\s*(?:,\s*([+-]?[\d\.]+)\s*)?\)/,i=t.match(e);if(i){var a=parseFloat(i[4]),s=b(parseInt(i[1]),0,360),o=b(parseFloat(i[2]),0,100),n=b(parseFloat(i[3]),0,100),r=b(isNaN(a)?1:a,0,1);return[s,o,n,r]}}}function o(t){var e=i(t);return e&&e.slice(0,3)}function n(t){var e=a(t);return e&&e.slice(0,3)}function r(t){var e=i(t);return e?e[3]:(e=a(t))?e[3]:(e=s(t))?e[3]:void 0}function h(t){return"#"+v(t[0])+v(t[1])+v(t[2])}function l(t,e){return 1>e||t[3]&&t[3]<1?c(t,e):"rgb("+t[0]+", "+t[1]+", "+t[2]+")"}function c(t,e){return void 0===e&&(e=void 0!==t[3]?t[3]:1),"rgba("+t[0]+", "+t[1]+", "+t[2]+", "+e+")"}function d(t,e){if(1>e||t[3]&&t[3]<1)return u(t,e);var i=Math.round(t[0]/255*100),a=Math.round(t[1]/255*100),s=Math.round(t[2]/255*100);return"rgb("+i+"%, "+a+"%, "+s+"%)"}function u(t,e){var i=Math.round(t[0]/255*100),a=Math.round(t[1]/255*100),s=Math.round(t[2]/255*100);return"rgba("+i+"%, "+a+"%, "+s+"%, "+(e||t[3]||1)+")"}function g(t,e){return 1>e||t[3]&&t[3]<1?m(t,e):"hsl("+t[0]+", "+t[1]+"%, "+t[2]+"%)"}function m(t,e){return void 0===e&&(e=void 0!==t[3]?t[3]:1),"hsla("+t[0]+", "+t[1]+"%, "+t[2]+"%, "+e+")"}function p(t,e){return void 0===e&&(e=void 0!==t[3]?t[3]:1),"hwb("+t[0]+", "+t[1]+"%, "+t[2]+"%"+(void 0!==e&&1!==e?", "+e:"")+")"}function f(t){return y[t.slice(0,3)]}function b(t,e,i){return Math.min(Math.max(e,t),i)}function v(t){var e=t.toString(16).toUpperCase();return e.length<2?"0"+e:e}var x=t("color-name");e.exports={getRgba:i,getHsla:a,getRgb:o,getHsl:n,getHwb:s,getAlpha:r,hexString:h,rgbString:l,rgbaString:c,percentString:d,percentaString:u,hslString:g,hslaString:m,hwbString:p,keyword:f};var y={};for(var k in x)y[x[k]]=k},{"color-name":5}],5:[function(t,e){e.exports={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]}},{}]},{},[1]),function(){"use strict";var t=this,e=t.Chart,i=function(t,e){this.config=e,t.length&&t[0].getContext&&(t=t[0]),t.getContext&&(t=t.getContext("2d")),this.ctx=t,this.canvas=t.canvas,this.width=t.canvas.width||parseInt(i.helpers.getStyle(t.canvas,"width"))||i.helpers.getMaximumWidth(t.canvas),this.height=t.canvas.height||parseInt(i.helpers.getStyle(t.canvas,"height"))||i.helpers.getMaximumHeight(t.canvas),this.aspectRatio=this.width/this.height,(isNaN(this.aspectRatio)||isFinite(this.aspectRatio)===!1)&&(this.aspectRatio=void 0!==e.aspectRatio?e.aspectRatio:2),this.originalCanvasStyleWidth=t.canvas.style.width,this.originalCanvasStyleHeight=t.canvas.style.height,i.helpers.retinaScale(this),e&&(this.controller=new i.Controller(this));var a=this;return i.helpers.addResizeListener(t.canvas.parentNode,function(){a.controller&&a.controller.config.options.responsive&&a.controller.resize()}),this.controller?this.controller:this};i.defaults={global:{responsive:!0,responsiveAnimationDuration:0,maintainAspectRatio:!0,events:["mousemove","mouseout","click","touchstart","touchmove","touchend"],hover:{onHover:null,mode:"single",animationDuration:400},onClick:null,defaultColor:"rgba(0,0,0,0.1)",elements:{},legendCallback:function(t){var e=[];e.push('<ul class="'+t.id+'-legend">');for(var i=0;i<t.data.datasets.length;i++)e.push('<li><span style="background-color:'+t.data.datasets[i].backgroundColor+'">'),t.data.datasets[i].label&&e.push(t.data.datasets[i].label),e.push("</span></li>");return e.push("</ul>"),e.join("")}}},"object"==typeof module&&module.exports&&(module.exports=i),t.Chart=i,i.noConflict=function(){return t.Chart=e,i}}.call(this),function(){"use strict";{var t=this,e=t.Chart,i=e.helpers={},a=i.each=function(t,e,i,a){var s=Array.prototype.slice.call(arguments,3);if(t)if(t.length===+t.length){var o;if(a)for(o=t.length-1;o>=0;o--)e.apply(i,[t[o],o].concat(s));else for(o=0;o<t.length;o++)e.apply(i,[t[o],o].concat(s))}else for(var n in t)e.apply(i,[t[n],n].concat(s))},s=i.clone=function(t){var e={};return a(t,function(a,o){t.hasOwnProperty(o)&&(e[o]=i.isArray(a)?a.slice(0):"object"==typeof a&&null!==a?s(a):a)}),e},o=i.extend=function(t){return a(Array.prototype.slice.call(arguments,1),function(e){a(e,function(i,a){e.hasOwnProperty(a)&&(t[a]=i)})}),t},n=(i.configMerge=function(t){var a=s(t);return i.each(Array.prototype.slice.call(arguments,1),function(t){i.each(t,function(s,o){if(t.hasOwnProperty(o))if("scales"===o)a[o]=i.scaleMerge(a.hasOwnProperty(o)?a[o]:{},s);else if("scale"===o)a[o]=i.configMerge(a.hasOwnProperty(o)?a[o]:{},e.scaleService.getScaleDefaults(s.type),s);else if(a.hasOwnProperty(o)&&i.isArray(a[o])&&i.isArray(s)){var n=a[o];i.each(s,function(t,e){e<n.length?n[e]="object"==typeof n[e]&&null!==n[e]&&"object"==typeof t&&null!==t?i.configMerge(n[e],t):t:n.push(t)})}else a[o]=a.hasOwnProperty(o)&&"object"==typeof a[o]&&null!==a[o]&&"object"==typeof s?i.configMerge(a[o],s):s})}),a},i.extendDeep=function(){function t(e){return i.each(arguments,function(a){a!==e&&i.each(a,function(i,a){e[a]&&e[a].constructor&&e[a].constructor===Object?t(e[a],i):e[a]=i})}),e}return t.apply(this,arguments)},i.scaleMerge=function(t,a){var o=s(t);return i.each(a,function(t,s){a.hasOwnProperty(s)&&("xAxes"===s||"yAxes"===s?o.hasOwnProperty(s)?i.each(t,function(t,a){a>=o[s].length||!o[s][a].type?o[s].push(i.configMerge(t.type?e.scaleService.getScaleDefaults(t.type):{},t)):o[s][a]=t.type!==o[s][a].type?i.configMerge(o[s][a],t.type?e.scaleService.getScaleDefaults(t.type):{},t):i.configMerge(o[s][a],t)}):(o[s]=[],i.each(t,function(t){o[s].push(i.configMerge(t.type?e.scaleService.getScaleDefaults(t.type):{},t))})):o[s]=o.hasOwnProperty(s)&&"object"==typeof o[s]&&null!==o[s]&&"object"==typeof t?i.configMerge(o[s],t):t)}),o},i.getValueAtIndexOrDefault=function(t,e,a){return void 0===t||null===t?a:i.isArray(t)?e<t.length?t[e]:a:t},i.indexOf=function(t,e){if(Array.prototype.indexOf)return t.indexOf(e);for(var i=0;i<t.length;i++)if(t[i]===e)return i;return-1},i.where=function(t,e){var a=[];return i.each(t,function(t){e(t)&&a.push(t)}),a},i.findNextWhere=function(t,e,i){(void 0===i||null===i)&&(i=-1);for(var a=i+1;a<t.length;a++){var s=t[a];if(e(s))return s}},i.findPreviousWhere=function(t,e,i){(void 0===i||null===i)&&(i=t.length);for(var a=i-1;a>=0;a--){var s=t[a];if(e(s))return s}},i.inherits=function(t){var e=this,i=t&&t.hasOwnProperty("constructor")?t.constructor:function(){return e.apply(this,arguments)},a=function(){this.constructor=i};return a.prototype=e.prototype,i.prototype=new a,i.extend=n,t&&o(i.prototype,t),i.__super__=e.prototype,i}),r=i.noop=function(){},h=(i.uid=function(){var t=0;return function(){return"chart-"+t++}}(),i.warn=function(t){window.console&&"function"==typeof window.console.warn&&console.warn(t)},i.amd="function"==typeof define&&define.amd,i.isNumber=function(t){return!isNaN(parseFloat(t))&&isFinite(t)}),l=(i.max=function(t){return Math.max.apply(Math,t)},i.min=function(t){return Math.min.apply(Math,t)},i.sign=function(t){return Math.sign?Math.sign(t):(t=+t,0===t||isNaN(t)?t:t>0?1:-1)},i.log10=function(t){return Math.log10?Math.log10(t):Math.log(t)/Math.LN10},i.getDecimalPlaces=function(t){if(t%1!==0&&h(t)){var e=t.toString();if(e.indexOf("e-")<0)return e.split(".")[1].length;if(e.indexOf(".")<0)return parseInt(e.split("e-")[1]);var i=e.split(".")[1].split("e-");return i[0].length+parseInt(i[1])}return 0},i.toRadians=function(t){return t*(Math.PI/180)},i.toDegrees=function(t){return t*(180/Math.PI)},i.getAngleFromPoint=function(t,e){var i=e.x-t.x,a=e.y-t.y,s=Math.sqrt(i*i+a*a),o=Math.atan2(a,i);return o<-.5*Math.PI&&(o+=2*Math.PI),{angle:o,distance:s}},i.aliasPixel=function(t){return t%2===0?0:.5},i.splineCurve=function(t,e,i,a){var s=t,o=e,n=i;s.skip&&(s=o),n.skip&&(n=o);var r=Math.sqrt(Math.pow(o.x-s.x,2)+Math.pow(o.y-s.y,2)),h=Math.sqrt(Math.pow(n.x-o.x,2)+Math.pow(n.y-o.y,2)),l=a*r/(r+h),c=a*h/(r+h);return{previous:{x:o.x-l*(n.x-s.x),y:o.y-l*(n.y-s.y)},next:{x:o.x+c*(n.x-s.x),y:o.y+c*(n.y-s.y)}}},i.nextItem=function(t,e,i){return i?e>=t.length-1?t[0]:t[e+1]:e>=t.length-1?t[t.length-1]:t[e+1]},i.previousItem=function(t,e,i){return i?0>=e?t[t.length-1]:t[e-1]:0>=e?t[0]:t[e-1]},i.niceNum=function(t,e){var a,s=Math.floor(i.log10(t)),o=t/Math.pow(10,s);return a=e?1.5>o?1:3>o?2:7>o?5:10:1>=o?1:2>=o?2:5>=o?5:10,a*Math.pow(10,s)},i.easingEffects={linear:function(t){return t},easeInQuad:function(t){return t*t},easeOutQuad:function(t){return-1*t*(t-2)},easeInOutQuad:function(t){return(t/=.5)<1?.5*t*t:-0.5*(--t*(t-2)-1)},easeInCubic:function(t){return t*t*t},easeOutCubic:function(t){return 1*((t=t/1-1)*t*t+1)},easeInOutCubic:function(t){return(t/=.5)<1?.5*t*t*t:.5*((t-=2)*t*t+2)},easeInQuart:function(t){return t*t*t*t},easeOutQuart:function(t){return-1*((t=t/1-1)*t*t*t-1)},easeInOutQuart:function(t){return(t/=.5)<1?.5*t*t*t*t:-0.5*((t-=2)*t*t*t-2)},easeInQuint:function(t){return 1*(t/=1)*t*t*t*t},easeOutQuint:function(t){return 1*((t=t/1-1)*t*t*t*t+1)},easeInOutQuint:function(t){return(t/=.5)<1?.5*t*t*t*t*t:.5*((t-=2)*t*t*t*t+2)},easeInSine:function(t){return-1*Math.cos(t/1*(Math.PI/2))+1},easeOutSine:function(t){return 1*Math.sin(t/1*(Math.PI/2))},easeInOutSine:function(t){return-0.5*(Math.cos(Math.PI*t/1)-1)},easeInExpo:function(t){return 0===t?1:1*Math.pow(2,10*(t/1-1))},easeOutExpo:function(t){return 1===t?1:1*(-Math.pow(2,-10*t/1)+1)},easeInOutExpo:function(t){return 0===t?0:1===t?1:(t/=.5)<1?.5*Math.pow(2,10*(t-1)):.5*(-Math.pow(2,-10*--t)+2)},easeInCirc:function(t){return t>=1?t:-1*(Math.sqrt(1-(t/=1)*t)-1)},easeOutCirc:function(t){return 1*Math.sqrt(1-(t=t/1-1)*t)},easeInOutCirc:function(t){return(t/=.5)<1?-0.5*(Math.sqrt(1-t*t)-1):.5*(Math.sqrt(1-(t-=2)*t)+1)},easeInElastic:function(t){var e=1.70158,i=0,a=1;return 0===t?0:1==(t/=1)?1:(i||(i=.3),a<Math.abs(1)?(a=1,e=i/4):e=i/(2*Math.PI)*Math.asin(1/a),-(a*Math.pow(2,10*(t-=1))*Math.sin(2*(1*t-e)*Math.PI/i)))},easeOutElastic:function(t){var e=1.70158,i=0,a=1;return 0===t?0:1==(t/=1)?1:(i||(i=.3),a<Math.abs(1)?(a=1,e=i/4):e=i/(2*Math.PI)*Math.asin(1/a),a*Math.pow(2,-10*t)*Math.sin(2*(1*t-e)*Math.PI/i)+1)},easeInOutElastic:function(t){var e=1.70158,i=0,a=1;return 0===t?0:2==(t/=.5)?1:(i||(i=.3*1.5),a<Math.abs(1)?(a=1,e=i/4):e=i/(2*Math.PI)*Math.asin(1/a),1>t?-.5*a*Math.pow(2,10*(t-=1))*Math.sin(2*(1*t-e)*Math.PI/i):a*Math.pow(2,-10*(t-=1))*Math.sin(2*(1*t-e)*Math.PI/i)*.5+1)},easeInBack:function(t){var e=1.70158;return 1*(t/=1)*t*((e+1)*t-e)},easeOutBack:function(t){var e=1.70158;return 1*((t=t/1-1)*t*((e+1)*t+e)+1)},easeInOutBack:function(t){var e=1.70158;return(t/=.5)<1?.5*t*t*(((e*=1.525)+1)*t-e):.5*((t-=2)*t*(((e*=1.525)+1)*t+e)+2)},easeInBounce:function(t){return 1-l.easeOutBounce(1-t)},easeOutBounce:function(t){return(t/=1)<1/2.75?7.5625*t*t:2/2.75>t?1*(7.5625*(t-=1.5/2.75)*t+.75):2.5/2.75>t?1*(7.5625*(t-=2.25/2.75)*t+.9375):1*(7.5625*(t-=2.625/2.75)*t+.984375)},easeInOutBounce:function(t){return.5>t?.5*l.easeInBounce(2*t):.5*l.easeOutBounce(2*t-1)+.5}}),c=(i.requestAnimFrame=function(){return window.requestAnimationFrame||window.webkitRequestAnimationFrame||window.mozRequestAnimationFrame||window.oRequestAnimationFrame||window.msRequestAnimationFrame||function(t){return window.setTimeout(t,1e3/60)}}(),i.cancelAnimFrame=function(){return window.cancelAnimationFrame||window.webkitCancelAnimationFrame||window.mozCancelAnimationFrame||window.oCancelAnimationFrame||window.msCancelAnimationFrame||function(t){return window.clearTimeout(t,1e3/60)}}(),i.getRelativePosition=function(t,e){var i,a,s=t.originalEvent||t,o=t.currentTarget||t.srcElement,n=o.getBoundingClientRect();return s.touches?(i=s.touches[0].clientX,a=s.touches[0].clientY):(i=s.clientX,a=s.clientY),i=Math.round((i-n.left)/(n.right-n.left)*o.width/e.currentDevicePixelRatio),a=Math.round((a-n.top)/(n.bottom-n.top)*o.height/e.currentDevicePixelRatio),{x:i,y:a}},i.addEvent=function(t,e,i){t.addEventListener?t.addEventListener(e,i):t.attachEvent?t.attachEvent("on"+e,i):t["on"+e]=i}),d=i.removeEvent=function(t,e,i){t.removeEventListener?t.removeEventListener(e,i,!1):t.detachEvent?t.detachEvent("on"+e,i):t["on"+e]=r},u=(i.bindEvents=function(t,e,i){t.events||(t.events={}),a(e,function(e){t.events[e]=function(){i.apply(t,arguments)},c(t.chart.canvas,e,t.events[e])})},i.unbindEvents=function(t,e){a(e,function(e,i){d(t.chart.canvas,i,e)})},i.getConstraintWidth=function(t){var e,i=document.defaultView.getComputedStyle(t)["max-width"],a=document.defaultView.getComputedStyle(t.parentNode)["max-width"],s=null!==i&&"none"!==i,o=null!==a&&"none"!==a;return(s||o)&&(e=Math.min(s?parseInt(i,10):Number.POSITIVE_INFINITY,o?parseInt(a,10):Number.POSITIVE_INFINITY)),e}),g=i.getConstraintHeight=function(t){var e,i=document.defaultView.getComputedStyle(t)["max-height"],a=document.defaultView.getComputedStyle(t.parentNode)["max-height"],s=null!==i&&"none"!==i,o=null!==a&&"none"!==a;return(i||a)&&(e=Math.min(s?parseInt(i,10):Number.POSITIVE_INFINITY,o?parseInt(a,10):Number.POSITIVE_INFINITY)),e},m=(i.getMaximumWidth=function(t){var e=t.parentNode,i=parseInt(m(e,"padding-left"))+parseInt(m(e,"padding-right")),a=e.clientWidth-i,s=u(t);return void 0!==s&&(a=Math.min(a,s)),a},i.getMaximumHeight=function(t){var e=t.parentNode,i=parseInt(m(e,"padding-top"))+parseInt(m(e,"padding-bottom")),a=e.clientHeight-i,s=g(t);return void 0!==s&&(a=Math.min(a,s)),a},i.getStyle=function(t,e){return t.currentStyle?t.currentStyle[e]:document.defaultView.getComputedStyle(t,null).getPropertyValue(e)});i.getMaximumSize=i.getMaximumWidth,i.retinaScale=function(t){var e=t.ctx,i=t.canvas.width,a=t.canvas.height;t.currentDevicePixelRatio=window.devicePixelRatio||1,1!==window.devicePixelRatio&&(e.canvas.height=a*window.devicePixelRatio,e.canvas.width=i*window.devicePixelRatio,e.scale(window.devicePixelRatio,window.devicePixelRatio),e.canvas.style.width=i+"px",e.canvas.style.height=a+"px",t.originalDevicePixelRatio=t.originalDevicePixelRatio||window.devicePixelRatio)},i.clear=function(t){t.ctx.clearRect(0,0,t.width,t.height)},i.fontString=function(t,e,i){return e+" "+t+"px "+i},i.longestText=function(t,e,i){t.font=e;var s=0;return a(i,function(e){var i=t.measureText(e).width;s=i>s?i:s}),s},i.drawRoundedRectangle=function(t,e,i,a,s,o){t.beginPath(),t.moveTo(e+o,i),t.lineTo(e+a-o,i),t.quadraticCurveTo(e+a,i,e+a,i+o),t.lineTo(e+a,i+s-o),t.quadraticCurveTo(e+a,i+s,e+a-o,i+s),t.lineTo(e+o,i+s),t.quadraticCurveTo(e,i+s,e,i+s-o),t.lineTo(e,i+o),t.quadraticCurveTo(e,i,e+o,i),t.closePath()},i.color=function(t){return window.Color?window.Color(t):(console.log("Color.js not found!"),t)},i.addResizeListener=function(t,e){var i=document.createElement("iframe"),a="chartjs-hidden-iframe";i.classlist?i.classlist.add(a):i.setAttribute("class",a),i.style.width="100%",i.style.display="block",i.style.border=0,i.style.height=0,i.style.margin=0,i.style.position="absolute",i.style.left=0,i.style.right=0,i.style.top=0,i.style.bottom=0,t.insertBefore(i,t.firstChild);(i.contentWindow||i).onresize=function(){e&&e()}},i.removeResizeListener=function(t){var e=t.querySelector(".chartjs-hidden-iframe");e&&e.parentNode.removeChild(e)},i.isArray=function(t){return Array.isArray?Array.isArray(t):"[object Array]"===Object.prototype.toString.call(arg)},i.isDatasetVisible=function(t){return!t.hidden}}}.call(this),function(){"use strict";var t=this,e=t.Chart,i=e.helpers;e.elements={},e.Element=function(t){i.extend(this,t),this.initialize.apply(this,arguments)},i.extend(e.Element.prototype,{initialize:function(){},pivot:function(){return this._view||(this._view=i.clone(this._model)),this._start=i.clone(this._view),this},transition:function(t){return this._view||(this._view=i.clone(this._model)),this._start||this.pivot(),i.each(this._model,function(e,a){if("_"!==a[0]&&this._model.hasOwnProperty(a))if(this._view[a])if(this._model[a]===this._view[a]);else if("string"==typeof e)try{var s=i.color(this._start[a]).mix(i.color(this._model[a]),t);this._view[a]=s.rgbString()}catch(o){this._view[a]=e}else if("number"==typeof e){var n=void 0!==this._start[a]?this._start[a]:0;this._view[a]=(this._model[a]-n)*t+n}else this._view[a]=e;else this._view[a]="number"==typeof e?e*t:e||null;else;},this),1===t&&delete this._start,this},tooltipPosition:function(){return{x:this._model.x,y:this._model.y}},hasValue:function(){return i.isNumber(this._model.x)&&i.isNumber(this._model.y)}}),e.Element.extend=i.inherits}.call(this),function(){"use strict";var t=this,e=t.Chart,i=e.helpers;e.defaults.global.animation={duration:1e3,easing:"easeOutQuart",onProgress:function(){},onComplete:function(){}},e.Animation=e.Element.extend({currentStep:null,numSteps:60,easing:"",render:null,onAnimationProgress:null,onAnimationComplete:null}),e.animationService={frameDuration:17,animations:[],dropFrames:0,addAnimation:function(t,e,a,s){s||(t.animating=!0);for(var o=0;o<this.animations.length;++o)if(this.animations[o].chartInstance===t)return void(this.animations[o].animationObject=e);this.animations.push({chartInstance:t,animationObject:e}),1==this.animations.length&&i.requestAnimFrame.call(window,this.digestWrapper)},cancelAnimation:function(t){var e=i.findNextWhere(this.animations,function(e){return e.chartInstance===t});e&&(this.animations.splice(e,1),t.animating=!1)},digestWrapper:function(){e.animationService.startDigest.call(e.animationService)},startDigest:function(){var t=Date.now(),e=0;this.dropFrames>1&&(e=Math.floor(this.dropFrames),this.dropFrames=this.dropFrames%1);for(var a=0;a<this.animations.length;a++)null===this.animations[a].animationObject.currentStep&&(this.animations[a].animationObject.currentStep=0),this.animations[a].animationObject.currentStep+=1+e,this.animations[a].animationObject.currentStep>this.animations[a].animationObject.numSteps&&(this.animations[a].animationObject.currentStep=this.animations[a].animationObject.numSteps),this.animations[a].animationObject.render(this.animations[a].chartInstance,this.animations[a].animationObject),this.animations[a].animationObject.currentStep==this.animations[a].animationObject.numSteps&&(this.animations[a].chartInstance.animating=!1,this.animations.splice(a,1),a--);var s=Date.now(),o=(s-t)/this.frameDuration;this.dropFrames+=o,this.animations.length>0&&i.requestAnimFrame.call(window,this.digestWrapper)}}}.call(this),function(){"use strict";var t=this,e=t.Chart,i=e.helpers;e.types={},e.instances={},e.controllers={},e.Controller=function(t){return this.chart=t,this.config=t.config,this.data=this.config.data,this.options=this.config.options=i.configMerge(e.defaults.global,e.defaults[this.config.type],this.config.options||{}),this.id=i.uid(),e.instances[this.id]=this,this.options.responsive&&this.resize(!0),this.initialize.call(this),this},i.extend(e.Controller.prototype,{initialize:function(){return this.bindEvents(),this.ensureScalesHaveIDs(),this.buildOrUpdateControllers(),this.buildScales(),this.resetElements(),this.initToolTip(),this.update(),this},clear:function(){return i.clear(this.chart),this},stop:function(){return e.animationService.cancelAnimation(this),this},resize:function(t){this.stop();var e=this.chart.canvas,a=i.getMaximumWidth(this.chart.canvas),s=this.options.maintainAspectRatio&&isNaN(this.chart.aspectRatio)===!1&&isFinite(this.chart.aspectRatio)&&0!==this.chart.aspectRatio?a/this.chart.aspectRatio:i.getMaximumHeight(this.chart.canvas);return e.width=this.chart.width=a,e.height=this.chart.height=s,i.retinaScale(this.chart),t||this.update(this.options.responsiveAnimationDuration),this},ensureScalesHaveIDs:function(){var t="x-axis-",e="y-axis-";this.options.scales&&(this.options.scales.xAxes&&this.options.scales.xAxes.length&&i.each(this.options.scales.xAxes,function(e,i){e.id=e.id||t+i},this),this.options.scales.yAxes&&this.options.scales.yAxes.length&&i.each(this.options.scales.yAxes,function(t,i){t.id=t.id||e+i},this))},buildScales:function(){if(this.scales={},this.options.scales&&(this.options.scales.xAxes&&this.options.scales.xAxes.length&&i.each(this.options.scales.xAxes,function(t){var i=e.scaleService.getScaleConstructor(t.type),a=new i({ctx:this.chart.ctx,options:t,data:this.data,id:t.id});this.scales[a.id]=a},this),this.options.scales.yAxes&&this.options.scales.yAxes.length&&i.each(this.options.scales.yAxes,function(t){var i=e.scaleService.getScaleConstructor(t.type),a=new i({ctx:this.chart.ctx,options:t,data:this.data,id:t.id});this.scales[a.id]=a},this)),this.options.scale){var t=e.scaleService.getScaleConstructor(this.options.scale.type),a=new t({ctx:this.chart.ctx,options:this.options.scale,data:this.data,chart:this.chart});this.scale=a,this.scales.radialScale=a}e.scaleService.update(this,this.chart.width,this.chart.height)},buildOrUpdateControllers:function(t){var a=[];if(i.each(this.data.datasets,function(i,s){i.type||(i.type=this.config.type);var o=i.type;return a.push(o),i.controller?void i.controller.updateIndex(s):(i.controller=new e.controllers[o](this,s),void(t&&i.controller.reset()))},this),a.length>1)for(var s=1;s<a.length;s++)if(a[s]!=a[s-1]){this.isCombo=!0;break}},resetElements:function(){i.each(this.data.datasets,function(t){t.controller.reset()},this)},update:function(t,a){e.scaleService.update(this,this.chart.width,this.chart.height),this.buildOrUpdateControllers(!0),i.each(this.data.datasets,function(t){t.controller.buildOrUpdateElements()},this),i.each(this.data.datasets,function(t){t.controller.update()},this),this.render(t,a)},render:function(t,a){if("undefined"!=typeof t&&0!==t||"undefined"==typeof t&&0!==this.options.animation.duration){var s=new e.Animation;s.numSteps=(t||this.options.animation.duration)/16.66,s.easing=this.options.animation.easing,s.render=function(t,e){var a=i.easingEffects[e.easing],s=e.currentStep/e.numSteps,o=a(s);t.draw(o,s,e.currentStep)},s.onAnimationProgress=this.options.onAnimationProgress,s.onAnimationComplete=this.options.onAnimationComplete,e.animationService.addAnimation(this,s,t,a)}else this.draw(),this.options.onAnimationComplete&&this.options.onAnimationComplete.call&&this.options.onAnimationComplete.call(this);return this},draw:function(t){var e=t||1;this.clear(),i.each(this.scales,function(t){t.draw(this.chartArea)},this),this.scale&&this.scale.draw(),i.each(this.data.datasets,function(e){i.isDatasetVisible(e)&&e.controller.draw(t)},this),this.tooltip.transition(e).draw()},getElementAtEvent:function(t){var e=i.getRelativePosition(t,this.chart),a=[];return i.each(this.data.datasets,function(t){i.isDatasetVisible(t)&&i.each(t.metaData,function(t){return t.inRange(e.x,e.y)?(a.push(t),a):void 0},this)},this),a},getElementsAtEvent:function(t){var e=i.getRelativePosition(t,this.chart),a=[];return i.each(this.data.datasets,function(t){i.isDatasetVisible(t)&&i.each(t.metaData,function(t){t.inLabelRange(e.x,e.y)&&a.push(t)},this)},this),a},getDatasetAtEvent:function(t){var e=i.getRelativePosition(t,this.chart),a=[];return i.each(this.data.datasets,function(t){i.isDatasetVisible(t)&&i.each(t.metaData,function(s){s.inLabelRange(e.x,e.y)&&i.each(t.metaData,function(t){a.push(t)},this)},this)},this),a.length?a:[]},generateLegend:function(){return this.options.legendCallback(this)},destroy:function(){this.clear(),i.unbindEvents(this,this.events),i.removeResizeListener(this.chart.canvas.parentNode);var t=this.chart.canvas;t.width=this.chart.width,t.height=this.chart.height,void 0!==this.chart.originalDevicePixelRatio&&this.chart.ctx.scale(1/this.chart.originalDevicePixelRatio,1/this.chart.originalDevicePixelRatio),t.style.width=this.chart.originalCanvasStyleWidth,t.style.height=this.chart.originalCanvasStyleHeight,delete e.instances[this.id]},toBase64Image:function(){return this.chart.canvas.toDataURL.apply(this.chart.canvas,arguments)},initToolTip:function(){this.tooltip=new e.Tooltip({_chart:this.chart,_data:this.data,_options:this.options},this)},bindEvents:function(){i.bindEvents(this,this.options.events,function(t){this.eventHandler(t)})},eventHandler:function(t){this.lastActive=this.lastActive||[],this.lastTooltipActive=this.lastTooltipActive||[],"mouseout"==t.type?(this.active=[],this.tooltipActive=[]):(this.active=function(){switch(this.options.hover.mode){case"single":return this.getElementAtEvent(t);case"label":return this.getElementsAtEvent(t);case"dataset":return this.getDatasetAtEvent(t);default:return t}}.call(this),this.tooltipActive=function(){switch(this.options.tooltips.mode){case"single":return this.getElementAtEvent(t);case"label":return this.getElementsAtEvent(t);case"dataset":return this.getDatasetAtEvent(t);default:return t}}.call(this)),this.options.hover.onHover&&this.options.hover.onHover.call(this,this.active),("mouseup"==t.type||"click"==t.type)&&this.options.onClick&&this.options.onClick.call(this,t,this.active);if(this.lastActive.length)switch(this.options.hover.mode){case"single":this.data.datasets[this.lastActive[0]._datasetIndex].controller.removeHoverStyle(this.lastActive[0],this.lastActive[0]._datasetIndex,this.lastActive[0]._index);break;case"label":case"dataset":for(var e=0;e<this.lastActive.length;e++)this.data.datasets[this.lastActive[e]._datasetIndex].controller.removeHoverStyle(this.lastActive[e],this.lastActive[e]._datasetIndex,this.lastActive[e]._index)}if(this.active.length&&this.options.hover.mode)switch(this.options.hover.mode){case"single":this.data.datasets[this.active[0]._datasetIndex].controller.setHoverStyle(this.active[0]);break;case"label":case"dataset":for(var a=0;a<this.active.length;a++)this.data.datasets[this.active[a]._datasetIndex].controller.setHoverStyle(this.active[a])}if((this.options.tooltips.enabled||this.options.tooltips.custom)&&(this.tooltip.initialize(),this.tooltip._active=this.tooltipActive),this.tooltip.pivot(),!this.animating){var s;i.each(this.active,function(t,e){t!==this.lastActive[e]&&(s=!0)},this),i.each(this.tooltipActive,function(t,e){t!==this.lastTooltipActive[e]&&(s=!0)},this),(this.lastActive.length!==this.active.length||this.lastTooltipActive.length!==this.tooltipActive.length||s)&&((this.options.tooltips.enabled||this.options.tooltips.custom)&&this.tooltip.update(),this.stop(),this.render(this.options.hover.animationDuration,!0))}return this.lastActive=this.active,this.lastTooltipActive=this.tooltipActive,this}})}.call(this),function(){"use strict";var t=this,e=t.Chart,i=e.helpers;e.defaults.scale={display:!0,gridLines:{show:!0,color:"rgba(0, 0, 0, 0.1)",lineWidth:1,drawOnChartArea:!0,drawTicks:!0,zeroLineWidth:1,zeroLineColor:"rgba(0,0,0,0.25)",offsetGridLines:!1},scaleLabel:{fontColor:"#666",fontFamily:"Helvetica Neue",fontSize:12,fontStyle:"normal",labelString:"",show:!1},ticks:{beginAtZero:!1,fontSize:12,fontStyle:"normal",fontColor:"#666",fontFamily:"Helvetica Neue",maxRotation:90,minRotation:20,mirror:!1,padding:10,reverse:!1,show:!0,callback:function(t){return""+t}}},e.Scale=e.Element.extend({beforeUpdate:i.noop,update:function(t,e,i){return this.beforeUpdate(),this.maxWidth=t,this.maxHeight=e,this.margins=i,this.beforeSetDimensions(),this.setDimensions(),this.afterSetDimensions(),this.beforeBuildTicks(),this.buildTicks(),this.afterBuildTicks(),this.beforeTickToLabelConversion(),this.convertTicksToLabels(),this.afterTickToLabelConversion(),this.beforeCalculateTickRotation(),this.calculateTickRotation(),this.afterCalculateTickRotation(),this.beforeFit(),this.fit(),this.afterFit(),this.afterUpdate(),this.minSize},afterUpdate:i.noop,beforeSetDimensions:i.noop,setDimensions:function(){this.isHorizontal()?(this.width=this.maxWidth,this.left=0,this.right=this.width):(this.height=this.maxHeight,this.top=0,this.bottom=this.height),this.paddingLeft=0,this.paddingTop=0,this.paddingRight=0,this.paddingBottom=0},afterSetDimensions:i.noop,beforeBuildTicks:i.noop,buildTicks:i.noop,afterBuildTicks:i.noop,beforeTickToLabelConversion:i.noop,convertTicksToLabels:function(){this.ticks=this.ticks.map(function(t,e,i){return this.options.ticks.userCallback?this.options.ticks.userCallback(t,e,i):this.options.ticks.callback(t,e,i)},this)},afterTickToLabelConversion:i.noop,beforeCalculateTickRotation:i.noop,calculateTickRotation:function(){var t=i.fontString(this.options.ticks.fontSize,this.options.ticks.fontStyle,this.options.ticks.fontFamily);this.ctx.font=t;var e,a,s=this.ctx.measureText(this.ticks[0]).width,o=this.ctx.measureText(this.ticks[this.ticks.length-1]).width;if(this.paddingRight=o/2+3,this.paddingLeft=s/2+3,this.labelRotation=0,this.options.display&&this.isHorizontal()){var n,r,h=i.longestText(this.ctx,t,this.ticks);this.labelWidth=h;for(var l=this.getPixelForTick(1)-this.getPixelForTick(0)-6;this.labelWidth>l&&this.labelRotation<=this.options.ticks.maxRotation;){if(n=Math.cos(i.toRadians(this.labelRotation)),r=Math.sin(i.toRadians(this.labelRotation)),e=n*s,a=n*o,e+this.options.ticks.fontSize/2>this.yLabelWidth&&(this.paddingLeft=e+this.options.ticks.fontSize/2),this.paddingRight=this.options.ticks.fontSize/2,r*h>this.maxHeight){this.labelRotation--;break}this.labelRotation++,this.labelWidth=n*h}}else this.labelWidth=0,this.paddingRight=0,this.paddingLeft=0;this.margins&&(this.paddingLeft-=this.margins.left,this.paddingRight-=this.margins.right,this.paddingLeft=Math.max(this.paddingLeft,0),this.paddingRight=Math.max(this.paddingRight,0))},afterCalculateTickRotation:i.noop,beforeFit:i.noop,fit:function(){if(this.minSize={width:0,height:0},this.minSize.width=this.isHorizontal()?this.maxWidth:this.options.gridLines.show&&this.options.display?10:0,this.minSize.height=this.isHorizontal()?this.options.gridLines.show&&this.options.display?10:0:this.maxHeight,this.options.scaleLabel.show&&(this.isHorizontal()?this.minSize.height+=1.5*this.options.scaleLabel.fontSize:this.minSize.width+=1.5*this.options.scaleLabel.fontSize),this.options.ticks.show&&this.options.display){var t=i.fontString(this.options.ticks.fontSize,this.options.ticks.fontStyle,this.options.ticks.fontFamily);if(this.isHorizontal()){var e=(this.maxHeight-this.minSize.height,i.longestText(this.ctx,t,this.ticks)),a=Math.sin(i.toRadians(this.labelRotation))*e+1.5*this.options.ticks.fontSize;this.minSize.height=Math.min(this.maxHeight,this.minSize.height+a),t=i.fontString(this.options.ticks.fontSize,this.options.ticks.fontStyle,this.options.ticks.fontFamily),this.ctx.font=t;var s=this.ctx.measureText(this.ticks[0]).width,o=this.ctx.measureText(this.ticks[this.ticks.length-1]).width,n=Math.cos(i.toRadians(this.labelRotation)),r=Math.sin(i.toRadians(this.labelRotation));this.paddingLeft=0!==this.labelRotation?n*s+3:s/2+3,this.paddingRight=0!==this.labelRotation?r*(this.options.ticks.fontSize/2)+3:o/2+3}else{var h=this.maxWidth-this.minSize.width,l=i.longestText(this.ctx,t,this.ticks);h>l?this.minSize.width+=l:this.minSize.width=this.maxWidth,this.paddingTop=this.options.ticks.fontSize/2,this.paddingBottom=this.options.ticks.fontSize/2}}this.margins&&(this.paddingLeft-=this.margins.left,this.paddingTop-=this.margins.top,this.paddingRight-=this.margins.right,this.paddingBottom-=this.margins.bottom,this.paddingLeft=Math.max(this.paddingLeft,0),this.paddingTop=Math.max(this.paddingTop,0),this.paddingRight=Math.max(this.paddingRight,0),this.paddingBottom=Math.max(this.paddingBottom,0)),this.width=this.minSize.width,this.height=this.minSize.height},afterFit:i.noop,isHorizontal:function(){return"top"==this.options.position||"bottom"==this.options.position},getRightValue:function a(t){return null===t||"undefined"==typeof t?0/0:"number"==typeof t&&isNaN(t)?0/0:"object"==typeof t?a(this.isHorizontal()?t.x:t.y):t},getLabelForIndex:i.noop,getPixelForValue:i.noop,getPixelForTick:function(t,e){if(this.isHorizontal()){var i=this.width-(this.paddingLeft+this.paddingRight),a=i/Math.max(this.ticks.length-(this.options.gridLines.offsetGridLines?0:1),1),s=a*t+this.paddingLeft;return e&&(s+=a/2),this.left+Math.round(s)}var o=this.height-(this.paddingTop+this.paddingBottom);return this.top+t*(o/(this.ticks.length-1))},getPixelForDecimal:function(t){if(this.isHorizontal()){var e=this.width-(this.paddingLeft+this.paddingRight),i=e*t+this.paddingLeft;return this.left+Math.round(i)}return this.top+t*this.height},draw:function(t){if(this.options.display){var e,a,s,o,n=0!==this.labelRotation;this.ctx.fillStyle=this.options.ticks.fontColor;var r=i.fontString(this.options.ticks.fontSize,this.options.ticks.fontStyle,this.options.ticks.fontFamily);if(this.isHorizontal()){e=!0;var h="bottom"==this.options.position?this.top:this.bottom-10,l="bottom"==this.options.position?this.top+10:this.bottom;a=!1,(this.options.ticks.fontSize+4)*this.ticks.length>this.width-(this.paddingLeft+this.paddingRight)&&(a=1+Math.floor((this.options.ticks.fontSize+4)*this.ticks.length/(this.width-(this.paddingLeft+this.paddingRight)))),i.each(this.ticks,function(s,o){if(!(a>1&&o%a>0||void 0===s||null===s)){var c=this.getPixelForTick(o),d=this.getPixelForTick(o,this.options.gridLines.offsetGridLines);this.options.gridLines.show&&(o===("undefined"!=typeof this.zeroLineIndex?this.zeroLineIndex:0)?(this.ctx.lineWidth=this.options.gridLines.zeroLineWidth,this.ctx.strokeStyle=this.options.gridLines.zeroLineColor,e=!0):e&&(this.ctx.lineWidth=this.options.gridLines.lineWidth,this.ctx.strokeStyle=this.options.gridLines.color,e=!1),c+=i.aliasPixel(this.ctx.lineWidth),this.ctx.beginPath(),this.options.gridLines.drawTicks&&(this.ctx.moveTo(c,h),this.ctx.lineTo(c,l)),this.options.gridLines.drawOnChartArea&&(this.ctx.moveTo(c,t.top),this.ctx.lineTo(c,t.bottom)),this.ctx.stroke()),this.options.ticks.show&&(this.ctx.save(),this.ctx.translate(d,n?this.top+12:"top"===this.options.position?this.bottom-10:this.top+10),this.ctx.rotate(-1*i.toRadians(this.labelRotation)),this.ctx.font=r,this.ctx.textAlign=n?"right":"center",this.ctx.textBaseline=n?"middle":"top"===this.options.position?"bottom":"top",this.ctx.fillText(s,0,0),this.ctx.restore())}},this),this.options.scaleLabel.show&&(this.ctx.textAlign="center",this.ctx.textBaseline="middle",this.ctx.fillStyle=this.options.scaleLabel.fontColor,this.ctx.font=i.fontString(this.options.scaleLabel.fontSize,this.options.scaleLabel.fontStyle,this.options.scaleLabel.fontFamily),s=this.left+(this.right-this.left)/2,o="bottom"==this.options.position?this.bottom-this.options.scaleLabel.fontSize/2:this.top+this.options.scaleLabel.fontSize/2,this.ctx.fillText(this.options.scaleLabel.labelString,s,o))}else{e=!0;var c="right"==this.options.position?this.left:this.right-5,d="right"==this.options.position?this.left+5:this.right;if(i.each(this.ticks,function(a,s){var o=this.getPixelForTick(s);if(this.options.gridLines.show&&(s===("undefined"!=typeof this.zeroLineIndex?this.zeroLineIndex:0)?(this.ctx.lineWidth=this.options.gridLines.zeroLineWidth,this.ctx.strokeStyle=this.options.gridLines.zeroLineColor,e=!0):e&&(this.ctx.lineWidth=this.options.gridLines.lineWidth,this.ctx.strokeStyle=this.options.gridLines.color,e=!1),o+=i.aliasPixel(this.ctx.lineWidth),this.ctx.beginPath(),this.options.gridLines.drawTicks&&(this.ctx.moveTo(c,o),this.ctx.lineTo(d,o)),this.options.gridLines.drawOnChartArea&&(this.ctx.moveTo(t.left,o),this.ctx.lineTo(t.right,o)),this.ctx.stroke()),this.options.ticks.show){var n,h=this.getPixelForTick(s,this.options.gridLines.offsetGridLines);this.ctx.save(),"left"==this.options.position?this.options.ticks.mirror?(n=this.right+this.options.ticks.padding,this.ctx.textAlign="left"):(n=this.right-this.options.ticks.padding,this.ctx.textAlign="right"):this.options.ticks.mirror?(n=this.left-this.options.ticks.padding,this.ctx.textAlign="right"):(n=this.left+this.options.ticks.padding,this.ctx.textAlign="left"),this.ctx.translate(n,h),this.ctx.rotate(-1*i.toRadians(this.labelRotation)),this.ctx.font=r,this.ctx.textBaseline="middle",this.ctx.fillText(a,0,0),this.ctx.restore()}},this),this.options.scaleLabel.show){s="left"==this.options.position?this.left+this.options.scaleLabel.fontSize/2:this.right-this.options.scaleLabel.fontSize/2,o=this.top+(this.bottom-this.top)/2;var u="left"==this.options.position?-.5*Math.PI:.5*Math.PI;this.ctx.save(),this.ctx.translate(s,o),this.ctx.rotate(u),this.ctx.textAlign="center",this.ctx.fillStyle=this.options.scaleLabel.fontColor,this.ctx.font=i.fontString(this.options.scaleLabel.fontSize,this.options.scaleLabel.fontStyle,this.options.scaleLabel.fontFamily),this.ctx.textBaseline="middle",this.ctx.fillText(this.options.scaleLabel.labelString,0,0),this.ctx.restore()}}}}})}.call(this),function(){"use strict";var t=this,e=t.Chart,i=e.helpers;e.scaleService={constructors:{},defaults:{},registerScaleType:function(t,e,a){this.constructors[t]=e,this.defaults[t]=i.clone(a)},getScaleConstructor:function(t){return this.constructors.hasOwnProperty(t)?this.constructors[t]:void 0},getScaleDefaults:function(t){return this.defaults.hasOwnProperty(t)?i.scaleMerge(e.defaults.scale,this.defaults[t]):{}},update:function(t,e,a){var s=e>30?5:2,o=a>30?5:2;if(t){var n=i.where(t.scales,function(t){return"left"==t.options.position}),r=i.where(t.scales,function(t){return"right"==t.options.position}),h=i.where(t.scales,function(t){return"top"==t.options.position}),l=i.where(t.scales,function(t){return"bottom"==t.options.position}),c=i.where(t.scales,function(t){return"chartArea"==t.options.position}),d=e/2,u=a/2;d-=2*s,u-=2*o;var g=(e-d)/(n.length+r.length),m=(a-u)/(h.length+l.length),p=[],f=function(t){var e=t.update(g,u);p.push({horizontal:!1,minSize:e,scale:t})},b=function(t){var e=t.update(d,m);p.push({horizontal:!0,minSize:e,scale:t})};i.each(n,f),i.each(r,f),i.each(h,b),i.each(l,b);var v=a-2*o,x=e-2*s;i.each(p,function(t){t.horizontal?v-=t.minSize.height:x-=t.minSize.width});var y=function(t){var e=i.findNextWhere(p,function(e){return e.scale===t});e&&t.update(e.minSize.width,v)},k=function(t){var e=i.findNextWhere(p,function(e){return e.scale===t}),a={left:D,right:w,top:0,bottom:0};e&&t.update(x,e.minSize.height,a)},D=s,w=s,C=o,S=o;i.each(n,y),i.each(r,y),i.each(n,function(t){D+=t.width}),i.each(r,function(t){w+=t.width}),i.each(h,k),i.each(l,k),i.each(h,function(t){C+=t.height}),i.each(l,function(t){S+=t.height}),i.each(n,function(t){var e=i.findNextWhere(p,function(e){return e.scale===t}),a={left:0,right:0,top:C,bottom:S};e&&t.update(e.minSize.width,v,a)}),i.each(r,function(t){var e=i.findNextWhere(p,function(e){return e.scale===t}),a={left:0,right:0,top:C,bottom:S};e&&t.update(e.minSize.width,v,a)}),D=s,w=s,C=o,S=o,i.each(n,function(t){D+=t.width}),i.each(r,function(t){w+=t.width}),i.each(h,function(t){C+=t.height}),i.each(l,function(t){S+=t.height});var _=a-C-S,A=e-D-w;(A!==x||_!==v)&&(i.each(n,function(t){t.height=_}),i.each(r,function(t){t.height=_}),i.each(h,function(t){t.width=A}),i.each(l,function(t){t.width=A}),v=_,x=A);var I=s,M=o,P=function(t){t.left=I,t.right=I+t.width,t.top=C,t.bottom=C+v,I=t.right},F=function(t){t.left=D,t.right=D+x,t.top=M,t.bottom=M+t.height,M=t.bottom};i.each(n,P),i.each(h,F),I+=x,M+=v,i.each(r,P),i.each(l,F),t.chartArea={left:D,top:C,right:D+x,bottom:C+v},i.each(c,function(e){e.left=t.chartArea.left,e.top=t.chartArea.top,e.right=t.chartArea.right,e.bottom=t.chartArea.bottom,e.update(x,v)})}}}}.call(this),function(){"use strict";function t(t,e){return e&&(a.isArray(e)?t=t.concat(e):t.push(e)),t}var e=this,i=e.Chart,a=i.helpers;i.defaults.global.tooltips={enabled:!0,custom:null,mode:"single",backgroundColor:"rgba(0,0,0,0.8)",titleFontFamily:"'Helvetica Neue', 'Helvetica', 'Arial', sans-serif",titleFontSize:12,titleFontStyle:"bold",titleSpacing:2,titleMarginBottom:6,titleColor:"#fff",titleAlign:"left",bodyFontFamily:"'Helvetica Neue', 'Helvetica', 'Arial', sans-serif",bodyFontSize:12,bodyFontStyle:"normal",bodySpacing:2,bodyColor:"#fff",bodyAlign:"left",footerFontFamily:"'Helvetica Neue', 'Helvetica', 'Arial', sans-serif",footerFontSize:12,footerFontStyle:"bold",footerSpacing:2,footerMarginTop:6,footerColor:"#fff",footerAlign:"left",yPadding:6,xPadding:6,caretSize:5,cornerRadius:6,xOffset:10,multiKeyBackground:"#fff",callbacks:{beforeTitle:a.noop,title:function(t,e){var i="";return t.length>0&&(t[0].xLabel?i=t[0].xLabel:e.labels.length>0&&t[0].index<e.labels.length&&(i=e.labels[t[0].index])),i},afterTitle:a.noop,beforeBody:a.noop,beforeLabel:a.noop,label:function(t,e){var i=e.datasets[t.datasetIndex].label||"";return i+": "+t.yLabel},afterLabel:a.noop,afterBody:a.noop,beforeFooter:a.noop,footer:a.noop,afterFooter:a.noop}},i.Tooltip=i.Element.extend({initialize:function(){var t=this._options;a.extend(this,{_model:{xPadding:t.tooltips.xPadding,yPadding:t.tooltips.yPadding,xOffset:t.tooltips.xOffset,bodyColor:t.tooltips.bodyColor,_bodyFontFamily:t.tooltips.bodyFontFamily,_bodyFontStyle:t.tooltips.bodyFontStyle,_bodyAlign:t.tooltips.bodyAlign,bodyFontSize:t.tooltips.bodyFontSize,bodySpacing:t.tooltips.bodySpacing,titleColor:t.tooltips.titleColor,_titleFontFamily:t.tooltips.titleFontFamily,_titleFontStyle:t.tooltips.titleFontStyle,titleFontSize:t.tooltips.titleFontSize,_titleAlign:t.tooltips.titleAlign,titleSpacing:t.tooltips.titleSpacing,titleMarginBottom:t.tooltips.titleMarginBottom,footerColor:t.tooltips.footerColor,_footerFontFamily:t.tooltips.footerFontFamily,_footerFontStyle:t.tooltips.footerFontStyle,footerFontSize:t.tooltips.footerFontSize,_footerAlign:t.tooltips.footerAlign,footerSpacing:t.tooltips.footerSpacing,footerMarginTop:t.tooltips.footerMarginTop,caretSize:t.tooltips.caretSize,cornerRadius:t.tooltips.cornerRadius,backgroundColor:t.tooltips.backgroundColor,opacity:0,legendColorBackground:t.tooltips.multiKeyBackground}})},getTitle:function(){var e=this._options.tooltips.callbacks.beforeTitle.apply(this,arguments),i=this._options.tooltips.callbacks.title.apply(this,arguments),a=this._options.tooltips.callbacks.afterTitle.apply(this,arguments),s=[];return s=t(s,e),s=t(s,i),s=t(s,a)},getBeforeBody:function(){var t=this._options.tooltips.callbacks.beforeBody.call(this,arguments);return a.isArray(t)?t:[t]},getBody:function(t,e){var i=[];return a.each(t,function(t){var a=this._options.tooltips.callbacks.beforeLabel.call(this,t,e)||"",s=this._options.tooltips.callbacks.label.call(this,t,e)||"",o=this._options.tooltips.callbacks.afterLabel.call(this,t,e)||"";i.push(a+s+o)},this),i},getAfterBody:function(){var t=this._options.tooltips.callbacks.afterBody.call(this,arguments);return a.isArray(t)?t:[t]},getFooter:function(){var e=this._options.tooltips.callbacks.beforeFooter.apply(this,arguments),i=this._options.tooltips.callbacks.footer.apply(this,arguments),a=this._options.tooltips.callbacks.afterFooter.apply(this,arguments),s=[];return s=t(s,e),s=t(s,i),s=t(s,a)},update:function(){this._chart.ctx;if(this._active.length){this._model.opacity=1;var t,e=this._active[0],i=[],s=[];if("single"==this._options.tooltips.mode){var o=e._yScale||e._scale;s.push({xLabel:e._xScale?e._xScale.getLabelForIndex(e._index,e._datasetIndex):"",yLabel:o?o.getLabelForIndex(e._index,e._datasetIndex):"",index:e._index,datasetIndex:e._datasetIndex}),t=this._active[0].tooltipPosition()}else a.each(this._data.datasets,function(t,i){if(a.isDatasetVisible(t)){var o=t.metaData[e._index],n=e._yScale||e._scale;s.push({xLabel:o._xScale?o._xScale.getLabelForIndex(o._index,o._datasetIndex):"",yLabel:n?n.getLabelForIndex(o._index,o._datasetIndex):"",index:e._index,datasetIndex:i})}}),a.each(this._active,function(t){i.push({borderColor:t._view.borderColor,backgroundColor:t._view.backgroundColor})},this),t=this._active[0].tooltipPosition(),t.y=this._active[0]._yScale.getPixelForDecimal(.5);a.extend(this._model,{title:this.getTitle(s,this._data),beforeBody:this.getBeforeBody(s,this._data),body:this.getBody(s,this._data),afterBody:this.getAfterBody(s,this._data),footer:this.getFooter(s,this._data)}),a.extend(this._model,{x:Math.round(t.x),y:Math.round(t.y),caretPadding:t.padding,labelColors:i})}else this._model.opacity=0;return this._options.tooltips.custom&&this._options.tooltips.custom.call(this,this._model),this},draw:function(){var t=this._chart.ctx,e=this._view;if(0!==this._view.opacity){e.position="top";var i=e.caretPadding||2,s=e.body.length+e.beforeBody.length+e.afterBody.length,o=2*e.yPadding;o+=e.title.length*e.titleFontSize,o+=(e.title.length-1)*e.titleSpacing,o+=e.title.length?e.titleMarginBottom:0,o+=s*e.bodyFontSize,o+=(s-1)*e.bodySpacing,o+=e.footer.length?e.footerMarginTop:0,o+=e.footer.length*e.footerFontSize,o+=(e.footer.length-1)*e.footerSpacing;var n=0;a.each(e.title,function(i){t.font=a.fontString(e.titleFontSize,e._titleFontStyle,e._titleFontFamily),n=Math.max(n,t.measureText(i).width)}),a.each(e.body,function(i){t.font=a.fontString(e.bodyFontSize,e._bodyFontStyle,e._bodyFontFamily),n=Math.max(n,t.measureText(i).width+("single"!=this._options.tooltips.mode?e.bodyFontSize+2:0))},this),a.each(e.footer,function(i){t.font=a.fontString(e.footerFontSize,e._footerFontStyle,e._footerFontFamily),n=Math.max(n,t.measureText(i).width)}),n+=2*e.xPadding;var r=n+e.caretSize+i;e.yAlign="center",e.y-o/2<0?e.yAlign="top":e.y+o/2>this._chart.height&&(e.yAlign="bottom"),e.xAlign="right",e.x+r>this._chart.width&&(e.xAlign="left");var h=e.x,l=e.y;if(l="top"==e.yAlign?e.y-e.caretSize-e.cornerRadius:"bottom"==e.yAlign?e.y-o+e.caretSize+e.cornerRadius:e.y-o/2,h="left"==e.xAlign?e.x-r:"right"==e.xAlign?e.x+i+e.caretSize:e.x+r/2,this._options.tooltips.enabled&&(t.fillStyle=a.color(e.backgroundColor).alpha(e.opacity).rgbString(),a.drawRoundedRectangle(t,h,l,n,o,e.cornerRadius),t.fill()),this._options.tooltips.enabled&&(t.fillStyle=a.color(e.backgroundColor).alpha(e.opacity).rgbString(),"left"==e.xAlign?(t.beginPath(),t.moveTo(e.x-i,e.y),t.lineTo(e.x-i-e.caretSize,e.y-e.caretSize),t.lineTo(e.x-i-e.caretSize,e.y+e.caretSize),t.closePath(),t.fill()):(t.beginPath(),t.moveTo(e.x+i,e.y),t.lineTo(e.x+i+e.caretSize,e.y-e.caretSize),t.lineTo(e.x+i+e.caretSize,e.y+e.caretSize),t.closePath(),t.fill())),this._options.tooltips.enabled){var c=l+e.yPadding,d=h+e.xPadding;e.title.length&&(t.textAlign=e._titleAlign,t.textBaseline="top",t.fillStyle=a.color(e.titleColor).alpha(e.opacity).rgbString(),t.font=a.fontString(e.titleFontSize,e._titleFontStyle,e._titleFontFamily),a.each(e.title,function(i,a){t.fillText(i,d,c),c+=e.titleFontSize+e.titleSpacing,a+1==e.title.length&&(c+=e.titleMarginBottom-e.titleSpacing)},this)),t.textAlign=e._bodyAlign,t.textBaseline="top",t.fillStyle=a.color(e.bodyColor).alpha(e.opacity).rgbString(),t.font=a.fontString(e.bodyFontSize,e._bodyFontStyle,e._bodyFontFamily),a.each(e.beforeBody,function(){t.fillText(e.beforeBody,d,c),c+=e.bodyFontSize+e.bodySpacing}),a.each(e.body,function(i,s){"single"!=this._options.tooltips.mode&&(t.fillStyle=a.color(e.labelColors[s].borderColor).alpha(e.opacity).rgbString(),t.fillRect(d,c,e.bodyFontSize,e.bodyFontSize),t.fillStyle=a.color(e.labelColors[s].backgroundColor).alpha(e.opacity).rgbString(),t.fillRect(d+1,c+1,e.bodyFontSize-2,e.bodyFontSize-2),t.fillStyle=a.color(e.bodyColor).alpha(e.opacity).rgbString()),t.fillText(i,d+("single"!=this._options.tooltips.mode?e.bodyFontSize+2:0),c),c+=e.bodyFontSize+e.bodySpacing},this),a.each(e.afterBody,function(){t.fillText(e.afterBody,d,c),c+=e.bodyFontSize}),c-=e.bodySpacing,e.footer.length&&(c+=e.footerMarginTop,t.textAlign=e._footerAlign,t.textBaseline="top",t.fillStyle=a.color(e.footerColor).alpha(e.opacity).rgbString(),t.font=a.fontString(e.footerFontSize,e._footerFontStyle,e._footerFontFamily),a.each(e.footer,function(i){t.fillText(i,d,c),c+=e.footerFontSize+e.footerSpacing},this))}}}})}.call(this),function(){"use strict";var t=this,e=t.Chart,i=e.helpers;e.defaults.bar={hover:{mode:"label"},scales:{xAxes:[{type:"category",categoryPercentage:.8,barPercentage:.9,gridLines:{offsetGridLines:!0}}],yAxes:[{type:"linear"}]}},e.controllers.bar=function(t,e){this.initialize.call(this,t,e)},i.extend(e.controllers.bar.prototype,{initialize:function(t,e){this.chart=t,this.index=e,this.linkScales(),this.addElements()},updateIndex:function(t){this.index=t},linkScales:function(){this.getDataset().xAxisID||(this.getDataset().xAxisID=this.chart.options.scales.xAxes[0].id),this.getDataset().yAxisID||(this.getDataset().yAxisID=this.chart.options.scales.yAxes[0].id)},getDataset:function(){return this.chart.data.datasets[this.index]},getScaleForID:function(t){return this.chart.scales[t]},getBarCount:function(){var t=0;return i.each(this.chart.data.datasets,function(e){i.isDatasetVisible(e)&&("bar"===e.type?++t:void 0===e.type&&"bar"===this.chart.config.type&&++t)},this),t},addElements:function(){this.getDataset().metaData=this.getDataset().metaData||[],i.each(this.getDataset().data,function(t,i){this.getDataset().metaData[i]=this.getDataset().metaData[i]||new e.elements.Rectangle({_chart:this.chart.chart,_datasetIndex:this.index,_index:i})},this)},addElementAndReset:function(t){this.getDataset().metaData=this.getDataset().metaData||[];var i=new e.elements.Rectangle({_chart:this.chart.chart,_datasetIndex:this.index,_index:t}),a=this.getBarCount();this.updateElement(i,t,!0,a),this.getDataset().metaData.splice(t,0,i)},removeElement:function(t){this.getDataset().metaData.splice(t,1)},reset:function(){this.update(!0)},buildOrUpdateElements:function(){var t=this.getDataset().data.length,e=this.getDataset().metaData.length;if(e>t)this.getDataset().metaData.splice(t,e-t);else if(t>e)for(var i=e;t>i;++i)this.addElementAndReset(i)},update:function(t){var e=this.getBarCount();i.each(this.getDataset().metaData,function(i,a){this.updateElement(i,a,t,e)},this)},updateElement:function(t,e,a,s){var o,n=this.getScaleForID(this.getDataset().xAxisID),r=this.getScaleForID(this.getDataset().yAxisID);o=r.getPixelForValue(r.min<0&&r.max<0?r.max:r.min>0&&r.max>0?r.min:0),i.extend(t,{_chart:this.chart.chart,_xScale:n,_yScale:r,_datasetIndex:this.index,_index:e,_model:{x:this.calculateBarX(e,this.index),y:a?o:this.calculateBarY(e,this.index),label:this.chart.data.labels[e],datasetLabel:this.getDataset().label,base:this.calculateBarBase(this.index,e),width:this.calculateBarWidth(s),backgroundColor:t.custom&&t.custom.backgroundColor?t.custom.backgroundColor:i.getValueAtIndexOrDefault(this.getDataset().backgroundColor,e,this.chart.options.elements.rectangle.backgroundColor),borderColor:t.custom&&t.custom.borderColor?t.custom.borderColor:i.getValueAtIndexOrDefault(this.getDataset().borderColor,e,this.chart.options.elements.rectangle.borderColor),borderWidth:t.custom&&t.custom.borderWidth?t.custom.borderWidth:i.getValueAtIndexOrDefault(this.getDataset().borderWidth,e,this.chart.options.elements.rectangle.borderWidth)}}),t.pivot()},calculateBarBase:function(t,e){var a=(this.getScaleForID(this.getDataset().xAxisID),this.getScaleForID(this.getDataset().yAxisID)),s=0;if(a.options.stacked){var o=this.chart.data.datasets[t].data[e];if(0>o)for(var n=0;t>n;n++){var r=this.chart.data.datasets[n];i.isDatasetVisible(r)&&r.yAxisID===a.id&&(s+=r.data[e]<0?r.data[e]:0)}else for(var h=0;t>h;h++){var l=this.chart.data.datasets[h];i.isDatasetVisible(l)&&l.yAxisID===a.id&&(s+=l.data[e]>0?l.data[e]:0)}return a.getPixelForValue(s)}return s=a.getPixelForValue(a.min),a.beginAtZero||a.min<=0&&a.max>=0||a.min>=0&&a.max<=0?s=a.getPixelForValue(0,0):a.min<0&&a.max<0&&(s=a.getPixelForValue(a.max)),s},getRuler:function(){var t=this.getScaleForID(this.getDataset().xAxisID),e=(this.getScaleForID(this.getDataset().yAxisID),this.getBarCount()),i=function(){for(var e=t.getPixelForValue(null,1)-t.getPixelForValue(null,0),i=2;i<this.getDataset().data.length;i++)e=Math.min(t.getPixelForValue(null,i)-t.getPixelForValue(null,i-1),e);return e}.call(this),a=i*t.options.categoryPercentage,s=(i-i*t.options.categoryPercentage)/2,o=a/e,n=o*t.options.barPercentage,r=o-o*t.options.barPercentage;return{datasetCount:e,tickWidth:i,categoryWidth:a,categorySpacing:s,fullBarWidth:o,barWidth:n,barSpacing:r}},calculateBarWidth:function(){var t=this.getScaleForID(this.getDataset().xAxisID),e=this.getRuler();return t.options.stacked?e.categoryWidth:e.barWidth},getBarIndex:function(t){for(var e=0,a=0;t>a;++a)i.isDatasetVisible(this.chart.data.datasets[a])&&("bar"===this.chart.data.datasets[a].type||void 0===this.chart.data.datasets[a].type&&"bar"===this.chart.config.type)&&++e;return e},calculateBarX:function(t,e){var i=(this.getScaleForID(this.getDataset().yAxisID),this.getScaleForID(this.getDataset().xAxisID)),a=this.getBarIndex(e),s=this.getRuler(),o=i.getPixelForValue(null,t,a,this.chart.isCombo);return o-=this.chart.isCombo?s.tickWidth/2:0,i.options.stacked?o+s.categoryWidth/2+s.categorySpacing:o+s.barWidth/2+s.categorySpacing+s.barWidth*a+s.barSpacing/2+s.barSpacing*a},calculateBarY:function(t,e){var a=(this.getScaleForID(this.getDataset().xAxisID),this.getScaleForID(this.getDataset().yAxisID)),s=this.getDataset().data[t];if(a.options.stacked){for(var o=0,n=0,r=0;e>r;r++){var h=this.chart.data.datasets[r];i.isDatasetVisible(h)&&(h.data[t]<0?n+=h.data[t]||0:o+=h.data[t]||0)}return a.getPixelForValue(0>s?n+s:o+s)}return a.getPixelForValue(s)},draw:function(t){var e=t||1;i.each(this.getDataset().metaData,function(t){t.transition(e).draw()},this)},setHoverStyle:function(t){var e=this.chart.data.datasets[t._datasetIndex],a=t._index;t._model.backgroundColor=t.custom&&t.custom.hoverBackgroundColor?t.custom.hoverBackgroundColor:i.getValueAtIndexOrDefault(e.hoverBackgroundColor,a,i.color(t._model.backgroundColor).saturate(.5).darken(.1).rgbString()),t._model.borderColor=t.custom&&t.custom.hoverBorderColor?t.custom.hoverBorderColor:i.getValueAtIndexOrDefault(e.hoverBorderColor,a,i.color(t._model.borderColor).saturate(.5).darken(.1).rgbString()),t._model.borderWidth=t.custom&&t.custom.hoverBorderWidth?t.custom.hoverBorderWidth:i.getValueAtIndexOrDefault(e.hoverBorderWidth,a,t._model.borderWidth)},removeHoverStyle:function(t){var e=(this.chart.data.datasets[t._datasetIndex],t._index);t._model.backgroundColor=t.custom&&t.custom.backgroundColor?t.custom.backgroundColor:i.getValueAtIndexOrDefault(this.getDataset().backgroundColor,e,this.chart.options.elements.rectangle.backgroundColor),t._model.borderColor=t.custom&&t.custom.borderColor?t.custom.borderColor:i.getValueAtIndexOrDefault(this.getDataset().borderColor,e,this.chart.options.elements.rectangle.borderColor),t._model.borderWidth=t.custom&&t.custom.borderWidth?t.custom.borderWidth:i.getValueAtIndexOrDefault(this.getDataset().borderWidth,e,this.chart.options.elements.rectangle.borderWidth)}})}.call(this),function(){"use strict";var t=this,e=t.Chart,i=e.helpers;e.defaults.bubble={hover:{mode:"single"},scales:{xAxes:[{type:"linear",position:"bottom",id:"x-axis-0"}],yAxes:[{type:"linear",position:"left",id:"y-axis-0"}]},tooltips:{template:"(<%= value.x %>, <%= value.y %>, <%= value.r %>)",multiTemplate:"<%if (datasetLabel){%><%=datasetLabel%>: <%}%>(<%= value.x %>, <%= value.y %>, <%= value.r %>)"}},e.controllers.bubble=function(t,e){this.initialize.call(this,t,e)},i.extend(e.controllers.bubble.prototype,{initialize:function(t,e){this.chart=t,this.index=e,this.linkScales(),this.addElements()},updateIndex:function(t){this.index=t},linkScales:function(){this.getDataset().xAxisID||(this.getDataset().xAxisID=this.chart.options.scales.xAxes[0].id),this.getDataset().yAxisID||(this.getDataset().yAxisID=this.chart.options.scales.yAxes[0].id)},getDataset:function(){return this.chart.data.datasets[this.index]},getScaleForId:function(t){return this.chart.scales[t]},addElements:function(){this.getDataset().metaData=this.getDataset().metaData||[],i.each(this.getDataset().data,function(t,i){this.getDataset().metaData[i]=this.getDataset().metaData[i]||new e.elements.Point({_chart:this.chart.chart,_datasetIndex:this.index,_index:i})},this)},addElementAndReset:function(t){this.getDataset().metaData=this.getDataset().metaData||[];var i=new e.elements.Point({_chart:this.chart.chart,_datasetIndex:this.index,_index:t});this.updateElement(i,t,!0),this.getDataset().metaData.splice(t,0,i)},removeElement:function(t){this.getDataset().metaData.splice(t,1)},reset:function(){this.update(!0)},buildOrUpdateElements:function(){var t=this.getDataset().data.length,e=this.getDataset().metaData.length;if(e>t)this.getDataset().metaData.splice(t,e-t);else if(t>e)for(var i=e;t>i;++i)this.addElementAndReset(i)},update:function(t){{var e,a=this.getDataset().metaData,s=this.getScaleForId(this.getDataset().yAxisID);this.getScaleForId(this.getDataset().xAxisID)}e=s.getPixelForValue(s.min<0&&s.max<0?s.max:s.min>0&&s.max>0?s.min:0),i.each(a,function(e,i){this.updateElement(e,i,t)},this)},updateElement:function(t,e,a){var s,o=this.getScaleForId(this.getDataset().yAxisID),n=this.getScaleForId(this.getDataset().xAxisID);s=o.getPixelForValue(o.min<0&&o.max<0?o.max:o.min>0&&o.max>0?o.min:0),i.extend(t,{_chart:this.chart.chart,_xScale:n,_yScale:o,_datasetIndex:this.index,_index:e,_model:{x:a?n.getPixelForDecimal(.5):n.getPixelForValue(this.getDataset().data[e],e,this.index,this.chart.isCombo),y:a?s:o.getPixelForValue(this.getDataset().data[e],e,this.index),radius:a?0:t.custom&&t.custom.radius?t.custom.radius:this.getRadius(this.getDataset().data[e]),backgroundColor:t.custom&&t.custom.backgroundColor?t.custom.backgroundColor:i.getValueAtIndexOrDefault(this.getDataset().backgroundColor,e,this.chart.options.elements.point.backgroundColor),borderColor:t.custom&&t.custom.borderColor?t.custom.borderColor:i.getValueAtIndexOrDefault(this.getDataset().borderColor,e,this.chart.options.elements.point.borderColor),borderWidth:t.custom&&t.custom.borderWidth?t.custom.borderWidth:i.getValueAtIndexOrDefault(this.getDataset().borderWidth,e,this.chart.options.elements.point.borderWidth),hitRadius:t.custom&&t.custom.hitRadius?t.custom.hitRadius:i.getValueAtIndexOrDefault(this.getDataset().hitRadius,e,this.chart.options.elements.point.hitRadius)}}),t._model.skip=t.custom&&t.custom.skip?t.custom.skip:isNaN(t._model.x)||isNaN(t._model.y),t.pivot()},getRadius:function(t){return t.r||this.chart.options.elements.point.radius},draw:function(t){var e=t||1;i.each(this.getDataset().metaData,function(t){t.transition(e),t.draw()},this)},setHoverStyle:function(t){var e=this.chart.data.datasets[t._datasetIndex],a=t._index;t._model.radius=t.custom&&t.custom.hoverRadius?t.custom.hoverRadius:i.getValueAtIndexOrDefault(e.hoverRadius,a,this.chart.options.elements.point.hoverRadius)+this.getRadius(this.getDataset().data[t._index]),t._model.backgroundColor=t.custom&&t.custom.hoverBackgroundColor?t.custom.hoverBackgroundColor:i.getValueAtIndexOrDefault(e.hoverBackgroundColor,a,i.color(t._model.backgroundColor).saturate(.5).darken(.1).rgbString()),t._model.borderColor=t.custom&&t.custom.hoverBorderColor?t.custom.hoverBorderColor:i.getValueAtIndexOrDefault(e.hoverBorderColor,a,i.color(t._model.borderColor).saturate(.5).darken(.1).rgbString()),t._model.borderWidth=t.custom&&t.custom.hoverBorderWidth?t.custom.hoverBorderWidth:i.getValueAtIndexOrDefault(e.hoverBorderWidth,a,t._model.borderWidth)},removeHoverStyle:function(t){var e=(this.chart.data.datasets[t._datasetIndex],t._index);t._model.radius=t.custom&&t.custom.radius?t.custom.radius:this.getRadius(this.getDataset().data[t._index]),t._model.backgroundColor=t.custom&&t.custom.backgroundColor?t.custom.backgroundColor:i.getValueAtIndexOrDefault(this.getDataset().backgroundColor,e,this.chart.options.elements.point.backgroundColor),t._model.borderColor=t.custom&&t.custom.borderColor?t.custom.borderColor:i.getValueAtIndexOrDefault(this.getDataset().borderColor,e,this.chart.options.elements.point.borderColor),t._model.borderWidth=t.custom&&t.custom.borderWidth?t.custom.borderWidth:i.getValueAtIndexOrDefault(this.getDataset().borderWidth,e,this.chart.options.elements.point.borderWidth)}})}.call(this),function(){"use strict";var t=this,e=t.Chart,i=e.helpers;e.defaults.doughnut={animation:{animateRotate:!0,animateScale:!1},hover:{mode:"single"},cutoutPercentage:50,tooltips:{callbacks:{title:function(){return""},label:function(t,e){return e.labels[t.index]+": "+e.datasets[t.datasetIndex].data[t.index]}}}},e.defaults.pie=i.clone(e.defaults.doughnut),i.extend(e.defaults.pie,{cutoutPercentage:0}),e.controllers.doughnut=e.controllers.pie=function(t,e){this.initialize.call(this,t,e)},i.extend(e.controllers.doughnut.prototype,{initialize:function(t,e){this.chart=t,this.index=e,this.linkScales(),this.addElements()},updateIndex:function(t){this.index=t},linkScales:function(){},getDataset:function(){return this.chart.data.datasets[this.index]},addElements:function(){this.getDataset().metaData=this.getDataset().metaData||[],i.each(this.getDataset().data,function(t,i){this.getDataset().metaData[i]=this.getDataset().metaData[i]||new e.elements.Arc({_chart:this.chart.chart,_datasetIndex:this.index,_index:i})},this)},addElementAndReset:function(t,a){this.getDataset().metaData=this.getDataset().metaData||[];var s=new e.elements.Arc({_chart:this.chart.chart,_datasetIndex:this.index,_index:t});a&&i.isArray(this.getDataset().backgroundColor)&&this.getDataset().backgroundColor.splice(t,0,a),this.updateElement(s,t,!0),this.getDataset().metaData.splice(t,0,s)},removeElement:function(t){this.getDataset().metaData.splice(t,1)},reset:function(){this.update(!0)},buildOrUpdateElements:function(){var t=this.getDataset().data.length,e=this.getDataset().metaData.length;if(e>t)this.getDataset().metaData.splice(t,e-t);else if(t>e)for(var i=e;t>i;++i)this.addElementAndReset(i)},getVisibleDatasetCount:function(){return i.where(this.chart.data.datasets,function(t){return i.isDatasetVisible(t)}).length},getRingIndex:function(t){for(var e=0,a=0;t>a;++a)i.isDatasetVisible(this.chart.data.datasets[a])&&++e;return e},update:function(t){this.chart.outerRadius=Math.max(i.min([this.chart.chart.width,this.chart.chart.height])/2-this.chart.options.elements.arc.borderWidth/2,0),this.chart.innerRadius=Math.max(this.chart.options.cutoutPercentage?this.chart.outerRadius/100*this.chart.options.cutoutPercentage:1,0),this.chart.radiusLength=(this.chart.outerRadius-this.chart.innerRadius)/this.getVisibleDatasetCount(),this.getDataset().total=0,i.each(this.getDataset().data,function(t){this.getDataset().total+=Math.abs(t)},this),this.outerRadius=this.chart.outerRadius-this.chart.radiusLength*this.getRingIndex(this.index),this.innerRadius=this.outerRadius-this.chart.radiusLength,i.each(this.getDataset().metaData,function(e,i){this.updateElement(e,i,t)},this)},updateElement:function(t,e,a){var s={x:this.chart.chart.width/2,y:this.chart.chart.height/2,startAngle:Math.PI*-.5,circumference:this.chart.options.animation.animateRotate?0:this.calculateCircumference(this.getDataset().data[e]),outerRadius:this.chart.options.animation.animateScale?0:this.outerRadius,innerRadius:this.chart.options.animation.animateScale?0:this.innerRadius};i.extend(t,{_chart:this.chart.chart,_datasetIndex:this.index,_index:e,_model:a?s:{x:this.chart.chart.width/2,y:this.chart.chart.height/2,circumference:this.calculateCircumference(this.getDataset().data[e]),outerRadius:this.outerRadius,innerRadius:this.innerRadius,backgroundColor:t.custom&&t.custom.backgroundColor?t.custom.backgroundColor:i.getValueAtIndexOrDefault(this.getDataset().backgroundColor,e,this.chart.options.elements.arc.backgroundColor),hoverBackgroundColor:t.custom&&t.custom.hoverBackgroundColor?t.custom.hoverBackgroundColor:i.getValueAtIndexOrDefault(this.getDataset().hoverBackgroundColor,e,this.chart.options.elements.arc.hoverBackgroundColor),borderWidth:t.custom&&t.custom.borderWidth?t.custom.borderWidth:i.getValueAtIndexOrDefault(this.getDataset().borderWidth,e,this.chart.options.elements.arc.borderWidth),borderColor:t.custom&&t.custom.borderColor?t.custom.borderColor:i.getValueAtIndexOrDefault(this.getDataset().borderColor,e,this.chart.options.elements.arc.borderColor),label:i.getValueAtIndexOrDefault(this.getDataset().label,e,this.chart.data.labels[e])}}),a||(t._model.startAngle=0===e?Math.PI*-.5:this.getDataset().metaData[e-1]._model.endAngle,t._model.endAngle=t._model.startAngle+t._model.circumference,e<this.getDataset().data.length-1&&(this.getDataset().metaData[e+1]._model.startAngle=t._model.endAngle)),t.pivot()},draw:function(t){var e=t||1;i.each(this.getDataset().metaData,function(t){t.transition(e).draw()},this)},setHoverStyle:function(t){var e=this.chart.data.datasets[t._datasetIndex],a=t._index;t._model.backgroundColor=t.custom&&t.custom.hoverBackgroundColor?t.custom.hoverBackgroundColor:i.getValueAtIndexOrDefault(e.hoverBackgroundColor,a,i.color(t._model.backgroundColor).saturate(.5).darken(.1).rgbString()),t._model.borderColor=t.custom&&t.custom.hoverBorderColor?t.custom.hoverBorderColor:i.getValueAtIndexOrDefault(e.hoverBorderColor,a,i.color(t._model.borderColor).saturate(.5).darken(.1).rgbString()),t._model.borderWidth=t.custom&&t.custom.hoverBorderWidth?t.custom.hoverBorderWidth:i.getValueAtIndexOrDefault(e.hoverBorderWidth,a,t._model.borderWidth)},removeHoverStyle:function(t){var e=(this.chart.data.datasets[t._datasetIndex],t._index);t._model.backgroundColor=t.custom&&t.custom.backgroundColor?t.custom.backgroundColor:i.getValueAtIndexOrDefault(this.getDataset().backgroundColor,e,this.chart.options.elements.arc.backgroundColor),t._model.borderColor=t.custom&&t.custom.borderColor?t.custom.borderColor:i.getValueAtIndexOrDefault(this.getDataset().borderColor,e,this.chart.options.elements.arc.borderColor),t._model.borderWidth=t.custom&&t.custom.borderWidth?t.custom.borderWidth:i.getValueAtIndexOrDefault(this.getDataset().borderWidth,e,this.chart.options.elements.arc.borderWidth)},calculateCircumference:function(t){return this.getDataset().total>0?1.999999*Math.PI*(t/this.getDataset().total):0}})}.call(this),function(){"use strict";var t=this,e=t.Chart,i=e.helpers;e.defaults.line={hover:{mode:"label"},scales:{xAxes:[{type:"category",id:"x-axis-0"}],yAxes:[{type:"linear",id:"y-axis-0"}]}},e.controllers.line=function(t,e){this.initialize.call(this,t,e)},i.extend(e.controllers.line.prototype,{initialize:function(t,e){this.chart=t,this.index=e,this.linkScales(),this.addElements()},updateIndex:function(t){this.index=t},linkScales:function(){this.getDataset().xAxisID||(this.getDataset().xAxisID=this.chart.options.scales.xAxes[0].id),this.getDataset().yAxisID||(this.getDataset().yAxisID=this.chart.options.scales.yAxes[0].id)},getDataset:function(){return this.chart.data.datasets[this.index]},getScaleForId:function(t){return this.chart.scales[t]},addElements:function(){this.getDataset().metaData=this.getDataset().metaData||[],this.getDataset().metaDataset=this.getDataset().metaDataset||new e.elements.Line({_chart:this.chart.chart,_datasetIndex:this.index,_points:this.getDataset().metaData}),i.each(this.getDataset().data,function(t,i){this.getDataset().metaData[i]=this.getDataset().metaData[i]||new e.elements.Point({_chart:this.chart.chart,_datasetIndex:this.index,_index:i})},this)},addElementAndReset:function(t){this.getDataset().metaData=this.getDataset().metaData||[];var i=new e.elements.Point({_chart:this.chart.chart,_datasetIndex:this.index,_index:t});this.updateElement(i,t,!0),this.getDataset().metaData.splice(t,0,i),this.updateBezierControlPoints()},removeElement:function(t){this.getDataset().metaData.splice(t,1)},reset:function(){this.update(!0)},buildOrUpdateElements:function(){var t=this.getDataset().data.length,e=this.getDataset().metaData.length;if(e>t)this.getDataset().metaData.splice(t,e-t);else if(t>e)for(var i=e;t>i;++i)this.addElementAndReset(i)},update:function(t){{var e,a=this.getDataset().metaDataset,s=this.getDataset().metaData,o=this.getScaleForId(this.getDataset().yAxisID);this.getScaleForId(this.getDataset().xAxisID)}e=o.getPixelForValue(o.min<0&&o.max<0?o.max:o.min>0&&o.max>0?o.min:0),i.extend(a,{_scale:o,_datasetIndex:this.index,_children:s,_model:{tension:a.custom&&a.custom.tension?a.custom.tension:this.getDataset().tension||this.chart.options.elements.line.tension,backgroundColor:a.custom&&a.custom.backgroundColor?a.custom.backgroundColor:this.getDataset().backgroundColor||this.chart.options.elements.line.backgroundColor,borderWidth:a.custom&&a.custom.borderWidth?a.custom.borderWidth:this.getDataset().borderWidth||this.chart.options.elements.line.borderWidth,borderColor:a.custom&&a.custom.borderColor?a.custom.borderColor:this.getDataset().borderColor||this.chart.options.elements.line.borderColor,borderCapStyle:a.custom&&a.custom.borderCapStyle?a.custom.borderCapStyle:this.getDataset().borderCapStyle||this.chart.options.elements.line.borderCapStyle,borderDash:a.custom&&a.custom.borderDash?a.custom.borderDash:this.getDataset().borderDash||this.chart.options.elements.line.borderDash,borderDashOffset:a.custom&&a.custom.borderDashOffset?a.custom.borderDashOffset:this.getDataset().borderDashOffset||this.chart.options.elements.line.borderDashOffset,borderJoinStyle:a.custom&&a.custom.borderJoinStyle?a.custom.borderJoinStyle:this.getDataset().borderJoinStyle||this.chart.options.elements.line.borderJoinStyle,fill:a.custom&&a.custom.fill?a.custom.fill:void 0!==this.getDataset().fill?this.getDataset().fill:this.chart.options.elements.line.fill,scaleTop:o.top,scaleBottom:o.bottom,scaleZero:e}}),a.pivot(),i.each(s,function(e,i){this.updateElement(e,i,t)},this),this.updateBezierControlPoints()},updateElement:function(t,e,a){var s,o=this.getScaleForId(this.getDataset().yAxisID),n=this.getScaleForId(this.getDataset().xAxisID);s=o.getPixelForValue(o.min<0&&o.max<0?o.max:o.min>0&&o.max>0?o.min:0),i.extend(t,{_chart:this.chart.chart,_xScale:n,_yScale:o,_datasetIndex:this.index,_index:e,_model:{x:n.getPixelForValue(this.getDataset().data[e],e,this.index,this.chart.isCombo),y:a?s:this.calculatePointY(this.getDataset().data[e],e,this.index,this.chart.isCombo),tension:t.custom&&t.custom.tension?t.custom.tension:this.getDataset().tension||this.chart.options.elements.line.tension,radius:t.custom&&t.custom.radius?t.custom.radius:i.getValueAtIndexOrDefault(this.getDataset().radius,e,this.chart.options.elements.point.radius),backgroundColor:t.custom&&t.custom.backgroundColor?t.custom.backgroundColor:i.getValueAtIndexOrDefault(this.getDataset().pointBackgroundColor,e,this.chart.options.elements.point.backgroundColor),borderColor:t.custom&&t.custom.borderColor?t.custom.borderColor:i.getValueAtIndexOrDefault(this.getDataset().pointBorderColor,e,this.chart.options.elements.point.borderColor),borderWidth:t.custom&&t.custom.borderWidth?t.custom.borderWidth:i.getValueAtIndexOrDefault(this.getDataset().pointBorderWidth,e,this.chart.options.elements.point.borderWidth),hitRadius:t.custom&&t.custom.hitRadius?t.custom.hitRadius:i.getValueAtIndexOrDefault(this.getDataset().hitRadius,e,this.chart.options.elements.point.hitRadius)}}),t._model.skip=t.custom&&t.custom.skip?t.custom.skip:isNaN(t._model.x)||isNaN(t._model.y)},calculatePointY:function(t,e,a){var s=(this.getScaleForId(this.getDataset().xAxisID),this.getScaleForId(this.getDataset().yAxisID));if(s.options.stacked){for(var o=0,n=0,r=this.chart.data.datasets.length-1;r>a;r--){var h=this.chart.data.datasets[r];i.isDatasetVisible(h)&&(h.data[e]<0?n+=h.data[e]||0:o+=h.data[e]||0)}return s.getPixelForValue(0>t?n+t:o+t)}return s.getPixelForValue(t)},updateBezierControlPoints:function(){i.each(this.getDataset().metaData,function(t,e){var a=i.splineCurve(i.previousItem(this.getDataset().metaData,e)._model,t._model,i.nextItem(this.getDataset().metaData,e)._model,t._model.tension);t._model.controlPointPreviousX=a.previous.x,t._model.controlPointNextX=a.next.x,t._model.controlPointNextY=a.next.y>this.chart.chartArea.bottom?this.chart.chartArea.bottom:a.next.y<this.chart.chartArea.top?this.chart.chartArea.top:a.next.y,t._model.controlPointPreviousY=a.previous.y>this.chart.chartArea.bottom?this.chart.chartArea.bottom:a.previous.y<this.chart.chartArea.top?this.chart.chartArea.top:a.previous.y,t.pivot()},this)},draw:function(t){var e=t||1;i.each(this.getDataset().metaData,function(t){t.transition(e)},this),this.getDataset().metaDataset.transition(e).draw(),i.each(this.getDataset().metaData,function(t){t.draw()})},setHoverStyle:function(t){var e=this.chart.data.datasets[t._datasetIndex],a=t._index;t._model.radius=t.custom&&t.custom.hoverRadius?t.custom.hoverRadius:i.getValueAtIndexOrDefault(e.pointHoverRadius,a,this.chart.options.elements.point.hoverRadius),t._model.backgroundColor=t.custom&&t.custom.hoverBackgroundColor?t.custom.hoverBackgroundColor:i.getValueAtIndexOrDefault(e.pointHoverBackgroundColor,a,i.color(t._model.backgroundColor).saturate(.5).darken(.1).rgbString()),t._model.borderColor=t.custom&&t.custom.hoverBorderColor?t.custom.hoverBorderColor:i.getValueAtIndexOrDefault(e.pointHoverBorderColor,a,i.color(t._model.borderColor).saturate(.5).darken(.1).rgbString()),t._model.borderWidth=t.custom&&t.custom.hoverBorderWidth?t.custom.hoverBorderWidth:i.getValueAtIndexOrDefault(e.pointHoverBorderWidth,a,t._model.borderWidth)},removeHoverStyle:function(t){var e=(this.chart.data.datasets[t._datasetIndex],t._index);t._model.radius=t.custom&&t.custom.radius?t.custom.radius:i.getValueAtIndexOrDefault(this.getDataset().radius,e,this.chart.options.elements.point.radius),t._model.backgroundColor=t.custom&&t.custom.backgroundColor?t.custom.backgroundColor:i.getValueAtIndexOrDefault(this.getDataset().pointBackgroundColor,e,this.chart.options.elements.point.backgroundColor),t._model.borderColor=t.custom&&t.custom.borderColor?t.custom.borderColor:i.getValueAtIndexOrDefault(this.getDataset().pointBorderColor,e,this.chart.options.elements.point.borderColor),t._model.borderWidth=t.custom&&t.custom.borderWidth?t.custom.borderWidth:i.getValueAtIndexOrDefault(this.getDataset().pointBorderWidth,e,this.chart.options.elements.point.borderWidth)}})}.call(this),function(){"use strict";var t=this,e=t.Chart,i=e.helpers;e.defaults.polarArea={scale:{type:"radialLinear",lineArc:!0},animateRotate:!0,animateScale:!0,tooltips:{callbacks:{title:function(){return""},label:function(t,e){return e.labels[t.index]+": "+t.yLabel}}}},e.controllers.polarArea=function(t,e){this.initialize.call(this,t,e)},i.extend(e.controllers.polarArea.prototype,{initialize:function(t,e){this.chart=t,this.index=e,this.linkScales(),this.addElements()},updateIndex:function(t){this.index=t},linkScales:function(){},getDataset:function(){return this.chart.data.datasets[this.index]},getScaleForId:function(t){return this.chart.scales[t]},addElements:function(){this.getDataset().metaData=this.getDataset().metaData||[],i.each(this.getDataset().data,function(t,i){this.getDataset().metaData[i]=this.getDataset().metaData[i]||new e.elements.Arc({_chart:this.chart.chart,_datasetIndex:this.index,_index:i})},this)},addElementAndReset:function(t){this.getDataset().metaData=this.getDataset().metaData||[];var i=new e.elements.Arc({_chart:this.chart.chart,_datasetIndex:this.index,_index:t});this.updateElement(i,t,!0),this.getDataset().metaData.splice(t,0,i)},removeElement:function(t){this.getDataset().metaData.splice(t,1)},reset:function(){this.update(!0)},buildOrUpdateElements:function(){var t=this.getDataset().data.length,e=this.getDataset().metaData.length;if(e>t)this.getDataset().metaData.splice(t,e-t);else if(t>e)for(var i=e;t>i;++i)this.addElementAndReset(i)},getVisibleDatasetCount:function(){return i.where(this.chart.data.datasets,function(t){return i.isDatasetVisible(t)}).length},update:function(t){this.chart.outerRadius=Math.max((i.min([this.chart.chart.width,this.chart.chart.height])-this.chart.options.elements.arc.borderWidth/2)/2,0),this.chart.innerRadius=Math.max(this.chart.options.cutoutPercentage?this.chart.outerRadius/100*this.chart.options.cutoutPercentage:1,0),this.chart.radiusLength=(this.chart.outerRadius-this.chart.innerRadius)/this.getVisibleDatasetCount(),this.getDataset().total=0,i.each(this.getDataset().data,function(t){this.getDataset().total+=Math.abs(t)},this),this.outerRadius=this.chart.outerRadius-this.chart.radiusLength*this.index,this.innerRadius=this.outerRadius-this.chart.radiusLength,i.each(this.getDataset().metaData,function(e,i){this.updateElement(e,i,t)},this)},updateElement:function(t,e,a){var s=1/this.getDataset().data.length*2,o=-.5*Math.PI+Math.PI*s*e,n=o+s*Math.PI,r={x:this.chart.chart.width/2,y:this.chart.chart.height/2,innerRadius:0,outerRadius:this.chart.options.animateScale?0:this.chart.scale.getDistanceFromCenterForValue(this.getDataset().data[e]),startAngle:this.chart.options.animateRotate?Math.PI*-.5:o,endAngle:this.chart.options.animateRotate?Math.PI*-.5:n,backgroundColor:t.custom&&t.custom.backgroundColor?t.custom.backgroundColor:i.getValueAtIndexOrDefault(this.getDataset().backgroundColor,e,this.chart.options.elements.arc.backgroundColor),hoverBackgroundColor:t.custom&&t.custom.hoverBackgroundColor?t.custom.hoverBackgroundColor:i.getValueAtIndexOrDefault(this.getDataset().hoverBackgroundColor,e,this.chart.options.elements.arc.hoverBackgroundColor),borderWidth:t.custom&&t.custom.borderWidth?t.custom.borderWidth:i.getValueAtIndexOrDefault(this.getDataset().borderWidth,e,this.chart.options.elements.arc.borderWidth),borderColor:t.custom&&t.custom.borderColor?t.custom.borderColor:i.getValueAtIndexOrDefault(this.getDataset().borderColor,e,this.chart.options.elements.arc.borderColor),label:i.getValueAtIndexOrDefault(this.chart.data.labels,e,this.chart.data.labels[e])};i.extend(t,{_chart:this.chart.chart,_datasetIndex:this.index,_index:e,_scale:this.chart.scale,_model:a?r:{x:this.chart.chart.width/2,y:this.chart.chart.height/2,innerRadius:0,outerRadius:this.chart.scale.getDistanceFromCenterForValue(this.getDataset().data[e]),startAngle:o,endAngle:n,backgroundColor:t.custom&&t.custom.backgroundColor?t.custom.backgroundColor:i.getValueAtIndexOrDefault(this.getDataset().backgroundColor,e,this.chart.options.elements.arc.backgroundColor),hoverBackgroundColor:t.custom&&t.custom.hoverBackgroundColor?t.custom.hoverBackgroundColor:i.getValueAtIndexOrDefault(this.getDataset().hoverBackgroundColor,e,this.chart.options.elements.arc.hoverBackgroundColor),borderWidth:t.custom&&t.custom.borderWidth?t.custom.borderWidth:i.getValueAtIndexOrDefault(this.getDataset().borderWidth,e,this.chart.options.elements.arc.borderWidth),borderColor:t.custom&&t.custom.borderColor?t.custom.borderColor:i.getValueAtIndexOrDefault(this.getDataset().borderColor,e,this.chart.options.elements.arc.borderColor),label:i.getValueAtIndexOrDefault(this.chart.data.labels,e,this.chart.data.labels[e])}}),t.pivot()},draw:function(t){var e=t||1;i.each(this.getDataset().metaData,function(t){t.transition(e).draw()},this)},setHoverStyle:function(t){var e=this.chart.data.datasets[t._datasetIndex],a=t._index;t._model.backgroundColor=t.custom&&t.custom.hoverBackgroundColor?t.custom.hoverBackgroundColor:i.getValueAtIndexOrDefault(e.hoverBackgroundColor,a,i.color(t._model.backgroundColor).saturate(.5).darken(.1).rgbString()),t._model.borderColor=t.custom&&t.custom.hoverBorderColor?t.custom.hoverBorderColor:i.getValueAtIndexOrDefault(e.hoverBorderColor,a,i.color(t._model.borderColor).saturate(.5).darken(.1).rgbString()),t._model.borderWidth=t.custom&&t.custom.hoverBorderWidth?t.custom.hoverBorderWidth:i.getValueAtIndexOrDefault(e.borderWidth,a,t._model.borderWidth)},removeHoverStyle:function(t){var e=(this.chart.data.datasets[t._datasetIndex],t._index);t._model.backgroundColor=t.custom&&t.custom.backgroundColor?t.custom.backgroundColor:i.getValueAtIndexOrDefault(this.getDataset().backgroundColor,e,this.chart.options.elements.arc.backgroundColor),t._model.borderColor=t.custom&&t.custom.borderColor?t.custom.borderColor:i.getValueAtIndexOrDefault(this.getDataset().borderColor,e,this.chart.options.elements.arc.borderColor),t._model.borderWidth=t.custom&&t.custom.borderWidth?t.custom.borderWidth:i.getValueAtIndexOrDefault(this.getDataset().borderWidth,e,this.chart.options.elements.arc.borderWidth)},calculateCircumference:function(t){return this.getDataset().total>0?2*Math.PI*(t/this.getDataset().total):0},updateScaleRange:function(){i.extend(this.chart.scale,{size:i.min([this.chart.width,this.chart.height]),xCenter:this.chart.width/2,yCenter:this.chart.height/2})}})}.call(this),function(){"use strict";var t=this,e=t.Chart,i=e.helpers;e.defaults.radar={scale:{type:"radialLinear"},elements:{line:{tension:0}}},e.controllers.radar=function(t,e){this.initialize.call(this,t,e)},i.extend(e.controllers.radar.prototype,{initialize:function(t,e){this.chart=t,this.index=e,this.linkScales(),this.addElements()},updateIndex:function(t){this.index=t},linkScales:function(){},getDataset:function(){return this.chart.data.datasets[this.index]},getScaleForId:function(t){return this.chart.scales[t]},addElements:function(){this.getDataset().metaData=this.getDataset().metaData||[],this.getDataset().metaDataset=this.getDataset().metaDataset||new e.elements.Line({_chart:this.chart.chart,_datasetIndex:this.index,_points:this.getDataset().metaData,_loop:!0}),i.each(this.getDataset().data,function(t,i){this.getDataset().metaData[i]=this.getDataset().metaData[i]||new e.elements.Point({_chart:this.chart.chart,_datasetIndex:this.index,_index:i,_model:{x:0,y:0}})},this)},addElementAndReset:function(t){this.getDataset().metaData=this.getDataset().metaData||[];var i=new e.elements.Point({_chart:this.chart.chart,_datasetIndex:this.index,_index:t});this.updateElement(i,t,!0),this.getDataset().metaData.splice(t,0,i),this.updateBezierControlPoints()},removeElement:function(t){this.getDataset().metaData.splice(t,1)},reset:function(){this.update(!0)},buildOrUpdateElements:function(){var t=this.getDataset().data.length,e=this.getDataset().metaData.length;if(e>t)this.getDataset().metaData.splice(t,e-t);else if(t>e)for(var i=e;t>i;++i)this.addElementAndReset(i)},update:function(t){var e,a=(this.getDataset().metaDataset,this.getDataset().metaData),s=this.chart.scale;e=s.min<0&&s.max<0?s.getPointPositionForValue(0,s.max):s.min>0&&s.max>0?s.getPointPositionForValue(0,s.min):s.getPointPositionForValue(0,0),i.extend(this.getDataset().metaDataset,{_datasetIndex:this.index,_children:this.getDataset().metaData,_model:{tension:this.getDataset().tension||this.chart.options.elements.line.tension,backgroundColor:this.getDataset().backgroundColor||this.chart.options.elements.line.backgroundColor,borderWidth:this.getDataset().borderWidth||this.chart.options.elements.line.borderWidth,borderColor:this.getDataset().borderColor||this.chart.options.elements.line.borderColor,fill:void 0!==this.getDataset().fill?this.getDataset().fill:this.chart.options.elements.line.fill,scaleTop:s.top,scaleBottom:s.bottom,scaleZero:e}}),this.getDataset().metaDataset.pivot(),i.each(a,function(e,i){this.updateElement(e,i,t)},this),this.updateBezierControlPoints()},updateElement:function(t,e,a){var s=this.chart.scale.getPointPositionForValue(e,this.getDataset().data[e]);i.extend(t,{_datasetIndex:this.index,_index:e,_scale:this.chart.scale,_model:{x:a?this.chart.scale.xCenter:s.x,y:a?this.chart.scale.yCenter:s.y,tension:t.custom&&t.custom.tension?t.custom.tension:this.chart.options.elements.line.tension,radius:t.custom&&t.custom.radius?t.custom.pointRadius:i.getValueAtIndexOrDefault(this.getDataset().pointRadius,e,this.chart.options.elements.point.radius),backgroundColor:t.custom&&t.custom.backgroundColor?t.custom.backgroundColor:i.getValueAtIndexOrDefault(this.getDataset().pointBackgroundColor,e,this.chart.options.elements.point.backgroundColor),borderColor:t.custom&&t.custom.borderColor?t.custom.borderColor:i.getValueAtIndexOrDefault(this.getDataset().pointBorderColor,e,this.chart.options.elements.point.borderColor),borderWidth:t.custom&&t.custom.borderWidth?t.custom.borderWidth:i.getValueAtIndexOrDefault(this.getDataset().pointBorderWidth,e,this.chart.options.elements.point.borderWidth),hitRadius:t.custom&&t.custom.hitRadius?t.custom.hitRadius:i.getValueAtIndexOrDefault(this.getDataset().hitRadius,e,this.chart.options.elements.point.hitRadius)}}),t._model.skip=t.custom&&t.custom.skip?t.custom.skip:isNaN(t._model.x)||isNaN(t._model.y)},updateBezierControlPoints:function(){i.each(this.getDataset().metaData,function(t,e){var a=i.splineCurve(i.previousItem(this.getDataset().metaData,e,!0)._model,t._model,i.nextItem(this.getDataset().metaData,e,!0)._model,t._model.tension);t._model.controlPointPreviousX=a.previous.x,t._model.controlPointNextX=a.next.x,t._model.controlPointNextY=a.next.y>this.chart.chartArea.bottom?this.chart.chartArea.bottom:a.next.y<this.chart.chartArea.top?this.chart.chartArea.top:a.next.y,t._model.controlPointPreviousY=a.previous.y>this.chart.chartArea.bottom?this.chart.chartArea.bottom:a.previous.y<this.chart.chartArea.top?this.chart.chartArea.top:a.previous.y,t.pivot()},this)},draw:function(t){var e=t||1;i.each(this.getDataset().metaData,function(t){t.transition(e)},this),this.getDataset().metaDataset.transition(e).draw(),i.each(this.getDataset().metaData,function(t){t.draw()})},setHoverStyle:function(t){var e=this.chart.data.datasets[t._datasetIndex],a=t._index;t._model.radius=t.custom&&t.custom.radius?t.custom.radius:i.getValueAtIndexOrDefault(e.pointHoverRadius,a,this.chart.options.elements.point.hoverRadius),t._model.backgroundColor=t.custom&&t.custom.hoverBackgroundColor?t.custom.hoverBackgroundColor:i.getValueAtIndexOrDefault(e.pointHoverBackgroundColor,a,i.color(t._model.backgroundColor).saturate(.5).darken(.1).rgbString()),t._model.borderColor=t.custom&&t.custom.hoverBorderColor?t.custom.hoverBorderColor:i.getValueAtIndexOrDefault(e.pointHoverBorderColor,a,i.color(t._model.borderColor).saturate(.5).darken(.1).rgbString()),t._model.borderWidth=t.custom&&t.custom.hoverBorderWidth?t.custom.hoverBorderWidth:i.getValueAtIndexOrDefault(e.pointBorderWidth,a,t._model.borderWidth)},removeHoverStyle:function(t){var e=(this.chart.data.datasets[t._datasetIndex],t._index);t._model.radius=t.custom&&t.custom.radius?t.custom.radius:i.getValueAtIndexOrDefault(this.getDataset().radius,e,this.chart.options.elements.point.radius),t._model.backgroundColor=t.custom&&t.custom.backgroundColor?t.custom.backgroundColor:i.getValueAtIndexOrDefault(this.getDataset().pointBackgroundColor,e,this.chart.options.elements.point.backgroundColor),t._model.borderColor=t.custom&&t.custom.borderColor?t.custom.borderColor:i.getValueAtIndexOrDefault(this.getDataset().pointBorderColor,e,this.chart.options.elements.point.borderColor),t._model.borderWidth=t.custom&&t.custom.borderWidth?t.custom.borderWidth:i.getValueAtIndexOrDefault(this.getDataset().pointBorderWidth,e,this.chart.options.elements.point.borderWidth)}})}.call(this),function(){"use strict";var t=this,e=t.Chart,i=(e.helpers,{position:"bottom"}),a=e.Scale.extend({buildTicks:function(){this.ticks=this.data.labels},getLabelForIndex:function(t){return this.ticks[t]},getPixelForValue:function(t,e,i,a){if(this.isHorizontal()){var s=this.width-(this.paddingLeft+this.paddingRight),o=s/Math.max(this.data.labels.length-(this.options.gridLines.offsetGridLines?0:1),1),n=o*e+this.paddingLeft;return this.options.gridLines.offsetGridLines&&a&&(n+=o/2),this.left+Math.round(n)}var r=this.height-(this.paddingTop+this.paddingBottom),h=r/Math.max(this.data.labels.length-(this.options.gridLines.offsetGridLines?0:1),1),l=h*e+this.paddingTop;return this.options.gridLines.offsetGridLines&&a&&(l+=h/2),this.top+Math.round(l)}});e.scaleService.registerScaleType("category",a,i)}.call(this),function(){"use strict";var t=this,e=t.Chart,i=e.helpers,a={position:"left",ticks:{callback:function(t,e,a){var s=a[1]-a[0];Math.abs(s)>1&&t!==Math.floor(t)&&(s=t-Math.floor(t));var o=i.log10(Math.abs(s)),n="";if(0!==t){var r=-1*Math.floor(o);r=Math.max(Math.min(r,20),0),n=t.toFixed(r)}else n="0";return n}}},s=e.Scale.extend({buildTicks:function(){this.min=null,this.max=null;var t=[],e=[];if(this.options.stacked){i.each(this.data.datasets,function(a){i.isDatasetVisible(a)&&(this.isHorizontal()?a.xAxisID===this.id:a.yAxisID===this.id)&&i.each(a.data,function(i,a){var s=this.getRightValue(i);isNaN(s)||(t[a]=t[a]||0,e[a]=e[a]||0,this.options.relativePoints?t[a]=100:0>s?e[a]+=s:t[a]+=s)},this)},this);var a=t.concat(e);this.min=i.min(a),this.max=i.max(a)}else i.each(this.data.datasets,function(t){i.isDatasetVisible(t)&&(this.isHorizontal()?t.xAxisID===this.id:t.yAxisID===this.id)&&i.each(t.data,function(t){var e=this.getRightValue(t);isNaN(e)||(null===this.min?this.min=e:e<this.min&&(this.min=e),null===this.max?this.max=e:e>this.max&&(this.max=e))},this)},this);this.ticks=[];var s;if(s=this.isHorizontal()?Math.min(11,Math.ceil(this.width/50)):Math.min(11,Math.ceil(this.height/(2*this.options.ticks.fontSize))),s=Math.max(2,s),this.options.ticks.beginAtZero){var o=i.sign(this.min),n=i.sign(this.max);0>o&&0>n?this.max=0:o>0&&n>0&&(this.min=0)}this.options.ticks.suggestedMin&&(this.min=Math.min(this.min,this.options.ticks.suggestedMin)),this.options.ticks.suggestedMax&&(this.max=Math.max(this.max,this.options.ticks.suggestedMax)),this.min===this.max&&(this.min--,this.max++);for(var r=i.niceNum(this.max-this.min,!1),h=i.niceNum(r/(s-1),!0),l=Math.floor(this.min/h)*h,c=Math.ceil(this.max/h)*h,d=Math.ceil((c-l)/h),u=0;d>=u;++u)this.ticks.push(l+u*h);("left"==this.options.position||"right"==this.options.position)&&this.ticks.reverse(),this.max=i.max(this.ticks),this.min=i.min(this.ticks),this.options.ticks.reverse?(this.ticks.reverse(),this.start=this.max,this.end=this.min):(this.start=this.min,this.end=this.max),this.zeroLineIndex=this.ticks.indexOf(0)},getLabelForIndex:function(t,e){return this.getRightValue(this.data.datasets[e].data[t])},getPixelForValue:function(t){var e,i=this.getRightValue(t),a=this.end-this.start;if(this.isHorizontal()){var s=this.width-(this.paddingLeft+this.paddingRight);return e=this.left+s/a*(i-this.start),Math.round(e+this.paddingLeft)}var o=this.height-(this.paddingTop+this.paddingBottom);return e=this.bottom-this.paddingBottom-o/a*(i-this.start),Math.round(e)}});e.scaleService.registerScaleType("linear",s,a)}.call(this),function(){"use strict";var t=this,e=t.Chart,i=e.helpers,a={position:"left",ticks:{callback:function(t){var i=t/Math.pow(10,Math.floor(e.helpers.log10(t)));return 1===i||2===i||5===i?t.toExponential():""}}},s=e.Scale.extend({buildTicks:function(){this.min=null,this.max=null;var t=[];this.options.stacked?(i.each(this.data.datasets,function(e){i.isDatasetVisible(e)&&(this.isHorizontal()?e.xAxisID===this.id:e.yAxisID===this.id)&&i.each(e.data,function(e,i){var a=this.getRightValue(e);isNaN(a)||(t[i]=t[i]||0,this.options.relativePoints?t[i]=100:t[i]+=a)},this)},this),this.min=i.min(t),this.max=i.max(t)):i.each(this.data.datasets,function(t){i.isDatasetVisible(t)&&(this.isHorizontal()?t.xAxisID===this.id:t.yAxisID===this.id)&&i.each(t.data,function(t){var e=this.getRightValue(t);isNaN(e)||(null===this.min?this.min=e:e<this.min&&(this.min=e),null===this.max?this.max=e:e>this.max&&(this.max=e))},this)},this),this.min===this.max&&(0!==this.min&&null!==this.min?(this.min=Math.pow(10,Math.floor(i.log10(this.min))-1),this.max=Math.pow(10,Math.floor(i.log10(this.max))+1)):(this.min=1,this.max=10)),this.tickValues=[];for(var e=Math.floor(i.log10(this.min)),a=Math.ceil(i.log10(this.max)),s=e;a>s;++s)for(var o=1;10>o;++o)this.tickValues.push(o*Math.pow(10,s));this.tickValues.push(1*Math.pow(10,a)),("left"==this.options.position||"right"==this.options.position)&&this.tickValues.reverse(),this.max=i.max(this.tickValues),this.min=i.min(this.tickValues),this.options.ticks.reverse?(this.tickValues.reverse(),this.start=this.max,this.end=this.min):(this.start=this.min,this.end=this.max),this.ticks=this.tickValues.slice()},getLabelForIndex:function(t,e){return this.getRightValue(this.data.datasets[e].data[t])},getPixelForTick:function(t,e){return this.getPixelForValue(this.tickValues[t],null,null,e)},getPixelForValue:function(t){var e,a=this.getRightValue(t),s=i.log10(this.end)-i.log10(this.start);if(this.isHorizontal()){if(0!==a){var o=this.width-(this.paddingLeft+this.paddingRight);return e=this.left+o/s*(i.log10(a)-i.log10(this.start)),e+this.paddingLeft}e=this.left+this.paddingLeft}else{if(0!==a){var n=this.height-(this.paddingTop+this.paddingBottom);return this.bottom-this.paddingBottom-n/s*(i.log10(a)-i.log10(this.start))}e=this.top+this.paddingTop}}});e.scaleService.registerScaleType("logarithmic",s,a)}.call(this),function(){"use strict";var t=this,e=t.Chart,i=e.helpers,a={display:!0,animate:!0,lineArc:!1,position:"chartArea",angleLines:{show:!0,color:"rgba(0, 0, 0, 0.1)",lineWidth:1},ticks:{showLabelBackdrop:!0,backdropColor:"rgba(255,255,255,0.75)",backdropPaddingY:2,backdropPaddingX:2},pointLabels:{fontFamily:"'Arial'",fontStyle:"normal",fontSize:10,fontColor:"#666"}},s=e.Scale.extend({getValueCount:function(){return this.data.labels.length},setDimensions:function(){this.width=this.maxWidth,this.height=this.maxHeight,this.xCenter=Math.round(this.width/2),this.yCenter=Math.round(this.height/2);var t=i.min([this.height,this.width]);this.drawingArea=this.options.display?t/2-(this.options.ticks.fontSize/2+this.options.ticks.backdropPaddingY):t/2},buildTicks:function(){this.min=null,this.max=null,i.each(this.data.datasets,function(t){i.isDatasetVisible(t)&&i.each(t.data,function(t){var e=this.getRightValue(t);isNaN(e)||(null===this.min?this.min=e:e<this.min&&(this.min=e),null===this.max?this.max=e:e>this.max&&(this.max=e))},this)},this),this.min===this.max&&(this.min--,this.max++),this.ticks=[];var t=Math.min(11,Math.ceil(this.drawingArea/(1.5*this.options.ticks.fontSize)));if(t=Math.max(2,t),this.options.ticks.beginAtZero){var e=i.sign(this.min),a=i.sign(this.max);0>e&&0>a?this.max=0:e>0&&a>0&&(this.min=0)}for(var s=i.niceNum(this.max-this.min,!1),o=i.niceNum(s/(t-1),!0),n=Math.floor(this.min/o)*o,r=Math.ceil(this.max/o)*o,h=n;r>=h;h+=o)this.ticks.push(h);this.max=i.max(this.ticks),this.min=i.min(this.ticks),this.options.ticks.reverse?(this.ticks.reverse(),this.start=this.max,this.end=this.min):(this.start=this.min,this.end=this.max),this.zeroLineIndex=this.ticks.indexOf(0)},getLabelForIndex:function(t,e){return this.getRightValue(this.data.datasets[e].data[t])},getCircumference:function(){return 2*Math.PI/this.getValueCount()},fit:function(){var t,e,a,s,o,n,r,h,l,c,d,u,g=i.min([this.height/2-this.options.pointLabels.fontSize-5,this.width/2]),m=this.width,p=0;for(this.ctx.font=i.fontString(this.options.pointLabels.fontSize,this.options.pointLabels.fontStyle,this.options.pointLabels.fontFamily),e=0;e<this.getValueCount();e++)t=this.getPointPosition(e,g),a=this.ctx.measureText(this.options.ticks.callback(this.data.labels[e])).width+5,0===e||e===this.getValueCount()/2?(s=a/2,t.x+s>m&&(m=t.x+s,o=e),t.x-s<p&&(p=t.x-s,r=e)):e<this.getValueCount()/2?t.x+a>m&&(m=t.x+a,o=e):e>this.getValueCount()/2&&t.x-a<p&&(p=t.x-a,r=e);l=p,c=Math.ceil(m-this.width),n=this.getIndexAngle(o),h=this.getIndexAngle(r),d=c/Math.sin(n+Math.PI/2),u=l/Math.sin(h+Math.PI/2),d=i.isNumber(d)?d:0,u=i.isNumber(u)?u:0,this.drawingArea=Math.round(g-(u+d)/2),this.setCenterPoint(u,d)},setCenterPoint:function(t,e){var i=this.width-e-this.drawingArea,a=t+this.drawingArea;this.xCenter=Math.round((a+i)/2+this.left),this.yCenter=Math.round(this.height/2+this.top)},getIndexAngle:function(t){var e=2*Math.PI/this.getValueCount();return t*e-Math.PI/2},getDistanceFromCenterForValue:function(t){if(null===t)return 0;var e=this.drawingArea/(this.max-this.min);return this.options.reverse?(this.max-t)*e:(t-this.min)*e},getPointPosition:function(t,e){var i=this.getIndexAngle(t);return{x:Math.round(Math.cos(i)*e)+this.xCenter,y:Math.round(Math.sin(i)*e)+this.yCenter}},getPointPositionForValue:function(t,e){return this.getPointPosition(t,this.getDistanceFromCenterForValue(e))},draw:function(){if(this.options.display){var t=this.ctx;if(i.each(this.ticks,function(e,a){if(a>0||this.options.reverse){var s=this.getDistanceFromCenterForValue(this.ticks[a]),o=this.yCenter-s;if(this.options.gridLines.show)if(t.strokeStyle=this.options.gridLines.color,t.lineWidth=this.options.gridLines.lineWidth,this.options.lineArc)t.beginPath(),t.arc(this.xCenter,this.yCenter,s,0,2*Math.PI),t.closePath(),t.stroke();else{t.beginPath();for(var n=0;n<this.getValueCount();n++){var r=this.getPointPosition(n,this.getDistanceFromCenterForValue(this.ticks[a]));0===n?t.moveTo(r.x,r.y):t.lineTo(r.x,r.y)}t.closePath(),t.stroke()}if(this.options.ticks.show){if(t.font=i.fontString(this.options.ticks.fontSize,this.options.ticks.fontStyle,this.options.ticks.fontFamily),this.options.ticks.showLabelBackdrop){var h=t.measureText(e).width;t.fillStyle=this.options.ticks.backdropColor,t.fillRect(this.xCenter-h/2-this.options.ticks.backdropPaddingX,o-this.options.ticks.fontSize/2-this.options.ticks.backdropPaddingY,h+2*this.options.ticks.backdropPaddingX,this.options.ticks.fontSize+2*this.options.ticks.backdropPaddingY)}t.textAlign="center",t.textBaseline="middle",t.fillStyle=this.options.ticks.fontColor,t.fillText(e,this.xCenter,o)}}},this),!this.options.lineArc){t.lineWidth=this.options.angleLines.lineWidth,t.strokeStyle=this.options.angleLines.color;for(var e=this.getValueCount()-1;e>=0;e--){if(this.options.angleLines.show){var a=this.getPointPosition(e,this.getDistanceFromCenterForValue(this.options.reverse?this.min:this.max));t.beginPath(),t.moveTo(this.xCenter,this.yCenter),t.lineTo(a.x,a.y),t.stroke(),t.closePath()}var s=this.getPointPosition(e,this.getDistanceFromCenterForValue(this.options.reverse?this.min:this.max)+5);t.font=i.fontString(this.options.pointLabels.fontSize,this.options.pointLabels.fontStyle,this.options.pointLabels.fontFamily),t.fillStyle=this.options.pointLabels.fontColor;var o=this.data.labels.length,n=this.data.labels.length/2,r=n/2,h=r>e||e>o-r,l=e===r||e===o-r;t.textAlign=0===e?"center":e===n?"center":n>e?"left":"right",t.textBaseline=l?"middle":h?"bottom":"top",t.fillText(this.data.labels[e],s.x,s.y)}}}}});e.scaleService.registerScaleType("radialLinear",s,a)}.call(this),function(){"use strict";if(!moment)return void console.warn("Chart.js - Moment.js could not be found! You must include it before Chart.js to use the time scale. Download at http://momentjs.com/");var t=this,e=t.Chart,i=e.helpers,a={units:["millisecond","second","minute","hour","day","week","month","quarter","year"],unit:{millisecond:{display:"SSS [ms]",maxStep:1e3},second:{display:"h:mm:ss a",maxStep:60},minute:{display:"h:mm:ss a",maxStep:60},hour:{display:"MMM D, hA",maxStep:24},day:{display:"ll",maxStep:7},week:{display:"ll",maxStep:4.3333},month:{display:"MMM YYYY",maxStep:12},quarter:{display:"[Q]Q - YYYY",maxStep:4},year:{display:"YYYY",maxStep:!1}}},s={position:"bottom",time:{format:!1,unit:!1,round:!1,displayFormat:!1}},o=e.Scale.extend({getLabelMoment:function(t,e){return this.labelMoments[t][e]},buildLabelMoments:function(){var t=[];this.data.labels&&this.data.labels.length>0?(i.each(this.data.labels,function(e){var i=this.parseTime(e);this.options.time.round&&i.startOf(this.options.time.round),t.push(i)},this),this.firstTick=this.options.time.min?this.parseTime(this.options.time.min):moment.min.call(this,t),this.lastTick=this.options.time.max?this.parseTime(this.options.time.max):moment.max.call(this,t)):(this.firstTick=null,this.lastTick=null),i.each(this.data.datasets,function(e){var a=[];"object"==typeof e.data[0]?i.each(e.data,function(t){var e=this.parseTime(this.getRightValue(t));this.options.time.round&&e.startOf(this.options.time.round),a.push(e),this.firstTick=null!==this.firstTick?moment.min(this.firstTick,e):e,this.lastTick=null!==this.lastTick?moment.max(this.lastTick,e):e},this):a=t,this.labelMoments.push(a)},this),this.firstTick=this.firstTick.clone(),this.lastTick=this.lastTick.clone()},buildTicks:function(){if(this.ticks=[],this.labelMoments=[],this.buildLabelMoments(),this.options.time.unit)this.tickUnit=this.options.time.unit||"day",this.displayFormat=a.unit[this.tickUnit].display,this.tickRange=Math.ceil(this.lastTick.diff(this.firstTick,this.tickUnit,!0));else{var t=this.width-(this.paddingLeft+this.paddingRight),e=t/this.options.ticks.fontSize+4,s=this.options.time.round?0:2;this.tickUnit="millisecond",this.tickRange=Math.ceil(this.lastTick.diff(this.firstTick,this.tickUnit,!0)+s),this.displayFormat=a.unit[this.tickUnit].display,i.each(a.units,function(t){this.tickRange<=e||(this.tickUnit=t,this.tickRange=Math.ceil(this.lastTick.diff(this.firstTick,this.tickUnit)+s),this.displayFormat=a.unit[t].display)},this)}this.firstTick.startOf(this.tickUnit),this.lastTick.endOf(this.tickUnit),this.smallestLabelSeparation=this.width,i.each(this.data.datasets,function(t,e){for(var i=1;i<this.labelMoments[e].length;i++)this.smallestLabelSeparation=Math.min(this.smallestLabelSeparation,this.labelMoments[e][i].diff(this.labelMoments[e][i-1],this.tickUnit,!0))},this),this.options.time.displayFormat&&(this.displayFormat=this.options.time.displayFormat);for(var o=0;o<=this.tickRange;++o)this.ticks.push(this.firstTick.clone().add(o,this.tickUnit))},getLabelForIndex:function(t,e){var i=this.data.labels&&t<this.data.labels.length?this.data.labels[t]:"";return"object"==typeof this.data.datasets[e].data[0]&&(i=this.getRightValue(this.data.datasets[e].data[t])),i},convertTicksToLabels:function(){this.ticks=this.ticks.map(function(t,e,i){var s=t.format(this.options.time.displayFormat?this.options.time.displayFormat:a.unit[this.tickUnit].display);return this.options.ticks.userCallback?this.options.ticks.userCallback(s,e,i):s},this)},getPixelForValue:function(t,e,i){var a=this.getLabelMoment(i,e),s=a.diff(this.firstTick,this.tickUnit,!0),o=s/this.tickRange;if(this.isHorizontal()){var n=this.width-(this.paddingLeft+this.paddingRight),r=(n/Math.max(this.ticks.length-1,1),n*o+this.paddingLeft);return this.left+Math.round(r)}var h=this.height-(this.paddingTop+this.paddingBottom),l=(h/Math.max(this.ticks.length-1,1),h*o+this.paddingTop);return this.top+Math.round(l)},parseTime:function(t){return"function"==typeof t.getMonth||"number"==typeof t?moment(t):t.isValid&&t.isValid()?t:"string"!=typeof this.options.time.format&&this.options.time.format.call?this.options.time.format(t):moment(t,this.options.time.format)}});e.scaleService.registerScaleType("time",o,s)}.call(this),function(){"use strict";var t=this,e=t.Chart,i=e.helpers;e.defaults.global.elements.arc={backgroundColor:e.defaults.global.defaultColor,borderColor:"#fff",borderWidth:2},e.elements.Arc=e.Element.extend({inLabelRange:function(t){var e=this._view;return e?Math.pow(t-e.x,2)<Math.pow(e.radius+e.hoverRadius,2):!1},inRange:function(t,e){var a=this._view;if(a){var s=i.getAngleFromPoint(a,{x:t,y:e}),o=a.startAngle<-.5*Math.PI?a.startAngle+2*Math.PI:a.startAngle>1.5*Math.PI?a.startAngle-2*Math.PI:a.startAngle,n=a.endAngle<-.5*Math.PI?a.endAngle+2*Math.PI:a.endAngle>1.5*Math.PI?a.endAngle-2*Math.PI:a.endAngle,r=s.angle>=o&&s.angle<=n,h=s.distance>=a.innerRadius&&s.distance<=a.outerRadius;return r&&h}return!1},tooltipPosition:function(){var t=this._view,e=t.startAngle+(t.endAngle-t.startAngle)/2,i=(t.outerRadius-t.innerRadius)/2+t.innerRadius;return{x:t.x+Math.cos(e)*i,y:t.y+Math.sin(e)*i}},draw:function(){var t=this._chart.ctx,e=this._view;t.beginPath(),t.arc(e.x,e.y,e.outerRadius,e.startAngle,e.endAngle),t.arc(e.x,e.y,e.innerRadius,e.endAngle,e.startAngle,!0),t.closePath(),t.strokeStyle=e.borderColor,t.lineWidth=e.borderWidth,t.fillStyle=e.backgroundColor,t.fill(),t.lineJoin="bevel",e.borderWidth&&t.stroke()}})}.call(this),function(){"use strict";var t=this,e=t.Chart,i=e.helpers;e.defaults.global.elements.line={tension:.4,backgroundColor:e.defaults.global.defaultColor,borderWidth:3,borderColor:e.defaults.global.defaultColor,borderCapStyle:"butt",borderDash:[],borderDashOffset:0,borderJoinStyle:"miter",fill:!0},e.elements.Line=e.Element.extend({draw:function(){var t=this._view,a=this._chart.ctx,s=this._children[0],o=this._children[this._children.length-1];if(a.save(),i.each(this._children,function(e,s){var o=i.previousItem(this._children,s),n=i.nextItem(this._children,s);return s||a.moveTo(e._view.x,t.scaleZero),e._view.skip&&!this.loop?(a.lineTo(o._view.x,t.scaleZero),void a.moveTo(n._view.x,t.scaleZero)):o._view.skip?void a.lineTo(e._view.x,e._view.y):t.tension>0&&s?void a.bezierCurveTo(o._view.controlPointNextX,o._view.controlPointNextY,e._view.controlPointPreviousX,e._view.controlPointPreviousY,e._view.x,e._view.y):void a.lineTo(e._view.x,e._view.y)},this),this._loop){if(t.tension>0&&!s._view.skip)return void a.bezierCurveTo(o._view.controlPointNextX,o._view.controlPointNextY,s._view.controlPointPreviousX,s._view.controlPointPreviousY,s._view.x,s._view.y);a.lineTo(s._view.x,s._view.y)}if(this._children.length>0&&t.fill&&(a.lineTo(this._children[this._children.length-1]._view.x,t.scaleZero),a.lineTo(this._children[0]._view.x,t.scaleZero),a.fillStyle=t.backgroundColor||e.defaults.global.defaultColor,a.closePath(),a.fill()),a.lineCap=t.borderCapStyle||e.defaults.global.elements.line.borderCapStyle,a.setLineDash&&a.setLineDash(t.borderDash||e.defaults.global.elements.line.borderDash),a.lineDashOffset=t.borderDashOffset||e.defaults.global.elements.line.borderDashOffset,a.lineJoin=t.borderJoinStyle||e.defaults.global.elements.line.borderJoinStyle,a.lineWidth=t.borderWidth||e.defaults.global.elements.line.borderWidth,a.strokeStyle=t.borderColor||e.defaults.global.defaultColor,a.beginPath(),i.each(this._children,function(e,s){var o=i.previousItem(this._children,s),n=i.nextItem(this._children,s);return s||a.moveTo(e._view.x,t.scaleZero),e._view.skip&&!this.loop?void a.moveTo(n._view.x,t.scaleZero):o._view.skip?void a.moveTo(e._view.x,e._view.y):(s||a.moveTo(e._view.x,e._view.y),t.tension>0&&s?void a.bezierCurveTo(o._view.controlPointNextX,o._view.controlPointNextY,e._view.controlPointPreviousX,e._view.controlPointPreviousY,e._view.x,e._view.y):void a.lineTo(e._view.x,e._view.y))},this),this._loop&&!s._view.skip){if(t.tension>0)return void a.bezierCurveTo(o._view.controlPointNextX,o._view.controlPointNextY,s._view.controlPointPreviousX,s._view.controlPointPreviousY,s._view.x,s._view.y);a.lineTo(s._view.x,s._view.y)}a.stroke(),a.restore()}})}.call(this),function(){"use strict";{var t=this,e=t.Chart;e.helpers}e.defaults.global.elements.point={radius:3,backgroundColor:e.defaults.global.defaultColor,borderWidth:1,borderColor:e.defaults.global.defaultColor,hitRadius:1,hoverRadius:4,hoverBorderWidth:1},e.elements.Point=e.Element.extend({inRange:function(t,e){var i=this._view;if(i){var a=i.hitRadius+i.radius;return Math.pow(t-i.x,2)+Math.pow(e-i.y,2)<Math.pow(a,2)}return!1},inLabelRange:function(t){var e=this._view;return e?Math.pow(t-e.x,2)<Math.pow(e.radius+e.hitRadius,2):!1},tooltipPosition:function(){var t=this._view;return{x:t.x,y:t.y,padding:t.radius+t.borderWidth}},draw:function(){var t=this._view,i=this._chart.ctx;t.skip||(t.radius>0||t.borderWidth>0)&&(i.beginPath(),i.arc(t.x,t.y,t.radius||e.defaults.global.elements.point.radius,0,2*Math.PI),i.closePath(),i.strokeStyle=t.borderColor||e.defaults.global.defaultColor,i.lineWidth=t.borderWidth||e.defaults.global.elements.point.borderWidth,i.fillStyle=t.backgroundColor||e.defaults.global.defaultColor,i.fill(),i.stroke())}})}.call(this),function(){"use strict";{var t=this,e=t.Chart;e.helpers}e.defaults.global.elements.rectangle={backgroundColor:e.defaults.global.defaultColor,borderWidth:0,borderColor:e.defaults.global.defaultColor},e.elements.Rectangle=e.Element.extend({draw:function(){var t=this._chart.ctx,e=this._view,i=e.width/2,a=e.x-i,s=e.x+i,o=e.base-(e.base-e.y),n=e.borderWidth/2;e.borderWidth&&(a+=n,s-=n,o+=n),t.beginPath(),t.fillStyle=e.backgroundColor,t.strokeStyle=e.borderColor,t.lineWidth=e.borderWidth,t.moveTo(a,e.base),t.lineTo(a,o),t.lineTo(s,o),t.lineTo(s,e.base),t.fill(),e.borderWidth&&t.stroke()},height:function(){var t=this._view;return t.base-t.y},inRange:function(t,e){var i=this._view,a=!1;return i&&(a=i.y<i.base?t>=i.x-i.width/2&&t<=i.x+i.width/2&&e>=i.y&&e<=i.base:t>=i.x-i.width/2&&t<=i.x+i.width/2&&e>=i.base&&e<=i.y),a},inLabelRange:function(t){var e=this._view;return e?t>=e.x-e.width/2&&t<=e.x+e.width/2:!1},tooltipPosition:function(){var t=this._view;return t.y<t.base?{x:t.x,y:t.y}:{x:t.x,y:t.base}}})}.call(this),function(){"use strict";{var t=this,e=t.Chart;e.helpers}e.Bar=function(t,i){return i.type="bar",new e(t,i)}}.call(this),function(){"use strict";var t=this,e=t.Chart,i=e.helpers,a={hover:{mode:"single"},scales:{xAxes:[{type:"linear",position:"bottom",id:"x-axis-0"}],yAxes:[{type:"linear",position:"left",id:"y-axis-0"}]},tooltips:{template:"(<%= value.x %>, <%= value.y %>)",multiTemplate:"<%if (datasetLabel){%><%=datasetLabel%>: <%}%>(<%= value.x %>, <%= value.y %>)"}};e.Bubble=function(t,s){return s.options=i.configMerge(a,s.options),s.type="bubble",new e(t,s)}}.call(this),function(){"use strict";var t=this,e=t.Chart,i=e.helpers,a={aspectRatio:1,legendTemplate:'<ul class="<%=name.toLowerCase()%>-legend"><% for (var i = 0; i < data.datasets[0].data.length; i++){%><li><span style="background-color:<%=data.datasets[0].backgroundColor[i]%>"><%if(data.labels && i < data.labels.length){%><%=data.labels[i]%><%}%></span></li><%}%></ul>'};e.Doughnut=function(t,s){return s.options=i.configMerge(a,s.options),s.type="doughnut",new e(t,s)}}.call(this),function(){"use strict";{var t=this,e=t.Chart;e.helpers}e.Line=function(t,i){return i.type="line",new e(t,i)}}.call(this),function(){"use strict";var t=this,e=t.Chart,i=e.helpers,a={aspectRatio:1,legendTemplate:'<ul class="<%=name.toLowerCase()%>-legend"><% for (var i = 0; i < data.datasets[0].data.length; i++){%><li><span style="background-color:<%=data.datasets[0].backgroundColor[i]%>"><%if(data.labels && i < data.labels.length){%><%=data.labels[i]%><%}%></span></li><%}%></ul>'};e.PolarArea=function(t,s){return s.options=i.configMerge(a,s.options),s.type="polarArea",new e(t,s)}}.call(this),function(){"use strict";var t=this,e=t.Chart,i=e.helpers,a={aspectRatio:1};e.Radar=function(t,s){return s.options=i.configMerge(a,s.options),s.type="radar",new e(t,s)}}.call(this),function(){"use strict";var t=this,e=t.Chart,i=e.helpers,a={hover:{mode:"single"},scales:{xAxes:[{type:"linear",position:"bottom",id:"x-axis-1"}],yAxes:[{type:"linear",position:"left",id:"y-axis-1"}]},tooltips:{template:"(<%= value.x %>, <%= value.y %>)",multiTemplate:"<%if (datasetLabel){%><%=datasetLabel%>: <%}%>(<%= value.x %>, <%= value.y %>)"}};e.Scatter=function(t,s){return s.options=i.configMerge(a,s.options),s.type="line",new e(t,s)}}.call(window);

	return window.Chart;
});
// jshint ignore:end;
define('w/stocks/detail',["lodash", "jquery", "moment", "./lib/chart", "widgets/views/main"], function(_, $, moment, Chart, WidgetView) {
	var displayFormats = {
		hour: "LT",
		day: "MMM D",
		month: "MMM YYYY",
		year: "YYYY"
	};

	// We create a custom scale type so we can control the spacing of labels
	var defaultConfig = {
		position: "bottom",

		time: {
			unit: false,
			round: false,
			format: false,
			displayFormat: false
		}
	};

	var StocksScale = Chart.scaleService.constructors.time.extend({
		/**
		 * This is a simplified version of the time scale's buildTicks function,
		 * removing a number of now-extraneous checks and making the number of
		 * ticks a fixed number.
		 */
		buildTicks: function() {
			this.ticks = [];


			var scaleLabelMoments = _.map(this.data.labels, this.parseTime, this);

			this.firstTick = this.parseTime(this.options.time.min || scaleLabelMoments[0]).clone();

			this.lastTick = this.parseTime(this.options.time.max || scaleLabelMoments[scaleLabelMoments.length - 1]).clone();

			this.labelMoments = _.map(this.data.datasets, function() {
				return scaleLabelMoments;
			});


			this.tickUnit = this.options.time.unit || "day";
			this.displayFormat = this.options.time.displayUnit;
			this.tickRange = Math.ceil(this.lastTick.diff(this.firstTick, this.tickUnit, true));


			this.smallestLabelSeparation = this.width;

			_.each(this.data.datasets, function(dataset, datasetIndex) {
				for (var i = 1; i < this.labelMoments[datasetIndex].length; i++) {
					this.smallestLabelSeparation = Math.min(this.smallestLabelSeparation, this.labelMoments[datasetIndex][i].diff(this.labelMoments[datasetIndex][i - 1], this.tickUnit, true));
				}
			}, this);


			// This is the key difference in the function. If we're showing more than 8 hours
			// of data generate 6 ticks, otherwise generate four.
			var numTicks = this.lastTick.diff(this.firstTick, "hours", true) > 8 ? 6 : 4;

			this.ticks = _.map(_.range(numTicks), function(i) {
				return this.firstTick.clone().add(((this.tickRange / numTicks) * i) + 1, this.tickUnit);
			}, this);
		}
	});

	Chart.scaleService.registerScaleType("stocksScale", StocksScale, defaultConfig);


	return WidgetView.extend({
		getTemplate: function() {
			return this.widget.templates.detail;
		},

		events: {
			"click header button.back": function() {
				this.model.set("state", "default");
			},

			"click header .tabs li": function(e) {
				if (!this.Auth.isPro) {
					$(e.currentTarget).addClass("active").siblings().removeClass("active");

					return;
				}

				if (e.currentTarget.getAttribute("data-id") === "overview") {
					clearInterval(this.newsInterval);

					this.off("before:destroy");

					this.state = "overview";

					this.render(this.stock);

					this.createChart();
				}
				else {
					this.state = "news";

					var loadNews = this.model.getNews.bind(this, this.stock.ticker, function(news) {
						this.render(_.assign({}, this.stock, {
							items: news
						}));
					}.bind(this));

					this.newsInterval = setInterval(loadNews, 120000);

					this.on("before:destroy", function() {
						clearInterval(this.newsInterval);
					});

					loadNews();
				}
			},

			"click .chart .picker li": function(e) {
				var elm = $(e.currentTarget);

				elm.addClass("active").siblings().removeClass("active");

				this.model.chartPeriod = elm.attr("data-value");

				this.model.refresh();
			}
		},


		initialize: function() {
			this.listenTo(this.model, "chart:loaded", function(data) {
				this.chartData = data;

				this.updateChart();
			});

			this.listenTo(this.model, "stock:loaded", function(stock) {
				this.stock = stock;

				this.updateData();
			});

			this.state = "overview";

			this.stock = _.find(this.model.data.stocks, {
				ticker: this.model.activeTicker
			});

			this.render(this.stock);
		},


		/**
		 * Updates the data stock data
		 */
		updateData: function() {
			var stock = this.stock;

			var price = this.$("header .price");
			price
				.children(".current.value").text(this.stock.value).end()
				.children(".change").text(this.stock.change + " (" + this.stock.changePercent + "%)");

			var closing = price.children(".current.closing");
			if (closing) {
				closing.show();
				closing.text(this.stock.value);
			}
			else {
				close.hide();
			}

			


			this.$(".details div span.value").each(function() {
				this.textContent = stock[this.getAttribute("data-field")];
			});
		},


		/**
		 * Updates the chart
		 */
		updateChart: function() {
			var data = this.chartData;

			if (!this.chart) {
				return this.createChart(data);
			}

			this.chart.data.labels = data.times;

			this.chart.data.datasets[0].data = data.values;

			this.chart.options.scales.xAxes[0].time.min = data.start;
			this.chart.options.scales.xAxes[0].time.max = data.end;

			this.chart.options.scales.xAxes[0].time.unit = data.interval || "hour";
			this.chart.options.scales.xAxes[0].time.displayFormat = displayFormats[data.interval || "hour"];

			this.chart.update();
		},


		/**
		 * Creates the chart
		 */
		createChart: function() {
			var data = this.chartData;

			var canvas = this.$(".chart canvas");

			if (!canvas.length) {
				return;
			}

			var tipElm = this.$(".chart .tooltip");

			this.chart = new Chart(canvas, {
				type: "line",
				data: {
					labels: data.times,
					datasets: [
						{
							fill: false,
							label: "Price",
							borderWidth: 2,
							data: data.values,
							borderColor: "#4184F3",
							pointHoverBorderWidth: 4,
							pointHoverBorderColor: "#4184F3",
							pointBorderColor: "rgba(0, 0, 0, 0)",
							pointHoverBackgroundColor: "#4184F3",
							pointBackgroundColor: "rgba(0, 0, 0, 0)",
						}
					]
				},
				options: {
					animation: {
						duration: 0
					},

					hover: {
						mode: "label",

						// This is a bit hacky, but it ensures that the hovered point is the same as the one
						// the tooltip is shown for, and that there's only ever one
						onHover: function() {
							this.active = this.tooltipActive = this.active.length ? [this.active[0]] : [];
						}
					},

					tooltips: {
						mode: "label",
						enabled: false,
						callbacks: {
							title: function(tooltipItems) {
								return tooltipItems && tooltipItems[0] && tooltipItems[0].yLabel;
							},
							label: function(tooltipItem) {
								return tooltipItem.xLabel;
							}
						},
						custom: function(tooltip) {
							if (!tipElm[0]) {
								this.$(".chart").append('<div class="tooltip"><span class="price"></span><span class="time"></span><span class="date"></span></div>');

								tipElm = this.$(".chart .tooltip");
							}

							if (!tooltip.opacity) {
								return tipElm.removeClass("visible");
							}

							if (tooltip.body) {
								var date = moment(parseInt(tooltip.body[0]));

								tipElm
									.find(".price").text(tooltip.title.toLocaleString())
									.next(".time").text(date.format("LT"))
									.next(".date").text(date.format("MMM Do, YYYY"));
							}

							// We move the tooltip to the right if anything in the first 150 pixels
							// is being hovered over
							tipElm.addClass("visible").toggleClass("right", tooltip.x < 150);
						}.bind(this)
					},

					elements: {
						line: {
							tension: 0.1
						}
					},

					scales: {
						xAxes: [{
							type: "stocksScale",
							time: {
								unit: data.interval || "hour",
								displayFormat: displayFormats[data.interval || "hour"],

								min: data.start,
								max: data.end,

								format: function (e) {
									return moment.utc(new Date(e));
								}
							},
							gridLines: {
								show: true,
								drawTicks: false,
								offsetGridLines: false,
								color: "rgba(0, 0, 0, 0)",
								zeroLineColor: "rgba(0, 0, 0, 0)"
							},
							ticks: {
								fontSize: 11,
								fontColor: "#AAA",
								fontFamily: "Roboto, sans-serif"
							}
						}],
						yAxes: [{
							type: "linear",
							gridLines: {
								offsetGridLines: true
							},
							ticks: {
								fontSize: 11,
								fontColor: "#AAA",
								fontFamily: "Roboto, sans-serif",
								callback: function(value) {
									// We need to pad the values so they don't get cut off
									return "  " + value.toLocaleString();
								}
							}
						}]
					}
				}
			});
		},

		onBeforeRender: function(data) {
			if (this.chart) {
				this.chart.destroy();

				delete this.chart;
			}

			if (this.Auth.isPro) {
				data[this.state] = true;
			}
			else {
				data.proSplash = true;
			}

			return data;
		}
	});
});

define("widgetTemplate!w/stocks/templates/desc.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Keep track of the latest prices and information on your stocks. Pro users see data in realtime and can view charts, news, and detailed stock information.<br /> <br /> After installation, go to the settings and enter your tickers.");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/stocks/templates/main.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("title",c,p,1),c,p,0,10,43,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<h2 class=\"header\">");t.b(t.v(t.f("title",c,p,0)));t.b("</h2>");});c.pop();}t.b(" ");if(t.s(t.f("tiny",c,p,1),c,p,0,63,367,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"val ");t.b(t.v(t.d("stocks.0.changeDirection",c,p,0)));t.b("\" title=\"");t.b(t.v(t.d("i18n.as_of",c,p,0)));t.b(" ");t.b(t.v(t.d("stocks.0.date",c,p,0)));t.b(" (");t.b(t.v(t.d("i18n.exchange_time",c,p,0)));t.b(")");if(t.s(t.d("stocks.0.extra",c,p,1),c,p,0,193,214,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" (");t.b(t.v(t.d("stocks.0.extra",c,p,0)));t.b(")");});c.pop();}t.b("\"> <span class=\"price\">");t.b(t.v(t.d("stocks.0.value",c,p,0)));t.b("</span> <span class=\"change\">");t.b(t.v(t.d("stocks.0.change",c,p,0)));t.b(" (");t.b(t.v(t.d("stocks.0.changePercent",c,p,0)));t.b("%)</span> </div> ");});c.pop();}t.b(" ");if(!t.s(t.f("tiny",c,p,1),c,p,1,0,0,"")){t.b(" <div class=\"list");if(!t.s(t.d("stocks.1",c,p,1),c,p,1,0,0,"")){t.b(" single");};t.b("\"> ");if(t.s(t.f("stocks",c,p,1),c,p,0,450,941,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"stock ");t.b(t.v(t.f("changeDirection",c,p,0)));t.b("\" title=\"");t.b(t.v(t.d("i18n.as_of",c,p,0)));t.b(" ");t.b(t.v(t.f("date",c,p,0)));t.b(" (");t.b(t.v(t.d("i18n.exchange_time",c,p,0)));t.b(")");if(t.s(t.f("extra",c,p,1),c,p,0,555,567,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" (");t.b(t.v(t.f("extra",c,p,0)));t.b(")");});c.pop();}t.b("\"> <div class=\"name\"> <span class=\"name\">");t.b(t.v(t.f("name",c,p,0)));t.b("</span> <span class=\"ticker\">");t.b(t.v(t.f("ticker",c,p,0)));t.b("</span> (<span class=\"exchange\">");t.b(t.v(t.f("exchange",c,p,0)));t.b("</span>) </div> <div class=\"price\"> <span class=\"current\">");t.b(t.v(t.f("value",c,p,0)));t.b(" ");if(t.s(t.f("closingPrice",c,p,1),c,p,0,794,841,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span class=\"closing\">(");t.b(t.v(t.f("closingPrice",c,p,0)));t.b(")</span>");});c.pop();}t.b(" </span> <span class=\"change\">");t.b(t.v(t.f("change",c,p,0)));t.b(" (");t.b(t.v(t.f("changePercent",c,p,0)));t.b("%)</span> </div> </div> ");});c.pop();}t.b(" </div> ");};return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/stocks/templates/detail.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<header class=\"");t.b(t.v(t.f("changeDirection",c,p,0)));t.b("\"> <div class=\"top-row\"> <button type=\"button\" class=\"material toggle back\"> <svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"> <path d=\"M20 11H7.83l5.59-5.59L12 4l-8 8 8 8 1.41-1.41L7.83 13H20v-2z\" /> </svg> </button> <div class=\"price-wrap\" style=\"\"> <div class=\"name\"> <span class=\"name\">");t.b(t.v(t.f("name",c,p,0)));t.b("</span> <span class=\"ticker\">");t.b(t.v(t.f("ticker",c,p,0)));t.b("</span> (<span class=\"exchange\">");t.b(t.v(t.f("exchange",c,p,0)));t.b("</span>) </div> <div class=\"price\"> <div class=\"current\"><span class=\"value\">");t.b(t.v(t.f("value",c,p,0)));t.b(" ");if(t.s(t.f("closingPrice",c,p,1),c,p,0,530,584,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("</span><span class=\"closing\">(");t.b(t.v(t.f("closingPrice",c,p,0)));t.b(")</span>");});c.pop();}t.b("</div> <div class=\"change\">");t.b(t.v(t.f("change",c,p,0)));t.b(" (");t.b(t.v(t.f("changePercent",c,p,0)));t.b("%)</div> </div> </div> </div> <ul class=\"tabs\"> <li data-id=\"overview\"");if(t.s(t.f("overview",c,p,1),c,p,0,740,755,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" class=\"active\"");});c.pop();}t.b(">");t.b(t.v(t.d("i18n.overview",c,p,0)));t.b("</li> <li data-id=\"news\"");if(t.s(t.f("news",c,p,1),c,p,0,819,834,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" class=\"active\"");});c.pop();}t.b(">");t.b(t.v(t.d("i18n.news",c,p,0)));t.b("</li> </ul> </header> ");if(t.s(t.f("proSplash",c,p,1),c,p,0,893,1020,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"splash pro-only\"> <span class=\"badge\">Pro</span> <p> ");t.b(t.v(t.d("i18n.pro_splash1",c,p,0)));t.b(" <br /> ");t.b(t.v(t.d("i18n.pro_splash2",c,p,0)));t.b(" </p> </div> ");});c.pop();}t.b(" ");if(t.s(t.f("overview",c,p,1),c,p,0,1048,3102,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"chart\"> <ul class=\"tabs picker\"> <li data-value=\"1d\" class=\"active\">");t.b(t.v(t.d("i18n.time_ranges.1d",c,p,0)));t.b("</li> <li data-value=\"5d\">");t.b(t.v(t.d("i18n.time_ranges.5d",c,p,0)));t.b("</li> <li data-value=\"1mo\">");t.b(t.v(t.d("i18n.time_ranges.1m",c,p,0)));t.b("</li> <li data-value=\"3mo\">");t.b(t.v(t.d("i18n.time_ranges.3m",c,p,0)));t.b("</li> <li data-value=\"1y\">");t.b(t.v(t.d("i18n.time_ranges.1y",c,p,0)));t.b("</li> <li data-value=\"5y\">");t.b(t.v(t.d("i18n.time_ranges.5y",c,p,0)));t.b("</li> <li data-value=\"max\">");t.b(t.v(t.d("i18n.time_ranges.max",c,p,0)));t.b("</li> </ul> <div class=\"tooltip\"> <span class=\"price\"></span> <span class=\"time\"></span> <span class=\"date\"></span> </div> <div class=\"canvas-wrapper\"> <canvas width=\"300\" height=\"200\"></canvas> </div> </div> <div class=\"details\"> <div> <span class=\"label\">");t.b(t.v(t.d("i18n.open",c,p,0)));t.b("</span> <span class=\"value\" data-field=\"open\">");t.b(t.v(t.f("open",c,p,0)));t.b("</span> </div> <div> <span class=\"label\">");t.b(t.v(t.d("i18n.prev_close",c,p,0)));t.b("</span> <span class=\"value\" data-field=\"previousClose\">");t.b(t.v(t.f("previousClose",c,p,0)));t.b("</span> </div> <div> <span class=\"label\">");t.b(t.v(t.d("i18n.high",c,p,0)));t.b("</span> <span class=\"value\" data-field=\"high\">");t.b(t.v(t.f("high",c,p,0)));t.b("</span> </div> <div> <span class=\"label\">");t.b(t.v(t.d("i18n.52high",c,p,0)));t.b("</span> <span class=\"value\" data-field=\"high52\">");t.b(t.v(t.f("high52",c,p,0)));t.b("</span> </div> <div> <span class=\"label\">");t.b(t.v(t.d("i18n.low",c,p,0)));t.b("</span> <span class=\"value\" data-field=\"low\">");t.b(t.v(t.f("low",c,p,0)));t.b("</span> </div> <div> <span class=\"label\">");t.b(t.v(t.d("i18n.52low",c,p,0)));t.b("</span> <span class=\"value\" data-field=\"low52\">");t.b(t.v(t.f("low52",c,p,0)));t.b("</span> </div> <div> <span class=\"label\">");t.b(t.v(t.d("i18n.volume",c,p,0)));t.b("</span> <span class=\"value\" data-field=\"volume\">");t.b(t.v(t.f("volume",c,p,0)));t.b("</span> </div> <div> <span class=\"label\">");t.b(t.v(t.d("i18n.avg_volume",c,p,0)));t.b("</span> <span class=\"value\" data-field=\"averageVolume\">");t.b(t.v(t.f("averageVolume",c,p,0)));t.b("</span> </div> <div> <span class=\"label\">");t.b(t.v(t.d("i18n.shares",c,p,0)));t.b("</span> <span class=\"value\" data-field=\"shares\">");t.b(t.v(t.f("shares",c,p,0)));t.b("</span> </div> <div> <span class=\"label\">");t.b(t.v(t.d("i18n.cap",c,p,0)));t.b("</span> <span class=\"value\" data-field=\"marketCap\">");t.b(t.v(t.f("marketCap",c,p,0)));t.b("</span> </div> <div> <span class=\"label\">");t.b(t.v(t.d("i18n.pe",c,p,0)));t.b("</span> <span class=\"value\" data-field=\"priceToEarnings\">");t.b(t.v(t.f("priceToEarnings",c,p,0)));t.b("</span> </div> <div> <span class=\"label\">");t.b(t.v(t.d("i18n.eps",c,p,0)));t.b("</span> <span class=\"value\" data-field=\"earningsPerShare\">");t.b(t.v(t.f("earningsPerShare",c,p,0)));t.b("</span> </div> </div> ");});c.pop();}t.b(" ");if(t.s(t.f("news",c,p,1),c,p,0,3125,3355,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"news-items\"> ");if(t.s(t.f("items",c,p,1),c,p,0,3161,3337,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <a href=\"");t.b(t.v(t.f("url",c,p,0)));t.b("\" class=\"item\"> <h3 class=\"title\">");t.b(t.v(t.f("title",c,p,0)));t.b("</h3> <p class=\"desc\">");t.b(t.t(t.f("desc",c,p,0)));t.b("</p> <span class=\"source\">");t.b(t.v(t.f("source",c,p,0)));t.b("</span> <span class=\"date\">");t.b(t.v(t.f("date",c,p,0)));t.b("</span> </a> ");});c.pop();}t.b(" </div> ");});c.pop();}return t.fl(); },partials: {}, subs: {  }})});
define('w/stocks/model',["jquery", "lodash", "widgets/model", "moment"], function($, _, WidgetModel, moment) {
	return WidgetModel.extend({
		widgetClassname: "tabbed-corner nomax",

		pro_tooltip: "stocks",

		refreshInterval: function() {
			return this.Auth.isPro ? 10000 : 300000;
		},

		defaults: {
			config: {
				title: "My Stocks",
				size: "small",
				stocks: ["AAPL", "FB", "GOOG", "NFLX", "TSLA", "^DJI"],
				regularinpost: "1"
			},
			data: {
				stocks: [
					{
						name: "Apple Inc.",
						ticker: "AAPL",
						exchange: "NasdaqGS",
						value: "118.47",
						change: "-0.31",
						changePercent: "-0.26",
						changeDirection: "down",
						date: "Nov 19th 11:00 AM"
					},
					{
						name: "Facebook Inc",
						ticker: "FB",
						exchange: "NasdaqGS",
						value: "106.20",
						change: "-0.06",
						changePercent: "-0.06",
						changeDirection: "down",
						date: "Nov 19th 11:00 AM"
					},
					{
						name: "Alphabet Inc",
						ticker: "GOOG",
						exchange: "NasdaqGS",
						value: "738.82",
						change: "+0.41",
						changePercent: "0.06",
						changeDirection: "up",
						date: "Nov 19th 11:00 AM"
					},
					{
						name: "Netflix, Inc.",
						ticker: "NFLX",
						exchange: "NasdaqGS",
						value: "120.20",
						change: "-0.02",
						changePercent: "-0.02",
						changeDirection: "down",
						date: "Nov 19th 11:00 AM"
					},
					{
						name: "Tesla Motors Inc",
						ticker: "TSLA",
						exchange: "NasdaqGS",
						value: "221.94",
						change: "+0.14",
						changePercent: "0.06",
						changeDirection: "up",
						date: "Nov 19th 11:00 AM"
					},
					{
						name: "Dow Jones Industrial Average",
						ticker: "^DJI",
						exchange: "DJI",
						value: "17,732.75",
						change: "-4.41",
						changePercent: "-0.02",
						changeDirection: "down",
						date: "Nov 19th 11:28 AM"
					}
				]
			}
		},

		autocomplete: function(val, cb) {
			$.getJSON("https://s.yimg.com/xb/v6/finance/autocomplete?nresults=5&output=json&lang=en-US&query=" + encodeURIComponent(val), function(d) {
				cb(_.map(d.ResultSet.Result, function(e) {
					return {
						value: e.symbol,
						label: e.name + " (" + e.symbol + ")"
					};
				}));
			});
		},


		initialize: function() {
			WidgetModel.prototype.initialize.call(this);

			if (this.config.symbol) {
				this.config.stocks = this.config.symbol.split(",").map(function(e) {
					return e.trim();
				});

				delete this.config.symbol;

				this.saveConfig();
			}
		},


		/**
		 * Loads chart data for the given period
		 *
		 * @param  {String}   ticker    The ticker
		 * @param  {String}   exchange  The exchange
		 * @param  {String}   period    The period to load data for, must be one of
		 *                              1d, 5d, 1m, 3m, 1y, 5y, or max
		 * @param  {Function} cb        The callback
		 */
		getChartData: function(ticker, exchange, period, cb) {
			if (period === "max") {
				period = "40y";
			}

			var intervals = {
				"1d": "5m",
				"5d": "30m",
				"1mo": "1d",
				"3mo": "1d",
				"1y": "1d",
				"5y": "1wk",
				"40y": "1wk"
			};

			var displayIntervals = {
				"1d": "hour",
				"5d": "day",
				"1mo": "day",
				"3mo": "month",
				"1y": "month",
				"5y": "year",
				"40y": "year"
			};

			$.ajax({
				type: "GET",
				url: "https://query1.finance.yahoo.com/v8/finance/chart/" + encodeURIComponent(ticker) + "?" +
					"range=" + period +
					"&interval=" + intervals[period] +
					"&includePrePost=false",
				dataType: "json",
				success: function(d) {
					var ret = {
						times: _.map(d.chart.result[0].timestamp, function(e) { return e * 1000; }),
						values: d.chart.result[0].indicators.quote[0].close,
						interval: displayIntervals[period]
					};

					ret.start = ret.times[0];
					ret.end = ret.times[ret.times.length - 1];

					cb.call(this, ret);
				}.bind(this)
			});
		},


		/**
		 * Retrieves news for a given stock ticker
		 *
		 * @param  {String}   ticker  The ticker to fetch news for
		 * @param  {Function} cb  The callback
		 */
		getNews: function(ticker, cb) {
			$.ajax({
				type: "GET",
				dataType: "json",
				url: "https://query1.finance.yahoo.com/v2/finance/news?symbols=" + ticker + "&count=10",
				success: function(d) {
					cb(_.map(d.Content.result, function(e) {
						return {
							url: e.url,
							title: e.title,
							desc: e.summary,
							source: e.provider_name,
							date: moment(e.provider_publish_time * 1000).fromNow()
						};
					}));
				}
			});
		},


		refresh: function() {
			var isDetail = this.get("state") === "detail",
				ticker = (this.config.stocks || ["GOOG"]).map(function(e) { return e.split(":").pop(); }).join(",");

			if (isDetail) {
				ticker = this.activeTicker;

				if (this.Auth.isPro) {
					this.getChartData(this.activeTicker, "", this.chartPeriod || "1d", function(chartData) {
						if (isDetail && this.activeTicker === ticker) {
							this.trigger("chart:loaded", chartData);
						}
					});
				}
			}

			$.ajax({
				type: "GET",
				url: "https://query1.finance.yahoo.com/v7/finance/quote?symbols=" + encodeURIComponent(ticker) + "&fields=" + [
						"symbol", "shortName", "regularMarketPrice", "regularMarketChangePercent",
						"regularMarketChange", "regularMarketVolume", "regularMarketDayLow", "regularMarketDayHigh", "fiftyTwoWeekLow", "fiftyTwoWeekHigh",
						"regularMarketOpen", "regularMarketPreviousClose", "preMarketPrice", "preMarketChangePercent", "preMarketTime", "postMarketPrice",
						"preMarketChange", "postMarketTime", "postMarketChange", "postMarketChangePercent", "epsTrailingTwelveMonths", "trailingPE", "marketCap",
						"averageDailyVolume3Month"
				].join(","),
				dataType: "json",
				success: function(d) {
					if (typeof d !== "object") {
						try {
							d = JSON.parse(d);
						}
						catch (e) {
							return;
						}
					}

					if (!d.quoteResponse || !d.quoteResponse.result || d.quoteResponse.error) {
						return;
					}

					var stocks = _.map(d.quoteResponse.result, function(e) {
						var marketType = "regularMarket";

						var getClosingPrice = function(e) {
							if (this.config.regularinpost !== "1") { return null; }
							return !e.regularMarketPrice ? null : e.regularMarketPrice.toLocaleString(undefined, { minimumFractionDigits: 2 });
						}.bind(this);

						var closingPrice = null;
						if ((!e.regularMarketTime || !e.regularMarketPrice || e.preMarketTime > e.regularMarketTime) && e.preMarketPrice) {
							marketType = "preMarket";
							closingPrice = getClosingPrice(e);
						}
						else if ((!e.regularMarketTime || !e.regularMarketPrice || e.postMarketTime > e.regularMarketTime) && e.postMarketPrice) {
							marketType = "postMarket";
							closingPrice = getClosingPrice(e);
						}

						return {
							name: e.shortName,
							ticker: e.symbol,
							exchange: e.fullExchangeName,

							closingPrice: closingPrice,

							value: (e[marketType + "Price"] || 0).toLocaleString(undefined, { minimumFractionDigits: 2 }),
							change: (e[marketType + "Change"] || 0).toLocaleString(undefined, { minimumFractionDigits: 2 }),
							changePercent: (e[marketType + "ChangePercent"] || 0).toLocaleString(undefined, { maximumFractionDigits: 2 }),
							changeDirection: (e[marketType + "Change"] || 0) > 0 ? "up" : "down",
							date: moment((e[marketType + "Time"] || 0) * 1000).format("MMM Do h:mm A"),

							low: (e.regularMarketDayLow || 0).toLocaleString(undefined, { minimumFractionDigits: 2 }),
							high: (e.regularMarketDayHigh || 0).toLocaleString(undefined, { minimumFractionDigits: 2 }),
							open: (e.regularMarketOpen || 0).toLocaleString(undefined, { minimumFractionDigits: 2 }),
							low52: (e.fiftyTwoWeekLow || 0).toLocaleString(undefined, { minimumFractionDigits: 2 }),
							high52: (e.fiftyTwoWeekHigh || 0).toLocaleString(undefined, { minimumFractionDigits: 2 }),
							previousClose: (e.regularMarketPreviousClose || 0).toLocaleString(undefined, { minimumFractionDigits: 2 }),

							volume: (e.regularMarketVolume || 0).toLocaleString(),
							marketCap: (e.marketCap || 0).toLocaleString(),
							shares: (e.sharesOutstanding || 0).toLocaleString(),
							averageVolume: (e.averageDailyVolume3Month || 0).toLocaleString(),

							earningsPerShare: (e.epsTrailingTwelveMonths || 0).toLocaleString(undefined, { minimumFractionDigits: 2 }),
							priceToEarnings: (e.trailingPE || 0).toLocaleString(),
							extraInfo: marketType === "preMarket" ? "Pre Market" : marketType === "postMarket" ? "After Hours" : null
						};
					}.bind(this));

					if (isDetail && this.activeTicker === ticker) {
						this.trigger("stock:loaded", stocks[0]);
					}
					else if (!isDetail) {
						this.saveData({
							stocks: stocks
						});
					}
				}.bind(this)
			});
		}
	});
});
/* ===================================================
 *	jquery-sortable.js v0.9.11
 *	http://johnny.github.com/jquery-sortable/
 * ===================================================
 *	Copyright (c) 2012 Jonas von Andrian
 *	All rights reserved.
 *
 *	Redistribution and use in source and binary forms, with or without
 *	modification, are permitted provided that the following conditions are met:
 *	* Redistributions of source code must retain the above copyright
 *		notice, this list of conditions and the following disclaimer.
 *	* Redistributions in binary form must reproduce the above copyright
 *		notice, this list of conditions and the following disclaimer in the
 *		documentation and/or other materials provided with the distribution.
 *	* The name of the author may not be used to endorse or promote products
 *		derived from this software without specific prior written permission.
 *
 *	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 *	ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 *	WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *	DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
 *	DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 *	(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *	LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 *	ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *	(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 *	SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * ========================================================== */


!function ($, window, undefined){
	var eventNames,
	pluginName = 'sortable',
	containerDefaults = {
		// If true, items can be dragged from this container
		drag: true,
		// If true, items can be droped onto this container
		drop: true,
		// Exclude items from being draggable, if the
		// selector matches the item
		exclude: "",
		// If true, search for nested containers within an item
		nested: true,
		// If true, the items are assumed to be arranged vertically
		vertical: true
	}, // end container defaults
	groupDefaults = {
		// This is executed after the placeholder has been moved.
		afterMove: function ($placeholder, container) {
		},
		// The exact css path between the container and its items, e.g. "> tbody"
		containerPath: "",
		// The css selector of the containers
		containerSelector: "ol, ul",
		// Distance the mouse has to travel to start dragging
		distance: 0,
		// The css selector of the drag handle
		handle: "",
		// The exact css path between the item and its subcontainers
		itemPath: "",
		// The css selector of the items
		itemSelector: "li",
		// Whether or not container dimensions and/or locations will change
		// This will force them to be recalculated on every move
		dynamicDimensions: false,
		// Check if the dragged item may be inside the container.
		// Use with care, since the search for a valid container entails a depth first search
		// and may be quite expensive.
		isValidTarget: function ($item, container) {
			return true
		},
		// Executed before onDrop if placeholder is detached.
		// This happens if pullPlaceholder is set to false and the drop occurs outside a container.
		onCancel: function ($item, container, _super, event) {
		},
		// Executed at the beginning of a mouse move event.
		// The Placeholder has not been moved yet.
		onDrag: function ($item, position, _super, event) {
			$item.css(position)
		},
		// Called after the drag has been started,
		// that is the mouse button is beeing held down and
		// the mouse is moving.
		// The container is the closest initialized container.
		// Therefore it might not be the container, that actually contains the item.
		onDragStart: function ($item, container, _super, event) {
			$item.css({
				height: $item.height(),
				width: $item.width()
			})
			$item.addClass("dragged")
			$("body").addClass("dragging")
		},
		// Called when the mouse button is being released, before the element is moved.
		// If a falsy value is returned, the drop will be canceled
		onBeforeDrop: function($item, placeholder, group, _super, event) {
			return true
		},
		// Called when the mouse button is beeing released
		onDrop: function ($item, container, _super, event) {
			$item.removeClass("dragged").removeAttr("style")
			$("body").removeClass("dragging")
		},
		// Called on mousedown. If falsy value is returned, the dragging will not start.
		// If clicked on input element, ignore
		onMousedown: function ($item, _super, event) {
			if (event.target.nodeName != 'INPUT') {
				event.preventDefault()
				return true
			}
		},
		// Template for the placeholder. Can be any valid jQuery input
		// e.g. a string, a DOM element.
		// The placeholder must have the class "placeholder"
		placeholder: '<li class="placeholder"/>',
		// If true, the position of the placeholder is calculated on every mousemove.
		// If false, it is only calculated when the mouse is above a container.
		pullPlaceholder: true,
		// Specifies serialization of the container group.
		// The pair $parent/$children is either container/items or item/subcontainers.
		// Note that this default method only works, if every item only has one subcontainer
		serialize: function ($parent, $children, parentIsContainer) {
			var result = $.extend({}, $parent.data())
			
			if(parentIsContainer)
				return $children
			else if ($children[0]){
				result.children = $children
				delete result.subContainer
			}

			delete result.sortable

			return result
		},
		// Set tolerance while dragging. Positive values decrease sensitivity,
		// negative values increase it.
		tolerance: 0
	}, // end group defaults
	containerGroups = {},
	groupCounter = 0,
	emptyBox = {
		left: 0,
		top: 0,
		bottom: 0,
		right:0
	}
	eventNames = {
		start: "touchstart.sortable mousedown.sortable",
		drop: "touchend.sortable touchcancel.sortable mouseup.sortable",
		drag: "touchmove.sortable mousemove.sortable",
		scroll: "scroll.sortable"
	}

	/*
	 * a is Array [left, right, top, bottom]
	 * b is array [left, top]
	 */
	function d(a,b) {
		var x = Math.max(0, a[0] - b[0], b[0] - a[1]),
		y = Math.max(0, a[2] - b[1], b[1] - a[3])
		return x+y;
	}

	function setDimensions(array, dimensions, tolerance, useOffset) {
		var i = array.length,
		offsetMethod = useOffset ? "offset" : "position"
		tolerance = tolerance || 0

		while(i--){
			var el = array[i].el ? array[i].el : $(array[i]),
			// use fitting method
			pos = el[offsetMethod]()
			pos.left += parseInt(el.css('margin-left'), 10)
			pos.top += parseInt(el.css('margin-top'),10)
			dimensions[i] = [
				pos.left - tolerance,
				pos.left + el.outerWidth() + tolerance,
				pos.top - tolerance,
				pos.top + el.outerHeight() + tolerance
			]
		}
	}

	function getRelativePosition(pointer, element) {
		var offset = element.offset()
		return {
			left: pointer.left - offset.left,
			top: pointer.top - offset.top
		}
	}

	function sortByDistanceDesc(dimensions, pointer, lastPointer) {
		pointer = [pointer.left, pointer.top]
		lastPointer = lastPointer && [lastPointer.left, lastPointer.top]

		var dim,
		i = dimensions.length,
		distances = []

		while(i--){
			dim = dimensions[i]
			distances[i] = [i,d(dim,pointer), lastPointer && d(dim, lastPointer)]
		}
		distances = distances.sort(function	(a,b) {
			return b[1] - a[1] || b[2] - a[2] || b[0] - a[0]
		})

		// last entry is the closest
		return distances
	}

	function ContainerGroup(options) {
		this.options = $.extend({}, groupDefaults, options)
		this.containers = []

		if(!this.options.parentContainer){
			this.scrollProxy = $.proxy(this.scroll, this)
			this.dragProxy = $.proxy(this.drag, this)
			this.dropProxy = $.proxy(this.drop, this)
			this.placeholder = $(this.options.placeholder)
			
			if(!options.isValidTarget)
				this.options.isValidTarget = undefined
		}
	}

	ContainerGroup.get = function	(options) {
		if( !containerGroups[options.group]) {
			if(options.group === undefined)
				options.group = groupCounter ++
			containerGroups[options.group] = new ContainerGroup(options)
		}
		return containerGroups[options.group]
	}

	ContainerGroup.prototype = {
		dragInit: function	(e, itemContainer) {
			this.$document = $(itemContainer.el[0].ownerDocument)

			if(itemContainer.enabled()){
				// get item to drag
				this.item = $(e.target).closest(this.options.itemSelector)
				this.itemContainer = itemContainer

				if(!this.options.onMousedown.call(this, this.item, groupDefaults.onMousedown, e))
					return

				this.setPointer(e)
				this.toggleListeners('on')
			} else {
				this.toggleListeners('on', ['drop'])
			}

			this.dragInitDone = true
		},
		drag: function	(e) {
			if(!this.dragging){
				if(!this.distanceMet(e))
					return

				this.options.onDragStart.call(this, this.item, this.itemContainer, groupDefaults.onDragStart, e)
				this.item.before(this.placeholder)
				this.dragging = true
			}

			this.setPointer(e)
			// place item under the cursor
			this.options.onDrag.call(this, 
									this.item,
									getRelativePosition(this.pointer, this.item.offsetParent()),
									groupDefaults.onDrag,
									e)

			var x = e.pageX,
			y = e.pageY,
			box = this.sameResultBox,
			t = this.options.tolerance

			if(!box || box.top - t > y || box.bottom + t < y || box.left - t > x || box.right + t < x)
				if(!this.searchValidTarget())
					this.placeholder.detach()
		},
		drop: function	(e) {
			this.toggleListeners('off')

			this.dragInitDone = false

			if(this.dragging){
				if (this.options.onBeforeDrop.call(this, this.item, this.placeholder, this, groupDefaults.onBeforeDrop, e)) {
					// processing Drop, check if placeholder is detached
					if(this.placeholder.closest("html")[0])
						this.placeholder.before(this.item).detach()
					else
						this.options.onCancel.call(this, this.item, this.itemContainer, groupDefaults.onCancel, e)
				}

				this.options.onDrop.call(this, this.item, this.getContainer(this.item), groupDefaults.onDrop, e)

				// cleanup
				this.clearDimensions()
				this.clearOffsetParent()
				this.lastAppendedItem = this.sameResultBox = undefined
				this.dragging = false
			}
		},
		searchValidTarget: function	(pointer, lastPointer) {
			if(!pointer){
				pointer = this.relativePointer || this.pointer
				lastPointer = this.lastRelativePointer || this.lastPointer
			}

			var distances = sortByDistanceDesc(this.getContainerDimensions(),
																				 pointer,
																				 lastPointer),
			i = distances.length

			while(i--){
				var index = distances[i][0],
				distance = distances[i][1]

				if(!distance || this.options.pullPlaceholder){
					var container = this.containers[index]
					if(!container.disabled){
						if(!this.$getOffsetParent()){
							var offsetParent = container.getItemOffsetParent()
							pointer = getRelativePosition(pointer, offsetParent)
							lastPointer = getRelativePosition(lastPointer, offsetParent)
						}
						if(container.searchValidTarget(pointer, lastPointer))
							return true
					}
				}
			}
			if(this.sameResultBox)
				this.sameResultBox = undefined
		},
		movePlaceholder: function	(container, item, method, sameResultBox) {
			var lastAppendedItem = this.lastAppendedItem
			if(!sameResultBox && lastAppendedItem && lastAppendedItem[0] === item[0])
				return;

			item[method](this.placeholder)
			this.lastAppendedItem = item
			this.sameResultBox = sameResultBox
			this.options.afterMove(this.placeholder, container)
		},
		getContainerDimensions: function	() {
			if(!this.containerDimensions || this.options.dynamicDimensions)
				setDimensions(this.containers, this.containerDimensions = [], this.options.tolerance, !this.$getOffsetParent())
			
			return this.containerDimensions
		},
		getContainer: function	(element) {
			return element.closest(this.options.containerSelector).data(pluginName)
		},
		$getOffsetParent: function	() {
			if(this.offsetParent === undefined){
				var i = this.containers.length - 1,
				offsetParent = this.containers[i].getItemOffsetParent()

				if(!this.options.parentContainer){
					while(i--){
						if(offsetParent[0] != this.containers[i].getItemOffsetParent()[0]){
							// If every container has the same offset parent,
							// use position() which is relative to this parent,
							// otherwise use offset()
							// compare #setDimensions
							offsetParent = false
							break;
						}
					}
				}
				
				this.offsetParent = offsetParent
			}
			return this.offsetParent
		},
		setPointer: function (e) {
			var pointer = {
				left: e.pageX,
				top: e.pageY
			}

			if(this.$getOffsetParent()){
				var relativePointer = getRelativePosition(pointer, this.$getOffsetParent())
				this.lastRelativePointer = this.relativePointer
				this.relativePointer = relativePointer
			}

			this.lastPointer = this.pointer
			this.pointer = pointer
		},
		distanceMet: function (e) {
			return (Math.max(
																 Math.abs(this.pointer.left - e.pageX),
																Math.abs(this.pointer.top - e.pageY)
												) >= this.options.distance)
		},
		scroll: function	(e) {
			this.clearDimensions()
			this.clearOffsetParent()
		},
		toggleListeners: function (method, events) {
			var that = this
			events = events || ['drag','drop','scroll']

			$.each(events,function	(i,event) {
				that.$document[method](eventNames[event], that[event + 'Proxy'])
			})
		},
		clearOffsetParent: function () {
			this.offsetParent = undefined
		},
		// Recursively clear container and item dimensions
		clearDimensions: function	() {
			this.containerDimensions = undefined
			var i = this.containers.length
			while(i--){
				this.containers[i].clearDimensions()
			}
		},
		destroy: function () {
			// TODO iterate over subgroups and destroy them
			// TODO remove all events
			containerGroups[this.options.group] = undefined
		}
	}

	function Container(element, options) {
		this.el = element
		this.options = $.extend( {}, containerDefaults, options)

		this.group = ContainerGroup.get(this.options)
		this.rootGroup = this.options.rootGroup || this.group
		this.parentContainer = this.options.parentContainer
		this.handle = this.rootGroup.options.handle || this.rootGroup.options.itemSelector

		var itemPath = this.rootGroup.options.itemPath,
		target = itemPath ? this.el.find(itemPath) : this.el

		target.on(eventNames.start, this.handle, $.proxy(this.dragInit, this))

		if(this.options.drop)
			this.group.containers.push(this)
	}

	Container.prototype = {
		dragInit: function	(e) {
			var rootGroup = this.rootGroup

			if( !rootGroup.dragInitDone &&
					e.which === 1 &&
					this.options.drag &&
					!$(e.target).is(this.options.exclude))
				rootGroup.dragInit(e, this)
		},
		searchValidTarget: function	(pointer, lastPointer) {
			var distances = sortByDistanceDesc(this.getItemDimensions(),
																				 pointer,
																				 lastPointer),
			i = distances.length,
			rootGroup = this.rootGroup,
			validTarget = !rootGroup.options.isValidTarget ||
				rootGroup.options.isValidTarget(rootGroup.item, this)

			if(!i && validTarget){
				var itemPath = this.rootGroup.options.itemPath,
				target = itemPath ? this.el.find(itemPath) : this.el

				rootGroup.movePlaceholder(this, target, "append")
				return true
			} else
				while(i--){
					var index = distances[i][0],
					distance = distances[i][1]
					if(!distance && this.hasChildGroup(index)){
						var found = this.getContainerGroup(index).searchValidTarget(pointer, lastPointer)
						if(found)
							return true
					}
					else if(validTarget){
						this.movePlaceholder(index, pointer)
						return true
					}
				}
		},
		movePlaceholder: function	(index, pointer) {
			var item = $(this.items[index]),
			dim = this.itemDimensions[index],
			method = "after",
			width = item.outerWidth(),
			height = item.outerHeight(),
			offset = item.offset(),
			sameResultBox = {
				left: offset.left,
				right: offset.left + width,
				top: offset.top,
				bottom: offset.top + height
			}
			if(this.options.vertical){
				var yCenter = (dim[2] + dim[3]) / 2,
				inUpperHalf = pointer.top <= yCenter
				if(inUpperHalf){
					method = "before"
					sameResultBox.bottom -= height / 2
				} else
					sameResultBox.top += height / 2
			} else {
				var xCenter = (dim[0] + dim[1]) / 2,
				inLeftHalf = pointer.left <= xCenter
				if(inLeftHalf){
					method = "before"
					sameResultBox.right -= width / 2
				} else
					sameResultBox.left += width / 2
			}
			if(this.hasChildGroup(index))
				sameResultBox = emptyBox
			this.rootGroup.movePlaceholder(this, item, method, sameResultBox)
		},
		getItemDimensions: function	() {
			if(!this.itemDimensions){
				this.items = this.$getChildren(this.el, "item").filter(":not(.placeholder, .dragged)").get()
				setDimensions(this.items, this.itemDimensions = [], this.options.tolerance)
			}
			return this.itemDimensions
		},
		getItemOffsetParent: function	() {
			var offsetParent,
			el = this.el
			// Since el might be empty we have to check el itself and
			// can not do something like el.children().first().offsetParent()
			if(el.css("position") === "relative" || el.css("position") === "absolute"	|| el.css("position") === "fixed")
				offsetParent = el
			else
				offsetParent = el.offsetParent()
			return offsetParent
		},
		hasChildGroup: function (index) {
			return this.options.nested && this.getContainerGroup(index)
		},
		getContainerGroup: function	(index) {
			var childGroup = $.data(this.items[index], "subContainer")
			if( childGroup === undefined){
				var childContainers = this.$getChildren(this.items[index], "container")
				childGroup = false

				if(childContainers[0]){
					var options = $.extend({}, this.options, {
						parentContainer: this,
						rootGroup: this.rootGroup,
						group: groupCounter ++
					})
					childGroup = childContainers[pluginName](options).data(pluginName).group
				}
				$.data(this.items[index], "subContainer", childGroup)
			}
			return childGroup
		},
		enabled: function () {
			return !this.disabled && (!this.parentContainer || this.parentContainer.enabled())
		},
		$getChildren: function (parent, type) {
			var options = this.rootGroup.options,
			path = options[type + "Path"],
			selector = options[type + "Selector"]

			parent = $(parent)
			if(path)
				parent = parent.find(path)

			return parent.children(selector)
		},
		_serialize: function (parent, isContainer) {
			var that = this,
			childType = isContainer ? "item" : "container",
			
			children = this.$getChildren(parent, childType).not(this.options.exclude).map(function () {
				return that._serialize($(this), !isContainer)
			}).get()
			
			return this.rootGroup.options.serialize(parent, children, isContainer)
		},
		clearDimensions: function	() {
			this.itemDimensions = undefined
			if(this.items && this.items[0]){
				var i = this.items.length
				while(i--){
					var group = $.data(this.items[i], "subContainer")
					if(group)
						group.clearDimensions()
				}
			}
		}
	}

	var API = {
		enable: function	(ignoreChildren) {
			this.disabled = false
		},
		disable: function	(ignoreChildren) {
			this.disabled = true
		},
		serialize: function () {
			return this._serialize(this.el, true)
		},
		destroy: function () {
			this.rootGroup.destroy()
		}
	}

	$.extend(Container.prototype, API)
	
	/**
	 * jQuery API
	 *
	 * Parameters are
	 *	 either options on init
	 *	 or a method name followed by arguments to pass to the method
	 */
	$.fn[pluginName] = function(methodOrOptions) {
		var args = Array.prototype.slice.call(arguments, 1)

		return this.map(function(){
			var $t = $(this),
			object = $t.data(pluginName)

			if(object && API[methodOrOptions])
				return API[methodOrOptions].apply(object, args) || this
			else if(!object && (methodOrOptions === undefined ||
													typeof methodOrOptions === "object"))
				$t.data(pluginName, new Container($t, methodOrOptions))

			return this
		});
	};

}(jQuery, window);
define("lib/jquery.sortable", ["jquery"], function(){});

define('w/todo/view',["jquery", "widgets/views/main", "lib/jquery.sortable"], function($, WidgetView) {
	return WidgetView.extend({
		events: {
			"input .item .title": "serialize",

			"click .header .new": function() {
				this.addItem();
			},

			"click .item .delete": function(e) {
				var elm = $(e.currentTarget).parent().parent().slideUp(function() {
					elm.remove();

					this.serialize();
				}.bind(this));
			},

			"click .item .tags div": function(e) {
				var color = e.currentTarget.getAttribute("data-color"),
					item = $(e.currentTarget).parents(".item");

				if (color === "none" || color === "important") {
					item.attr("data-color", "").attr("style", "")[color === "none" ? "removeClass" : "addClass"]("important");
				}
				else {
					item.first().removeClass("important").attr("data-color", color).css("background-color", color);
				}

				this.serialize();
			},

			"change .item .check": function(e) {
				$(e.currentTarget).parent().toggleClass("done", e.currentTarget.checked);

				this.serialize();
			},

			"keydown .item .title": function(e) {
				if (e.which === 13) {
					e.preventDefault();

					this.addItem($(e.currentTarget).parent());
				}
			}
		},

		initialize: function() {
			// We check the viewChange flag so we don't re-render every time a
			// box is ticked or an item moved
			this.listenTo(this.model, "change", function(model, options) {
				if (!options.viewChange) {
					this.render();
				}
			});

			this.render();
		},

		serialize: function() {
			this.model.set("syncData", {
				items: this.sortable.sortable("serialize").get()
			}, {
				viewChange: true
			});
		},

		addItem: function(title, after) {
			if (typeof title !== "string") {
				after = title;
				title = "";
			}

			var html = '<div class="item"><input type="checkbox" class="check"/><input class="title" type="text" maxlength="255" value="' +
				title + '" /><div class="tools"><span class="tag">&#xE629;</span><span class="delete">&#xE678;</span><span class="m' +
						'ove">&#xE693;</span><div class="tags"><div data-color="none">None</div><div data-color="important" style="' +
						'background-color: #FFECEC;">Important</div>' +
							this.model.config.tags.map(function(e) {
								return '<div data-color="' + e.color + '" style="background-color: ' + e.color + ';">' + e.name + '</div>';
							}) +
						'</div></div></div>';

			if (after) {
				$(html).insertAfter(after).find(".title").focus();
			}
			else {
				$(html).appendTo(this.sortable).find(".title").focus();
			}

			this.serialize();
		},

		onBeforeRender: function(data) {
			data.items = this.model.syncData.items;

			data.tags = this.model.config.tags;

			if (this.model.config.title) {
				data.title = this.model.config.title;
			}

			if (this.model.config.font === "light") {
				data.font = "#FAFAFA";
				data.ifont = "#FFF";
			}

			return data;
		},

		onRender: function() {
			this.sortable = this.$(".list").sortable({
				handle: ".move",
				itemSelector: ".item",
				placeholder: "<div class=\"item holder\"/>",
				onDragStart: function(item) {
					item.css({
						height: item.outerHeight(),
						width: item.outerWidth()
					});

					item.addClass("dragged");
				},
				onDrag: function(item, position) {
					var ctx = $(item.context),
						ctp = ctx.position(),
						ctpp = ctx.parent().position();

					position.top -= ctp.top + ctpp.top + 10;
					position.left -= ctp.left + ctpp.left + 10;

					item.css(position);
				},
				onDrop: function(item, container, _super) {
					this.serialize();

					_super(item, container);
				}.bind(this),
				serialize: function(item, children, isContainer) {
					if (isContainer) {
						return children;
					}
					else {
						var ret = {
							title: item.find(".title").val().trim().slice(0, 255)
						};

						if (item.attr("data-color")) {
							ret.color = item.attr("data-color");
						}
						else if (item.hasClass("important")) {
							ret.important = true;
						}

						if (item.hasClass("done")) {
							ret.done = true;
						}

						return ret;
					}
				}
			});
		}
	});
});

define("widgetTemplate!w/todo/templates/desc.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Keep track of what you need to do with this simple to-do list.<br /> <br /> To add an item click the Add Item link in the top right corner of the widget.");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/todo/templates/main.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<h2 class=\"header\"> ");t.b(t.v(t.f("title",c,p,0)));t.b(" <button type=\"button\" class=\"material flat blue new\">");t.b(t.v(t.d("i18n.add",c,p,0)));t.b("</button> </h2> <div class=\"list\" style=\"color: ");t.b(t.v(t.f("font",c,p,0)));t.b(";\"> ");if(t.s(t.f("items",c,p,1),c,p,0,165,860,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"item");if(t.s(t.f("important",c,p,1),c,p,0,196,206,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" important");});c.pop();}if(t.s(t.f("done",c,p,1),c,p,0,229,234,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" done");});c.pop();}if(t.s(t.f("color",c,p,1),c,p,0,253,290,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("\" style=\"background-color: ");t.b(t.v(t.f("color",c,p,0)));t.b(";");});c.pop();}t.b("\"> <input type=\"checkbox\" class=\"check\"");if(t.s(t.f("done",c,p,1),c,p,0,348,356,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" checked");});c.pop();}t.b(" /> <input class=\"title\" type=\"text\" maxlength=\"255\" value=\"");t.b(t.v(t.f("title",c,p,0)));t.b("\" style=\"color: ");t.b(t.v(t.f("ifont",c,p,0)));t.b(";\" /> <div class=\"tools\"> <span class=\"tag\">&#xE629;</span> <span class=\"delete\">&#xE678;</span> <span class=\"move\">&#xE693;</span> <div class=\"tags\"> <div data-color=\"none\">");t.b(t.v(t.d("i18n.none",c,p,0)));t.b("</div> <div data-color=\"important\" style=\"background-color: #FFECEC;\">");t.b(t.v(t.d("i18n.important",c,p,0)));t.b("</div> ");if(t.s(t.f("tags",c,p,1),c,p,0,750,829,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div data-color=\"");t.b(t.v(t.f("color",c,p,0)));t.b("\" style=\"background-color: ");t.b(t.v(t.f("color",c,p,0)));t.b(";\">");t.b(t.v(t.f("name",c,p,0)));t.b("</div>");});c.pop();}t.b(" </div> </div> </div> ");});c.pop();}t.b(" </div>");return t.fl(); },partials: {}, subs: {  }})});
define('w/todo/model',["widgets/model"], function(WidgetModel) {
	return WidgetModel.extend({
		widgetClassname: "tabbed",
		
		defaults: {
			config: {
				title: "i18n.title",
				size: "variable",
				tags: [],
				font: "dark"
			},
			syncData: {
				items: [
					{
						title: "These are sample to-do items"
					},
					{
						title: "This one is important",
						important: true
					},
					{
						title: "This one is done",
						done: true
					},
					{
						title: "And this one is undone"
					}
				]
			}
		},

		initialize: function() {
			if (typeof this.data === "object" && this.data.items) {
				this.saveSyncData(this.data);

				delete this.data;
			}

			WidgetModel.prototype.initialize.call(this);
		}
	});
});
define('w/topsites/view',["widgets/views/main"], function(WidgetView) {
	return WidgetView.extend({
		onBeforeRender: function(data) {
			if (this.model.config.title) {
				data.title = this.model.config.title;
			}

			data.newTab = this.model.config.target === "_blank";

			return data;
		}
	});
});

define("widgetTemplate!w/topsites/templates/desc.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("This widget displays a list of your most visited websites and pages as determined by Chrome.");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/topsites/templates/main.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("title",c,p,1),c,p,0,10,43,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<h2 class=\"header\">");t.b(t.v(t.f("title",c,p,0)));t.b("</h2>");});c.pop();}t.b(" <div class=\"items\"> ");if(t.s(t.f("sites",c,p,1),c,p,0,84,175,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <a class=\"item\" href=\"");t.b(t.v(t.f("url",c,p,0)));t.b("\" style=\"background-image: url('");t.b(t.v(t.f("favicon",c,p,0)));t.b("')\">");t.b(t.v(t.f("title",c,p,0)));t.b("</a> ");});c.pop();}t.b(" </div>");return t.fl(); },partials: {}, subs: {  }})});
define('w/topsites/model',["lodash", "browser/api", "widgets/model"], function(_, Browser, WidgetModel) {
	return WidgetModel.extend({
		defaults: {
			config: {
				show: 5,
				size: "variable",
				title: "i18n.name"
			},
			data: {
				sites: [{
					title: "Google",
					url: "https://www.google.com/",
					favicon: "https://www.google.com/s2/favicons?domain=www.google.com&sz=32"
				}, {
					title: "Facebook",
					url: "https://www.facebook.com/",
					favicon: "https://www.google.com/s2/favicons?domain=www.facebook.com&sz=16"
				}, {
					title: "Youtube",
					url: "https://www.youtube.com/",
					favicon: "https://www.google.com/s2/favicons?domain=www.youtube.com&sz=32"
				}, {
					title: "Amazon",
					url: "https://www.amazon.com/",
					favicon: "https://www.google.com/s2/favicons?domain=www.amazon.com&sz=32"
				}, {
					title: "Wikipedia",
					url: "https://www.wikipedia.org/",
					favicon: "https://www.google.com/s2/favicons?domain=www.wikipedia.org&sz=32"
				}]
			}
		},

		initialize: function() {
			if (this.config && this.config.target) {
				delete this.config.target;
			}

			WidgetModel.prototype.initialize.call(this);
		},

		refresh: function() {
			Browser.topSites.get(function(sites) {
				this.saveData({
					sites: _.take(_.map(sites, function(e) {
						e.favicon = Browser.getFavicon(e.url);

						return e;
					}), this.config.show)
				});
			}.bind(this));
		}
	});
});
define('w/traffic/view',["moment", "widgets/views/main"], function(moment, WidgetView) {
	return WidgetView.extend({
		events: {
			"click .dest": function(e) {
				e.preventDefault();

				this._dest = this._dest === "work" ? "home" : "work";

				this.render();
			}
		},

		onBeforeRender: function(data) {
			this._dest = this._dest || (moment(this.model.config.time, "hh:mm").add(1, "hours").isAfter() ? "work" : "home");

			data.dest = this.translate("to_" + this._dest);
			data.toEnc = encodeURIComponent(this.model.config[this._dest]);
			data.fromEnc = encodeURIComponent(this.model.config[this._dest === "work" ? "home" : "work"]);

			var time = moment.duration(data[this._dest] || 0, "seconds"),
				hours = time.get("hours"),
				minutes = Math.round(time.asMinutes() % 60);

			if (this.model.get("size") === "tiny") {
				data.time = hours ? (this.translate("hours_letter", hours) + " " + this.translate("minutes_letter", minutes)) : this.translate("minute" + (minutes !== 1 ? "s" : "") + "_short", minutes);
			}
			else {
				data.time = "";

				if (hours > 0) {
					data.time += this.translate("hour" + (hours !== 1 ? "s" : ""), hours);
				}

				if (minutes > 0) {
					data.time += " " + this.translate("minute" + (minutes !== 1 ? "s" : "") + (hours > 0 ? "_short" : ""), minutes);
				}
			}

			return data;
		}
	});
});

define("widgetTemplate!w/traffic/templates/desc.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Keep up to date with the current time in traffic to either home or work.<br /> <br /> After installation, enter your home and work addresses and when you leave.");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/traffic/templates/main.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<a href=\"https://www.google.com/maps/dir/");t.b(t.v(t.f("fromEnc",c,p,0)));t.b("/");t.b(t.v(t.f("toEnc",c,p,0)));t.b("\"> <span class=\"value\">");t.b(t.v(t.f("time",c,p,0)));t.b("</span> <span class=\"label\">");t.b(t.v(t.f("dest",c,p,0)));t.b("</span> </a>");return t.fl(); },partials: {}, subs: {  }})});
define('w/traffic/model',["lodash", "jquery", "widgets/model"], function(_, $, WidgetModel) {
	return WidgetModel.extend({
		refreshInterval: 300000,

		defaults: {
			config: {
				time: "09:00",
				home: "1 Hacker Way, Menlo Park, CA 94025",
				work: "1600 Amphitheatre Pkwy, Mountain View, CA 94043",
				mode: "D",
				size: "small"
			},
			data: {
				home: 653,
				work: 542
			}
		},

		refresh: function() {
			var homeURL = "https://www.bing.com/maps/directions.ashx?d=0~1&w=" + encodeURIComponent(this.config.work || this.defaults.config.work) +
					"~" + encodeURIComponent(this.config.home || this.defaults.config.home) + "&mode=" + (this.config.mode || this.defaults.config.mode);

			var workURL = "https://www.bing.com/maps/directions.ashx?d=0~1&w=" + encodeURIComponent(this.config.home || this.defaults.config.home) +
						"~" + encodeURIComponent(this.config.work || this.defaults.config.work) + "&mode=" + (this.config.mode || this.defaults.config.mode);

			$.when($.getJSON(homeURL), $.getJSON(workURL)).then(function(homeResp, workResp) {
				var homeData = homeResp[0],
					workData = workResp[0];

				var data = {
					home: 0,
					work: 0
				};

				// We use a trycatch instead of existence checks because they get extremely long
				try {
					var homeSummary = homeData.routeResults[0].routes[0].routeLegs[0].summary;

					data.home = homeSummary.timeWithTraffic || homeSummary.time || 0;


					var workSummary = workData.routeResults[0].routes[0].routeLegs[0].summary;

					data.work = workSummary.timeWithTraffic || workSummary.time || 0;


					if (data.home && data.work) {
						this.saveData(data);
					}
				}
				catch (e) {}

				try {
					this.config.home = workData.resolvedWaypoints[0][0].address.formattedAddress;
					this.config.work = workData.resolvedWaypoints[0][1].address.formattedAddress;

					this.saveConfig();
				}
				catch (e) {}
			}.bind(this));
		}
	});
});
define('w/translate/view',["lodash", "jquery", "browser/api", "widgets/views/main"], function(_, $, Browser, WidgetView) {
	var languages = [
		["af", "Afrikaans"],
		["af", "Afrikaans"],
		["sq", "Albanian"],
		["ar", "Arabic"],
		["hy", "Armenian"],
		["az", "Azerbaijani"],
		["eu", "Basque"],
		["be", "Belarusian"],
		["bn", "Bengali"],
		["bs", "Bosnian"],
		["bg", "Bulgarian"],
		["my", "Burmese"],
		["ca", "Catalan"],
		["ceb", "Cebuano"],
		["zh-CN", "Chinese (Simplified)"],
		["zh-TW", "Chinese (Traditional)"],
		["hr", "Croatian"],
		["cs", "Czech"],
		["da", "Danish"],
		["nl", "Dutch"],
		["en", "English"],
		["eo", "Esperanto"],
		["et", "Estonian"],
		["tl", "Filipino"],
		["fi", "Finnish"],
		["fr", "French"],
		["gl", "Galician"],
		["ka", "Georgian"],
		["de", "German"],
		["el", "Greek"],
		["gu", "Gujarati"],
		["ht", "Haitian"],
		["ha", "Hausa"],
		["iw", "Hebrew"],
		["hi", "Hindi"],
		["hmn", "Hmong"],
		["hu", "Hungarian"],
		["is", "Icelandic"],
		["ig", "Igbo"],
		["id", "Indonesian"],
		["ga", "Irish"],
		["it", "Italian"],
		["ja", "Japanese"],
		["jv", "Javanese"],
		["kn", "Kannada"],
		["kk", "Kazakh"],
		["km", "Khmer"],
		["ko", "Korean"],
		["lo", "Lao"],
		["la", "Latin"],
		["lv", "Latvian"],
		["lt", "Lithuanian"],
		["mk", "Macedonian"],
		["mg", "Malagasy"],
		["ms", "Malay"],
		["ml", "Malayalam"],
		["mt", "Maltese"],
		["mi", "Maori"],
		["mr", "Marathi"],
		["mn", "Mongolian"],
		["no", "Norwegian"],
		["ny", "Nyanja"],
		["fa", "Persian"],
		["pl", "Polish"],
		["pt", "Portuguese"],
		["pa", "Punjabi"],
		["ro", "Romanian"],
		["ru", "Russian"],
		["sr", "Serbian"],
		["si", "Sinhala"],
		["sk", "Slovak"],
		["sl", "Slovenian"],
		["so", "Somali"],
		["es", "Spanish"],
		["su", "Sundanese"],
		["sw", "Swahili"],
		["sv", "Swedish"],
		["tg", "Tajik"],
		["ta", "Tamil"],
		["te", "Telugu"],
		["th", "Thai"],
		["tr", "Turkish"],
		["uk", "Ukrainian"],
		["ur", "Urdu"],
		["uz", "Uzbek"],
		["vi", "Vietnamese"],
		["cy", "Welsh"],
		["yi", "Yiddish"],
		["yo", "Yoruba"],
		["zu", "Zulu"]
	];

	return WidgetView.extend({
		events: {
			"input textarea.from": "exec",

			"change select.from, select.to": function() {
				this.model.saveData({
					from: this.from.val(),
					to: this.to.val()
				});

				this.exec();
			},

			"click button.swap": function() {
				var currFrom = this.from.val(),
					currTo = this.to.val();

				this.from.val(currTo);
				this.to.val(currFrom === "auto" ? (Browser.language === "pt-PT" ? "pt" : Browser.language) : currFrom);

				this.from.trigger("change");
			}
		},

		_lastTranslated: "",

		exec: _.throttle(function() {
			var toLang = this.to.val(),
				fromLang = this.from.val(),
				value = this.fromArea.val().trim();

			if (fromLang + "|" + toLang + "|" + value !== this._lastTranslated) {
				this._lastTranslated = fromLang + "|" + toLang + "|" + value;

				if (value === "") {
					this.status.text("");

					this.toArea.val("");

					return;
				}

				this.status.text(this.translate("translating"));

				this.model.getTranslation(value, fromLang, toLang, function(err, d) {
					// If we aren't still translating with the same parameters, abort
					if (fromLang + "|" + toLang + "|" + value !== this._lastTranslated) {
						return;
					}

					if (err || !d || !d.text) {
						this.status.text("");

						return this.toArea.val(this.translate("unknown"));
					}

					this.status.text(_.find(languages, [d.language])[1]);

					this.toArea.val(d.text);
				}.bind(this));
			}
		}, 500),

		initialize: function() {
			this.render();
		},

		onBeforeRender: function(data) {
			data.languages = languages;

			return data;
		},

		onRender: function(data) {
			this.to = this.$("select.to");
			this.status = this.$(".status");
			this.from = this.$("select.from");
			this.toArea = this.$("textarea.to");
			this.fromArea = this.$("textarea.from");

			this.from.val(data.from || "auto");
			this.to.val(data.to || (Browser.language === "pt-PT" ? "pt" : Browser.language));
		}
	});
});

define("widgetTemplate!w/translate/templates/desc.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Translate between any of 90 languages, in real time, without leaving your page.");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/translate/templates/main.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<div class=\"selectbar\"> <select class=\"from\"> <option value=\"auto\">");t.b(t.v(t.d("i18n.detect_lang",c,p,0)));t.b("</option> ");if(t.s(t.f("languages",c,p,1),c,p,0,111,147,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<option value=\"");t.b(t.v(t.f("0",c,p,0)));t.b("\">");t.b(t.v(t.f("1",c,p,0)));t.b("</option>");});c.pop();}t.b(" </select> <button type=\"button\" class=\"material toggle swap\"> <svg viewBox=\"0 0 24 24\" xmlns=\"http://www.w3.org/2000/svg\"> <path d=\"M6.99 11L3 15l3.99 4v-3H14v-2H6.99v-3zM21 9l-3.99-4v3H10v2h7.01v3L21 9z\" /> </svg> </button> <select class=\"to\"> ");if(t.s(t.f("languages",c,p,1),c,p,0,421,457,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<option value=\"");t.b(t.v(t.f("0",c,p,0)));t.b("\">");t.b(t.v(t.f("1",c,p,0)));t.b("</option>");});c.pop();}t.b(" </select> </div> <span class=\"status\"></span> <textarea class=\"from\" placeholder=\"");t.b(t.v(t.d("i18n.from_placeholder",c,p,0)));t.b("\" maxlength=\"1000\"></textarea> <textarea class=\"to\" placeholder=\"");t.b(t.v(t.d("i18n.to_placeholder",c,p,0)));t.b("\" readonly></textarea>");return t.fl(); },partials: {}, subs: {  }})});
define('w/translate/model',["jquery", "lodash", "widgets/model"], function($, _, WidgetModel) {
	return WidgetModel.extend({
		defaults: {
			data: {
				from: "auto"
			}
		},

		getTranslation: function(text, from, to, cb) {
			$.ajax({
				type: "POST",
				dataType: "text",
				url: "https://www.google.com/async/translate?nocache=" + new Date().getTime(),
				data: "async=translate,sl:" + from + ",tl:" + to + ",st:" + encodeURIComponent(text) + ",qc:true,ac:true,id:1,_pms:qd,_fmt:json",
				success: function(d) {
					try {
						d = JSON.parse(d.replace(")]}'", "").trim());
					}
					catch (e) {}

					if (!d || !d.translateData || !d.translateData.response || !d.translateData.response.sentences || !d.translateData.response.sentences.length) {
						return cb(true);
					}

					d = d.translateData.response;

					var text = _.pluck(d.sentences, "trans").join("\n").trim();

					if (text === "") {
						return cb(true);
					}

					cb(null, {
						text: text,
						language: from === "auto" ? ((d.detected_languages && d.detected_languages.srclangs && d.detected_languages.srclangs[0]) || from) : from
					});
				}.bind(this)
			}).fail(function() {
				cb(true);
			});
		}
	});
});
define('w/unitconversion/view',["widgets/views/main", "core/settings", "lodash", "jquery"], function(WidgetView, settings, _, $) {
	return WidgetView.extend({
		events: {
			"change select.uc-category": "updateCategory",
			"click .uc-refresh a": "updateCategory",
			"change select.uc-from": function(e) {
				var widget = this.getWidget(e);
				this.model.from = $(e.currentTarget).find("option:selected").val();
				this.updateConfig();
				this.directUpdate(widget);
			},
			"change select.uc-to": function(e) {
				var widget = this.getWidget(e);
				this.model.to = $(e.currentTarget).find("option:selected").val();
				this.updateConfig();
				this.directUpdate(widget);
			},
			"input input.uc-input": function(e) {
				this.model.input = $(e.currentTarget).closest(".uc-wrapper").find(".uc-input").val(); 
				this.directUpdate(this.getWidget(e));
			},
			"click div.uc-copy a": function(e) {
				var elem = $(e.currentTarget).closest(".uc-wrapper").find(".uc-result .value")[0];
				var range = document.createRange();
				range.selectNode(elem);
				window.getSelection().removeAllRanges();
				window.getSelection().addRange(range);
				document.execCommand("copy");
				window.getSelection().removeAllRanges();		
				e.preventDefault();
				e.stopPropagation();
			},
			"click div.uc-swap a": function(e) {
				var widget = this.getWidget(e);
				e.preventDefault();
				e.stopPropagation();
				var temp = this.model.from;
				this.model.from = this.model.to;
				this.model.to = temp;
				this.updateConfig();
				this.directUpdate(widget);
			}
		},

		updateCategory: function(e) {
			e.preventDefault();
			e.stopPropagation();
			var category = $(e.currentTarget).closest(".uc-wrapper").find(".uc-category").find("option:selected").val();

			if (!category) {
				this.model.area = null;
				this.render();
				return;
			}

			if (this.getCachedCategory(category)) {
				this.model.area = category;
				this.render();
				return;
			}

			$.ajax({
				type: "GET",
				url: settings.apidomain + "/unitconv/list?cat=" + category,
				headers: { 
					Accept : "application/json",
					"Content-Type": "application/json"
				},
				beforeSend: function() {
					this.render({
						loading: true
					});
				}.bind(this),
				complete: function() {
					this.render({
						loading: false
					});
				}.bind(this),
				fail: function() {
					this.model.error = true;
				}.bind(this),
				success: function(d) {
					if (typeof d !== "object") {
						d = JSON.parse(d);
					}

					var units = [{
						"k": "",
						"n": this.widget.strings.units.select_unit,
						"s": true
					}].concat(
						d.map(function(item) {
							return {
								"k": item.a,
								"n": (item.a === item.n) ? item.a : (item.a + ", " + item.n),
								"coeff": item.c
							};
						})
					);
					
					this.model.cache[category] = units;
					this.model.area = category;
					this.updateConfig(e.currentTarget);
				}.bind(this)
			});
		},

		getWidget: function(event) {
			return $(event.currentTarget).closest(".widget");
		},

		getCachedCategory: function(name) {
			this.model.cache = this.model.cache || {};
			return this.model.cache[name];
		},

		updateConfig: function() {
			if (!this.model.from || !this.model.to || !this.model.area) {
				return;
			}

			var itemFrom = this.getItem(this.model.area, this.model.from);
			var itemTo = this.getItem(this.model.area, this.model.to);
			if (!itemFrom || !itemTo) {
				return;
			}

			var config = this.model.config;
			if (config.area === this.model.area) {
				if (_.isEqual(config.from, itemFrom)) {
					if (_.isEqual(config.to, itemTo)) {
						return;
					}
				}
			}

			config.area = this.model.area;
			config.from = itemFrom;
			config.to = itemTo;

			this.model.saveConfig();
		},

		getItem: function(area, key) {
			var units = this.getCachedCategory(area);
			if (!units) {
				if (this.model.cacheTemp) {
					units = this.model.cacheTemp[area];
				}
			}

			if (!units) {
				return null;
			}

			return units.find(function(item) {
				return item.k === key;
			}.bind(this));
		},

		calculate: function(from, to, input) {
			return input / from.coeff * to.coeff;
		},

		directUpdate: function(widget) {
			var value = "";
			var unit = "";
			var fromItem = this.getItem(this.model.area, this.model.from);
			var toItem = this.getItem(this.model.area, this.model.to);
			if (fromItem && toItem) {
				var input = this.model.input;
				if (input && input !== "") {
					input = Number(input);
					if (isNaN(input)) {
						value = "ERR";
					} else {
						var calculated = this.calculate(fromItem, toItem, input);
						if (!isNaN(calculated)) {
							value = calculated > 1 ? calculated.toFixed(7) : calculated.toFixed(12);
							var parts = value.split('.');
							if (parts.length === 2 && value.indexOf('e') < 0) {
								var part1 = parts[1].replace(new RegExp("[0,.]+$"), "");
								value = parts[0];
								if (part1.length > 0) {
									value += "." + part1;
								}
							}
							
							unit = toItem.k;
						}
					}
				}
			}

			var wrapper = $(widget).find(".uc-result");
			wrapper.find('.value').text(value);
			wrapper.find('.unit').text(unit);
		},

		onBeforeRender: function(data) {
			data.config = this.model.config;
			data.area = this.model.area;
			data.from = this.model.from;
			data.to = this.model.to;
			data.input = this.model.input;

			var cats = ",acceleration,angle,apparentPower,area,charge,current,digital,each,energy,force,frequency,illuminance,length,mass,pace,partsPer,power,pressure,reactiveEnergy,reactivePower,speed,temperature,time,voltage,volume,volumeFlowRate";
			data.cat_options = cats.split(",").map(function(cat){ 
				return {
					"k": cat,
					"n": data.i18n.cat[cat || "select_category"],
					"s": data.area === cat
				};
			});

			var units = this.getCachedCategory(data.area);
			if (!units && this.model.area) {
				if (data.config && data.config.from) {
					units = [];

					units.push(data.config.from);
					if (data.config.to) {
						units.push(data.config.to);
					}
				}				

				this.model.cacheTemp = this.model.cacheTemp || {};
				this.model.cacheTemp[this.model.area] = units;
				data.offline = true;
			}

			if (!units) {
				data.froms = [];
				data.toes = [];
			} else {
				data.froms = units.map(function(item) {
					return {
						"k": item.k,
						"n": item.n,
						"s": item.k === data.from
					};
				});

				data.toes = units.map(function(item) {
					return {
						"k": item.k,
						"n": item.n,
						"s": item.k === data.to
					};
				});
			}
 
			 return data;
		}
	});
});

define("widgetTemplate!w/unitconversion/templates/desc.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("This widget converts between different units of measurement for the same quantity.");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/unitconversion/templates/main.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.d("config.title",c,p,1),c,p,0,17,57,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<h2 class=\"header\">");t.b(t.v(t.d("config.title",c,p,0)));t.b("</h2>");});c.pop();}t.b(" <div class=\"uc-wrapper\"> ");if(t.s(t.f("loading",c,p,1),c,p,0,112,346,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"loading\"> <svg class=\"spinner\" width=\"65px\" height=\"65px\" viewBox=\"0 0 66 66\" xmlns=\"http://www.w3.org/2000/svg\"> <circle fill=\"none\" stroke-width=\"6\" stroke-linecap=\"round\" cx=\"33\" cy=\"33\" r=\"30\"></circle> </svg> </div> ");});c.pop();}t.b(" ");if(!t.s(t.f("loading",c,p,1),c,p,1,0,0,"")){t.b(" <div class=\"form-group\"> <select class=\"form-control uc-category\" name=\"uc-category\"> ");if(t.s(t.f("cat_options",c,p,1),c,p,0,474,533,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <option value=\"");t.b(t.v(t.f("k",c,p,0)));t.b("\" ");if(t.s(t.f("s",c,p,1),c,p,0,503,511,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("selected");});c.pop();}t.b(">");t.b(t.v(t.f("n",c,p,0)));t.b("</option> ");});c.pop();}t.b(" </select> </div> <div class=\"uc-from-label\"> <label>");t.b(t.v(t.d("i18n.messages.from",c,p,0)));t.b("</label> <div class=\"uc-refresh\"> <a href=\"#\" title=\"");t.b(t.v(t.d("i18n.messages.refresh_tooltip",c,p,0)));t.b("\"> <span class=\"icon m-icon\">refresh</span> </a> </div> </div> <div class=\"form-group\"> <select class=\"form-control uc-from\"  name=\"uc-from\" ");if(!t.s(t.f("area",c,p,1),c,p,1,0,0,"")){t.b("disabled");};t.b(" ");if(t.s(t.f("offline",c,p,1),c,p,0,890,898,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("disabled");});c.pop();}t.b("> ");if(t.s(t.f("froms",c,p,1),c,p,0,922,981,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <option value=\"");t.b(t.v(t.f("k",c,p,0)));t.b("\" ");if(t.s(t.f("s",c,p,1),c,p,0,951,959,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("selected");});c.pop();}t.b(">");t.b(t.v(t.f("n",c,p,0)));t.b("</option> ");});c.pop();}t.b(" </select> </div> <label>");t.b(t.v(t.d("i18n.messages.to",c,p,0)));t.b("</label> <div class=\"form-group\"> <select class=\"form-control uc-to\"  name=\"uc-to\" ");if(!t.s(t.f("area",c,p,1),c,p,1,0,0,"")){t.b("disabled");};t.b(" ");if(t.s(t.f("offline",c,p,1),c,p,0,1158,1166,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("disabled");});c.pop();}t.b("> ");if(t.s(t.f("toes",c,p,1),c,p,0,1189,1248,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <option value=\"");t.b(t.v(t.f("k",c,p,0)));t.b("\" ");if(t.s(t.f("s",c,p,1),c,p,0,1218,1226,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("selected");});c.pop();}t.b(">");t.b(t.v(t.f("n",c,p,0)));t.b("</option> ");});c.pop();}t.b(" </select> </div> <div class=\"uc-result-wrapper\"> <div class=\"uc-values\"> <div class=\"uc-source\"> <input type=\"search\" class=\"form-control uc-input\" value=\"");t.b(t.v(t.f("input",c,p,0)));t.b("\" /> </div> <div class=\"uc-result\"> = <span class=\"value\"></span> <span class=\"unit\"></span> </div> </div> <div class=\"uc-copy\"> <a href=\"#\" title=\"");t.b(t.v(t.d("i18n.messages.copy_tooltip",c,p,0)));t.b("\"> <span class=\"icon m-icon\">description</span> </a> </div> <div class=\"uc-swap\"> <a href=\"#\" title=\"");t.b(t.v(t.d("i18n.messages.swap_tooltip",c,p,0)));t.b("\"> <span class=\"icon m-icon\">swap_vert</span> </a> </div> </div> ");};t.b(" </div> ");return t.fl(); },partials: {}, subs: {  }})});
define('w/unitconversion/model',["jquery", "lodash", "browser/api", "widgets/model"], function($, _, Browser, WidgetModel) {
	return WidgetModel.extend({
		widgetClassname: "tabbed",

		qty: 1,
		result_value: "55.55",
		result_currency: "GBP",
		// category: "Select a category...",

		defaults: {
			config: {
				title: "i18n.default_title",
				category: ""
			},
			data: {
			}
		},

		/**
		 * We override this so we only refresh once on init
		 */
		initialize: function() {
			if (this.config) {
				if (this.config.from) {
					this.from = this.config.from.k;
				}
				if (this.config.to) {
					this.to = this.config.to.k;
				}
				this.area = this.config.area;
			}	
		}
	});
});
define('w/unread/view',["widgets/views/main"], function(WidgetView) {
	return WidgetView.extend({
		onBeforeRender: function(data) {
			data.user = this.model.config.user || 0;
			data.inbox = this.model.config.open === "inbox";

			if (data.count === 0) {
				data.label = this.translate("unread_none");
			}
			else if (data.count === 1) {
				data.label = this.translate("unread_one");
			}
			else {
				data.label = this.translate("unread_many");
			}

			data.count = data.count.toLocaleString();

			return data;
		}
	});
});

define("widgetTemplate!w/unread/templates/desc.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Use this widget to keep track of your unread emails in Gmail.<br /> <br /> Please note that you'll need to be signed in for this widget to get your unread messages.");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/unread/templates/main.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<a href=\"");if(t.s(t.f("inbox",c,p,1),c,p,0,19,54,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("https://inbox.google.com/u/");t.b(t.v(t.f("user",c,p,0)));});c.pop();}if(!t.s(t.f("inbox",c,p,1),c,p,1,0,0,"")){t.b("https://mail.google.com/?authuser=");t.b(t.v(t.f("user",c,p,0)));};t.b("\"> <span class=\"value\" data-tooltip=\"");if(t.s(t.f("messages",c,p,1),c,p,0,176,223,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<b>");t.b(t.v(t.f("subject",c,p,0)));t.b("</b><br />");t.b(t.v(t.f("excerpt",c,p,0)));t.b("<br /><br />");});c.pop();}t.b("\">");t.b(t.v(t.f("count",c,p,0)));t.b("</span> <span class=\"label\">");t.b(t.v(t.f("label",c,p,0)));t.b("</span> </a>");return t.fl(); },partials: {}, subs: {  }})});
define('w/unread/model',["lodash", "jquery", "browser/api", "widgets/model"], function(_, $, Browser, WidgetModel) {
	return WidgetModel.extend({
		refreshInterval: 120000,

		defaults: {
			config: {
				user: "0",
				open: "gmail"
			},
			data: {
				count: 1,
				messages: [
					{
						subject: "This is a sample message subject",
						excerpt: "And this is some sample message content!!"
					}
				]
			}
		},

		refresh: function() {
			var cancelFn = function() {
				return {
					cancel: true
				};
			};

			Browser.webRequest.onAuthRequired.addListener(cancelFn, {
				urls: ["https://mail.google.com/mail/u/*/feed/atom/"],
				types: ["xmlhttprequest"]
			}, ["blocking"]);

			$.get("https://mail.google.com/mail/u/" + (this.config.user || 0) + "/feed/atom/", function(d) {
				try {
					d = $(d);

					this.saveData({
						count: parseInt(d.find("fullcount").text()) || 0,
						messages: _.map(d.find("entry").toArray().slice(0, 4), function(e) {
							return {
								subject: e.querySelector("title").textContent,
								excerpt: e.querySelector("summary").textContent
							};
						})
					});
				}
				catch (e) {
					this.saveData({
						count: 0,
						messages: []
					});
				}
			}.bind(this)).fail(function() {
				this.saveData({
					count: 0,
					messages: []
				});
			}.bind(this)).always(function() {
				Browser.webRequest.onAuthRequired.removeListener(cancelFn);
			});
		}
	});
});
define('w/voice/view',["widgets/views/main"], function(WidgetView) {
	return WidgetView.extend({
		onBeforeRender: function(data) {
			data.user = this.model.config.user || 0;

			return data;
		}
	});
});

define("widgetTemplate!w/voice/templates/desc.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Use this widget to keep track of your missed calls and text messages in Google Voice.<br /> <br /> Please note that this widget can't get your missed calls and messages if you aren't signed in.");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/voice/templates/main.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<a href=\"https://www.google.com/voice/b/");t.b(t.v(t.f("user",c,p,0)));t.b("/\"> <span class=\"value\" data-tooltip=\"<b><span style=&quot;float:right&quot;>");t.b(t.v(t.f("texts",c,p,0)));t.b(" ");t.b(t.v(t.d("i18n.texts",c,p,0)));t.b("</span>");t.b(t.v(t.f("missed",c,p,0)));t.b(" ");t.b(t.v(t.d("i18n.calls",c,p,0)));t.b("&nbsp;&nbsp;&nbsp;</b><br /><br />");if(t.s(t.f("messages",c,p,1),c,p,0,228,441,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<b>");t.b(t.v(t.f("type",c,p,0)));t.b(": ");t.b(t.v(t.f("from",c,p,0)));t.b("<span style=&quot;float:right&quot;>");t.b(t.v(t.f("date",c,p,0)));t.b("</span></b><br />");if(t.s(t.f("excerpt",c,p,1),c,p,0,322,423,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<span style=&quot;display:inline-block;max-height:60px;overflow:hidden&quot;>");t.b(t.v(t.f("excerpt",c,p,0)));t.b("</span><br />");});c.pop();}t.b("<br />");});c.pop();}t.b("\">");t.b(t.v(t.f("count",c,p,0)));t.b("</span> <span class=\"label\">");t.b(t.v(t.d("i18n.missed",c,p,0)));t.b("</span> </a>");return t.fl(); },partials: {}, subs: {  }})});
define('w/voice/model',["lodash", "jquery", "widgets/model"], function(_, $, WidgetModel) {
	return WidgetModel.extend({
		refreshInterval: 120000,

		defaults: {
			config: {
				size: "tiny",
				user: "0"
			},
			data: {
				count: 1,
				texts: 0,
				missed: 1,
				messages: [
					{
						type: "Call",
						date: "1 hour ago",
						from: "(123) 456-7890",
						excerpt: "This is a sample transcript from a voicemail"
					}
				]
			}
		},

		refresh: function() {
			$.get("https://www.google.com/voice/b/" + (this.config.user || 0) + "/inbox/recent/all/", function(d) {
				try {
					if (!(d && (d = $(d)) && (d = d.find("json")).length && (d = d.text()) && (d = JSON.parse(d)) && d.unreadCounts)) {
						return;
					}

					var data = {
						count: d.unreadCounts.all || 0,
						texts: d.unreadCounts.sms || 0,
						missed: d.unreadCounts.inbox || 0
					};

					var call = this.translate("call"),
						text = this.translate("text");

					data.messages = _(d.messages).filter("isRead").map(function(e) {
						return {
							from: e.displayNumber,
							date: e.relativeStartTime,
							excerpt: e.messageText || e.note || false,
							type: (e.type === 10 || e.type === 11) ? text : call
						};
					}).compact().take(4).value();

					this.saveData(data);
				}
				catch (e) {
					this.error();
				}
			}.bind(this));
		}
	});
});
define('w/weather/view',["lodash", "jquery", "widgets/views/main"], function(_, $, WidgetView) {
	return WidgetView.extend({
		events: {
			"click .temp .toggle span": function(e) {
				e.preventDefault();
				e.stopPropagation();

				this.model.config.units = e.currentTarget.getAttribute("data-units") === "metric" ? "metric" : "imperial";

				this.model.saveConfig();

				this.model.refresh();
			},

			"click .header-wrapper .toggle-hourly span:last-child": function(e) {
				if (!this.Auth.isPro) {
					return;
				}

				e.preventDefault();
				e.stopPropagation();

				this.model.config.hourly = (this.model.config.hourly === "enabled") ? "" : "enabled";

				this.model.saveConfig();

				this.model.refresh();
			},

			"click button.more": function(e) {
				var btn = $(e.currentTarget),
					details = btn.parent().next(".details"),
					isVisible = details.hasClass("visible");

				e.stopPropagation();

				btn.text(this.translate(isVisible ? "more" : "less"));

				if (isVisible) {
					details.css("height", details[0].offsetHeight);

					requestAnimationFrame(function() {
						details.removeClass("visible").css("height", "");
					});
				}
				else {
					// Remove the transition and get the final height
					details.css("transition", "none").addClass("visible");

					var height = details[0].offsetHeight;

					// Reset the element
					details.css("transition", "").removeClass("visible");

					// Trigger layout
					details[0].offsetHeight; // jshint ignore:line

					// Add the visible class
					details.addClass("visible");

					// Set the final height so we transition smoothly
					details.css("height", height);

					setTimeout(function() {
						details.css("height", "");
					}, 200);
				}
			},

			"keydown .forecast": function(e) {
				var dir;

				if (e.which === 39 || e.which === 40) {
					dir = "next";
				}
				else if (e.which === 37 || e.which === 38) {
					dir = "prev";
				}

				if (!dir) {
					return;
				}

				// Stop the tabs from scrolling
				e.stopPropagation();


				var fElm = $(e.currentTarget),
					items = fElm.find(".items .item.active");

				var selectedElm = items[dir](".item");

				if (!selectedElm.length && e.currentTarget.classList.contains("hourly")) {
					// Move the daily forecast up one
					fElm.prev(".forecast").trigger($.Event("keydown", { which: dir === "next" ? 39 : 37 }));

					// And make the first hourly item active
					selectedElm = fElm.find(".items .item")[dir === "next" ? "first" : "last"]();

					if (dir === "prev") {
						// Scroll to the end
						fElm.find(".items .pull").css("margin-left", -(selectedElm[0].parentElement.scrollWidth - selectedElm[0].parentElement.offsetWidth));

						fElm.find("button.prev").prop("disabled", false).siblings(".next").prop("disabled", true);
					}
				}
				else if (!selectedElm.length) {
					selectedElm = items.siblings(".item")[dir === "next" ? "first" : "last"]();
				}

				selectedElm.click();

				// If the element isn't mostly in view, scroll it into view
				if (selectedElm[0].offsetLeft + 30 < 0) {
					fElm.find("button.prev").click();
				}
				else if (selectedElm[0].offsetLeft + selectedElm[0].offsetWidth - 30 > selectedElm[0].parentElement.offsetWidth) {
					fElm.find("button.next").click();
				}
			},

			"click .forecast button": "scrollForecast",
			"click .forecast.daily .item[data-index]": "loadDailyForecast",
			"click .forecast.hourly .item[data-index]": "loadHourlyForecast"
		},


		loadDailyForecast: function(e) {
			if (!this.Auth.isPro) {
				return;
			}

			var elm = $(e.currentTarget),
				loc = elm.parents(".location").first();

			var day = elm.attr("data-index"),
				locIndex = loc.attr("data-index");

			var dayForecast = this.model.data.weather[locIndex].forecast[day];

			this.activeDays[locIndex] = dayForecast;

			elm.addClass("active").siblings().removeClass("active");

			loc.children(".current").html(this.widget.templates.details.render({
				current: dayForecast,
				isPro: this.Auth.isPro,
				i18n: this.widget.strings,
				units: this.model.data.units,
				showDetails: loc.find(".current .details.extended").hasClass("visible")
			}));


			if (dayForecast.hourly) {
				loc.find(".forecast.hourly .items").html('<div class="pull"></div>' +

					_.map(dayForecast.hourly, function(e, i) {
						return '<div class="item" data-index="' + i + '">' +
							'<div class="period">' + e.date + '</div>' +

							'<div class="cond ' + e.conditions + '" title="' + e.caption + '"></div>' +

							'<span class="temp">' + e.temp + '&deg;</span>' +
						'</div>';
					}).join("")
				);

				loc.find(".forecast.hourly button.prev").prop("disabled", true).siblings(".next").prop("disabled", false);
			}
		},


		loadHourlyForecast: function(e) {
			var elm = $(e.currentTarget),
				loc = elm.parents(".location").first();

			var locIndex = loc.attr("data-index"),
				activeDay = this.activeDays[locIndex] || this.model.data.weather[locIndex].forecast[0];

			var hourForecast = activeDay.hourly[elm.attr("data-index")];

			elm.addClass("active").siblings().removeClass("active");

			loc.children(".current").html(this.widget.templates.details.render({
				current: hourForecast,
				isPro: this.Auth.isPro,
				i18n: this.widget.strings,
				units: this.model.data.units,
				showDetails: loc.find(".current .details.extended").hasClass("visible")
			}));
		},


		scrollForecast: function(e) {
			var direction = e.currentTarget.getAttribute("data-direction");

			// The prev and next buttons appear just before and just after the items list, respectively
			var items = e.currentTarget.nextElementSibling || e.currentTarget.previousElementSibling;

			var pull = items.children[0],
				offsetWidth = items.offsetWidth,
				finalLeft = -(parseInt(pull.style.marginLeft) || 0);


			// The scrollWidth value isn't the width of the scrollable content
			// since we aren't scrolling. We need to add our offset back to get
			// the actual value
			var scrollWidth = items.scrollWidth + finalLeft;


			// Scroll by the element width, minus some padding
			if (direction === "left") {
				finalLeft -= offsetWidth - 50;

				// This stops the forecast from scrolling to just after the beginning
				if (finalLeft < 60) {
					finalLeft = 0;
				}
			}
			else if (direction === "right") {
				finalLeft += offsetWidth - 50;

				if (finalLeft + offsetWidth + 60 >= scrollWidth) {
					finalLeft = scrollWidth - offsetWidth;
				}
			}

			if (finalLeft < 0) {
				finalLeft = 0;
			}


			pull.style.marginLeft = -finalLeft + "px";

			// Update the state of the navigation buttons
			if (scrollWidth - offsetWidth > 15) {
				items.previousElementSibling.disabled = finalLeft === 0;

				items.nextElementSibling.disabled = finalLeft + offsetWidth >= scrollWidth - 10;
			}
		},


		activeDays: {},

		onBeforeRender: function(data) {
			if (!data.weather) {
				data.weather = [];
			}

			this.activeDays = {};

			data.units = this.model.data.units || {};

			data.unitsToggle = [{
				value: "imperial",
				label: "F"
			}, {
				value: "metric",
				label: "C"
			}];

			if (data.units.temp === "C") {
				data.unitsToggle = [data.unitsToggle[1], data.unitsToggle[0]];
			}


			if (this.Auth.isPro) {
				data.weather = _.each(data.weather, function(loc) {
					if (loc.forecast && loc.forecast[0]) {
						loc.forecast[0].active = true;
					}
				}, this);
			}

			return data;
		},

		render: function(data, partials) {
			return WidgetView.prototype.render.call(this, data || this.model.data, partials || {
				details: this.widget.templates.details
			});
		}
	});
});

define("widgetTemplate!w/weather/templates/desc.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("Use this widget to display the weather and a forecast for the next 5 days on your page.  After installation, enter your location in the settings. <br /><br /> Pro users get hourly and daily forecasts for the next 10 days, and can select any to view more details.");return t.fl(); },partials: {}, subs: {  }})});

define("widgetTemplate!w/weather/templates/main.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");if(t.s(t.f("weather",c,p,1),c,p,0,12,1984,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"location\" data-index=\"");t.b(t.v(t.f("index",c,p,0)));t.b("\"> <div class=\"");if(!t.s(t.f("tiny",c,p,1),c,p,1,0,0,"")){t.b("header-wrapper");};t.b("\"> <h2 class=\"header\"><a href=\"https://www.google.com/search?q=weather%20");t.b(t.v(t.f("nameEnc",c,p,0)));t.b("\">");t.b(t.v(t.f("name",c,p,0)));t.b("</a></h2> ");if(!t.s(t.f("tiny",c,p,1),c,p,1,0,0,"")){t.b(" <div> <div class=\"toggle-hourly\"> <span data-units=\"D\" class=\"active\">D</span> <span>/</span> <span data-title=\"title-weather\" data-units=\"H\" class=\"");if(!t.s(t.f("isPro",c,p,1),c,p,1,0,0,"")){t.b("upgrade-to-pro");};t.b(" ");t.b(t.v(t.f("hourly",c,p,0)));t.b("\">H</span> </div> </div> ");};t.b(" </div> ");if(t.s(t.f("tiny",c,p,1),c,p,0,462,703,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <span class=\"temp\"> ");t.b(t.v(t.d("current.temp",c,p,0)));t.b("&deg;<sup class=\"toggle\"> <span data-units=\"");t.b(t.v(t.d("unitsToggle.0.value",c,p,0)));t.b("\" class=\"active\">");t.b(t.v(t.d("unitsToggle.0.label",c,p,0)));t.b("</span> <span data-units=\"");t.b(t.v(t.d("unitsToggle.1.value",c,p,0)));t.b("\">");t.b(t.v(t.d("unitsToggle.1.label",c,p,0)));t.b("</span> </sup> </span> ");});c.pop();}t.b(" ");if(!t.s(t.f("tiny",c,p,1),c,p,1,0,0,"")){t.b(" <div class=\"current\"> ");t.b(t.rp("<details0",c,p,""));t.b(" </div> ");if(t.s(t.d("forecast.0.date",c,p,1),c,p,0,785,1366,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"forecast daily");if(t.s(t.f("isPro",c,p,1),c,p,0,822,829,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" is-pro");});c.pop();}t.b("\" tabindex=\"-1\"> <button type=\"button\" class=\"material fab prev\" data-direction=\"left\" disabled></button> <div class=\"items\"> <div class=\"pull\"></div> ");if(t.s(t.f("forecast",c,p,1),c,p,0,1003,1257,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"item");if(t.s(t.f("active",c,p,1),c,p,0,1031,1038,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" active");});c.pop();}t.b("\" data-index=\"");t.b(t.v(t.f("index",c,p,0)));t.b("\"> <div class=\"period\">");t.b(t.v(t.f("date",c,p,0)));t.b("</div> <div class=\"cond ");t.b(t.v(t.f("conditions",c,p,0)));t.b("\" title=\"");t.b(t.v(t.f("caption",c,p,0)));t.b("\"></div> <span class=\"high\">");t.b(t.v(t.f("high",c,p,0)));t.b("&deg;</span> / <span class=\"low\">");t.b(t.v(t.f("low",c,p,0)));t.b("&deg;</span> </div> ");});c.pop();}t.b(" </div> <button type=\"button\" class=\"material fab next\" data-direction=\"right\"></button> </div> ");});c.pop();}t.b(" ");if(t.s(t.d("forecast.0.hourly.0",c,p,1),c,p,0,1411,1942,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"forecast hourly");if(t.s(t.f("isPro",c,p,1),c,p,0,1449,1456,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" is-pro");});c.pop();}t.b("\" tabindex=\"-1\"> <button type=\"button\" class=\"material fab prev\" data-direction=\"left\" disabled></button> <div class=\"items\"> <div class=\"pull\"></div> ");if(t.s(t.d("forecast.0.hourly",c,p,1),c,p,0,1639,1824,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"item\" data-index=\"");t.b(t.v(t.f("index",c,p,0)));t.b("\"> <div class=\"period\">");t.b(t.v(t.f("date",c,p,0)));t.b("</div> <div class=\"cond ");t.b(t.v(t.f("conditions",c,p,0)));t.b("\" title=\"");t.b(t.v(t.f("caption",c,p,0)));t.b("\"></div> <span class=\"temp\">");t.b(t.v(t.f("temp",c,p,0)));t.b("&deg;</span> </div> ");});c.pop();}t.b(" </div> <button type=\"button\" class=\"material fab next\" data-direction=\"right\"></button> </div> ");});c.pop();}t.b(" ");};t.b(" </div> ");});c.pop();}return t.fl(); },partials: {"<details0":{name:"details", partials: {}, subs: {  }}}, subs: {  }})});

define("widgetTemplate!w/weather/templates/details.hjs",["hogan"],function(h){return new h.Template({code: function (c,p,i) { var t=this;t.b(i=i||"");t.b("<div class=\"cond ");t.b(t.v(t.d("current.conditions",c,p,0)));t.b("\"></div> <span class=\"temp\"> ");if(t.s(t.d("current.temp",c,p,1),c,p,0,85,101,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(t.v(t.d("current.temp",c,p,0)));});c.pop();}t.b(t.v(t.d("current.high",c,p,0)));t.b("&deg;<sup class=\"toggle\"> <span data-units=\"");t.b(t.v(t.d("unitsToggle.0.value",c,p,0)));t.b("\" class=\"active\">");t.b(t.v(t.d("unitsToggle.0.label",c,p,0)));t.b("</span> <span data-units=\"");t.b(t.v(t.d("unitsToggle.1.value",c,p,0)));t.b("\">");t.b(t.v(t.d("unitsToggle.1.label",c,p,0)));t.b("</span> </sup> </span> <div class=\"details\"> <div class=\"status\">");t.b(t.v(t.d("current.caption",c,p,0)));t.b("</div> ");if(!t.s(t.f("isPro",c,p,1),c,p,1,0,0,"")){t.b(" <div class=\"wind\"> <span>");t.b(t.v(t.d("i18n.wind",c,p,0)));t.b("</span> <svg xmlns=\"http://www.w3.org/2000/svg\" class=\"direction\" viewBox=\"0 0 24 24\"> <path d=\"M12 2L4.5 20.29l.71.71L12 18l6.79 3 .71-.71z\" style=\"transform: rotate(");t.b(t.v(t.d("current.windDir",c,p,0)));t.b("deg)\" /> </svg> ");t.b(t.v(t.d("current.windSpeed",c,p,0)));t.b(" ");t.b(t.v(t.d("units.speed",c,p,0)));t.b(" </div> ");};t.b(" <div><span>");t.b(t.v(t.d("i18n.precipitation",c,p,0)));t.b("</span> ");t.b(t.v(t.d("current.precip",c,p,0)));t.b("%</div> ");if(t.s(t.f("isPro",c,p,1),c,p,0,790,938,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<button type=\"button\" class=\"material flat more\">");if(t.s(t.f("showDetails",c,p,1),c,p,0,855,868,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(t.v(t.d("i18n.less",c,p,0)));});c.pop();}if(!t.s(t.f("showDetails",c,p,1),c,p,1,0,0,"")){t.b(t.v(t.d("i18n.more",c,p,0)));};t.b("</button>");});c.pop();}t.b(" </div> ");if(t.s(t.f("isPro",c,p,1),c,p,0,966,2275,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" ");if(t.s(t.f("current",c,p,1),c,p,0,979,2262,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"details extended");if(t.s(t.f("showDetails",c,p,1),c,p,0,1024,1032,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" visible");});c.pop();}t.b("\"> ");if(t.s(t.f("windSpeed",c,p,1),c,p,0,1065,1335,"{{ }}")){t.rs(c,p,function(c,p,t){t.b(" <div class=\"wind\"> <span>");t.b(t.v(t.d("i18n.wind",c,p,0)));t.b("</span> <svg xmlns=\"http://www.w3.org/2000/svg\" class=\"direction\" viewBox=\"0 0 24 24\"> <path d=\"M12 2L4.5 20.29l.71.71L12 18l6.79 3 .71-.71z\" style=\"transform: rotate(");t.b(t.v(t.f("windDir",c,p,0)));t.b("deg)\" /> </svg> ");t.b(t.v(t.f("windSpeed",c,p,0)));t.b(" ");t.b(t.v(t.d("units.speed",c,p,0)));t.b(" </div> ");});c.pop();}t.b(" ");if(t.s(t.f("uv",c,p,1),c,p,0,1357,1399,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div><span>");t.b(t.v(t.d("i18n.uv",c,p,0)));t.b("</span> ");t.b(t.v(t.f("uv",c,p,0)));t.b("</div>");});c.pop();}t.b(" ");if(t.s(t.f("feelsLike",c,p,1),c,p,0,1421,1482,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div><span>");t.b(t.v(t.d("i18n.feelslike",c,p,0)));t.b("</span> ");t.b(t.v(t.f("feelsLike",c,p,0)));t.b("&deg;</div>");});c.pop();}t.b(" ");if(t.s(t.f("baro",c,p,1),c,p,0,1506,1576,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div><span>");t.b(t.v(t.d("i18n.barometer",c,p,0)));t.b("</span> ");t.b(t.v(t.f("baro",c,p,0)));t.b(" ");t.b(t.v(t.d("units.pressure",c,p,0)));t.b("</div>");});c.pop();}t.b(" ");if(t.s(t.f("visibility",c,p,1),c,p,0,1601,1678,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div><span>");t.b(t.v(t.d("i18n.visibility",c,p,0)));t.b("</span> ");t.b(t.v(t.f("visibility",c,p,0)));t.b(" ");t.b(t.v(t.d("units.distance",c,p,0)));t.b("</div>");});c.pop();}t.b(" ");if(t.s(t.f("humidity",c,p,1),c,p,0,1707,1762,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div><span>");t.b(t.v(t.d("i18n.humidity",c,p,0)));t.b("</span> ");t.b(t.v(t.f("humidity",c,p,0)));t.b("%</div>");});c.pop();}t.b(" ");if(t.s(t.f("dewPoint",c,p,1),c,p,0,1789,1848,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div><span>");t.b(t.v(t.d("i18n.dewpoint",c,p,0)));t.b("</span> ");t.b(t.v(t.f("dewPoint",c,p,0)));t.b("&deg;</div>");});c.pop();}t.b(" ");if(t.s(t.f("moonPhase",c,p,1),c,p,0,1876,1932,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div><span>");t.b(t.v(t.d("i18n.moonphase",c,p,0)));t.b("</span> ");t.b(t.v(t.f("moonPhase",c,p,0)));t.b("</div>");});c.pop();}t.b(" ");if(t.s(t.f("sunrise",c,p,1),c,p,0,1959,2011,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div><span>");t.b(t.v(t.d("i18n.sunrise",c,p,0)));t.b("</span> ");t.b(t.v(t.f("sunrise",c,p,0)));t.b("</div>");});c.pop();}t.b(" ");if(t.s(t.f("sunset",c,p,1),c,p,0,2035,2085,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div><span>");t.b(t.v(t.d("i18n.sunset",c,p,0)));t.b("</span> ");t.b(t.v(t.f("sunset",c,p,0)));t.b("</div>");});c.pop();}t.b(" ");if(t.s(t.f("moonrise",c,p,1),c,p,0,2110,2164,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div><span>");t.b(t.v(t.d("i18n.moonrise",c,p,0)));t.b("</span> ");t.b(t.v(t.f("moonrise",c,p,0)));t.b("</div>");});c.pop();}t.b(" ");if(t.s(t.f("moonset",c,p,1),c,p,0,2190,2242,"{{ }}")){t.rs(c,p,function(c,p,t){t.b("<div><span>");t.b(t.v(t.d("i18n.moonset",c,p,0)));t.b("</span> ");t.b(t.v(t.f("moonset",c,p,0)));t.b("</div>");});c.pop();}t.b(" </div> ");});c.pop();}t.b(" ");});c.pop();}return t.fl(); },partials: {}, subs: {  }})});
define('w/weather/model',["lodash", "widgets/model", "moment"], function(_, WidgetModel, moment) {
	return WidgetModel.extend({
		refreshInterval: 300000,

		pro_tooltip: "weather",

		defaults: {
			config: {
				size: "variable",
				units: "imperial",
				hourly: "enabled",
				forecast: "enabled",
				location: ["San Francisco, CA"],
				resolvedLocs: ["defaultLoc"],
				resolvedNames: ["San Francisco, CA"]
			},

			data: {
				pro_tooltip: "text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 text 11 22 ",
				units: {
					temp: "F",
					pressure: "in",
					speed: "mph",
					distance: "mi"
				},
				weather: [
					{
						name: "San Francisco, CA",
						current: {
							caption: "Mostly Sunny",
							icon: 2,
							temp: 59,
							windSpeed: 4,
							windDir: 136,
							precip: 0,
							conditions: "sunny"
						},
						forecast: [
							{
								caption: "Sunny",
								icon: 1,
								high: 62,
								low: 49,
								windSpeed: 9,
								precip: 0,
								windDir: 97,
								date: "Thu",
								conditions: "sunny"
							},
							{
								caption: "Sunny",
								icon: 1,
								high: 62,
								low: 50,
								windSpeed: 7,
								precip: 0,
								windDir: 109,
								date: "Fri",
								conditions: "sunny"
							},
							{
								caption: "Sunny",
								icon: 1,
								high: 60,
								low: 51,
								windSpeed: 13,
								precip: 30,
								windDir: 1,
								date: "Sat",
								conditions: "sunny"
							},
							{
								caption: "Sunny",
								icon: 1,
								high: 58,
								low: 47,
								windSpeed: 24,
								precip: 80,
								windDir: 123,
								date: "Sun",
								conditions: "sunny"
							},
							{
								caption: "Sunny",
								icon: 1,
								high: 58,
								low: 50,
								windSpeed: 17,
								precip: 10,
								windDir: 146,
								date: "Mon",
								conditions: "sunny"
							}
						]
					}
				]
			}
		},

		autocomplete: function(val, cb) {
			this.Auth.ajax({
				url: "/weather/autocomplete?s=" + val,
				success: function(d) {
					if (d && typeof(d) === "string") {
						try {
							var data = JSON.parse(d);
							var items = _.compact(_.flatten(_.map(data, function(e) {
								if (e === "%s" || e === "")	{ return null; }
								var tokens = e.split(",");
								var value = e;
								var label = e;
								if (tokens.length !== 3) {
									return {
										value: value,
										label: label
									};
								}
								
								return [
									{
										value: tokens[0] + "," +  tokens[2] /*+ "," + tokens[1] + " region"*/,
										label: tokens[0] + "," +  tokens[2] /*+ "," + tokens[1] + " region"*/,
									},
									{
										value: tokens[0] + "," +  tokens[2] + "," + tokens[1] + " region",
										label: tokens[0] + "," +  tokens[2] + "," + tokens[1] + " region",
									},
								];								
							})));
							if (items && items.length > 0) {
								var empty = {
									value: "<novalue>",
									label: "."
								};
	
								items = [empty].concat(items);
							}
							cb(items);
						} catch(e) {
						}							
					}
				}.bind(this)
			});
		},

		initialize: function() {
			WidgetModel.prototype.initialize.call(this);

			if (this.config.woeid || this.config.woeloc) {
				delete this.config.woeid;
				delete this.config.woeloc;
			}

			if (this.config.units && this.config.units === "standard") {
				this.config.units = "imperial";
			}

			if (this.get("size") === "small") {
				this.config.forecast = "disabled";

				this.set("size", "variable");
			}
			else if (this.get("size") === "medium") {
				this.set("size", "variable");
			}


			// If we're previewing, refresh anyway so Pro users can test a fully interactive version
			if (this.isPreview) {
				this.refresh();
			}
		},

		resolveLocs: function(cb) {
			var arr = this.config.location.slice();

			arr.forEach(function(e, i, a) { a[i] = e.replace(/\|/g, " "); });

			this.Auth.ajax({
				url: "/weather/locations/resolve/" + encodeURIComponent(arr.join("|")),
				success: function(d) {
					if (d && d.locations) {
						this.config.location = [];
						this.config.resolvedLocs = [];
						this.config.resolvedNames = [];

						_.each(d.locations, function(e) {
							this.config.location.push(e.name);
							this.config.resolvedNames.push(e.name);
							this.config.resolvedLocs.push([e.lat, e.lon]);
						}, this);
					}
					else {
						this.config.resolvedLocs = ["defaultLoc"];

						this.config.location = ["San Francisco, CA"];
						this.config.resolvedNames = ["San Francisco, CA"];
					}

					cb.call(this);
				}.bind(this)
			});
		},

		getCondition: function(code) {
			if (typeof code === "string") {
				code = parseInt(code);
			}

			switch (code) {
				case 1:
				case 2: //"Mostly Sunny"
				case 39: //"Fair"
					return "sunny";

				case 3:
				case 4:
					return "partlycloudy";

				case 5:
				case 6:
				case 7:
				case 9:
				case 12:
				case 32:
				case 36: //"Fog"
				case 90: //"Smoke"
				case 91:
					return "cloudy";

				case 8:
				case 19:
				case 46:
					return "lightrain";

				case 14:
				case 22:
				case 49: //"Rain"
					return "rain";

				case 10:
				case 15:
				case 25:
				case 52:
					return "snow";

				case 16:
				case 20:
				case 26:
				case 43:
				case 47:
				case 82:
					return "lightsnow";

				case 23:
					return "showers";

				case 24:
				case 75:
				case 76: //"Light Rain and Snow"
				case 77:
				case 78:
					return "lightrain-snow";

				case 27:
				case 54:
					return "tstorms";

				case 28:
				case 29: //"Mostly Clear"				
					return "clear-night";

				case 30:
				case 31: //"Mostly cloudy"
					return "partlycloudy-night";

				case 50:
					return "showers-night";

				default:
					return "sunny";
			}
		},

		refresh: function() {
			var get = function() {
				var done = 0,
					units,
					erred = false,
					locs = this.config.resolvedLocs.length,
					weather = new Array(this.config.resolvedLocs.length);

				var next = function(err) {
					if (err || erred) {
						erred = true;

						return;
					}

					done++;

					if (done !== locs) {
						return;
					}

					this.saveData({
						units: units,
						weather: weather
					});
				}.bind(this);

				_.each(this.config.resolvedLocs, function(loc, i) {
					var isDefaultLoc = loc === "defaultLoc";

					if (isDefaultLoc) {
						loc = [37.777, -122.42];
					}

					this.Auth.ajax({
						url: "/weather",
						data: {
							lat: loc[0],
							lon: loc[1],
							units: this.config.units || null,
							hourly: this.config.hourly === "enabled" ? true : null,
							nc: new Date().getTime()
						}
					}).done(function(d) {
						if (!d) {
							return next(true);
						}

						if (typeof d !== "object") {
							try {
								d = JSON.parse(d);
							}
							catch (e) {
								return next(true);
							}
						}

						if (!units && d.units) {
							units = d.units;
						}

						var ret = {
							index: i,
							name: this.config.resolvedNames[i],
							nameEnc: encodeURIComponent(this.config.resolvedNames[i]),
							current: d.current,
							hourly: this.config.hourly === "enabled" && this.Auth.isPro ? "active" : "" 
						};

						var formatValues = function(d) {
							if (d.icon) {
								d.conditions = this.getCondition(d.icon);
							}

							if (d.sunrise) {
								d.sunrise = moment(d.sunrise).format("LT");
							}

							if (d.sunset) {
								d.sunset = moment(d.sunset).format("LT");
							}

							if (d.moonrise) {
								d.moonrise = moment(d.moonrise).format("LT");
							}

							if (d.moonset) {
								d.moonset = moment(d.moonset).format("LT");
							}

							return d;
						}.bind(this);

						formatValues(ret.current);

						if (!this.config.forecast || this.config.forecast === "enabled") {
							ret.forecast = _.map(d.forecast, function(e, i) {
								e.hourly = _.map(e.hourly, function(e, i) {
									e.index = i;

									e.date = moment(e.date).format("h A");

									return formatValues(e);
								});

								e.index = i;

								e.date = moment(e.date).format("ddd");

								return formatValues(e);
							});
						}

						weather[i] = ret;

						next();
					}.bind(this)).fail(function() {
						next(true);
					});
				}, this);
			};

			var doResolve = function() {
				if (typeof this.config.location === "string") {
					this.config.location = [this.config.location];
				}
	
				if (this.config.resolvedNames && this.config.resolvedNames.join("|") === this.config.location.join("|")) {
					get.call(this);
				}
				else {
					this.resolveLocs(get);
				}
			}
			.bind(this);

			var isDefaultLoc = _.size(this.config.resolvedLocs) === 1 && _.head(this.config.resolvedLocs) === "defaultLoc";
			if (!isDefaultLoc) {
				doResolve();
			}
			else{
				this.Auth.ajax({
					url: "/weather/getLocation",
					success: function(d) {
						if (d && typeof(d) === "string") {
							var data = {};
							try {
								data = JSON.parse(d);
							} catch(e) {
							}							

							if (!data.geoplugin_city || data.geoplugin_city === "") { return; } //The resolve function does does not work if city is absent
							var name = data.geoplugin_city;
							if (!data.geoplugin_regionCode && data.geoplugin_regionCode !== "") {
								name += ", ";
								name += data.geoplugin_regionCode;
							}
							if (!data.geoplugin_countryName && data.geoplugin_countryName !== "") {
								name += ", ";
								name += data.geoplugin_countryName;
							}
							this.config.location = [name];
							this.config.resolvedNames = [name];
							this.config.resolvedLocs = [[data.geoplugin_latitude, data.geoplugin_longitude]];
							this.saveData();
						}
					}.bind(this),
				}).always(function() {
					doResolve();
				});
			}
		}
	});
});
/**
 * The snackbar view
 *
 * This is nearly 100% Material spec compliant (except positioning, centered just doesn't work).
 *
 * It accepts text, a timeout, and a single button and callback. This does _not_ handle multiple snackbars properly.
 */
define('modals/snackbar',["jquery", "lodash", "backbone"], function($, _, Backbone) {
	var openSnackbar;

	var Snackbar = Backbone.View.extend({
		tagName: "div",
		className: "snackbar",

		events: {
			"click button": function() {
				this.cb();

				this.trigger("actionClick");
			}
		},

		close: function(cb) {
			if (this._isPending) {
				this._isPendingClose = true;

				this._pendingCloseCB = cb;

				return;
			}

			this.animationPlayer.onfinish = function() {
				this.remove();

				this.trigger("destroy");

				if (openSnackbar === this) {
					openSnackbar = null;
				}

				if (typeof cb === "function") {
					cb();
				}
			}.bind(this);

			// If we're just starting to open, don't reverse the whole animation, just remove
			if (this.animationPlayer.currentTime > 50) {
				this.animationPlayer.reverse();
			}
			else {
				this.animationPlayer.pause();

				this.animationPlayer.onfinish();
			}

			return this;
		},

		text: "",
		cb: _.noop,
		duration: 6000,

		constructor: function(options, cb) {
			this.cid = _.uniqueId("view");

			this._ensureElement();

			if (typeof options === "string") {
				this.text = options;
			}
			else {
				_.assign(this, options);
			}

			if (typeof cb === "function") {
				this.cb = cb;
			}

			if (openSnackbar) {
				this._isPending = true;

				openSnackbar.close(function() {
					if (this._isPendingClose) {
						this.remove();

						if (typeof this._pendingCloseCB === "function") {
							this._pendingCloseCB();
						}

						return;
					}

					this.initialize();
				}.bind(this));
			}
			else {
				this.initialize();
			}

			openSnackbar = this;
		},

		initialize: function() {
			this._isPending = false;

			$('<span class="text"></span>').text(this.text).appendTo(this.$el);

			if (this.button && this.button.text) {
				var btn = document.createElement("button");

				btn.setAttribute("type", "button");
				btn.setAttribute("class", "material flat " + (this.button.classes || "green"));

				btn.textContent = this.button.text;

				this.el.appendChild(btn);
			}

			this.$el.appendTo(document.body).on("click", this.close.bind(this));


			// Animate into view
			this.animationPlayer = this.el.animate([{
				opacity: 0,
				transform: "translateY(40px)"
			}, {
				opacity: 1,
				transform: "translateY(0)"
			}], {
				duration: 300,
				easing: "cubic-bezier(.165, .84, .44, 1)"
			});

			setTimeout(this.close.bind(this), this.duration);
		}
	});

	return Snackbar;
});
/**
 * The settings model
 */
define('settings/model',["lodash", "backbone", "storage/storage"], function(_, Backbone, Storage) {
	var Model = Backbone.Model.extend({
		initialize: function() {
			Storage.on("done updated", function(storage) {
				this.storage = storage;

				this.set(_.assign({
					_tabs: storage.tabs
				}, storage.settings), {
					external: true
				});

				this.trigger("storage:updated");
			}, this);

			_.each(["layout", "columns"], function(prop) {
				this.on("change:" + prop, function(model, value, options) {
					if ((options && options.external === true) || !model.previous(prop)) {
						return;
					}

					this.handleLayoutChange(prop, value);
				}, this);
			}, this);

			this.on("change", function(model, options) {
				if (options && options.external === true) {
					return;
				}

				this.saving = true;

				this.trigger("save:start");

				this.storage.settings = _.omit(this.toJSON(), "_tabs");

				this.storage.tabs = this.get("_tabs");

				this.storage.sync(true, function() {
					this.saving = false;

					this.trigger("save save:finish");
				}.bind(this));
			});
		},


		/**
		 * Handles changes to the tab layout.
		 *
		 * This function does not save its results since change:* event handlers are
		 * always called before general change handlers in Backbone. So, the general
		 * handler will be called just after this runs and will save the _tabs property.
		 *
		 * @param   {String}  prop   The name of the property that changed
		 * @param   {*}       value  The new value
		 */
		handleLayoutChange: function(prop, value) {
			this.set("_tabs", _.map(this.get("_tabs"), function(tab) {
				var wasGrid = prop === "layout" && (typeof tab.isGrid === "boolean" ? tab.isGrid : this.previous("layout") === "grid") && value !== "grid";

				// Remove the legacy layout properties
				if (typeof tab.fixed !== "undefined" || typeof tab.isGrid !== "undefined") {
					delete tab.fixed;
					delete tab.isGrid;
				}

				// Increase or decrease the number of columns as appropriate
				if (prop === "columns" || wasGrid) {
					// Make a shallow clone of the columns to ensure all listeners down the line
					// register the change
					tab.columns = tab.columns.slice();

					var columns = wasGrid ? this.get("columns") : value;

					if (tab.columns.length < columns) {
						for (var i = columns - tab.columns.length; i > 0; i--) {
							tab.columns.push([]); // Push empty columns until the value is reached
						}
					}
					else if (tab.columns.length > columns) {
						var toRemove = tab.columns.length - columns;

						// First look for any empty columns that can be removed, which is the logical
						// process a user would follow to remove a column
						var colIndex = 0;

						while (toRemove && tab.columns[colIndex]) {
							if (tab.columns[colIndex].length === 0) {
								tab.columns.splice(colIndex, 1);

								toRemove--;

								continue;
							}

							colIndex++;
						}

						if (toRemove) {
							// Move all widgets in extra columns to the first
							tab.columns[0] = tab.columns[0].concat(_.flatten(_.takeRight(tab.columns, toRemove)));

							// And delete the extra columns
							tab.columns.splice(columns);
						}
					}
				}
				else if (tab.columns.length > 1) {
					// Move all widgets in all columns to the first
					tab.columns = [_.flatten(tab.columns)];
				}

				// If this was a grid-based tab, remove the extra loc property on each widget
				if (wasGrid) {
					tab.columns = _.map(tab.columns, function(col) {
						return _.map(col, function(e) {
							delete e.loc; // Delete the loc property from all widgets

							return e;
						});
					});
				}

				return tab;
			}, this));
		}
	});

	return _.once(function() {
		return new Model();
	});
});
/**
 * The settings page base
 */
define('settings/page',["lodash", "jquery", "backbone", "core/analytics", "core/auth", "settings/model", "core/render"], function(_, $, Backbone, Track, Auth, model, render) {
	var View = Backbone.View.extend({
		constructor: function(options) {
			this.tagName = "div";

			this.attributes = _.assign(this.attributes || {}, {
				"data-id": this.id
			});

			this.className = "page " + this.id + (this.className ? " " + this.className : "");

			this.template = function(data, partials) {
				return render("settings/" + this.id, _.assign({
					isPro: Auth.isPro
				}, data), partials);
			};

			// All pages share a single settings model
			this.model = model();

			this.listenTo(this.model, this.monitorProps ? "change:" + this.monitorProps.join(" change:") : "change", _.throttle(function() {
				var options = _.last(arguments);

				if (options && options.noRender) {
					return;
				}

				// Get a selector for the currently focused element so we can restore focus
				var el = this.$(":focus")[0];

				var focusedElm = [];

				while (el && el.parentElement && el !== this.el) {
					focusedElm.unshift(el.tagName + ":nth-child(" + (Array.prototype.indexOf.call(el.parentElement.children, el) + 1) + ")");

					el = el.parentElement;
				}

				focusedElm = focusedElm.join(" > ");


				var scrollTop = this.$("main").scrollTop();


				this.render();


				this.$("main").scrollTop(scrollTop);

				if (focusedElm) {
					this.$("> " + focusedElm).focus();
				}
			}, 100));

			Backbone.View.prototype.constructor.call(this, options);


			// The change event fires on text inputs when they're focused out, which is what we want,
			// and as changes happen on others, which is also what we want
			var inputChange = function(e) {
				var value;

				if (e.currentTarget.type === "checkbox") {
					value = e.currentTarget.checked;
				}
				else {
					value = e.currentTarget.value;
				}

				this.onInputChange(e.currentTarget, e.currentTarget.name, value);
			}.bind(this);

			this.$el.on("change", "input, textarea, select", inputChange);
		},


		/**
		 * General input change handler
		 *
		 * @param   {HTMLElement}  elm    The input element
		 * @param   {String}       name   The name of the input
		 * @param   {String}       value  The value of the input
		 */
		onInputChange: function(elm, name, value) {
			this.model.set(name, value, {
				noRender: true
			});
		},


		transitionIn: function(cb) {
			this.render();

			var header = this.$("header")[0],
				sections = this.$("section");


			// After every animation is done, call the cb.
			//
			// We add an extra call in case there aren't any elements to animate.
			var done = _.after((header ? 1 : 0) + sections.length + 1, cb || _.noop);

			done();


			if (header) {
				header.animate([{
					opacity: 0,
					transform: "translateY(-20%)"
				}, {
					opacity: 1,
					transform: "translateY(0)"
				}], {
					duration: 150,
					easing: "cubic-bezier(.4, 0, .2, 1)"
				}).onfinish = done;
			}


			if (sections.length) {
				_.each(sections, function(e, i) {
					var player = e.animate([{
						opacity: 0,
						transform: "translateY(30px)"
					}, {
						opacity: 1,
						transform: "translateY(0)"
					}], {
						duration: 150,
						easing: "cubic-bezier(.4, 0, .2, 1)"
					});

					if (i) {
						player.pause();

						setTimeout(function() {
							player.play();
						}, i * 50);
					}

					player.onfinish = done;
				});
			}

			Track.pageview("Settings: " + this.id, "/settings/" + this.id);
		},

		transitionOut: function(cb) {
			var header = this.$("header")[0],
				sections = this.$("section");


			// After every animation is done, call the cb.
			//
			// We add an extra call in case there aren't any elements to animate.
			var done = _.after((header ? 1 : 0) + sections.length + 1, cb || _.noop);

			done();


			if (header) {
				header.animate([{
					opacity: 1,
					transform: "translateY(0)"
				}, {
					opacity: 0,
					transform: "translateY(-20%)"
				}], {
					duration: 150,
					fill: "forwards",
					easing: "cubic-bezier(.4, 0, .2, 1)"
				}).onfinish = done;
			}


			if (sections.length) {
				_.each(sections, function(e, i) {
					var player = e.animate([{
						opacity: 1,
						transform: "translateY(0)"
					}, {
						opacity: 0,
						transform: "translateY(30px)"
					}], {
						duration: 150,
						fill: "forwards",
						easing: "cubic-bezier(.4, 0, .2, 1)"
					});

					if (sections.length - i > 1) {
						player.pause();

						setTimeout(function() {
							player.play();
						}, (sections.length - i - 1) * 50);
					}

					player.onfinish = done;
				});
			}
		},


		/**
		 * Sets the values of all radio and checkbox inputs
		 *
		 * @param  {Object}  data  The rendered data
		 */
		setDynamicControls: function(data) {
			var controls = this.dynamicControls,
				elms = this.el.querySelectorAll("input[type='radio'], input[type='checkbox'], select");

			if (!controls || !elms.length) {
				return;
			}

			_.each(elms, function(e) {
				if (!controls[e.name] || typeof data[controls[e.name]] === "undefined") {
					return;
				}

				if (e.type === "checkbox") {
					e.checked = !!data[controls[e.name]];
				}
				else if (e.type === "radio") {
					if (data[controls[e.name]] === e.value) {
						e.checked = true;
					}
				}
				else if (e.tagName.toLowerCase() === "select") {
					e.value = data[controls[e.name]];
				}
			});
		},

		onBeforeRender: function(data) {
			return data;
		},

		render: function() {
			var data = this.model.toJSON();

			this.trigger("before:render", data);

			var ret = this.onBeforeRender(data);

			if (ret === false) {
				return this;
			}

			data = ret || data;

			this.$el.html(this.template(data));

			this.setDynamicControls(data);

			this.trigger("render", data);

			this.onRender(data);

			return this;
		},

		onRender: _.noop
	});

	return View;
});
/**
 * The accounts and sync settings page
 */
define('settings/pages/accounts',[
	"jquery", "lodash", "i18n/i18n", "modals/alert", "core/auth", "storage/storage", "storage/syncapi", "settings/page"
], function($, _, Translate, Alert, Auth, Storage, SyncAPI, Page) {
	var View = Page.extend({
		id: "accounts",

		events: {
			"click button.sign-in": function() {
				Alert({
					title: Translate("storage.signin_confirm.title"),
					contents: [Translate("storage.signin_confirm.desc")],
					buttons: {
						negative: Translate("storage.signin_confirm.keep_account"),
						positive: Translate("storage.signin_confirm.keep_local")
					}
				}, function(sendData) {
					SyncAPI.authorize(this.model.storage, sendData, function() {
						// If the user is Pro, we need to reload so the app initializes properly
						if (Auth.isPro) {
							location.reload();
						}
					}.bind(this));
				}.bind(this));
			},

			"click button.reset": function() {
				Alert({
					contents: [Translate("settings.accounts.reset_confirm_desc"), Translate("settings.accounts.reset_confirm_desc2")],
					confirm: true
				}, function() {
					Storage.reset(function() {
						location.reload();
					});
				});
			},

			"click button.sign-out": function() {
				Auth.signout();
			}
		},

		initialize: function() {
			this.listenTo(this.model, "storage:updated", _.ary(this.render, 0));
		},

		onBeforeRender: function() {
			return {
				signedIn: Auth.isSignedIn,
				signedInMsg: Translate("settings.accounts.status.signed_in", this.model.storage.user.fname + " " + this.model.storage.user.lname, this.model.storage.user.email)
			};
		}
	});

	return View;
});
/**
 * The debug tools. This contains advanced tools that users can be instructed to use for troubleshooting.
 */
define('settings/debug',["backbone", "browser/api", "storage/filesystem", "modals/modals", "core/render"], function(Backbone, Browser, FileSystem, Modal, render) {
	var modal = new (Modal.extend({
		width: 800,
		classes: "debug-tools"
	}))();

	var View = Backbone.View.extend({
		el: modal.content,

		events: {
			"click button": "execute"
		},


		/**
		 * Takes a click event from one of the dialog buttons and executes its appropriate action
		 *
		 * @api     private
		 * @param   {Event}  e
		 */
		execute: function(e) {
			var action = e.currentTarget.getAttribute("data-action");

			if (!action) {
				return;
			}

			switch (action) {
				case "clear-localstorage":
					Browser.storage.clear();

					this.setStatus("Local storage cleared");
				break;

				case "clear-fs":
					FileSystem.clear();
				break;

				case "clear-oauth":
					delete Browser.storage.oauth;

					this.setStatus("OAuth cache cleared");
				break;

				case "get-info":
					this.setStatus("Compiling information, please wait");

					Browser.runtime.getPlatformInfo(function(info) {
						this.setStatus();

						alert(
							"Debug info (hit Ctrl+C or Cmd+C to copy):" + "\n" +
							"ProductivityTab Version: " + Browser.app.version + "\n" +
							"Chrome Version: " + (/Chrome\/([0-9.]+)/.exec(navigator.userAgent) || [])[1] + "\n" +
							"Operating System: " + info.os + "\n" +
							"OAuth keys: " + Object.keys(JSON.parse(Browser.storage.oauth || "{}")).join(", ") + "\n" +
							"Sync Token: " + JSON.parse(Browser.storage.syncData || "{}").token + "\n" +
							"Sync Client: " + JSON.parse(Browser.storage.syncData || "{}").client + "\n" +
							"Uses: " + Browser.storage.uses + "\n" +
							"Cached themes: " + Object.keys(JSON.parse(Browser.storage.config || "{}").cached || {}).length + "\n" +
							"Tabs: " + JSON.parse(Browser.storage.config || "{}").tabs.length + "\n" +
							"Local data size: " + (Browser.storage.config || "").length
						);
					}.bind(this));
				break;

				case "update":
					if (confirm(
						"If an update is available, this may reload the extension in Chrome, closing any open ProductivityTab tabs.  Before executing this, ensure that a tab other" +
						" than ProductivityTab is open otherwise Chrome itself will close.\r\nHit cancel to open a new tab and avoid this or OK to continue."
					)) {
						Browser.runtime.requestUpdateCheck(function(status, details) {
							if (status === "throttled") {
								this.setStatus("Update check failed due to throttling, try again later");
							}
							else if (status === "update_available") {
								this.setStatus((details && details.version) + " available.  Update is pending and should install momentarily.");
							}
							else {
								this.setStatus("No updates available");
							}
						}.bind(this));
					}
				break;

				case "reload-extension":
					if (confirm(
						"This will reload the extension in Chrome, closing any open ProductivityTab tabs.  Before executing this, ensure that a tab other" +
						" than ProductivityTab is open otherwise Chrome itself will close.\r\nHit cancel to open a new tab and avoid this or OK to continue."
					)) {
						Browser.runtime.reload();
					}
				break;

				case "execute":
					var textarea = this.$(".console textarea");

					var out = eval(textarea.val()); // jshint ignore:line

					if (out) {
						textarea.val("Output: " + out.toString());
					}
				break;
			}
		},

		/**
		 * Populates the status text area in the dialog with the provided text
		 *
		 * @api    private
		 * @param  {String}  [status]
		 */
		setStatus: function(status) {
			this.$(".status").text(status || "").toggleClass("no-status", !status);
		},

		show: function() {
			modal.show();
		},

		initialize: function() {
			this.$el.html(render("settings/debug"));

			modal.mo.appendTo(document.body);

			modal.show();
		}
	});

	return View;
});
/**
 * The advanced settings page
 */
define('settings/pages/advanced',[
	"lodash", "moment", "browser/api", "i18n/i18n", "modals/alert", "settings/page", "settings/debug", "storage/deprecate"
], function(_, moment, Browser, Translate, Alert, Page, DebugTools, Deprecate) {
	var View = Page.extend({
		id: "advanced",

		monitorProps: ["customCSS"],

		events: {
			"click .backups button.backup": function() {
				this.backup();

				this.render();
			},

			"click .backups button.upload": function() {
				this.$(".backups input[type=file]").click();
			},

			"click .backups .backup button.restore": function(e) {
				this.restore(parseInt(e.currentTarget.parentElement.getAttribute("data-date")));
			},

			"click .backups .backup button.download": function(e) {
				this.download(parseInt(e.currentTarget.parentElement.getAttribute("data-date")));
			},

			"click .debug-tools button": function() {
				if (!this.DebugTools) {
					this.DebugTools = new DebugTools();
				}
				else {
					this.DebugTools.show();
				}
			}
		},


		/**
		 * Creates a new backup
		 *
		 * @param   {Array}  [backups]  An array of existing backups
		 */
		backup: function(backups) {
			if (!Array.isArray(backups)) {
				backups = JSON.parse(Browser.storage.backups || "[]");
			}

			backups.unshift({
				date: new Date().getTime(),
				data: {
					themes: this.model.storage.themes,
					settings: this.model.storage.settings,
					tabs: this.model.storage.tabsSync
				}
			});

			backups = backups.slice(0, 4);

			Browser.storage.backups = JSON.stringify(backups);
			Browser.storage.lastBackup = new Date().getTime();

			backups = null;
		},


		/**
		 * Given a date, restores a backup
		 *
		 * @param   {String|Number}  d  Either a backup's JSON contents or the timestamp of the backup to restore
		 */
		restore: function(d) {
			Alert({
				contents: [Translate("settings.advanced.backups.restore_confirm")],
				confirm: true
			}, function() {
				try {
					var backups = JSON.parse(Browser.storage.backups || "[]"),
						backup;

					if (typeof d === "string") {
						backup = JSON.parse(d).data;
					}
					else {
						// Pull the backup so we can insert a new one without erasing others
						backup = _.pullAt(backups, _.findIndex(backups, "date", d))[0].data;
					}

					// Create a new backup now, before restoring
					this.backup(backups);

					this.model.storage.themes = backup.themes;
					this.model.storage.tabs = Deprecate.tabs(backup.tabs);
					this.model.storage.settings = Deprecate.settings(backup.settings);

					this.model.storage.sync(true, function() {
						this.trigger("restore");

						this.render();
					}.bind(this));
				}
				catch (e) {
					Alert(Translate("settings.advanced.backups.restore_error"));
				}
			}.bind(this));
		},


		/**
		 * Saves a backup to the user's computer as a JSON file
		 *
		 * @param   {Number}  timestamp  The timestamp of the backup to download
		 */
		download: function(timestamp) {
			try {
				var backup = _.find(JSON.parse(Browser.storage.backups || "[]"), "date", timestamp);

				var a = document.createElement("a"),
					url = URL.createObjectURL(new Blob([JSON.stringify(backup)], {
						type: "octet/stream"
					}));

				a.href = url;

				a.download = Translate("settings.advanced.backups.download_name") + " " + moment(timestamp).format("LL") + ".json";

				a.click();

				URL.revokeObjectURL(url);
			}
			catch(e) {}
		},


		/**
		 * Handles the change event on the file input, restoring from an uploaded backup
		 *
		 * @param   {Event}  e  The change event
		 */
		upload: function(e) {
			if (e.currentTarget.files.length) {
				var fr = new FileReader();

				fr.onloadend = function() {
					if (!fr.error) {
						this.restore(fr.result);
					}
				}.bind(this);

				fr.readAsText(e.currentTarget.files[0]);
			}
		},


		/**
		 * General input change handler
		 *
		 * @param   {HTMLElement}  elm    The input element
		 * @param   {String}       name   The name of the input
		 * @param   {String}       value  The value of the input
		 */
		onInputChange: function(elm, name, value) {
			switch (name) {
				case "css":
					this.model.set("customCSS", value);
				break;

				case "backup-upload":
					if (elm.files.length) {
						var fr = new FileReader();

						fr.onloadend = function() {
							if (!fr.error) {
								this.restore(fr.result);
							}
						}.bind(this);

						fr.readAsText(elm.files[0]);
					}
				break;
			}
		},


		onBeforeRender: function(data) {
			return {
				backups: _.map(JSON.parse(Browser.storage.backups || "[]"), function(e) {
					return {
						date: e.date,
						label: e.label || moment(e.date).calendar()
					};
				}),

				css: data.customCSS
			};
		}
	});

	return View;
});
/**
 * The misc settings page
 */
define('settings/pages/misc',["settings/page"], function(Page) {
	var View = Page.extend({
		id: "misc",

		dynamicControls: {
			"openLinksInNewTab": "openLinksInNewTab"
		},

		monitorProps: ["openLinksInNewTab"]
	});

	return View;
});
/**
 * Initializes UserVoice and it's autoprompts
 */
define('core/uservoice',["core/auth", "storage/storage", "browser/api"], function(Auth, Storage, Browser) {
	var initUV = function() {
		var uv = document.createElement("script");

		uv.async = true;
		uv.type = "text/javascript";
		uv.src = "https://widget.uservoice.com/YLT6rl3u3uU75IbSodIBw.js";

		var s = document.getElementsByTagName("script")[0];

		s.parentNode.insertBefore(uv, s);

		window.UserVoice.push(["set", {
			accent_color: "#448dd6",
			trigger_color: "white",
			screenshot_enabled: "false",
			trigger_background_color: "rgba(46, 49, 51, 0.6)"
		}]);


		Storage.on("done", function(storage) {
			window.UserVoice.push(["identify", {
				id: Auth.get("user") || "",
				email: storage.user.email,
				name: (storage.user.fname + " " + storage.user.lname).trim() || undefined,
				type: Browser.app.newTab ? "New Tab" : "Main",
				account: {
					id: Auth.get("subscription") || "",
					plan: Auth.get("plan") || "free"
				}
			}]);
		});


		window.UserVoice.push(["autoprompt", {
			position: "toast"
		}]);
	};

	if (Math.random() * 5 < 1) {
		window.UserVoice = window.UserVoice || [];

		initUV();
	}

	return function() {
		if (!window.UserVoice) {
			window.UserVoice = [];

			initUV();
		}

		window.UserVoice.push(Array.prototype.slice.call(arguments));
	};
});
/**
 * The checkout handler
 */
define('settings/checkout',["lodash", "jquery", "browser/api", "core/analytics", "modals/alert", "i18n/i18n", "core/auth"], function(_, $, Browser, Track, Alert, Translate, Auth) {
	var POPUP_WIDTH = 400,
		POPUP_HEIGHT = 500,
		PRO_URL = "https://api.ichro.me/billing/v1/checkout",
		ADFREE_URL = "https://api.ichro.me/billing/v1/adfree/checkout";

	var Checkout = function(type, isUpdating) {
		var url;

		if (type === "adfree") {
			url = ADFREE_URL + "?" + $.param({
				auth_token: Auth.get("token"),
				appVersion: Browser.app.version
			});
		}
		else {
			this.isUpdating = !!isUpdating;

			url = PRO_URL + "?" + $.param({
				plan: Auth.get("plan"),
				updating: this.isUpdating,
				auth_token: Auth.get("token"),
				appVersion: Browser.app.version
			});
		}

		Browser.windows.create({
			url: url,
			type: "popup",
			focused: true,
			width: POPUP_WIDTH,
			height: POPUP_HEIGHT,
			top: Math.round((screen.availHeight - POPUP_HEIGHT) / 2),
			left: Math.round((screen.availWidth - POPUP_WIDTH) / 2)
		}, function(win) {
			this._windowId = win.id;

			this.removeListener = function(id) {
				if (id === win.id) {
					this.destroy(true);
				}
			}.bind(this);

			Browser.windows.onRemoved.addListener(this.removeListener);

			this.initAPI();
		}.bind(this));

		this.unloadListener = this.destroy.bind(this);

		window.addEventListener("beforeunload", this.unloadListener);
	};

	Checkout.prototype = {
		/**
		 * Starts listening for requests to the internal intercepted extension API.
		 *
		 * We use this method instead of something like externally-connectable since
		 * it doesn't require an extra permission.
		 */
		initAPI: function() {
			var handlers = {
				cancel: function() {
					this.destroy();
				}.bind(this),

				subscribe: function(params) {
					this.subscribe(params.plan, params.paymentNonce);
				}.bind(this),

				upgrade: function(params) {
					this.upgradeToAdFree(params.paymentNonce);
				}.bind(this),

				checkoutStrings: function() {
					return Translate.getAll().settings.pro.checkout;
				},

				resize: function(params) {
					var data = {};

					if (params.width) {
						data.width = parseInt(params.width);
						data.left = Math.round((screen.availWidth - params.width) / 2);
					}

					if (params.height) {
						data.height = parseInt(params.height);
						data.top = Math.round((screen.availHeight - params.height) / 2);
					}

					Browser.windows.update(this._windowId, data);

					return {
						success: true
					};
				}.bind(this)
			};

			this.webRequestListener = function(info) {
				// Adapted from http://stackoverflow.com/a/3855394/900747
				var params = {},
					idx;

				_.each(new URL(info.url).search.substr(1).split("&"), function(e) {
					idx = e.indexOf("=");

					if (idx === -1) {
						params[e] = "";
					}
					else {
						params[e.substring(0, idx)] = decodeURIComponent(e.substr(idx + 1).replace(/\+/g, " "));
					}
				});

				if (params.method && handlers[params.method]) {
					var resp = handlers[params.method](params);

					if (resp) {
						return {
							redirectUrl: "data:application/json;charset=utf8;utf-8," + encodeURIComponent(JSON.stringify(resp))
						};
					}
				}
			};

			Browser.webRequest.onBeforeRequest.addListener(this.webRequestListener, {
				windowId: this._windowId,
				types: ["xmlhttprequest"],
				urls: ["https://api.ichro.me/app-intercept/v1*"]
			}, ["blocking"]);
		},

		destroy: function(fromRemove) {
			Browser.webRequest.onBeforeRequest.removeListener(this.webRequestListener);

			Browser.windows.onRemoved.removeListener(this.removeListener);

			window.removeEventListener("beforeunload", this.unloadListener);

			if (!fromRemove) {
				Browser.windows.remove(this._windowId);
			}
		},

		subscribe: function(plan, paymentNonce) {
			var isUpdating = this.isUpdating;

			this.destroy();

			Auth.ajax({
				method: "PUT",
				url: "/billing/v1/plan",
				data: {
					plan: plan,
					paymentNonce: paymentNonce
				},
				success: function(d) {
					if (d && d.success) {
						if (d.authToken) {
							Auth.set("token", d.authToken);
						}

						if (!isUpdating) {
							Track.FB.logPurchase(plan === "MONTHLY-PRO" ? 4.99 : 29.99, "USD", { fb_content_type: "pro", fb_content_id: plan });
						}

						Alert({
							title: Translate("settings.pro.checkout.thank_you"),
							contents: isUpdating ? null : [Translate("settings.pro.checkout.thank_you2")]
						});

						// Changes to the Pro state require a reload since it's used during initialization
						if (!isUpdating) {
							setTimeout(function() {
								location.reload();
							}, 4000);
						}
					}
					else {
						Alert([Translate("settings.pro.checkout.error"), Translate("settings.pro.checkout.error2")]);
					}
				}
			}).fail(function() {
				Alert([Translate("settings.pro.checkout.error"), Translate("settings.pro.checkout.error2")]);
			});
		},

		upgradeToAdFree: function(paymentNonce) {
			this.destroy();

			Auth.ajax({
				method: "PUT",
				url: "/billing/v1/adfree/upgrade",
				data: {
					paymentNonce: paymentNonce
				},
				success: function(d) {
					if (d && d.success) {
						if (d.authToken) {
							Auth.set("token", d.authToken);
						}

						Track.FB.logPurchase(10, "USD", { fb_content_type: "adfree", fb_content_id: "adfree_onetime" });

						Alert({
							title: Translate("settings.ads.thank_you"),
							contents: [Translate("settings.pro.checkout.thank_you2")]
						});

						setTimeout(function() {
							location.reload();
						}, 4000);
					}
					else {
						Alert([Translate("settings.pro.checkout.error"), Translate("settings.pro.checkout.error2")]);
					}
				}
			}).fail(function() {
				Alert([Translate("settings.pro.checkout.error"), Translate("settings.pro.checkout.error2")]);
			});
		}
	};

	return Checkout;
});
/**
 * The Pro settings page
 */
define('settings/pages/pro',[
	"lodash", "moment", "core/auth", "core/analytics", "modals/alert", "i18n/i18n", "storage/storage", "storage/syncapi", "settings/page", "core/uservoice", "settings/checkout"
], function(_, moment, Auth, Track, Alert, Translate, Storage, SyncAPI, Page, UserVoice, Checkout) {
	if (!Auth.isPro || Auth.get("plan") === "trial") {
		var PromoView = Page.extend({
			id: "pro",
			className: "promo",

			events: {
				"click button.upgrade": function() {
					Track.FB.logEvent("INITIATED_CHECKOUT", null, { fb_content_type: "pro" });

					if (!Auth.isSignedIn) {
						Alert({
							confirm: true,
							title: Translate("settings.pro.checkout.signin"),
							contents: [Translate("settings.pro.checkout.signin_desc")],
							buttons: {
								positive: Translate("settings.pro.checkout.signin_btn")
							}
						}, function() {
							Alert({
								title: Translate("storage.signin_confirm.title"),
								contents: [Translate("storage.signin_confirm.desc")],
								buttons: {
									negative: Translate("storage.signin_confirm.keep_account"),
									positive: Translate("storage.signin_confirm.keep_local")
								}
							}, function(sendData) {
								Storage.on("done", function(storage) {
									SyncAPI.authorize(storage, sendData, function() {
										if (Auth.isPro) {
											location.reload();
										}
										else {
											new Checkout("pro");
										}
									});
								});
							});
						});

						return;
					}

					new Checkout("pro");
				},

				"click header .business a": function(e) {
					e.preventDefault();

					UserVoice("show", { mode: "contact" });
				}
			},

			onInputChange: _.noop,

			onBeforeRender: function() {
				var plan = (Auth.get("plan") || "").replace("pro_", "").replace("-PRO", "");

				var isTrial = Auth.get("isTrial") || false;
				
				var expiration = new Date();
				var trialExpirationTime = Auth.get("trialExpiration");
				if (trialExpirationTime) {
					 expiration = new Date(Number(trialExpirationTime));
				}

				var ret = {
					uneditable: plan && plan !== "monthly" && plan !== "yearly" && plan !== "MONTHLY" && plan !== "YEARLY",
					desc: Translate("settings.pro.plan.desc", Translate("settings.pro.plan.types." + plan)),
					isSubscribed: Auth.isPro && !isTrial,
					isTrial: isTrial,
					trialExpiration: moment.utc(expiration).format("LL")
				};
	
				if (this._subscriptionInfo) {
					_.assign(ret, this._subscriptionInfo);
				}
	
				return ret;
			},

			onRender: function() {
				Track.FB.logEvent("VIEWED_CONTENT", null, { fb_content_type: "page", fb_content_id: "pro" });
			}
		});

		return PromoView;
	}

	var View = Page.extend({
		id: "pro",

		events: {
			"click section.plan button.update-plan, section.plan button.update-billing": function() {
				new Checkout("pro", true);
			},

			"click section.plan button.cancel": function() {
				Alert({
					confirm: true,
					contents: [Translate("settings.pro.plan.cancel_notice"), Translate("settings.pro.plan.cancel_notice2")]
				}, function() {
					Auth.ajax({
						method: "PUT",
						url: "/billing/v1/plan",
						data: {
							plan: "free"
						},
						success: function(d) {
							if (!d || !d.authToken) {
								return;
							}

							Track.FB.logEvent("CanceledPlan");

							Auth.set("token", d.authToken);

							location.reload();
						}
					});
				});
			}
		},

		// If no properties are provided then all changes will be monitored
		monitorProps: ["nonExistentProperty"],

		loadPlan: function() {
			Auth.ajax({
				method: "GET",
				url: "/billing/v1/plan",
				success: function(d) {
					if (!d) {
						return;
					}

					this._subscriptionInfo = {
						status: Translate("settings.pro.plan.status_" + d.status),
						subscriptionDate: moment.utc(d.subscribed).format("LL"),
						paidThrough: moment.utc(d.paidThrough).format("LL"),
						nextBill: Translate("settings.pro.plan.next_bill_value", d.nextBillAmount * 1, moment.utc(d.nextBillDate).format("LL"))
					};

					this.render();
				}.bind(this)
			});
		},

		initialize: function() {
			this.listenTo(Auth, "change", function() {
				this._subscriptionInfo = null;

				this.render();

				this.loadPlan();
			});

			this.loadPlan();
		},

		onInputChange: _.noop,

		onBeforeRender: function() {
			var plan = (Auth.get("plan") || "").replace("pro_", "").replace("-PRO", "");

			var ret = {
				uneditable: plan && plan !== "monthly" && plan !== "yearly" && plan !== "MONTHLY" && plan !== "YEARLY",
				desc: Translate("settings.pro.plan.desc", Translate("settings.pro.plan.types." + plan)),
				isSubscribed: Auth.isPro
			};

			if (this._subscriptionInfo) {
				_.assign(ret, this._subscriptionInfo);
			}

			return ret;
		}
	});

	return View;
});
/**
 * The tabs settings page
 */
define('settings/pages/tabs',["lodash", "i18n/i18n", "modals/alert", "settings/page"], function(_, Translate, Alert, Page) {
	var View = Page.extend({
		id: "tabs",

		monitorProps: ["defaultTab", "_tabs"],

		events: {
			"click .tabs .tab[data-id] button[data-action]": function(e) {
				var action = e.currentTarget.getAttribute("data-action"),
					tabIndex = parseInt(e.currentTarget.parentElement.getAttribute("data-id"));

				var tabs = _.clone(this.model.get("_tabs"));

				var tab = tabs[tabIndex];

				var save = function() {
					var defaultTab = this.model.get("defaultTab");

					var set = {};

					set._tabs = _.map(tabs, function(e, i) {
						if (e.id === defaultTab && !set.defaultTab) {
							set.defaultTab = i + 1;
						}

						e.id = i + 1;

						return e;
					});

					// If the default tab wasn't found, then it must have been deleted.
					// Set the first tab as default.
					set.defaultTab = set.defaultTab || 1;

					this.model.set(set);
				}.bind(this);

				switch (action) {
					case "make-default":
						this.model.set("defaultTab", tab.id);
					break;

					case "delete":
						if (tabs.length === 1) {
							return;
						}

						Alert({
							confirm: true,
							contents: [Translate("settings.tabs.delete_confirm")]
						}, function() {
							tabs.splice(tabIndex, 1);

							save();
						});
					break;

					case "move-up": case "move-down":
						tabs.splice(tabIndex + (action === "move-up" ? -1 : 1), 0, tabs.splice(tabIndex, 1)[0]);

						save();
					break;
				}
			},

			"click button.create-new": "createTab"
		},


		/**
		 * Creates a new tab
		 *
		 * @public
		 * @return  {Object}  The newly created tab
		 */
		createTab: function() {
			var tabs = _.clone(this.model.get("_tabs"));

			var columns = this.model.get("columns");

			var tab = {
				name: "",
				id: tabs.length + 1,
				columns: new Array(columns)
			};


			var index = -1;

			while (++index < columns) {
				tab.columns[index] = [];
			}


			tabs.push(tab);

			this.model.set("_tabs", tabs);

			// The page has now been re-rendered, focus on the new tab's name field
			this.$(".tabs .tab input[name='tab-name']").focus();
		},


		/**
		 * Handles input changes, persisting changes to the model
		 *
		 * @param   {HTMLElement}  elm    The input element
		 * @param   {String}       name   The name of the input
		 * @param   {String}       value  The value of the input
		 */
		onInputChange: function(elm, name, value) {
			if (name === "tab-name") {
				var tabIndex = elm.parentElement.getAttribute("data-id");

				var tabs = _.clone(this.model.get("_tabs"));

				// If we don't clone this (_.assign({}, obj) does the same thing) then the
				// change will happen in the actual tabs array and the _.isEqual check
				// in Backbone.Model.set will determine that the property is unchanged.
				tabs[tabIndex] = _.assign({}, tabs[tabIndex], {
					name: value
				});

				this.model.set("_tabs", tabs);
			}
		},


		onBeforeRender: function(data) {
			return {
				tabs: _.map(data._tabs, function(e) {
					return {
						name: e.name,
						index: e.id - 1,
						isDefault: e.id === data.defaultTab
					};
				})
			};
		}
	});

	return View;
});
/**
 * The toolbar settings page
 */
define('settings/pages/toolbar',["lodash", "jquery", "core/auth", "settings/page"], function(_, $, Auth, Page) {
	var builtInSearchEngines = ["default", "yahoo", "bing", "duckduckgo", "ask", "aol", "startpage"];

	var View = Page.extend({
		id: "toolbar",

		dynamicControls: {
			"style": "style",
			"search-engine": "searchEngine",
			"search-url": "customSearchURL",
			"omnibox-capture": "captureFocus",
			"voice-search": "voice",
			"ok-google": "ok_google",
			"new-tab": "searchInNewTab",
			"google-plus": "gplus",
			"gmail": "gmail",
			"apps-menu": "apps"
		},

		monitorProps: ["apps", "gmail", "links", "ok", "plus", "searchEngine", "captureFocus", "searchInNewTab", "toolbar", "voice"],

		events: {
			"click .links button.remove": function(e) {
				var elm = $(e.currentTarget.parentElement);

				var links = _.clone(this.model.get("links"));

				links.splice(elm.attr("data-link"), 1);

				this.model.set("links", links);

				elm.remove();
			}
		},


		/**
		 * Handles input changes, persisting changes to the model
		 *
		 * @param   {HTMLElement}  elm    The input element
		 * @param   {String}       name   The name of the input
		 * @param   {String}       value  The value of the input
		 */
		onInputChange: function(elm, name, value) {
			var keyMap = {
				"style": "toolbar",
				"voice-search": "voice",
				"ok-google": "ok",
				"new-tab": "searchInNewTab",
				"omnibox-capture": "captureFocus",
				"google-plus": "plus",
				"gmail": "gmail",
				"apps-menu": "apps"
			};

			if (keyMap[name]) {
				this.model.set(keyMap[name], value, {
					noRender: true
				});
			}
			else if (name === "search-engine" && value === "custom") {
				$(elm).parents(".input").first().children(".input.other").addClass("visible");
			}
			else if (name === "search-engine" || name === "search-url") {
				$(elm).parents(".input").first().children(".input.other").removeClass("visible");

				this.model.set("searchEngine", value, {
					noRender: true
				});
			}
			else if (name === "link-text" || name === "link-url") {
				var links = _.clone(this.model.get("links")),
					field = name === "link-text" ? "text" : "link",
					index = elm.parentElement.getAttribute("data-link");

				if (index === "new") {
					index = links.length;

					links.push({
						link: "",
						text: ""
					});
				}
				else {
					links[index] = _.clone(links[index]);
				}

				links[index][field] = value;

				this.model.set("links", links);
			}
		},


		onBeforeRender: function(data) {
			var ret = {
				style: data.toolbar,
				searchEngine: data.searchEngine === "google" ? "default" : builtInSearchEngines.indexOf(data.searchEngine) === -1 ? "custom" : data.searchEngine,
				voice: data.voice,
				ok_google: data.ok,
				searchInNewTab: data.searchInNewTab,
				gplus: data.plus,
				gmail: data.gmail,
				apps: data.apps,
				captureFocus: data.captureFocus,
				customLinks: _.map(data.links, function(e, i) {
					return _.assign({}, e, { i: i });
				}),
				canAddLinks: data.links.length < (Auth.isPro ? 8 : 3),
				canSelectSearch: Auth.isPro
			};

			if (ret.searchEngine === "custom") {
				ret.customSearchURL = data.searchEngine;
			}

			return ret;
		}
	});

	return View;
});
/**
 * The themes controller.  This manages almost everything related to theme usage
 */
define('themes/utils',["lodash", "backbone", "browser/api", "storage/storage", "i18n/i18n"], function(_, Backbone, Browser, Storage, Translate) {
	var Model = Backbone.Model.extend({
		initialize: function() {
			Storage.on("done updated", function(storage) {
				this.set({
					custom: storage.themes,
					cached: storage.cached,
					backgroundImage: storage.settings.backgroundImage
				});
			}, this);
		}
	});


	var themes = {
		model: new Model(),

		defaults: {
			name: Translate("themes.edit.default_name"),
			images: false,
			offline: false,
			time: false,
			rotating: false,
			resolution: false,
			color: "#EEE",
			position: "top center",
			scaling: "cover",
			repeat: "no-repeat",
			fixed: "scroll"
		},

		/**
		 * Gets a theme when given either a theme name or object
		 *
		 * @api    public
		 * @param  {String|Object} theme The theme to retrieve
		 * @return {Object}        The retrieved theme
		 */
		get: function(theme) {
			var defTheme = this.model.get("cached")[0];

			if (((typeof theme === "object" && theme.id) || theme) === "custom") {
				theme = {
					id: "custom",
					image: this.model.get("backgroundImage")
				};
			}
			else if (((typeof theme === "object" && theme.id) || theme) === "default") {
				theme = defTheme;
			}
			else if (typeof theme === "object") {
				theme = (this.model.get("cached")[theme.id] || this.model.get("custom")[(theme.id + "").replace("custom", "")] || theme);
			}
			else {
				theme = (this.model.get("cached")[theme] || this.model.get("custom")[(theme + "").replace("custom", "")] || defTheme);
			}

			return theme;
		},


		/**
		 * Provided with a theme ID or spec, returns the theme's image, which may
		 * be a video.
		 *
		 * @api    public
		 * @param  {String|Object} theme The theme to retrieve the image for
		 * @return {String|Boolean}      The retrieved image or false if it could not be determined
		 */
		getImage: function(theme) {
			var image = false,
				rand;


			if (typeof theme !== "object") {
				theme = this.get(theme);
			}


			if (theme.image || theme.video) {
				image = theme.image || theme.video;

				// When updating a dynamic theme's background image we need to
				// make sure the browser sees a change
				if (image.indexOf("filesystem") === 0) {
					image += "?nocache=" + new Date().getTime();
				}
			}
			else if (theme.images && typeof this.model.get("cached")[theme.id] !== "undefined") {
				switch (theme.type) {
					case "random_daily":
						// Because of the way this is done, all themes will show the same image on different
						// computers on the same day without any centralization!
						rand = Math.sin(new Date().setHours(0, 0, 0, 0)) * 10000;

						image = this.model.get("cached")[theme.images[Math.floor((rand - Math.floor(rand)) * theme.images.length)]].image;
					break;

					case "sunrise_sunset":
						if (!this.SunCalc) {
							/*
								(c) 2011-2014, Vladimir Agafonkin
								SunCalc is a JavaScript library for calculating sun/mooon position and light phases.
								https://github.com/mourner/suncalc

								Modified by Avi Kohn to only include necessary data and functions
							*/
							/* jshint ignore:start */
							this.SunCalc=function(){var g=Math.PI,a=Math.sin,l=Math.cos,v=Math.asin,w=Math.acos,c=g/180,q=23.4397*c,r=[[-6,"dawn","dusk"],
							[6,"gHEnd","gH"]];return function(x,y){var n=c*-y,z=c*x,s=Math.round((new Date).valueOf()/864E5-0.5+2440588-2451545-9E-4-n/(2*g)),h=9E-4
							+(0+n)/(2*g)+s,e=c*(357.5291+0.98560028*h),f;f=c*(1.9148*a(e)+0.02*a(2*e)+3E-4*a(3*e));f=e+f+102.9372*c+g;var t;t=v(a(0)*l(q)+l(0)*a(q)*
							a(f));var h=2451545+h+0.0053*a(e)-0.0069*a(2*f),p={},k,u,m,b,d;k=0;for(u=r.length;k<u;k+=1)m=r[k],b=z,d=t,b=w((a(m[0]*c)-a(b)*a(d))/(l(b)
							*l(d))),d=f,b=2451545+(9E-4+(b+n)/(2*g)+s)+0.0053*a(e)-0.0069*a(2*d),d=h-(b-h),p[m[1]]=new Date(864E5*(d+0.5-2440588)),p[m[2]]=new Date(
							864E5*(b+0.5-2440588));return p}}();
							/* jshint ignore:end */
						}

						var lat = Browser.storage.lat,
							lon = Browser.storage.lon,
							times;

						if (lat && lon) {
							times = this.SunCalc(lat, lon);
						}
						else {
							// If lat and lon aren't set, default to Chicago. This should be roughly accurate for most users.
							times = this.SunCalc(41.85, -87.65);

							// Then attempt to get a location and save, this needs to be here for synced sunrise themes.
							// It can't be in the background page since it needs permissions from the user.
							navigator.geolocation.getCurrentPosition(function(pos) {
								if (pos && pos.coords) {
									Browser.storage.lat = parseFloat(pos.coords.latitude.toFixed(2));
									Browser.storage.lon = parseFloat(pos.coords.longitude.toFixed(2));
								}
							});
						}


						times = [times.dawn.getTime() - 18E5, times.gHEnd.getTime() + 72E5, times.gH.getTime() - 36E5, times.dusk.getTime()];


						var dt = new Date().getTime();

						rand = Math.sin(new Date().setHours(0, 0, 0, 0)) * 10000;


						// If after sunrise start and before sunrise end
						if (dt >= times[0] && dt < times[1]) {
							var sunrise = theme.images.slice(0, theme.groups[0]); // Then slice images at the indicated groups

							image = this.model.get("cached")[sunrise[Math.floor((rand - Math.floor(rand)) * sunrise.length)]].image; // And pick one randomly
						}

						// If after sunrise end and before sunset start
						else if (dt >= times[1] && dt < times[2]) {
							var daytime = theme.images.slice(theme.groups[0], theme.groups[1]);

							image = this.model.get("cached")[daytime[Math.floor((rand - Math.floor(rand)) * daytime.length)]].image;
						}

						// If after sunset start and before sunset end
						else if (dt >= times[2] && dt < times[3]) {
							var sunset = theme.images.slice(theme.groups[1], theme.groups[2]);

							image = this.model.get("cached")[sunset[Math.floor((rand - Math.floor(rand)) * sunset.length)]].image;
						}

						// Otherwise, it's nighttime
						else {
							var nighttime = theme.images.slice(theme.groups[2], theme.groups[3]);

							image = this.model.get("cached")[nighttime[Math.floor((rand - Math.floor(rand)) * nighttime.length)]].image;
						}
					break;

					default:
						image = this.model.get("cached")[theme.images[Math.floor(Math.random() * theme.images.length)]].image;
					break;
				}
			}


			// If an image can't be found, this is probably a preview. Return the
			// remote URL
			if (!image) {
				if (theme.images) {
					image = "https://themes.ichro.me/images/" + theme.images[Math.floor(Math.random() * theme.images.length)] + ".jpg";
				}
				else if ((theme.oType || theme.type) === "video") {
					image = "https://themes.ichro.me/images/" + theme.id + ".mp4";
				}
				else {
					image = "https://themes.ichro.me/images/" + theme.id + ".jpg";
				}
			}

			return image;
		}
	};


	return themes;
});
define('themes/model',["lodash", "backbone", "browser/api", "themes/utils", "i18n/i18n"], function(_, Backbone, Browser, Utils, Translate) {
	var model = Backbone.Model.extend({
		url: "https://api.ichro.me/themes/v1/list?extension=" + Browser.app.id + "&version=" + Browser.app.version + "&lang=" + Browser.language,

		defaults: {
			index: [],
			themes: [],
			custom: [],
			categories: []
		},

		initialize: function() {
			Utils.model.on("change:cached", function() {
				this.parse(this.manifest);
			}, this);

			Utils.model.on("change:custom", this.updateCustom, this);

			this.updateCustom();
		},


		/**
		 * Parses the custom themes from the Utils model and stores them locally
		 *
		 * @api    private
		 */
		updateCustom: function() {
			var custom = JSON.parse(JSON.stringify(Utils.model.get("custom") || []));

			custom = custom.map(function(e, i) {
				var theme = _.defaults(e, Utils.defaults);

				theme.id = i;

				theme.custom = true;

				theme.thumb = theme.image;

				return theme;
			});

			this.set("custom", custom);

			this.trigger("change");
		},

		parse: function(d) {
			// This caches the manifest so newly cached themes only involve a reparse
			if (!this.manifest) {
				this.manifest = JSON.parse(JSON.stringify(d));
			}

			var index = {},
				themes = [],
				categories = [];

			var cached = Utils.model.get("cached"),
				types = {
					random: {
						icon: "&#xE69C;",
						desc: Translate("themes.random")
					},
					random_daily: {
						icon: "&#xE63F;",
						desc: Translate("themes.random_daily")
					},
					sunrise_sunset: {
						icon: "&#xE63D;",
						desc: Translate("themes.sunrise_sunset")
					},
					feed: {
						icon: "&#xE66A;",
						desc: Translate("themes.feed")
					},
					video: {
						icon: "&#xE69D;",
						desc: Translate("themes.video")
					}
				};


			d.themes.forEach(function(e) {
				var theme = _.clone(e);

				theme.filterCategories = e.categories;
				theme.offline = !!cached[e.id];
				theme.thumb = theme.thumb || "https://themes.ichro.me/thumbnails/" + e.id + ".png";

				if (e.resolution) {
					theme.resolution = e.resolution[0] + "x" + e.resolution[1];
				}

				if (e.images || e.size) {
					theme.stats = "";

					if (e.images) {
						theme.stats += Translate("themes.images", e.images.length) + (e.size ? ", " : "");
					}

					if (e.size) {
						theme.stats += e.size;
					}
				}

				if (e.type && e.type === "video") {
					theme.proOnly = true;
				}

				if (e.type && types[e.type]) {
					theme.type = types[e.type];

					theme.oType = e.type;
				}

				if (e.source) {
					theme.source = e.source;
				}

				if (e.name) {
					theme.name = e.name;
				}


				var categories = [];

				e.categories.forEach(function(e) {
					if (d.categories[e]) {
						categories.push(d.categories[e]);
					}
				});

				theme.categories = categories.join(", ");


				index[e.id] = themes.length;

				themes.push(theme);
			});


			_.each(d.categories, function(e, i) {
				categories.push({
					name: e,
					id: parseInt(i)
				});
			});


			return {
				index: index,
				themes: themes,
				categories: categories.sort(function(a, b) { return a - b; })
			};
		}
	});

	return model;
});
/**
 * This module controls theme displaying and previewing
 */
define('themes/controller',["lodash", "jquery", "backbone", "core/auth", "themes/utils"], function(_, $, Backbone, Auth, Utils) {
	var Themes = Backbone.View.extend({
		el: "body",


		initialize: function() {
			this.listenTo(Utils.model, "change:cached change:backgroundImage", function() {
				var newTheme = Utils.get(this.theme);

				// If the theme itself hasn't changed and it's a random one, we
				// don't want to pick a new image
				if (newTheme.image || newTheme.video || JSON.stringify(this.theme) !== JSON.stringify(newTheme)) {
					this.theme = newTheme;

					this.render();

					this.trigger("change:theme");
				}
			});
		},


		/**
		 * Previews a theme, hiding all modals and adding a transparent overlay
		 *
		 * @param   {Object|String}  theme  The theme to preview
		 */
		preview: function(theme) {
			theme = typeof theme === "object" ? theme : Utils.get(theme);

			this.render(theme, true);

			var hidePreview = function() {
				clearTimeout(removeTimeout);

				$(".previewHidden").removeClass("previewHidden").addClass("visible");

				previewOverlay.remove();

				this.render();
			}.bind(this);

			// Some themes are Pro-only. Anyone can preview them, but we don't
			// want them to "preview" one forever, so we hide the preview after
			// 2 minutes
			var removeTimeout = setTimeout(hidePreview, 120000);

			var previewOverlay = $('<div class="preview-overlay visible"></div>').one("click", hidePreview).appendTo(this.el);

			$(".modal.visible, .settings.visible, .modal-overlay.visible").removeClass("visible").addClass("previewHidden");
		},


		/**
		 * Updates the currently active theme
		 *
		 * @param  {Object|String}  theme  The theme or theme ID to make current
		 */
		setTheme: function(theme) {
			// The utils convert a number of inputs into a consistent themes spec
			this.theme = Utils.get(theme);

			this.render();

			this.trigger("change:theme");
		},


		/**
		 * Get a CSS string for the given theme
		 *
		 * @param  {Object} theme The theme to generate CSS for
		 * @return {String}       A CSS string
		 */
		getCSS: function(theme) {
			var css = "",
				image = Utils.getImage(theme);

			if (theme.color) {
				css += "background-color: " + theme.color + ";";
			}

			if (image) {
				css += "background-image: url(\"" + image + "\");";
			}

			if (theme.scaling) {
				css += "background-size: " + theme.scaling + ";";
			}

			if (theme.position) {
				css += "background-position: " + theme.position + ";";
			}

			if (theme.repeat) {
				css += "background-repeat: " + theme.repeat + ";";
			}

			if (theme.fixed) {
				css += "background-attachment: " + theme.fixed + ";";
			}

			if (theme["inline-css"]) {
				css += theme["inline-css"];
			}

			return css;
		},


		render: function(theme, preview) {
			theme = theme || this.theme;

			if ((theme.oType || theme.type) === "video") {
				if (!preview && !Auth.isPro) {
					return;
				}

				if (!this.video) {
					this.video = document.createElement("video");

					this.video.loop = true;
					this.video.autoplay = true;

					this.video.setAttribute("class", "bg-video");

					this.$el.prepend(this.video);
				}

				this.video.src = Utils.getImage(theme);
			}
			else {
				// If a video element is present (from a previous theme), destroy it
				if (this.video) {
					this.video.pause();

					this.video.src = "";

					this.video.load();

					$(this.video).remove();

					delete this.video;
				}

				this.$el.attr("style", this.getCSS(theme || this.theme));
			}
		}
	});

	return new Themes();
});
/**
 * This manages theme downloading and caching
 */
define('themes/cacher',["lodash", "jquery", "hogan", "backbone", "storage/filesystem", "storage/storage", "core/status", "lib/parseurl"], function(_, $, Hogan, Backbone, FileSystem, Storage, Status, parseUrl) {
	var Model = Backbone.Model.extend({
		initialize: function() {
			Storage.on("done updated", function(storage) {
				this.set({
					custom: storage.themes,
					cached: storage.cached
				});

				this.storage = storage;
			}, this);
		}
	});


	/**
	 * The cacher utility
	 *
	 * @constructor
	 * @api   public
	 * @param {Object}  theme                  The theme to cache
	 * @param {Object}  [options]              The cache options
	 * @param {Object}  [options.events]       A hash of events to attach to the cacher
	 * @param {Boolean} [options.manual=false] Whether or not to wait for manual cache execution
	 */
	var Cacher = function(theme, options) {
		this.theme = theme;

		options = options || {};

		if (options.events) {
			this.on(options.events);
		}

		if (!options.manual) {
			this.cache();
		}
	};

	_.extend(Cacher.prototype, Backbone.Events);

	Cacher.prototype.model = new Model();


	/**
	 * This function does the actual theme caching
	 *
	 * @api    public
	 * @param {Object} [theme] The theme or error from the getFeed function, where applicable
	 */
	Cacher.prototype.cache = function(theme) {
		// If this is an RSS theme, get the image from the feed first
		if (typeof theme === "undefined" && this.theme.oType === "feed") {
			return this.getFeed(this.cache.bind(this));
		}

		// If theme is false an error occurred in getFeed
		else if (theme === false) {
			this.error();
		}

		// Otherwise, set theme to this.theme
		else if (!theme) {
			theme = this.theme;
		}


		var cached = this.model.get("cached"),
			ids;

		if (cached[theme.id]) {
			// New images might have been added to the theme, so loop
			// through and make sure they're all there. If not, cache them.
			ids = (theme.images || []).filter(function(e) {
				return !cached[e];
			});

			// If this is something like a dynamic theme, inherit information
			// about the current image and the last fetched time
			if (cached[theme.id].currentImage) {
				theme.currentImage = cached[theme.id].currentImage;
			}

			if (cached[theme.id].lastFetched) {
				theme.lastFetched = cached[theme.id].lastFetched;
			}
		}
		else {
			if (theme.images) {
				ids = theme.images.filter(function(e) {
					return !cached[e];
				});
			}
			else {
				ids = [theme.id];
			}
		}


		// If the theme is already cached, cleanup
		if (!ids.length) {
			if (cached[theme.id] && cached[theme.id].image) {
				return this.cleanup(cached[theme.id].image);
			}
			else {
				return this.cleanup();
			}
		}

		var that = this,
			length = ids.length,
			err = this.error.bind(this);

		var isVideo = this.theme.oType === "video";

		FileSystem.get(function(fs) {
			fs.root.getDirectory("Themes", { create: true }, function(dir) {
				var active = 0;

				that.trigger("progress", length, 0);

				ids.forEach(function(id) {
					active++;

					dir.getFile(id + (isVideo ? ".mp4" : ".jpg"), { create: true }, function(fe) {
						var xhr = new XMLHttpRequest();

						xhr.open("GET", (id === theme.id && theme.oType === "feed" ? theme.image : "https://themes.ichro.me/images/" + id + (isVideo ? ".mp4" : ".jpg")));

						xhr.responseType = "blob";

						xhr.onload = function() {
							if (xhr.status !== 200) {
								return err();
							}

							var blob = xhr.response;

							fe.createWriter(function(writer) {
								writer.onwrite = function() {
									active--;

									// This stores the image as a theme
									cached[id] = {
										id: id,
										offline: true
									};

									cached[id][isVideo ? "video" : "image"] = fe.toURL();

									if (active === 0) {
										that.cleanup(cached[id][isVideo ? "video" : "image"]);
									}
									else {
										// length - active might seem to be vulnerable to a race condition at first
										// glance, but the async handlers (dir.getFile) are pushed to the end of the
										// call stack so they can only be called _after_ the forEach is finished
										that.trigger("progress", length, length - active);
									}
								};

								writer.onerror = err;

								writer.write(blob);
							}, err);
						};

						xhr.send();
					}, err);
				});
			}, err);
		}, err);
	};


	/**
	 * The global error handler
	 *
	 * @api    private
	 * @param  {FileError} [e] The FileSystem error, if any
	 */
	Cacher.prototype.error = function(e) {
		// If the FS object has "expired", maybe because of slow
		// requests, restart the caching
		if (e && e.name === "InvalidStateError") {
			return this.cache(this.theme);
		}

		Status.error(e);

		this.trigger("error", e);
	};


	/**
	 * Fetches a theme's RSS feed.  Callable as a standalone function.
	 *
	 * @api    public
	 * @param  {Function} cb      The callback
	 * @param  {Object}   [theme] The theme to fetch, required when called as a standalone function
	 */
	Cacher.prototype.getFeed = function(cb, theme) {
		theme = theme || this.theme;

		// `this` is either a Cacher instance or the Cacher prototype,
		// either way, this.model is defined correctly
		var cached = this.model.get("cached");

		if (cached[theme.id]) {
			theme.image = cached[theme.id].image;

			return cb(theme);
		}

		if (!theme.url || !theme.format) {
			return cb(false);
		}


		var utils = {
				Math: {
					rand: function() {
						return function(max) {
							return Math.floor(Math.random() * max);
						};
					},
					drand: function() {
						return function(max) {
							var rand = Math.sin(new Date().setHours(0, 0, 0, 0)) * 10000;

							return Math.floor((rand - Math.floor(rand)) * max);
						};
					}
				}
			};

		// These are utilities that the URL and image parser are rendered with
		// They can be used to incorporate things like random numbers
		Object.getOwnPropertyNames(Math).forEach(function(e) {
			if (typeof Math[e] === "function") {
				utils.Math[e] = function() {
					return function(args) {
						return Math[e].apply(window, args.split(", "));
					};
				};
			}
			else {
				utils.Math[e] = Math[e];
			}
		});


		$.get(Hogan.compile(theme.url).render(utils), function(d) {
			try {
				var doc;

				if (theme.selector && theme.attr) {
					doc = $(d);

					var url = doc.find(theme.selector);

					if (theme.attr === "text") {
						url = url.text();
					}
					else if (theme.attr === "html") {
						url = url.html();
					}
					else {
						url = url.attr(theme.attr);
					}

					utils.res = url;
				}
				else {
					if (typeof d === "object") {
						utils.res = d;
					}
					else {
						utils.res = JSON.parse(d);
					}
				}

				// Special case handling until a better theme system can be implemented with ServiceWorker
				try {
					if (theme.id === 0) {
						theme.currentImage = {
							name: utils.res.name,
							url: utils.res.sourceUrl,
							source: (utils.res.author || "") + (utils.res.author && (utils.res.copyright || utils.res.source) ? " — " : "") + (utils.res.copyright || utils.res.source || "")
						};
					}
					else if ((theme.id === 82 || theme.id === 83) && utils.res.images && utils.res.images[0] && utils.res.images[0].copyright) {
						theme.currentImage = {
							source: utils.res.images[0].copyrightsource,
							name: utils.res.images[0].copyright.replace(utils.res.images[0].copyrightsource, "").replace(/\(\s*?\)/g, "").trim()
						};
					}
					else if (theme.id === 84 && utils.res.free && utils.res.free[0]) {
						theme.currentImage = {
							name: utils.res.free[0].title,
							source: utils.res.free[0].vendor
						};
					}
					else if (theme.id === 86) {
						theme.currentImage = {
							name: doc.find("item title").text(),
							source: doc.find("item source").text(),
							desc: doc.find("item description").text(),
							url: doc.find("item guid").text()
						};
					}
				}
				catch (e) {}

				theme.image = Hogan.compile(theme.format).render(utils);

				theme.lastFetched = new Date().getTime();

				cb(theme);
			}
			catch(e) {
				Status.error(e);

				cb(false);
			}
		}).fail(function() {
			cb(false);
		});
	};


	/**
	 * Cleans up the theme object, restoring metadata and triggers
	 * the complete event with the newly cached theme
	 *
	 * @api    private
	 * @param  {String} [image] The image (if any) to set on the theme if it
	 *                          doesn't have an images array
	 */
	Cacher.prototype.cleanup = function(image) {
		var theme = this.theme;

		var isVideo = this.theme.oType === "video";

		if (!theme.images && image) {
			theme[isVideo ? "video" : "image"] = image;
		}
		else {
			delete theme.video;
			delete theme.image;
		}

		if (theme.oType) {
			theme.type = theme.oType;

			delete theme.oType;
		}

		theme.offline = true;

		delete theme.size;
		delete theme.stats;
		delete theme.thumb;
		delete theme.original;
		delete theme.resolution;
		delete theme.categories;
		delete theme.filterCategories;

		this.model.storage.cached[theme.id] = theme;

		this.model.set("cached", this.model.storage.cached);

		this.model.storage.sync();

		this.trigger("complete", theme);
	};


	Cacher.Custom = {
		/**
		 * Caches a custom theme's image by URL, saves the theme and returns
		 * the newly saved theme object
		 *
		 * @api    public
		 * @param  {Object}   theme The theme to save
		 * @param  {Number}   id    The ID to save the theme under
		 * @param  {Function} cb    The callback
		 */
		cache: function(theme, id, cb) {
			// If the theme doesn't need any caching, delete the old image if present and return
			if (theme.image.indexOf("data:") === 0 || theme.image.indexOf("filesystem:") === 0 || theme.image.indexOf("/") === 0) {
				theme.offline = true;

				this.deleteImage(theme.id, function() {
					cb(theme);
				});

				return;
			}


			var err = function(e) {
				if (e && e.name === "InvalidStateError") {
					return this.cache(theme, id, cb);
				}

				theme.image = false;

				cb(theme);
			}.bind(this);


			var url = parseUrl(theme.image),
				ext = url.match(/\.([0-9a-z]+)(?:[\?#]|$)/i);

			if (ext && ext[1] && !ext[1].match(/^(jpg|png|gif|svg|webp|bmp)$/i)) {
				err();
			}

			FileSystem.get(function(fs) {
				fs.root.getDirectory("Themes", { create: true }, function(tDir) {
					tDir.getDirectory("Custom", { create: true }, function(dir) {
						dir.getFile(id, { create: true }, function(fe) {
							var xhr = new XMLHttpRequest();

							xhr.open("GET", url);

							xhr.responseType = "blob";

							xhr.onload = function() {
								if (xhr.status !== 200) {
									return err();
								}

								var blob = xhr.response;

								fe.createWriter(function(writer) {
									writer.onwrite = function() {
										theme.image = fe.toURL() + "#OrigURL:" + url;

										theme.offline = true;

										cb(theme);
									};

									writer.onerror = err;

									writer.write(blob);
								}, err);
							};

							xhr.send();
						}, err);
					}, err);
				}, err);
			}, err);
		},


		/**
		 * Deletes a theme and it's image and re-enumerates the remaining themes
		 *
		 * @api    public
		 * @param  {Number}   id    The ID of the theme to delete
		 * @param  {Function} cb    The callback
		 */
		delete: function(id, cb) {
			this.deleteImage(id, function() {
				this.reEnumerate(id, function() {
					Cacher.prototype.model.storage.themes.splice(id, 1);

					Cacher.prototype.model.set("custom", Cacher.prototype.model.storage.themes);

					Cacher.prototype.model.storage.sync();

					cb();
				}.bind(this));
			}.bind(this));
		},


		/**
		 * Re-enumerates the saved images of custom themes to match their index
		 *
		 * @api    public
		 * @param  {Number}   id The ID of the theme to re-enumerate from
		 * @param  {Function} cb The callback
		 */
		reEnumerate: function(id, cb) {
			var err = function(e) {
					if (e && e.name === "InvalidStateError") {
						return this.reEnumerate(id, cb);
					}

					cb();
				}.bind(this),
				themes = Cacher.prototype.model.get("custom");

			FileSystem.get(function(fs) {
				fs.root.getDirectory("Themes", { create: true }, function(tDir) {
					tDir.getDirectory("Custom", { create: true }, function(dir) {
						var entries = [],
							rename = function() {
								var length = entries.length,
									done = 0;

								entries.forEach(function(e) {
									var nName = parseInt(e.name);

									if (typeof nName !== "undefined" && nName > id && themes[nName] && (nName + "").length === e.name.length) { // The theme name is just a number
										e.moveTo(dir, nName - 1, function(fe) {
											var oURL = themes[nName].image.split("#OrigURL:")[1];

											themes[nName].image = fe.toURL() + (oURL ? "#OrigURL:" + oURL : "");

											done++;

											if (done === length) {
												cb();
											}
										});
									}
									else {
										done++;

										if (done === length) {
											cb();
										}
									}
								});
							},
							reader = dir.createReader();

						(function read() { // Recursive and self executing, necessary as per the specs
							reader.readEntries(function(results) {
								if (!results.length) {
									entries.sort(function(a, b) {
										return a.name < b.name ? -1 : a.name > b.name; // 400x faster than localeCompare
									});

									rename();
								}
								else {
									entries = entries.concat(Array.prototype.slice.call(results, 0));

									read();
								}
							}, err);
						})();
					}, err);
				}, err);
			}, err);
		},


		/**
		 * Saves a theme's uploaded image, along with the theme and returns the newly saved theme object
		 *
		 * @api    public
		 * @param  {Object}   theme The theme to save
		 * @param  {File}     file  The uploaded file
		 * @param  {Number}   id    The ID to save the theme under
		 * @param  {Function} cb    The callback
		 */
		saveUpload: function(theme, file, id, cb) {
			var err = function(e) {
				if (e && e.name === "InvalidStateError") {
					return this.saveUpload(theme, file, id, cb);
				}

				theme.image = false;

				cb(theme);
			}.bind(this);

			FileSystem.get(function(fs) {
				fs.root.getDirectory("Themes", { create: true }, function(tDir) {
					tDir.getDirectory("Custom", { create: true }, function(dir) {
						dir.getFile(id, { create: true }, function(fe) {
							fe.createWriter(function(writer) {
								writer.onwrite = function() {
									theme.image = fe.toURL();

									theme.offline = true;

									cb(theme);
								};

								writer.onerror = err;

								writer.write(file);
							}, err);
						}, err);
					}, err);
				}, err);
			}, err);
		},


		/**
		 * Deletes a themes previous image
		 *
		 * @api    public
		 * @param  {Number}   id The ID of the theme to delete the image from
		 * @param  {Function} cb The callback
		 */
		deleteImage: function(id, cb) {
			var err = function(e) {
				if (e && e.name === "InvalidStateError") {
					return this.deleteImage(id, cb);
				}

				cb();
			}.bind(this);

			FileSystem.get(function(fs) {
				fs.root.getDirectory("Themes", { create: true }, function(tDir) {
					tDir.getDirectory("Custom", { create: true }, function(dir) {
						dir.getFile(id, { create: false }, function(fe) {
							fe.remove(cb, err);
						}, err);
					}, err);
				}, err);
			}, err);
		}
	};

	return Cacher;
});
// Spectrum Colorpicker v1.6.1
// https://github.com/bgrins/spectrum
// Author: Brian Grinstead
// License: MIT

(function (factory) {
    "use strict";

    if (typeof define === 'function' && define.amd) { // AMD
        define('lib/jquery.spectrum',['jquery'], factory);
    }
    else if (typeof exports == "object" && typeof module == "object") { // CommonJS
        module.exports = factory;
    }
    else { // Browser
        factory(jQuery);
    }
})(function($, undefined) {
    "use strict";

    var defaultOpts = {

        // Callbacks
        beforeShow: noop,
        move: noop,
        change: noop,
        show: noop,
        hide: noop,

        // Options
        color: false,
        flat: false,
        showInput: false,
        allowEmpty: false,
        showButtons: true,
        clickoutFiresChange: false,
        showInitial: false,
        showPalette: false,
        showPaletteOnly: false,
        hideAfterPaletteSelect: false,
        togglePaletteOnly: false,
        showSelectionPalette: true,
        localStorageKey: false,
        appendTo: "body",
        maxSelectionSize: 7,
        cancelText: "cancel",
        chooseText: "choose",
        togglePaletteMoreText: "more",
        togglePaletteLessText: "less",
        clearText: "Clear Color Selection",
        noColorSelectedText: "No Color Selected",
        preferredFormat: false,
        className: "", // Deprecated - use containerClassName and replacerClassName instead.
        containerClassName: "",
        replacerClassName: "",
        showAlpha: false,
        theme: "sp-light",
        palette: [["#ffffff", "#000000", "#ff0000", "#ff8000", "#ffff00", "#008000", "#0000ff", "#4b0082", "#9400d3"]],
        selectionPalette: [],
        disabled: false,
        offset: null
    },
    spectrums = [],
    IE = !!/msie/i.exec( window.navigator.userAgent ),
    rgbaSupport = (function() {
        function contains( str, substr ) {
            return !!~('' + str).indexOf(substr);
        }

        var elem = document.createElement('div');
        var style = elem.style;
        style.cssText = 'background-color:rgba(0,0,0,.5)';
        return contains(style.backgroundColor, 'rgba') || contains(style.backgroundColor, 'hsla');
    })(),
    replaceInput = [
        "<div class='sp-replacer'>",
            "<div class='sp-preview'><div class='sp-preview-inner'></div></div>",
            "<div class='sp-dd'>&#9660;</div>",
        "</div>"
    ].join(''),
    markup = (function () {

        // IE does not support gradients with multiple stops, so we need to simulate
        //  that for the rainbow slider with 8 divs that each have a single gradient
        var gradientFix = "";
        if (IE) {
            for (var i = 1; i <= 6; i++) {
                gradientFix += "<div class='sp-" + i + "'></div>";
            }
        }

        return [
            "<div class='sp-container sp-hidden'>",
                "<div class='sp-palette-container'>",
                    "<div class='sp-palette sp-thumb sp-cf'></div>",
                    "<div class='sp-palette-button-container sp-cf'>",
                        "<button type='button' class='sp-palette-toggle'></button>",
                    "</div>",
                "</div>",
                "<div class='sp-picker-container'>",
                    "<div class='sp-top sp-cf'>",
                        "<div class='sp-fill'></div>",
                        "<div class='sp-top-inner'>",
                            "<div class='sp-color'>",
                                "<div class='sp-sat'>",
                                    "<div class='sp-val'>",
                                        "<div class='sp-dragger'></div>",
                                    "</div>",
                                "</div>",
                            "</div>",
                            "<div class='sp-clear sp-clear-display'>",
                            "</div>",
                            "<div class='sp-hue'>",
                                "<div class='sp-slider'></div>",
                                gradientFix,
                            "</div>",
                        "</div>",
                        "<div class='sp-alpha'><div class='sp-alpha-inner'><div class='sp-alpha-handle'></div></div></div>",
                    "</div>",
                    "<div class='sp-input-container sp-cf'>",
                        "<input class='sp-input' type='text' spellcheck='false'  />",
                    "</div>",
                    "<div class='sp-initial sp-thumb sp-cf'></div>",
                    "<div class='sp-button-container sp-cf'>",
                        "<a class='sp-cancel' href='#'></a>",
                        "<button type='button' class='sp-choose'></button>",
                    "</div>",
                "</div>",
            "</div>"
        ].join("");
    })();

    function paletteTemplate (p, color, className, opts) {
        var html = [];
        for (var i = 0; i < p.length; i++) {
            var current = p[i];
            if(current) {
                var tiny = tinycolor(current);
                var c = tiny.toHsl().l < 0.5 ? "sp-thumb-el sp-thumb-dark" : "sp-thumb-el sp-thumb-light";
                c += (tinycolor.equals(color, current)) ? " sp-thumb-active" : "";
                var formattedString = tiny.toString(opts.preferredFormat || "rgb");
                var swatchStyle = rgbaSupport ? ("background-color:" + tiny.toRgbString()) : "filter:" + tiny.toFilter();
                html.push('<span title="' + formattedString + '" data-color="' + tiny.toRgbString() + '" class="' + c + '"><span class="sp-thumb-inner" style="' + swatchStyle + ';" /></span>');
            } else {
                var cls = 'sp-clear-display';
                html.push($('<div />')
                    .append($('<span data-color="" style="background-color:transparent;" class="' + cls + '"></span>')
                        .attr('title', opts.noColorSelectedText)
                    )
                    .html()
                );
            }
        }
        return "<div class='sp-cf " + className + "'>" + html.join('') + "</div>";
    }

    function hideAll() {
        for (var i = 0; i < spectrums.length; i++) {
            if (spectrums[i]) {
                spectrums[i].hide();
            }
        }
    }

    function instanceOptions(o, callbackContext) {
        var opts = $.extend({}, defaultOpts, o);
        opts.callbacks = {
            'move': bind(opts.move, callbackContext),
            'change': bind(opts.change, callbackContext),
            'show': bind(opts.show, callbackContext),
            'hide': bind(opts.hide, callbackContext),
            'beforeShow': bind(opts.beforeShow, callbackContext)
        };

        return opts;
    }

    function spectrum(element, o) {

        var opts = instanceOptions(o, element),
            flat = opts.flat,
            showSelectionPalette = opts.showSelectionPalette,
            localStorageKey = opts.localStorageKey,
            theme = opts.theme,
            callbacks = opts.callbacks,
            resize = throttle(reflow, 10),
            visible = false,
            dragWidth = 0,
            dragHeight = 0,
            dragHelperHeight = 0,
            slideHeight = 0,
            slideWidth = 0,
            alphaWidth = 0,
            alphaSlideHelperWidth = 0,
            slideHelperHeight = 0,
            currentHue = 0,
            currentSaturation = 0,
            currentValue = 0,
            currentAlpha = 1,
            palette = [],
            paletteArray = [],
            paletteLookup = {},
            selectionPalette = opts.selectionPalette.slice(0),
            maxSelectionSize = opts.maxSelectionSize,
            draggingClass = "sp-dragging",
            shiftMovementDirection = null;

        var doc = element.ownerDocument,
            body = doc.body,
            boundElement = $(element),
            disabled = false,
            container = $(markup, doc).addClass(theme),
            pickerContainer = container.find(".sp-picker-container"),
            dragger = container.find(".sp-color"),
            dragHelper = container.find(".sp-dragger"),
            slider = container.find(".sp-hue"),
            slideHelper = container.find(".sp-slider"),
            alphaSliderInner = container.find(".sp-alpha-inner"),
            alphaSlider = container.find(".sp-alpha"),
            alphaSlideHelper = container.find(".sp-alpha-handle"),
            textInput = container.find(".sp-input"),
            paletteContainer = container.find(".sp-palette"),
            initialColorContainer = container.find(".sp-initial"),
            cancelButton = container.find(".sp-cancel"),
            clearButton = container.find(".sp-clear"),
            chooseButton = container.find(".sp-choose"),
            toggleButton = container.find(".sp-palette-toggle"),
            isInput = boundElement.is("input"),
            isInputTypeColor = isInput && boundElement.attr("type") === "color" && inputTypeColorSupport(),
            shouldReplace = isInput && !flat,
            replacer = (shouldReplace) ? $(replaceInput).addClass(theme).addClass(opts.className).addClass(opts.replacerClassName) : $([]),
            offsetElement = (shouldReplace) ? replacer : boundElement,
            previewElement = replacer.find(".sp-preview-inner"),
            initialColor = opts.color || (isInput && boundElement.val()),
            colorOnShow = false,
            preferredFormat = opts.preferredFormat,
            currentPreferredFormat = preferredFormat,
            clickoutFiresChange = !opts.showButtons || opts.clickoutFiresChange,
            isEmpty = !initialColor,
            allowEmpty = opts.allowEmpty && !isInputTypeColor;

        function applyOptions() {

            if (opts.showPaletteOnly) {
                opts.showPalette = true;
            }

            toggleButton.text(opts.showPaletteOnly ? opts.togglePaletteMoreText : opts.togglePaletteLessText);

            if (opts.palette) {
                palette = opts.palette.slice(0);
                paletteArray = $.isArray(palette[0]) ? palette : [palette];
                paletteLookup = {};
                for (var i = 0; i < paletteArray.length; i++) {
                    for (var j = 0; j < paletteArray[i].length; j++) {
                        var rgb = tinycolor(paletteArray[i][j]).toRgbString();
                        paletteLookup[rgb] = true;
                    }
                }
            }

            container.toggleClass("sp-flat", flat);
            container.toggleClass("sp-input-disabled", !opts.showInput);
            container.toggleClass("sp-alpha-enabled", opts.showAlpha);
            container.toggleClass("sp-clear-enabled", allowEmpty);
            container.toggleClass("sp-buttons-disabled", !opts.showButtons);
            container.toggleClass("sp-palette-buttons-disabled", !opts.togglePaletteOnly);
            container.toggleClass("sp-palette-disabled", !opts.showPalette);
            container.toggleClass("sp-palette-only", opts.showPaletteOnly);
            container.toggleClass("sp-initial-disabled", !opts.showInitial);
            container.addClass(opts.className).addClass(opts.containerClassName);

            reflow();
        }

        function initialize() {

            if (IE) {
                container.find("*:not(input)").attr("unselectable", "on");
            }

            applyOptions();

            if (shouldReplace) {
                boundElement.after(replacer).hide();
            }

            if (!allowEmpty) {
                clearButton.hide();
            }

            if (flat) {
                boundElement.after(container).hide();
            }
            else {

                var appendTo = opts.appendTo === "parent" ? boundElement.parent() : $(opts.appendTo);
                if (appendTo.length !== 1) {
                    appendTo = $("body");
                }

                appendTo.append(container);
            }

            updateSelectionPaletteFromStorage();

            offsetElement.bind("click.spectrum touchstart.spectrum", function (e) {
                if (!disabled) {
                    toggle();
                }

                e.stopPropagation();

                if (!$(e.target).is("input")) {
                    e.preventDefault();
                }
            });

            if(boundElement.is(":disabled") || (opts.disabled === true)) {
                disable();
            }

            // Prevent clicks from bubbling up to document.  This would cause it to be hidden.
            container.click(stopPropagation);

            // Handle user typed input
            textInput.change(setFromTextInput);
            textInput.bind("paste", function () {
                setTimeout(setFromTextInput, 1);
            });
            textInput.keydown(function (e) { if (e.keyCode == 13) { setFromTextInput(); } });

            cancelButton.text(opts.cancelText);
            cancelButton.bind("click.spectrum", function (e) {
                e.stopPropagation();
                e.preventDefault();
                revert();
                hide();
            });

            clearButton.attr("title", opts.clearText);
            clearButton.bind("click.spectrum", function (e) {
                e.stopPropagation();
                e.preventDefault();
                isEmpty = true;
                move();

                if(flat) {
                    //for the flat style, this is a change event
                    updateOriginalInput(true);
                }
            });

            chooseButton.text(opts.chooseText);
            chooseButton.bind("click.spectrum", function (e) {
                e.stopPropagation();
                e.preventDefault();

                if (IE && textInput.is(":focus")) {
                    textInput.trigger('change');
                }

                if (isValid()) {
                    updateOriginalInput(true);
                    hide();
                }
            });

            toggleButton.text(opts.showPaletteOnly ? opts.togglePaletteMoreText : opts.togglePaletteLessText);
            toggleButton.bind("click.spectrum", function (e) {
                e.stopPropagation();
                e.preventDefault();

                opts.showPaletteOnly = !opts.showPaletteOnly;

                // To make sure the Picker area is drawn on the right, next to the
                // Palette area (and not below the palette), first move the Palette
                // to the left to make space for the picker, plus 5px extra.
                // The 'applyOptions' function puts the whole container back into place
                // and takes care of the button-text and the sp-palette-only CSS class.
                if (!opts.showPaletteOnly && !flat) {
                    container.css('left', '-=' + (pickerContainer.outerWidth(true) + 5));
                }
                applyOptions();
            });

            draggable(alphaSlider, function (dragX, dragY, e) {
                currentAlpha = (dragX / alphaWidth);
                isEmpty = false;
                if (e.shiftKey) {
                    currentAlpha = Math.round(currentAlpha * 10) / 10;
                }

                move();
            }, dragStart, dragStop);

            draggable(slider, function (dragX, dragY) {
                currentHue = parseFloat(dragY / slideHeight);
                isEmpty = false;
                if (!opts.showAlpha) {
                    currentAlpha = 1;
                }
                move();
            }, dragStart, dragStop);

            draggable(dragger, function (dragX, dragY, e) {

                // shift+drag should snap the movement to either the x or y axis.
                if (!e.shiftKey) {
                    shiftMovementDirection = null;
                }
                else if (!shiftMovementDirection) {
                    var oldDragX = currentSaturation * dragWidth;
                    var oldDragY = dragHeight - (currentValue * dragHeight);
                    var furtherFromX = Math.abs(dragX - oldDragX) > Math.abs(dragY - oldDragY);

                    shiftMovementDirection = furtherFromX ? "x" : "y";
                }

                var setSaturation = !shiftMovementDirection || shiftMovementDirection === "x";
                var setValue = !shiftMovementDirection || shiftMovementDirection === "y";

                if (setSaturation) {
                    currentSaturation = parseFloat(dragX / dragWidth);
                }
                if (setValue) {
                    currentValue = parseFloat((dragHeight - dragY) / dragHeight);
                }

                isEmpty = false;
                if (!opts.showAlpha) {
                    currentAlpha = 1;
                }

                move();

            }, dragStart, dragStop);

            if (!!initialColor) {
                set(initialColor);

                // In case color was black - update the preview UI and set the format
                // since the set function will not run (default color is black).
                updateUI();
                currentPreferredFormat = preferredFormat || tinycolor(initialColor).format;

                addColorToSelectionPalette(initialColor);
            }
            else {
                updateUI();
            }

            if (flat) {
                show();
            }

            function paletteElementClick(e) {
                if (e.data && e.data.ignore) {
                    set($(e.target).closest(".sp-thumb-el").data("color"));
                    move();
                }
                else {
                    set($(e.target).closest(".sp-thumb-el").data("color"));
                    move();
                    updateOriginalInput(true);
                    if (opts.hideAfterPaletteSelect) {
                      hide();
                    }
                }

                return false;
            }

            var paletteEvent = IE ? "mousedown.spectrum" : "click.spectrum touchstart.spectrum";
            paletteContainer.delegate(".sp-thumb-el", paletteEvent, paletteElementClick);
            initialColorContainer.delegate(".sp-thumb-el:nth-child(1)", paletteEvent, { ignore: true }, paletteElementClick);
        }

        function updateSelectionPaletteFromStorage() {

            if (localStorageKey && window.localStorage) {

                // Migrate old palettes over to new format.  May want to remove this eventually.
                try {
                    var oldPalette = window.localStorage[localStorageKey].split(",#");
                    if (oldPalette.length > 1) {
                        delete window.localStorage[localStorageKey];
                        $.each(oldPalette, function(i, c) {
                             addColorToSelectionPalette(c);
                        });
                    }
                }
                catch(e) { }

                try {
                    selectionPalette = window.localStorage[localStorageKey].split(";");
                }
                catch (e) { }
            }
        }

        function addColorToSelectionPalette(color) {
            if (showSelectionPalette) {
                var rgb = tinycolor(color).toRgbString();
                if (!paletteLookup[rgb] && $.inArray(rgb, selectionPalette) === -1) {
                    selectionPalette.push(rgb);
                    while(selectionPalette.length > maxSelectionSize) {
                        selectionPalette.shift();
                    }
                }

                if (localStorageKey && window.localStorage) {
                    try {
                        window.localStorage[localStorageKey] = selectionPalette.join(";");
                    }
                    catch(e) { }
                }
            }
        }

        function getUniqueSelectionPalette() {
            var unique = [];
            if (opts.showPalette) {
                for (var i = 0; i < selectionPalette.length; i++) {
                    var rgb = tinycolor(selectionPalette[i]).toRgbString();

                    if (!paletteLookup[rgb]) {
                        unique.push(selectionPalette[i]);
                    }
                }
            }

            return unique.reverse().slice(0, opts.maxSelectionSize);
        }

        function drawPalette() {

            var currentColor = get();

            var html = $.map(paletteArray, function (palette, i) {
                return paletteTemplate(palette, currentColor, "sp-palette-row sp-palette-row-" + i, opts);
            });

            updateSelectionPaletteFromStorage();

            if (selectionPalette) {
                html.push(paletteTemplate(getUniqueSelectionPalette(), currentColor, "sp-palette-row sp-palette-row-selection", opts));
            }

            paletteContainer.html(html.join(""));
        }

        function drawInitial() {
            if (opts.showInitial) {
                var initial = colorOnShow;
                var current = get();
                initialColorContainer.html(paletteTemplate([initial, current], current, "sp-palette-row-initial", opts));
            }
        }

        function dragStart() {
            if (dragHeight <= 0 || dragWidth <= 0 || slideHeight <= 0) {
                reflow();
            }
            container.addClass(draggingClass);
            shiftMovementDirection = null;
            boundElement.trigger('dragstart.spectrum', [ get() ]);
        }

        function dragStop() {
            container.removeClass(draggingClass);
            boundElement.trigger('dragstop.spectrum', [ get() ]);
        }

        function setFromTextInput() {

            var value = textInput.val();

            if ((value === null || value === "") && allowEmpty) {
                set(null);
                updateOriginalInput(true);
            }
            else {
                var tiny = tinycolor(value);
                if (tiny.isValid()) {
                    set(tiny);
                    updateOriginalInput(true);
                }
                else {
                    textInput.addClass("sp-validation-error");
                }
            }
        }

        function toggle() {
            if (visible) {
                hide();
            }
            else {
                show();
            }
        }

        function show() {
            var event = $.Event('beforeShow.spectrum');

            if (visible) {
                reflow();
                return;
            }

            boundElement.trigger(event, [ get() ]);

            if (callbacks.beforeShow(get()) === false || event.isDefaultPrevented()) {
                return;
            }

            hideAll();
            visible = true;

            $(doc).bind("click.spectrum", clickout);
            $(window).bind("resize.spectrum", resize);
            replacer.addClass("sp-active");
            container.removeClass("sp-hidden");

            reflow();
            updateUI();

            colorOnShow = get();

            drawInitial();
            callbacks.show(colorOnShow);
            boundElement.trigger('show.spectrum', [ colorOnShow ]);
        }

        function clickout(e) {
            // Return on right click.
            if (e.button == 2) { return; }

            if (clickoutFiresChange) {
                updateOriginalInput(true);
            }
            else {
                revert();
            }
            hide();
        }

        function hide() {
            // Return if hiding is unnecessary
            if (!visible || flat) { return; }
            visible = false;

            $(doc).unbind("click.spectrum", clickout);
            $(window).unbind("resize.spectrum", resize);

            replacer.removeClass("sp-active");
            container.addClass("sp-hidden");

            callbacks.hide(get());
            boundElement.trigger('hide.spectrum', [ get() ]);
        }

        function revert() {
            set(colorOnShow, true);
        }

        function set(color, ignoreFormatChange) {
            if (tinycolor.equals(color, get())) {
                // Update UI just in case a validation error needs
                // to be cleared.
                updateUI();
                return;
            }

            var newColor, newHsv;
            if (!color && allowEmpty) {
                isEmpty = true;
            } else {
                isEmpty = false;
                newColor = tinycolor(color);
                newHsv = newColor.toHsv();

                currentHue = (newHsv.h % 360) / 360;
                currentSaturation = newHsv.s;
                currentValue = newHsv.v;
                currentAlpha = newHsv.a;
            }
            updateUI();

            if (newColor && newColor.isValid() && !ignoreFormatChange) {
                currentPreferredFormat = preferredFormat || newColor.getFormat();
            }
        }

        function get(opts) {
            opts = opts || { };

            if (allowEmpty && isEmpty) {
                return null;
            }

            return tinycolor.fromRatio({
                h: currentHue,
                s: currentSaturation,
                v: currentValue,
                a: Math.round(currentAlpha * 100) / 100
            }, { format: opts.format || currentPreferredFormat });
        }

        function isValid() {
            return !textInput.hasClass("sp-validation-error");
        }

        function move() {
            updateUI();

            callbacks.move(get());
            boundElement.trigger('move.spectrum', [ get() ]);
        }

        function updateUI() {

            textInput.removeClass("sp-validation-error");

            updateHelperLocations();

            // Update dragger background color (gradients take care of saturation and value).
            var flatColor = tinycolor.fromRatio({ h: currentHue, s: 1, v: 1 });
            dragger.css("background-color", flatColor.toHexString());

            // Get a format that alpha will be included in (hex and names ignore alpha)
            var format = currentPreferredFormat;
            if (currentAlpha < 1 && !(currentAlpha === 0 && format === "name")) {
                if (format === "hex" || format === "hex3" || format === "hex6" || format === "name") {
                    format = "rgb";
                }
            }

            var realColor = get({ format: format }),
                displayColor = '';

             //reset background info for preview element
            previewElement.removeClass("sp-clear-display");
            previewElement.css('background-color', 'transparent');

            if (!realColor && allowEmpty) {
                // Update the replaced elements background with icon indicating no color selection
                previewElement.addClass("sp-clear-display");
            }
            else {
                var realHex = realColor.toHexString(),
                    realRgb = realColor.toRgbString();

                // Update the replaced elements background color (with actual selected color)
                if (rgbaSupport || realColor.alpha === 1) {
                    previewElement.css("background-color", realRgb);
                }
                else {
                    previewElement.css("background-color", "transparent");
                    previewElement.css("filter", realColor.toFilter());
                }

                if (opts.showAlpha) {
                    var rgb = realColor.toRgb();
                    rgb.a = 0;
                    var realAlpha = tinycolor(rgb).toRgbString();
                    var gradient = "linear-gradient(left, " + realAlpha + ", " + realHex + ")";

                    if (IE) {
                        alphaSliderInner.css("filter", tinycolor(realAlpha).toFilter({ gradientType: 1 }, realHex));
                    }
                    else {
                        alphaSliderInner.css("background", "-webkit-" + gradient);
                        alphaSliderInner.css("background", "-moz-" + gradient);
                        alphaSliderInner.css("background", "-ms-" + gradient);
                        // Use current syntax gradient on unprefixed property.
                        alphaSliderInner.css("background",
                            "linear-gradient(to right, " + realAlpha + ", " + realHex + ")");
                    }
                }

                displayColor = realColor.toString(format);
            }

            // Update the text entry input as it changes happen
            if (opts.showInput) {
                textInput.val(displayColor);
            }

            if (opts.showPalette) {
                drawPalette();
            }

            drawInitial();
        }

        function updateHelperLocations() {
            var s = currentSaturation;
            var v = currentValue;

            if(allowEmpty && isEmpty) {
                //if selected color is empty, hide the helpers
                alphaSlideHelper.hide();
                slideHelper.hide();
                dragHelper.hide();
            }
            else {
                //make sure helpers are visible
                alphaSlideHelper.show();
                slideHelper.show();
                dragHelper.show();

                // Where to show the little circle in that displays your current selected color
                var dragX = s * dragWidth;
                var dragY = dragHeight - (v * dragHeight);
                dragX = Math.max(
                    -dragHelperHeight,
                    Math.min(dragWidth - dragHelperHeight, dragX - dragHelperHeight)
                );
                dragY = Math.max(
                    -dragHelperHeight,
                    Math.min(dragHeight - dragHelperHeight, dragY - dragHelperHeight)
                );
                dragHelper.css({
                    "top": dragY + "px",
                    "left": dragX + "px"
                });

                var alphaX = currentAlpha * alphaWidth;
                alphaSlideHelper.css({
                    "left": (alphaX - (alphaSlideHelperWidth / 2)) + "px"
                });

                // Where to show the bar that displays your current selected hue
                var slideY = (currentHue) * slideHeight;
                slideHelper.css({
                    "top": (slideY - slideHelperHeight) + "px"
                });
            }
        }

        function updateOriginalInput(fireCallback) {
            var color = get(),
                displayColor = '',
                hasChanged = !tinycolor.equals(color, colorOnShow);

            if (color) {
                displayColor = color.toString(currentPreferredFormat);
                // Update the selection palette with the current color
                addColorToSelectionPalette(color);
            }

            if (isInput) {
                boundElement.val(displayColor);
            }

            if (fireCallback && hasChanged) {
                callbacks.change(color);
                boundElement.trigger('change', [ color ]);
            }
        }

        function reflow() {
            dragWidth = dragger.width();
            dragHeight = dragger.height();
            dragHelperHeight = dragHelper.height();
            slideWidth = slider.width();
            slideHeight = slider.height();
            slideHelperHeight = slideHelper.height();
            alphaWidth = alphaSlider.width();
            alphaSlideHelperWidth = alphaSlideHelper.width();

            if (!flat) {
                container.css("position", "absolute");
                if (opts.offset) {
                    container.offset(opts.offset);
                } else {
                    container.offset(getOffset(container, offsetElement));
                }
            }

            updateHelperLocations();

            if (opts.showPalette) {
                drawPalette();
            }

            boundElement.trigger('reflow.spectrum');
        }

        function destroy() {
            boundElement.show();
            offsetElement.unbind("click.spectrum touchstart.spectrum");
            container.remove();
            replacer.remove();
            spectrums[spect.id] = null;
        }

        function option(optionName, optionValue) {
            if (optionName === undefined) {
                return $.extend({}, opts);
            }
            if (optionValue === undefined) {
                return opts[optionName];
            }

            opts[optionName] = optionValue;
            applyOptions();
        }

        function enable() {
            disabled = false;
            boundElement.attr("disabled", false);
            offsetElement.removeClass("sp-disabled");
        }

        function disable() {
            hide();
            disabled = true;
            boundElement.attr("disabled", true);
            offsetElement.addClass("sp-disabled");
        }

        function setOffset(coord) {
            opts.offset = coord;
            reflow();
        }

        initialize();

        var spect = {
            show: show,
            hide: hide,
            toggle: toggle,
            reflow: reflow,
            option: option,
            enable: enable,
            disable: disable,
            offset: setOffset,
            set: function (c) {
                set(c);
                updateOriginalInput();
            },
            get: get,
            destroy: destroy,
            container: container
        };

        spect.id = spectrums.push(spect) - 1;

        return spect;
    }

    /**
    * checkOffset - get the offset below/above and left/right element depending on screen position
    * Thanks https://github.com/jquery/jquery-ui/blob/master/ui/jquery.ui.datepicker.js
    */
    function getOffset(picker, input) {
        var extraY = 0;
        var dpWidth = picker.outerWidth();
        var dpHeight = picker.outerHeight();
        var inputHeight = input.outerHeight();
        var doc = picker[0].ownerDocument;
        var docElem = doc.documentElement;
        var viewWidth = docElem.clientWidth + $(doc).scrollLeft();
        var viewHeight = docElem.clientHeight + $(doc).scrollTop();
        var offset = input.offset();
        offset.top += inputHeight;

        offset.left -=
            Math.min(offset.left, (offset.left + dpWidth > viewWidth && viewWidth > dpWidth) ?
            Math.abs(offset.left + dpWidth - viewWidth) : 0);

        offset.top -=
            Math.min(offset.top, ((offset.top + dpHeight > viewHeight && viewHeight > dpHeight) ?
            Math.abs(dpHeight + inputHeight - extraY) : extraY));

        return offset;
    }

    /**
    * noop - do nothing
    */
    function noop() {

    }

    /**
    * stopPropagation - makes the code only doing this a little easier to read in line
    */
    function stopPropagation(e) {
        e.stopPropagation();
    }

    /**
    * Create a function bound to a given object
    * Thanks to underscore.js
    */
    function bind(func, obj) {
        var slice = Array.prototype.slice;
        var args = slice.call(arguments, 2);
        return function () {
            return func.apply(obj, args.concat(slice.call(arguments)));
        };
    }

    /**
    * Lightweight drag helper.  Handles containment within the element, so that
    * when dragging, the x is within [0,element.width] and y is within [0,element.height]
    */
    function draggable(element, onmove, onstart, onstop) {
        onmove = onmove || function () { };
        onstart = onstart || function () { };
        onstop = onstop || function () { };
        var doc = document;
        var dragging = false;
        var offset = {};
        var maxHeight = 0;
        var maxWidth = 0;
        var hasTouch = ('ontouchstart' in window);

        var duringDragEvents = {};
        duringDragEvents["selectstart"] = prevent;
        duringDragEvents["dragstart"] = prevent;
        duringDragEvents["touchmove mousemove"] = move;
        duringDragEvents["touchend mouseup"] = stop;

        function prevent(e) {
            if (e.stopPropagation) {
                e.stopPropagation();
            }
            if (e.preventDefault) {
                e.preventDefault();
            }
            e.returnValue = false;
        }

        function move(e) {
            if (dragging) {
                // Mouseup happened outside of window
                if (IE && doc.documentMode < 9 && !e.button) {
                    return stop();
                }

                var t0 = e.originalEvent && e.originalEvent.touches && e.originalEvent.touches[0];
                var pageX = t0 && t0.pageX || e.pageX;
                var pageY = t0 && t0.pageY || e.pageY;

                var dragX = Math.max(0, Math.min(pageX - offset.left, maxWidth));
                var dragY = Math.max(0, Math.min(pageY - offset.top, maxHeight));

                if (hasTouch) {
                    // Stop scrolling in iOS
                    prevent(e);
                }

                onmove.apply(element, [dragX, dragY, e]);
            }
        }

        function start(e) {
            var rightclick = (e.which) ? (e.which == 3) : (e.button == 2);

            if (!rightclick && !dragging) {
                if (onstart.apply(element, arguments) !== false) {
                    dragging = true;
                    maxHeight = $(element).height();
                    maxWidth = $(element).width();
                    offset = $(element).offset();

                    $(doc).bind(duringDragEvents);
                    $(doc.body).addClass("sp-dragging");

                    if (!hasTouch) {
                        move(e);
                    }

                    prevent(e);
                }
            }
        }

        function stop() {
            if (dragging) {
                $(doc).unbind(duringDragEvents);
                $(doc.body).removeClass("sp-dragging");
                onstop.apply(element, arguments);
            }
            dragging = false;
        }

        $(element).bind("touchstart mousedown", start);
    }

    function throttle(func, wait, debounce) {
        var timeout;
        return function () {
            var context = this, args = arguments;
            var throttler = function () {
                timeout = null;
                func.apply(context, args);
            };
            if (debounce) clearTimeout(timeout);
            if (debounce || !timeout) timeout = setTimeout(throttler, wait);
        };
    }

    function inputTypeColorSupport() {
        return $.fn.spectrum.inputTypeColorSupport();
    }

    /**
    * Define a jQuery plugin
    */
    var dataID = "spectrum.id";
    $.fn.spectrum = function (opts, extra) {

        if (typeof opts == "string") {

            var returnValue = this;
            var args = Array.prototype.slice.call( arguments, 1 );

            this.each(function () {
                var spect = spectrums[$(this).data(dataID)];
                if (spect) {
                    var method = spect[opts];
                    if (!method) {
                        throw new Error( "Spectrum: no such method: '" + opts + "'" );
                    }

                    if (opts == "get") {
                        returnValue = spect.get();
                    }
                    else if (opts == "container") {
                        returnValue = spect.container;
                    }
                    else if (opts == "option") {
                        returnValue = spect.option.apply(spect, args);
                    }
                    else if (opts == "destroy") {
                        spect.destroy();
                        $(this).removeData(dataID);
                    }
                    else {
                        method.apply(spect, args);
                    }
                }
            });

            return returnValue;
        }

        // Initializing a new instance of spectrum
        return this.spectrum("destroy").each(function () {
            var options = $.extend({}, opts, $(this).data());
            var spect = spectrum(this, options);
            $(this).data(dataID, spect.id);
        });
    };

    $.fn.spectrum.load = true;
    $.fn.spectrum.loadOpts = {};
    $.fn.spectrum.draggable = draggable;
    $.fn.spectrum.defaults = defaultOpts;
    $.fn.spectrum.inputTypeColorSupport = function inputTypeColorSupport() {
        if (typeof inputTypeColorSupport._cachedResult === "undefined") {
            var colorInput = $("<input type='color' value='!' />")[0];
            inputTypeColorSupport._cachedResult = colorInput.type === "color" && colorInput.value !== "!";
        }
        return inputTypeColorSupport._cachedResult;
    };

    $.spectrum = { };
    $.spectrum.localization = { };
    $.spectrum.palettes = { };

    $.fn.spectrum.processNativeColorInputs = function () {
        var colorInputs = $("input[type=color]");
        if (colorInputs.length && !inputTypeColorSupport()) {
            colorInputs.spectrum({
                preferredFormat: "hex6"
            });
        }
    };

    // TinyColor v1.1.2
    // https://github.com/bgrins/TinyColor
    // Brian Grinstead, MIT License

    (function() {

    var trimLeft = /^[\s,#]+/,
        trimRight = /\s+$/,
        tinyCounter = 0,
        math = Math,
        mathRound = math.round,
        mathMin = math.min,
        mathMax = math.max,
        mathRandom = math.random;

    var tinycolor = function(color, opts) {

        color = (color) ? color : '';
        opts = opts || { };

        // If input is already a tinycolor, return itself
        if (color instanceof tinycolor) {
           return color;
        }
        // If we are called as a function, call using new instead
        if (!(this instanceof tinycolor)) {
            return new tinycolor(color, opts);
        }

        var rgb = inputToRGB(color);
        this._originalInput = color,
        this._r = rgb.r,
        this._g = rgb.g,
        this._b = rgb.b,
        this._a = rgb.a,
        this._roundA = mathRound(100*this._a) / 100,
        this._format = opts.format || rgb.format;
        this._gradientType = opts.gradientType;

        // Don't let the range of [0,255] come back in [0,1].
        // Potentially lose a little bit of precision here, but will fix issues where
        // .5 gets interpreted as half of the total, instead of half of 1
        // If it was supposed to be 128, this was already taken care of by `inputToRgb`
        if (this._r < 1) { this._r = mathRound(this._r); }
        if (this._g < 1) { this._g = mathRound(this._g); }
        if (this._b < 1) { this._b = mathRound(this._b); }

        this._ok = rgb.ok;
        this._tc_id = tinyCounter++;
    };

    tinycolor.prototype = {
        isDark: function() {
            return this.getBrightness() < 128;
        },
        isLight: function() {
            return !this.isDark();
        },
        isValid: function() {
            return this._ok;
        },
        getOriginalInput: function() {
          return this._originalInput;
        },
        getFormat: function() {
            return this._format;
        },
        getAlpha: function() {
            return this._a;
        },
        getBrightness: function() {
            var rgb = this.toRgb();
            return (rgb.r * 299 + rgb.g * 587 + rgb.b * 114) / 1000;
        },
        setAlpha: function(value) {
            this._a = boundAlpha(value);
            this._roundA = mathRound(100*this._a) / 100;
            return this;
        },
        toHsv: function() {
            var hsv = rgbToHsv(this._r, this._g, this._b);
            return { h: hsv.h * 360, s: hsv.s, v: hsv.v, a: this._a };
        },
        toHsvString: function() {
            var hsv = rgbToHsv(this._r, this._g, this._b);
            var h = mathRound(hsv.h * 360), s = mathRound(hsv.s * 100), v = mathRound(hsv.v * 100);
            return (this._a == 1) ?
              "hsv("  + h + ", " + s + "%, " + v + "%)" :
              "hsva(" + h + ", " + s + "%, " + v + "%, "+ this._roundA + ")";
        },
        toHsl: function() {
            var hsl = rgbToHsl(this._r, this._g, this._b);
            return { h: hsl.h * 360, s: hsl.s, l: hsl.l, a: this._a };
        },
        toHslString: function() {
            var hsl = rgbToHsl(this._r, this._g, this._b);
            var h = mathRound(hsl.h * 360), s = mathRound(hsl.s * 100), l = mathRound(hsl.l * 100);
            return (this._a == 1) ?
              "hsl("  + h + ", " + s + "%, " + l + "%)" :
              "hsla(" + h + ", " + s + "%, " + l + "%, "+ this._roundA + ")";
        },
        toHex: function(allow3Char) {
            return rgbToHex(this._r, this._g, this._b, allow3Char);
        },
        toHexString: function(allow3Char) {
            return '#' + this.toHex(allow3Char);
        },
        toHex8: function() {
            return rgbaToHex(this._r, this._g, this._b, this._a);
        },
        toHex8String: function() {
            return '#' + this.toHex8();
        },
        toRgb: function() {
            return { r: mathRound(this._r), g: mathRound(this._g), b: mathRound(this._b), a: this._a };
        },
        toRgbString: function() {
            return (this._a == 1) ?
              "rgb("  + mathRound(this._r) + ", " + mathRound(this._g) + ", " + mathRound(this._b) + ")" :
              "rgba(" + mathRound(this._r) + ", " + mathRound(this._g) + ", " + mathRound(this._b) + ", " + this._roundA + ")";
        },
        toPercentageRgb: function() {
            return { r: mathRound(bound01(this._r, 255) * 100) + "%", g: mathRound(bound01(this._g, 255) * 100) + "%", b: mathRound(bound01(this._b, 255) * 100) + "%", a: this._a };
        },
        toPercentageRgbString: function() {
            return (this._a == 1) ?
              "rgb("  + mathRound(bound01(this._r, 255) * 100) + "%, " + mathRound(bound01(this._g, 255) * 100) + "%, " + mathRound(bound01(this._b, 255) * 100) + "%)" :
              "rgba(" + mathRound(bound01(this._r, 255) * 100) + "%, " + mathRound(bound01(this._g, 255) * 100) + "%, " + mathRound(bound01(this._b, 255) * 100) + "%, " + this._roundA + ")";
        },
        toName: function() {
            if (this._a === 0) {
                return "transparent";
            }

            if (this._a < 1) {
                return false;
            }

            return hexNames[rgbToHex(this._r, this._g, this._b, true)] || false;
        },
        toFilter: function(secondColor) {
            var hex8String = '#' + rgbaToHex(this._r, this._g, this._b, this._a);
            var secondHex8String = hex8String;
            var gradientType = this._gradientType ? "GradientType = 1, " : "";

            if (secondColor) {
                var s = tinycolor(secondColor);
                secondHex8String = s.toHex8String();
            }

            return "progid:DXImageTransform.Microsoft.gradient("+gradientType+"startColorstr="+hex8String+",endColorstr="+secondHex8String+")";
        },
        toString: function(format) {
            var formatSet = !!format;
            format = format || this._format;

            var formattedString = false;
            var hasAlpha = this._a < 1 && this._a >= 0;
            var needsAlphaFormat = !formatSet && hasAlpha && (format === "hex" || format === "hex6" || format === "hex3" || format === "name");

            if (needsAlphaFormat) {
                // Special case for "transparent", all other non-alpha formats
                // will return rgba when there is transparency.
                if (format === "name" && this._a === 0) {
                    return this.toName();
                }
                return this.toRgbString();
            }
            if (format === "rgb") {
                formattedString = this.toRgbString();
            }
            if (format === "prgb") {
                formattedString = this.toPercentageRgbString();
            }
            if (format === "hex" || format === "hex6") {
                formattedString = this.toHexString();
            }
            if (format === "hex3") {
                formattedString = this.toHexString(true);
            }
            if (format === "hex8") {
                formattedString = this.toHex8String();
            }
            if (format === "name") {
                formattedString = this.toName();
            }
            if (format === "hsl") {
                formattedString = this.toHslString();
            }
            if (format === "hsv") {
                formattedString = this.toHsvString();
            }

            return formattedString || this.toHexString();
        },

        _applyModification: function(fn, args) {
            var color = fn.apply(null, [this].concat([].slice.call(args)));
            this._r = color._r;
            this._g = color._g;
            this._b = color._b;
            this.setAlpha(color._a);
            return this;
        },
        lighten: function() {
            return this._applyModification(lighten, arguments);
        },
        brighten: function() {
            return this._applyModification(brighten, arguments);
        },
        darken: function() {
            return this._applyModification(darken, arguments);
        },
        desaturate: function() {
            return this._applyModification(desaturate, arguments);
        },
        saturate: function() {
            return this._applyModification(saturate, arguments);
        },
        greyscale: function() {
            return this._applyModification(greyscale, arguments);
        },
        spin: function() {
            return this._applyModification(spin, arguments);
        },

        _applyCombination: function(fn, args) {
            return fn.apply(null, [this].concat([].slice.call(args)));
        },
        analogous: function() {
            return this._applyCombination(analogous, arguments);
        },
        complement: function() {
            return this._applyCombination(complement, arguments);
        },
        monochromatic: function() {
            return this._applyCombination(monochromatic, arguments);
        },
        splitcomplement: function() {
            return this._applyCombination(splitcomplement, arguments);
        },
        triad: function() {
            return this._applyCombination(triad, arguments);
        },
        tetrad: function() {
            return this._applyCombination(tetrad, arguments);
        }
    };

    // If input is an object, force 1 into "1.0" to handle ratios properly
    // String input requires "1.0" as input, so 1 will be treated as 1
    tinycolor.fromRatio = function(color, opts) {
        if (typeof color == "object") {
            var newColor = {};
            for (var i in color) {
                if (color.hasOwnProperty(i)) {
                    if (i === "a") {
                        newColor[i] = color[i];
                    }
                    else {
                        newColor[i] = convertToPercentage(color[i]);
                    }
                }
            }
            color = newColor;
        }

        return tinycolor(color, opts);
    };

    // Given a string or object, convert that input to RGB
    // Possible string inputs:
    //
    //     "red"
    //     "#f00" or "f00"
    //     "#ff0000" or "ff0000"
    //     "#ff000000" or "ff000000"
    //     "rgb 255 0 0" or "rgb (255, 0, 0)"
    //     "rgb 1.0 0 0" or "rgb (1, 0, 0)"
    //     "rgba (255, 0, 0, 1)" or "rgba 255, 0, 0, 1"
    //     "rgba (1.0, 0, 0, 1)" or "rgba 1.0, 0, 0, 1"
    //     "hsl(0, 100%, 50%)" or "hsl 0 100% 50%"
    //     "hsla(0, 100%, 50%, 1)" or "hsla 0 100% 50%, 1"
    //     "hsv(0, 100%, 100%)" or "hsv 0 100% 100%"
    //
    function inputToRGB(color) {

        var rgb = { r: 0, g: 0, b: 0 };
        var a = 1;
        var ok = false;
        var format = false;

        if (typeof color == "string") {
            color = stringInputToObject(color);
        }

        if (typeof color == "object") {
            if (color.hasOwnProperty("r") && color.hasOwnProperty("g") && color.hasOwnProperty("b")) {
                rgb = rgbToRgb(color.r, color.g, color.b);
                ok = true;
                format = String(color.r).substr(-1) === "%" ? "prgb" : "rgb";
            }
            else if (color.hasOwnProperty("h") && color.hasOwnProperty("s") && color.hasOwnProperty("v")) {
                color.s = convertToPercentage(color.s);
                color.v = convertToPercentage(color.v);
                rgb = hsvToRgb(color.h, color.s, color.v);
                ok = true;
                format = "hsv";
            }
            else if (color.hasOwnProperty("h") && color.hasOwnProperty("s") && color.hasOwnProperty("l")) {
                color.s = convertToPercentage(color.s);
                color.l = convertToPercentage(color.l);
                rgb = hslToRgb(color.h, color.s, color.l);
                ok = true;
                format = "hsl";
            }

            if (color.hasOwnProperty("a")) {
                a = color.a;
            }
        }

        a = boundAlpha(a);

        return {
            ok: ok,
            format: color.format || format,
            r: mathMin(255, mathMax(rgb.r, 0)),
            g: mathMin(255, mathMax(rgb.g, 0)),
            b: mathMin(255, mathMax(rgb.b, 0)),
            a: a
        };
    }


    // Conversion Functions
    // --------------------

    // `rgbToHsl`, `rgbToHsv`, `hslToRgb`, `hsvToRgb` modified from:
    // <http://mjijackson.com/2008/02/rgb-to-hsl-and-rgb-to-hsv-color-model-conversion-algorithms-in-javascript>

    // `rgbToRgb`
    // Handle bounds / percentage checking to conform to CSS color spec
    // <http://www.w3.org/TR/css3-color/>
    // *Assumes:* r, g, b in [0, 255] or [0, 1]
    // *Returns:* { r, g, b } in [0, 255]
    function rgbToRgb(r, g, b){
        return {
            r: bound01(r, 255) * 255,
            g: bound01(g, 255) * 255,
            b: bound01(b, 255) * 255
        };
    }

    // `rgbToHsl`
    // Converts an RGB color value to HSL.
    // *Assumes:* r, g, and b are contained in [0, 255] or [0, 1]
    // *Returns:* { h, s, l } in [0,1]
    function rgbToHsl(r, g, b) {

        r = bound01(r, 255);
        g = bound01(g, 255);
        b = bound01(b, 255);

        var max = mathMax(r, g, b), min = mathMin(r, g, b);
        var h, s, l = (max + min) / 2;

        if(max == min) {
            h = s = 0; // achromatic
        }
        else {
            var d = max - min;
            s = l > 0.5 ? d / (2 - max - min) : d / (max + min);
            switch(max) {
                case r: h = (g - b) / d + (g < b ? 6 : 0); break;
                case g: h = (b - r) / d + 2; break;
                case b: h = (r - g) / d + 4; break;
            }

            h /= 6;
        }

        return { h: h, s: s, l: l };
    }

    // `hslToRgb`
    // Converts an HSL color value to RGB.
    // *Assumes:* h is contained in [0, 1] or [0, 360] and s and l are contained [0, 1] or [0, 100]
    // *Returns:* { r, g, b } in the set [0, 255]
    function hslToRgb(h, s, l) {
        var r, g, b;

        h = bound01(h, 360);
        s = bound01(s, 100);
        l = bound01(l, 100);

        function hue2rgb(p, q, t) {
            if(t < 0) t += 1;
            if(t > 1) t -= 1;
            if(t < 1/6) return p + (q - p) * 6 * t;
            if(t < 1/2) return q;
            if(t < 2/3) return p + (q - p) * (2/3 - t) * 6;
            return p;
        }

        if(s === 0) {
            r = g = b = l; // achromatic
        }
        else {
            var q = l < 0.5 ? l * (1 + s) : l + s - l * s;
            var p = 2 * l - q;
            r = hue2rgb(p, q, h + 1/3);
            g = hue2rgb(p, q, h);
            b = hue2rgb(p, q, h - 1/3);
        }

        return { r: r * 255, g: g * 255, b: b * 255 };
    }

    // `rgbToHsv`
    // Converts an RGB color value to HSV
    // *Assumes:* r, g, and b are contained in the set [0, 255] or [0, 1]
    // *Returns:* { h, s, v } in [0,1]
    function rgbToHsv(r, g, b) {

        r = bound01(r, 255);
        g = bound01(g, 255);
        b = bound01(b, 255);

        var max = mathMax(r, g, b), min = mathMin(r, g, b);
        var h, s, v = max;

        var d = max - min;
        s = max === 0 ? 0 : d / max;

        if(max == min) {
            h = 0; // achromatic
        }
        else {
            switch(max) {
                case r: h = (g - b) / d + (g < b ? 6 : 0); break;
                case g: h = (b - r) / d + 2; break;
                case b: h = (r - g) / d + 4; break;
            }
            h /= 6;
        }
        return { h: h, s: s, v: v };
    }

    // `hsvToRgb`
    // Converts an HSV color value to RGB.
    // *Assumes:* h is contained in [0, 1] or [0, 360] and s and v are contained in [0, 1] or [0, 100]
    // *Returns:* { r, g, b } in the set [0, 255]
     function hsvToRgb(h, s, v) {

        h = bound01(h, 360) * 6;
        s = bound01(s, 100);
        v = bound01(v, 100);

        var i = math.floor(h),
            f = h - i,
            p = v * (1 - s),
            q = v * (1 - f * s),
            t = v * (1 - (1 - f) * s),
            mod = i % 6,
            r = [v, q, p, p, t, v][mod],
            g = [t, v, v, q, p, p][mod],
            b = [p, p, t, v, v, q][mod];

        return { r: r * 255, g: g * 255, b: b * 255 };
    }

    // `rgbToHex`
    // Converts an RGB color to hex
    // Assumes r, g, and b are contained in the set [0, 255]
    // Returns a 3 or 6 character hex
    function rgbToHex(r, g, b, allow3Char) {

        var hex = [
            pad2(mathRound(r).toString(16)),
            pad2(mathRound(g).toString(16)),
            pad2(mathRound(b).toString(16))
        ];

        // Return a 3 character hex if possible
        if (allow3Char && hex[0].charAt(0) == hex[0].charAt(1) && hex[1].charAt(0) == hex[1].charAt(1) && hex[2].charAt(0) == hex[2].charAt(1)) {
            return hex[0].charAt(0) + hex[1].charAt(0) + hex[2].charAt(0);
        }

        return hex.join("");
    }
        // `rgbaToHex`
        // Converts an RGBA color plus alpha transparency to hex
        // Assumes r, g, b and a are contained in the set [0, 255]
        // Returns an 8 character hex
        function rgbaToHex(r, g, b, a) {

            var hex = [
                pad2(convertDecimalToHex(a)),
                pad2(mathRound(r).toString(16)),
                pad2(mathRound(g).toString(16)),
                pad2(mathRound(b).toString(16))
            ];

            return hex.join("");
        }

    // `equals`
    // Can be called with any tinycolor input
    tinycolor.equals = function (color1, color2) {
        if (!color1 || !color2) { return false; }
        return tinycolor(color1).toRgbString() == tinycolor(color2).toRgbString();
    };
    tinycolor.random = function() {
        return tinycolor.fromRatio({
            r: mathRandom(),
            g: mathRandom(),
            b: mathRandom()
        });
    };


    // Modification Functions
    // ----------------------
    // Thanks to less.js for some of the basics here
    // <https://github.com/cloudhead/less.js/blob/master/lib/less/functions.js>

    function desaturate(color, amount) {
        amount = (amount === 0) ? 0 : (amount || 10);
        var hsl = tinycolor(color).toHsl();
        hsl.s -= amount / 100;
        hsl.s = clamp01(hsl.s);
        return tinycolor(hsl);
    }

    function saturate(color, amount) {
        amount = (amount === 0) ? 0 : (amount || 10);
        var hsl = tinycolor(color).toHsl();
        hsl.s += amount / 100;
        hsl.s = clamp01(hsl.s);
        return tinycolor(hsl);
    }

    function greyscale(color) {
        return tinycolor(color).desaturate(100);
    }

    function lighten (color, amount) {
        amount = (amount === 0) ? 0 : (amount || 10);
        var hsl = tinycolor(color).toHsl();
        hsl.l += amount / 100;
        hsl.l = clamp01(hsl.l);
        return tinycolor(hsl);
    }

    function brighten(color, amount) {
        amount = (amount === 0) ? 0 : (amount || 10);
        var rgb = tinycolor(color).toRgb();
        rgb.r = mathMax(0, mathMin(255, rgb.r - mathRound(255 * - (amount / 100))));
        rgb.g = mathMax(0, mathMin(255, rgb.g - mathRound(255 * - (amount / 100))));
        rgb.b = mathMax(0, mathMin(255, rgb.b - mathRound(255 * - (amount / 100))));
        return tinycolor(rgb);
    }

    function darken (color, amount) {
        amount = (amount === 0) ? 0 : (amount || 10);
        var hsl = tinycolor(color).toHsl();
        hsl.l -= amount / 100;
        hsl.l = clamp01(hsl.l);
        return tinycolor(hsl);
    }

    // Spin takes a positive or negative amount within [-360, 360] indicating the change of hue.
    // Values outside of this range will be wrapped into this range.
    function spin(color, amount) {
        var hsl = tinycolor(color).toHsl();
        var hue = (mathRound(hsl.h) + amount) % 360;
        hsl.h = hue < 0 ? 360 + hue : hue;
        return tinycolor(hsl);
    }

    // Combination Functions
    // ---------------------
    // Thanks to jQuery xColor for some of the ideas behind these
    // <https://github.com/infusion/jQuery-xcolor/blob/master/jquery.xcolor.js>

    function complement(color) {
        var hsl = tinycolor(color).toHsl();
        hsl.h = (hsl.h + 180) % 360;
        return tinycolor(hsl);
    }

    function triad(color) {
        var hsl = tinycolor(color).toHsl();
        var h = hsl.h;
        return [
            tinycolor(color),
            tinycolor({ h: (h + 120) % 360, s: hsl.s, l: hsl.l }),
            tinycolor({ h: (h + 240) % 360, s: hsl.s, l: hsl.l })
        ];
    }

    function tetrad(color) {
        var hsl = tinycolor(color).toHsl();
        var h = hsl.h;
        return [
            tinycolor(color),
            tinycolor({ h: (h + 90) % 360, s: hsl.s, l: hsl.l }),
            tinycolor({ h: (h + 180) % 360, s: hsl.s, l: hsl.l }),
            tinycolor({ h: (h + 270) % 360, s: hsl.s, l: hsl.l })
        ];
    }

    function splitcomplement(color) {
        var hsl = tinycolor(color).toHsl();
        var h = hsl.h;
        return [
            tinycolor(color),
            tinycolor({ h: (h + 72) % 360, s: hsl.s, l: hsl.l}),
            tinycolor({ h: (h + 216) % 360, s: hsl.s, l: hsl.l})
        ];
    }

    function analogous(color, results, slices) {
        results = results || 6;
        slices = slices || 30;

        var hsl = tinycolor(color).toHsl();
        var part = 360 / slices;
        var ret = [tinycolor(color)];

        for (hsl.h = ((hsl.h - (part * results >> 1)) + 720) % 360; --results; ) {
            hsl.h = (hsl.h + part) % 360;
            ret.push(tinycolor(hsl));
        }
        return ret;
    }

    function monochromatic(color, results) {
        results = results || 6;
        var hsv = tinycolor(color).toHsv();
        var h = hsv.h, s = hsv.s, v = hsv.v;
        var ret = [];
        var modification = 1 / results;

        while (results--) {
            ret.push(tinycolor({ h: h, s: s, v: v}));
            v = (v + modification) % 1;
        }

        return ret;
    }

    // Utility Functions
    // ---------------------

    tinycolor.mix = function(color1, color2, amount) {
        amount = (amount === 0) ? 0 : (amount || 50);

        var rgb1 = tinycolor(color1).toRgb();
        var rgb2 = tinycolor(color2).toRgb();

        var p = amount / 100;
        var w = p * 2 - 1;
        var a = rgb2.a - rgb1.a;

        var w1;

        if (w * a == -1) {
            w1 = w;
        } else {
            w1 = (w + a) / (1 + w * a);
        }

        w1 = (w1 + 1) / 2;

        var w2 = 1 - w1;

        var rgba = {
            r: rgb2.r * w1 + rgb1.r * w2,
            g: rgb2.g * w1 + rgb1.g * w2,
            b: rgb2.b * w1 + rgb1.b * w2,
            a: rgb2.a * p  + rgb1.a * (1 - p)
        };

        return tinycolor(rgba);
    };


    // Readability Functions
    // ---------------------
    // <http://www.w3.org/TR/AERT#color-contrast>

    // `readability`
    // Analyze the 2 colors and returns an object with the following properties:
    //    `brightness`: difference in brightness between the two colors
    //    `color`: difference in color/hue between the two colors
    tinycolor.readability = function(color1, color2) {
        var c1 = tinycolor(color1);
        var c2 = tinycolor(color2);
        var rgb1 = c1.toRgb();
        var rgb2 = c2.toRgb();
        var brightnessA = c1.getBrightness();
        var brightnessB = c2.getBrightness();
        var colorDiff = (
            Math.max(rgb1.r, rgb2.r) - Math.min(rgb1.r, rgb2.r) +
            Math.max(rgb1.g, rgb2.g) - Math.min(rgb1.g, rgb2.g) +
            Math.max(rgb1.b, rgb2.b) - Math.min(rgb1.b, rgb2.b)
        );

        return {
            brightness: Math.abs(brightnessA - brightnessB),
            color: colorDiff
        };
    };

    // `readable`
    // http://www.w3.org/TR/AERT#color-contrast
    // Ensure that foreground and background color combinations provide sufficient contrast.
    // *Example*
    //    tinycolor.isReadable("#000", "#111") => false
    tinycolor.isReadable = function(color1, color2) {
        var readability = tinycolor.readability(color1, color2);
        return readability.brightness > 125 && readability.color > 500;
    };

    // `mostReadable`
    // Given a base color and a list of possible foreground or background
    // colors for that base, returns the most readable color.
    // *Example*
    //    tinycolor.mostReadable("#123", ["#fff", "#000"]) => "#000"
    tinycolor.mostReadable = function(baseColor, colorList) {
        var bestColor = null;
        var bestScore = 0;
        var bestIsReadable = false;
        for (var i=0; i < colorList.length; i++) {

            // We normalize both around the "acceptable" breaking point,
            // but rank brightness constrast higher than hue.

            var readability = tinycolor.readability(baseColor, colorList[i]);
            var readable = readability.brightness > 125 && readability.color > 500;
            var score = 3 * (readability.brightness / 125) + (readability.color / 500);

            if ((readable && ! bestIsReadable) ||
                (readable && bestIsReadable && score > bestScore) ||
                ((! readable) && (! bestIsReadable) && score > bestScore)) {
                bestIsReadable = readable;
                bestScore = score;
                bestColor = tinycolor(colorList[i]);
            }
        }
        return bestColor;
    };


    // Big List of Colors
    // ------------------
    // <http://www.w3.org/TR/css3-color/#svg-color>
    var names = tinycolor.names = {
        aliceblue: "f0f8ff",
        antiquewhite: "faebd7",
        aqua: "0ff",
        aquamarine: "7fffd4",
        azure: "f0ffff",
        beige: "f5f5dc",
        bisque: "ffe4c4",
        black: "000",
        blanchedalmond: "ffebcd",
        blue: "00f",
        blueviolet: "8a2be2",
        brown: "a52a2a",
        burlywood: "deb887",
        burntsienna: "ea7e5d",
        cadetblue: "5f9ea0",
        chartreuse: "7fff00",
        chocolate: "d2691e",
        coral: "ff7f50",
        cornflowerblue: "6495ed",
        cornsilk: "fff8dc",
        crimson: "dc143c",
        cyan: "0ff",
        darkblue: "00008b",
        darkcyan: "008b8b",
        darkgoldenrod: "b8860b",
        darkgray: "a9a9a9",
        darkgreen: "006400",
        darkgrey: "a9a9a9",
        darkkhaki: "bdb76b",
        darkmagenta: "8b008b",
        darkolivegreen: "556b2f",
        darkorange: "ff8c00",
        darkorchid: "9932cc",
        darkred: "8b0000",
        darksalmon: "e9967a",
        darkseagreen: "8fbc8f",
        darkslateblue: "483d8b",
        darkslategray: "2f4f4f",
        darkslategrey: "2f4f4f",
        darkturquoise: "00ced1",
        darkviolet: "9400d3",
        deeppink: "ff1493",
        deepskyblue: "00bfff",
        dimgray: "696969",
        dimgrey: "696969",
        dodgerblue: "1e90ff",
        firebrick: "b22222",
        floralwhite: "fffaf0",
        forestgreen: "228b22",
        fuchsia: "f0f",
        gainsboro: "dcdcdc",
        ghostwhite: "f8f8ff",
        gold: "ffd700",
        goldenrod: "daa520",
        gray: "808080",
        green: "008000",
        greenyellow: "adff2f",
        grey: "808080",
        honeydew: "f0fff0",
        hotpink: "ff69b4",
        indianred: "cd5c5c",
        indigo: "4b0082",
        ivory: "fffff0",
        khaki: "f0e68c",
        lavender: "e6e6fa",
        lavenderblush: "fff0f5",
        lawngreen: "7cfc00",
        lemonchiffon: "fffacd",
        lightblue: "add8e6",
        lightcoral: "f08080",
        lightcyan: "e0ffff",
        lightgoldenrodyellow: "fafad2",
        lightgray: "d3d3d3",
        lightgreen: "90ee90",
        lightgrey: "d3d3d3",
        lightpink: "ffb6c1",
        lightsalmon: "ffa07a",
        lightseagreen: "20b2aa",
        lightskyblue: "87cefa",
        lightslategray: "789",
        lightslategrey: "789",
        lightsteelblue: "b0c4de",
        lightyellow: "ffffe0",
        lime: "0f0",
        limegreen: "32cd32",
        linen: "faf0e6",
        magenta: "f0f",
        maroon: "800000",
        mediumaquamarine: "66cdaa",
        mediumblue: "0000cd",
        mediumorchid: "ba55d3",
        mediumpurple: "9370db",
        mediumseagreen: "3cb371",
        mediumslateblue: "7b68ee",
        mediumspringgreen: "00fa9a",
        mediumturquoise: "48d1cc",
        mediumvioletred: "c71585",
        midnightblue: "191970",
        mintcream: "f5fffa",
        mistyrose: "ffe4e1",
        moccasin: "ffe4b5",
        navajowhite: "ffdead",
        navy: "000080",
        oldlace: "fdf5e6",
        olive: "808000",
        olivedrab: "6b8e23",
        orange: "ffa500",
        orangered: "ff4500",
        orchid: "da70d6",
        palegoldenrod: "eee8aa",
        palegreen: "98fb98",
        paleturquoise: "afeeee",
        palevioletred: "db7093",
        papayawhip: "ffefd5",
        peachpuff: "ffdab9",
        peru: "cd853f",
        pink: "ffc0cb",
        plum: "dda0dd",
        powderblue: "b0e0e6",
        purple: "800080",
        rebeccapurple: "663399",
        red: "f00",
        rosybrown: "bc8f8f",
        royalblue: "4169e1",
        saddlebrown: "8b4513",
        salmon: "fa8072",
        sandybrown: "f4a460",
        seagreen: "2e8b57",
        seashell: "fff5ee",
        sienna: "a0522d",
        silver: "c0c0c0",
        skyblue: "87ceeb",
        slateblue: "6a5acd",
        slategray: "708090",
        slategrey: "708090",
        snow: "fffafa",
        springgreen: "00ff7f",
        steelblue: "4682b4",
        tan: "d2b48c",
        teal: "008080",
        thistle: "d8bfd8",
        tomato: "ff6347",
        turquoise: "40e0d0",
        violet: "ee82ee",
        wheat: "f5deb3",
        white: "fff",
        whitesmoke: "f5f5f5",
        yellow: "ff0",
        yellowgreen: "9acd32"
    };

    // Make it easy to access colors via `hexNames[hex]`
    var hexNames = tinycolor.hexNames = flip(names);


    // Utilities
    // ---------

    // `{ 'name1': 'val1' }` becomes `{ 'val1': 'name1' }`
    function flip(o) {
        var flipped = { };
        for (var i in o) {
            if (o.hasOwnProperty(i)) {
                flipped[o[i]] = i;
            }
        }
        return flipped;
    }

    // Return a valid alpha value [0,1] with all invalid values being set to 1
    function boundAlpha(a) {
        a = parseFloat(a);

        if (isNaN(a) || a < 0 || a > 1) {
            a = 1;
        }

        return a;
    }

    // Take input from [0, n] and return it as [0, 1]
    function bound01(n, max) {
        if (isOnePointZero(n)) { n = "100%"; }

        var processPercent = isPercentage(n);
        n = mathMin(max, mathMax(0, parseFloat(n)));

        // Automatically convert percentage into number
        if (processPercent) {
            n = parseInt(n * max, 10) / 100;
        }

        // Handle floating point rounding errors
        if ((math.abs(n - max) < 0.000001)) {
            return 1;
        }

        // Convert into [0, 1] range if it isn't already
        return (n % max) / parseFloat(max);
    }

    // Force a number between 0 and 1
    function clamp01(val) {
        return mathMin(1, mathMax(0, val));
    }

    // Parse a base-16 hex value into a base-10 integer
    function parseIntFromHex(val) {
        return parseInt(val, 16);
    }

    // Need to handle 1.0 as 100%, since once it is a number, there is no difference between it and 1
    // <http://stackoverflow.com/questions/7422072/javascript-how-to-detect-number-as-a-decimal-including-1-0>
    function isOnePointZero(n) {
        return typeof n == "string" && n.indexOf('.') != -1 && parseFloat(n) === 1;
    }

    // Check to see if string passed in is a percentage
    function isPercentage(n) {
        return typeof n === "string" && n.indexOf('%') != -1;
    }

    // Force a hex value to have 2 characters
    function pad2(c) {
        return c.length == 1 ? '0' + c : '' + c;
    }

    // Replace a decimal with it's percentage value
    function convertToPercentage(n) {
        if (n <= 1) {
            n = (n * 100) + "%";
        }

        return n;
    }

    // Converts a decimal to a hex value
    function convertDecimalToHex(d) {
        return Math.round(parseFloat(d) * 255).toString(16);
    }
    // Converts a hex value to a decimal
    function convertHexToDecimal(h) {
        return (parseIntFromHex(h) / 255);
    }

    var matchers = (function() {

        // <http://www.w3.org/TR/css3-values/#integers>
        var CSS_INTEGER = "[-\\+]?\\d+%?";

        // <http://www.w3.org/TR/css3-values/#number-value>
        var CSS_NUMBER = "[-\\+]?\\d*\\.\\d+%?";

        // Allow positive/negative integer/number.  Don't capture the either/or, just the entire outcome.
        var CSS_UNIT = "(?:" + CSS_NUMBER + ")|(?:" + CSS_INTEGER + ")";

        // Actual matching.
        // Parentheses and commas are optional, but not required.
        // Whitespace can take the place of commas or opening paren
        var PERMISSIVE_MATCH3 = "[\\s|\\(]+(" + CSS_UNIT + ")[,|\\s]+(" + CSS_UNIT + ")[,|\\s]+(" + CSS_UNIT + ")\\s*\\)?";
        var PERMISSIVE_MATCH4 = "[\\s|\\(]+(" + CSS_UNIT + ")[,|\\s]+(" + CSS_UNIT + ")[,|\\s]+(" + CSS_UNIT + ")[,|\\s]+(" + CSS_UNIT + ")\\s*\\)?";

        return {
            rgb: new RegExp("rgb" + PERMISSIVE_MATCH3),
            rgba: new RegExp("rgba" + PERMISSIVE_MATCH4),
            hsl: new RegExp("hsl" + PERMISSIVE_MATCH3),
            hsla: new RegExp("hsla" + PERMISSIVE_MATCH4),
            hsv: new RegExp("hsv" + PERMISSIVE_MATCH3),
            hsva: new RegExp("hsva" + PERMISSIVE_MATCH4),
            hex3: /^([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,
            hex6: /^([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/,
            hex8: /^([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/
        };
    })();

    // `stringInputToObject`
    // Permissive string parsing.  Take in a number of formats, and output an object
    // based on detected format.  Returns `{ r, g, b }` or `{ h, s, l }` or `{ h, s, v}`
    function stringInputToObject(color) {

        color = color.replace(trimLeft,'').replace(trimRight, '').toLowerCase();
        var named = false;
        if (names[color]) {
            color = names[color];
            named = true;
        }
        else if (color == 'transparent') {
            return { r: 0, g: 0, b: 0, a: 0, format: "name" };
        }

        // Try to match string input using regular expressions.
        // Keep most of the number bounding out of this function - don't worry about [0,1] or [0,100] or [0,360]
        // Just return an object and let the conversion functions handle that.
        // This way the result will be the same whether the tinycolor is initialized with string or object.
        var match;
        if ((match = matchers.rgb.exec(color))) {
            return { r: match[1], g: match[2], b: match[3] };
        }
        if ((match = matchers.rgba.exec(color))) {
            return { r: match[1], g: match[2], b: match[3], a: match[4] };
        }
        if ((match = matchers.hsl.exec(color))) {
            return { h: match[1], s: match[2], l: match[3] };
        }
        if ((match = matchers.hsla.exec(color))) {
            return { h: match[1], s: match[2], l: match[3], a: match[4] };
        }
        if ((match = matchers.hsv.exec(color))) {
            return { h: match[1], s: match[2], v: match[3] };
        }
        if ((match = matchers.hsva.exec(color))) {
            return { h: match[1], s: match[2], v: match[3], a: match[4] };
        }
        if ((match = matchers.hex8.exec(color))) {
            return {
                a: convertHexToDecimal(match[1]),
                r: parseIntFromHex(match[2]),
                g: parseIntFromHex(match[3]),
                b: parseIntFromHex(match[4]),
                format: named ? "name" : "hex8"
            };
        }
        if ((match = matchers.hex6.exec(color))) {
            return {
                r: parseIntFromHex(match[1]),
                g: parseIntFromHex(match[2]),
                b: parseIntFromHex(match[3]),
                format: named ? "name" : "hex"
            };
        }
        if ((match = matchers.hex3.exec(color))) {
            return {
                r: parseIntFromHex(match[1] + '' + match[1]),
                g: parseIntFromHex(match[2] + '' + match[2]),
                b: parseIntFromHex(match[3] + '' + match[3]),
                format: named ? "name" : "hex"
            };
        }

        return false;
    }

    window.tinycolor = tinycolor;
    })();

    $(function () {
        if ($.fn.spectrum.load) {
            $.fn.spectrum.processNativeColorInputs();
        }
    });

});
/**
 * This is the custom theme create/edit dialog
 */
define('themes/custom',[
	"lodash", "jquery", "backbone", "core/analytics", "modals/modals", "themes/utils", "themes/cacher", "i18n/i18n", "core/render", "lib/unextend", "lib/jquery.spectrum"
], function(_, $, Backbone, Track, Modal, Utils, Cacher, Translate, render, unextend) {
	var Model =  Backbone.Model.extend({
			defaults: function() {
				return _.clone(Utils.defaults);
			}
		}),
		View = Backbone.View.extend({
			el: function() {
				return this.modal.content;
			},


			events: {
				"click .btn.save": "save",
				"click .btn.preview": "preview",
				"change .color, .image, .upload input, .position, .scaling, .repeat": "updatePreview",

				"click input:not([type=radio], [type=checkbox]), textarea, select": function(e) {
					if (e.which === 13) {
						this.save(e); // This calls preventDefault
					}
				},
				"change .upload input": function() {
					this.$(".image").val("").change();
				}
			},


			/**
			 * Updates the theme preview from the form
			 *
			 * @api    private
			 */
			updatePreview: function() {
				var image = this.$(".image").val(),
					uploadInput = this.$(".upload input")[0],
					next = function(url) {
						this.$(".preview").first().css({
							backgroundColor: this.$("#color").val(),
							backgroundSize: this.$("#scaling").val(),
							backgroundRepeat: this.$("#repeat").val(),
							backgroundAttachment: this.$("#fixed").val(),
							backgroundPosition: this.$("#position").val(),
							backgroundImage: "url(\"" + (url || "") + "\")"
						});
					}.bind(this);

				if (image) {
					next(image);
				}
				else if (uploadInput && uploadInput.files.length) {
					var fr = new FileReader();

					fr.onloadend = function() {
						if (fr.error) {
							next();
						}
						else {
							next(fr.result);
						}
					};

					fr.readAsDataURL(uploadInput.files[0]);
				}
				else {
					next();
				}
			},


			/**
			 * Serializes the form and triggers a preview event
			 *
			 * @api    private
			 */
			preview: function(e) {
				if (e && e.preventDefault) {
					e.preventDefault();
				}

				var next = function(theme) {
					Track.event("Themes", "Preview", "Custom");

					this.trigger("preview", theme);
				}.bind(this);

				var theme = this.serialize(),
					uploadInput = this.$(".upload input")[0];

				if (!theme.image && uploadInput && uploadInput.files.length) {
					var fr = new FileReader();

					fr.onloadend = function() {
						if (!fr.error) {
							theme.image = fr.result;
						}

						next(theme);
					};

					fr.readAsDataURL(uploadInput.files[0]);
				}
				else {
					next(theme);
				}
			},


			/**
			 * Saves the theme and destroys the modal, finishing the creation process
			 *
			 * @api    public
			 * @param  {Event|Function} [e] The event to call preventDefault() on or a callback function
			 */
			save: function(e) {
				if (typeof e === "function") {
					var cb = e;
				}
				else if (e && e.preventDefault) {
					e.preventDefault();
				}


				var theme = unextend(Utils.defaults, this.serialize()),
					themes = Utils.model.get("custom"),
					editing = typeof this.editing !== "undefined",
					id = (editing ? this.editing : themes.length);


				var next = function(d) {
					theme = d || theme;

					if (editing && themes[this.editing]) {
						Cacher.prototype.model.storage.themes[this.editing] = theme;
					}
					else {
						Cacher.prototype.model.storage.themes.push(theme);
					}

					Cacher.prototype.model.storage.sync();

					Track.event("Themes", (editing ? "Edit" : "Create"), "custom" + id);

					this.trigger("save", theme);

					if (cb) {
						cb();
					}

					this.destroy();
				}.bind(this);


				var upload;

				if (theme.image && typeof theme.image === "string") {
					try { // This is a user-provided URL, anything could happen
						Cacher.Custom.cache(theme, id, next);
					}
					catch(err) {
						alert(Translate("themes.edit.cache_error"));
					}
				}
				else if ((upload = this.$(".upload input")[0].files).length) {
					try { // Again, who knows what could go wrong
						Cacher.Custom.saveUpload(theme, upload[0], id, next);
					}
					catch(err) {
						alert(Translate("themes.edit.upload_error"));
					}
				}
				else if (editing) {
					Cacher.Custom.deleteImage(id, next);
				}
				else {
					next();
				}
			},


			/**
			 * Serializes the form into an unextended theme object
			 *
			 * @api    public
			 * @return {Object} The serialized theme
			 */
			serialize: function() {
				var theme = {};

				this.$("form").serializeArray().forEach(function(e) {
					if (e.value) {
						theme[e.name] = e.value;
					}
				});

				return theme;
			},


			/**
			 * Destroys the dialog, modal and model
			 *
			 * @api    public
			 */
			destroy: function() {
				// modal.hide() triggers a destroy which in turn calls this.remove();
				this.modal.hide();
			},


			constructor: function() {
				this.modal = new (Modal.extend({
					destroyOnHide: true,
					classes: "themes create"
				}))().on("destroy", this.remove, this);

				return Backbone.View.apply(this, arguments);
			},


			initialize: function(options) {
				if (options && typeof options.theme === "number") {
					this.model = new Model(Utils.model.get("custom")[options.theme]);

					this.editing = options.theme;
				}
				else {
					this.model = new Model();
				}

				this.render();

				this.modal.mo.appendTo(document.body);

				requestAnimationFrame(this.modal.show.bind(this.modal));
			},

			remove: function() {
				this.$("#color").spectrum("destroy");

				Backbone.View.prototype.remove.call(this);
			},

			render: function() {
				this.$("#color").spectrum("destroy");

				this.$el.html(render("themes.custom", this.model.attributes));

				var preview = this.$(".preview")[0];

				this.$("#color").spectrum({
					showInput: true,
					showAlpha: true,
					showInitial: true,
					showButtons: false,
					preferredFormat: "rgb",
					clickoutFiresChange: true,
					move: _.debounce(function(color) {
						preview.style.backgroundColor = color;
					}, 35, {
						maxWait: 35,
						leading: true,
						trailing: true
					})
				});

				this.$("#repeat").val(this.model.get("repeat"));
				this.$("#scaling").val(this.model.get("scaling"));
				this.$("#position").val(this.model.get("position"));

				this.updatePreview();
			}
		});

	return View;
});
/**
 * The themes modal
 */
define(
	'themes/themes',["lodash", "jquery", "backbone", "browser/api", "core/auth", "core/analytics", "modals/modals", "themes/model", "themes/controller", "themes/utils", "themes/custom", "themes/cacher", "i18n/i18n", "core/render"],
	function(_, $, Backbone, Browser, Auth, Track, Modal, Model, Themes, Utils, Custom, Cacher, Translate, render) {
		var modal = new (Modal.extend({
			classes: "themes",
		}))();

		var View = Backbone.View.extend({
			el: modal.content,


			/**
			 * This holds an array of theme images so the scroll handler doesn't
			 * have to query for them while handling lazy-loading.
			 *
			 * @type {Element[]}
			 */
			images: [],


			events: {
				"click .btn.use": "use",
				"click .btn.edit": "edit",
				"click .btn.delete": "delete",
				"click .btn.preview": "preview",
				"click .nav li[data-id]": "filter",
				"click .nav li.create .btn": "createTheme"
			},


			/**
			 * Creates a new custom theme
			 *
			 * @api    private
			 */
			createTheme: function() {
				this.createModal = new Custom();

				this.createModal.on("save", function() {
					this.model.updateCustom();
				}, this).on("preview", function(theme) {
					this.trigger("preview", theme);
				}, this);

				Track.pageview("Themes: Create", "/themes/create");
			},


			/**
			 * Edits a custom theme
			 *
			 * @api    private
			 * @param  {Event} e The event
			 */
			edit: function(e) {
				this.editModal = new Custom({ theme: parseInt($(e.currentTarget).closest(".theme").attr("data-id")) });

				this.editModal.on("save", function() {
					this.model.updateCustom();
				}, this).on("preview", function(theme) {
					this.trigger("preview", theme);
				}, this);

				Track.pageview("Themes: Edit", "/themes/edit");
			},


			/**
			 * Deletes a custom theme
			 *
			 * @api    private
			 * @param  {Event} e The event
			 */
			delete: function(e) {
				if (!confirm(Translate("themes.delete_confirm"))) {
					return false;
				}

				var id = parseInt($(e.currentTarget).closest(".theme").attr("data-id"));

				Cacher.Custom.delete(id, function(err) {
					if (err) {
						alert(Translate("themes.delete_error"));
					}

					this.model.updateCustom();
				}.bind(this));
			},


			/**
			 * Handles the preview click event and parses out the theme image
			 * to trigger the preview event with
			 *
			 * @api    private
			 * @param  {Event} e
			 */
			preview: function(e) {
				e.preventDefault();

				var index = this.model.get("index"),
					themes = this.model.get("themes"),
					custom = Utils.model.get("custom"),
					cached = Utils.model.get("cached"),
					parent = $(e.currentTarget).parents(".theme").first(),
					id = parseInt(parent.attr("data-id") || 0);

				if (parent.hasClass("custom")) {
					Track.event("Themes", "Preview", "custom" + id);

					return this.trigger("preview", custom[id], "custom" + id);
				}

				var theme = _.clone(themes[index[id]]);

				if (!theme) {
					return;
				}

				if (!cached[theme.id] && theme.oType === "feed") {
					var specs = parent.find(".specs:first"),
						oHtml = specs.html();

					specs.html("<span>" + Translate("themes.feed_fetching") + "</span>");

					return Cacher.prototype.getFeed(function(theme) {
						if (theme === false) {
							specs.html("<span>" + Translate("themes.feed_error") + "</span>");

							setTimeout(function() {
								specs.html(oHtml);
							}, 7000);
						}
						else {
							Track.event("Themes", "Preview", theme.id);

							specs.html(oHtml);

							this.trigger("preview", theme);
						}
					}.bind(this), theme);
				}
				else if (cached[theme.id]) {
					theme = cached[theme.id];
				}

				Track.event("Themes", "Preview", theme.id);

				this.trigger("preview", theme);
			},


			/**
			 * Handles the use click event, caches the theme and trigger the
			 * use event with the newly cached theme
			 *
			 * @api    private
			 * @param  {Event} e
			 */
			use: function(e) {
				e.preventDefault();

				var index = this.model.get("index"),
					themes = this.model.get("themes"),
					custom = Utils.model.get("custom"),
					parent = $(e.currentTarget).parents(".theme").first(),
					id = parseInt(parent.attr("data-id") || 0);

				if (parent.hasClass("custom")) {
					Track.event("Themes", "Use", "custom" + id);

					return this.trigger("use", custom[id], "custom" + id);
				}

				var theme = _.clone(themes[index[id]]);

				if (!theme) {
					return;
				}

				var specs = parent.find(".specs:first"),
					oHtml = specs.html(),
					config = {
						events: {
							progress: function(total, done) {
								specs.html("<span>" + Translate("themes.caching") + "</span><span>" + Translate("themes.cache_status", done, total) + "</span>");
							},
							complete: function(theme) {
								specs.html(oHtml);

								Track.event("Themes", "Use", theme.id);

								this.trigger("use", theme, theme.id);
							}.bind(this),
							error: function() {
								specs.html("<span>" + Translate("themes.cache_error") + "</span>");

								setTimeout(function() {
									specs.html(oHtml);
								}, 7000);
							}
						}
					};


				if (theme.proOnly && !Auth.isPro) {
					specs.html("<span>" + Translate("themes.pro_only") + "</span>");

					setTimeout(function() {
						specs.html(oHtml);
					}, 3000);

					return;
				}


				if (theme.oType === "sunrise_sunset") {
					navigator.geolocation.getCurrentPosition(function(pos) {
						if (pos && pos.coords) {
							Browser.storage.lat = parseFloat(pos.coords.latitude.toFixed(2));
							Browser.storage.lon = parseFloat(pos.coords.longitude.toFixed(2));
						}

						// There's no need to store the cacher in a variable since the events are passed on creation
						new Cacher(theme, config);
					}.bind(this));
				}
				else {
					new Cacher(theme, config);
				}
			},


			/**
			 * Handles nav click events and filters the themes
			 *
			 * @api    private
			 * @param  {Event} e
			 */
			filter: function(e) {
				var elm = $(e.currentTarget),
					id = elm.attr("data-id"),
					themes = [];


				if (id === "custom") {
					themes = this.model.get("custom");
				}
				else if ((id = parseInt(id)) || id === 0) {
					themes = this.model.get("themes").filter(function(e) {
						return e.filterCategories && e.filterCategories.indexOf(id) !== -1;
					});
				}
				else {
					themes = [].concat(this.model.get("custom"), this.model.get("themes"));
				}


				// This fades the container out and back in so the filtering isn't a sudden jolt
				var container = this.$el.addClass("fadeout").children(".container");

				setTimeout(function() {
					container.html(render("themes.listing", {
						themes: themes
					})).scrollTop(0).end().removeClass("fadeout");

					this.images = this.$(".theme .push").toArray();

					this.lazyLoad();
				}.bind(this), 250);


				elm.addClass("active").siblings().removeClass("active");
			},


			/**
			 * Handles thumbnail lazy-loading
			 *
			 * @api    private
			 */
			lazyLoad: function() {
				var length = this.images.length;

				// There might not be any images left to lazy-load
				if (!length) {
					return;
				}

				var coords,
					innerHeight = window.innerHeight; // Querying innerHeight can get costly in a loop

				this.images = this.images.filter(function(img) {
					coords = img.getBoundingClientRect();

					if (((coords.top >= 0 && coords.left >= 0 && coords.top) <= innerHeight)) {
						// This removes the `lazy` class from the image
						img.className = "push";

						return false;
					}

					return true;
				});
			},

			show: function() {
				if (!this.fetched) {
					this.model.fetch();

					this.fetched = true;
				}
				else {
					// Call render to reset the listing
					this.render();
				}

				modal.show();

				Track.pageview("Themes", "/themes");

				return this;
			},

			initialize: function() {
				this.model = new Model();

				modal.mo.appendTo(document.body);


				this.on("use", function() {
					modal.hide();
				}, this);

				this.on("preview", Themes.preview, Themes);


				var refresh = function() {
					this.$el.html(render("themes", {
						categories: this.model.get("categories")
					}));


					// Unfortunately scroll events don't bubble so this can't be attached in the events hash
					this.$(".container").on("scroll", _.debounce(this.lazyLoad.bind(this), 100, {
						// Never wait more than 100ms, which is only 10x a second and easy for
						// the computer but still snappy to a person
						maxWait: 100,
						leading: true
					}));


					this.render();
				};

				this.model.on("change", refresh, this);

				refresh.call(this);
			},

			render: function() {
				this.$(".container").html(render("themes.listing", {
					themes: [].concat(this.model.get("custom"), this.model.get("themes"))
				}));

				this.images = this.$(".theme .push").toArray();

				this.lazyLoad();
			}
		});

		return _.once(function() {
			return new View();
		});
	}
);
/**
 * The visual settings page
 */
define('settings/pages/visual',["jquery", "i18n/i18n", "modals/alert", "core/auth", "settings/page", "themes/utils", "themes/themes"], function($, Translate, Alert, Auth, Page, Utils, themePicker) {
	var View = Page.extend({
		id: "visual",

		dynamicControls: {
			theme: "style",
			layout: "layout",
			column_width: "column_width"
		},

		monitorProps: ["theme", "backgroundImage", "layout", "columns", "columnWidth", "style"],

		events: {
			"click .background button.select": function() {
				themePicker().show().once("use", function(theme, id) {
					this.model.set("theme", id || theme.id, {
						noRender: true
					});

					this.$(".current-background").text(theme.name || (typeof theme.id === "number" ? Translate("settings.visual.unnamed", theme.id) : ""));
				}, this);
			},

			"click .theme button.preview": function(e) {
				this.previewStyle(e.currentTarget.parentNode.getAttribute("data-id"));
			}
		},


		/**
		 * General input change handler
		 *
		 * @param   {HTMLElement}  elm    The input element
		 * @param   {String}       name   The name of the input
		 * @param   {String}       value  The value of the input
		 */
		onInputChange: function(elm, name, value) {
			switch (name) {
				case "background-url":
					if (value && value.trim()) {
						this.model.set("theme", "custom");

						this.model.set("backgroundImage", value);
					}
					else {
						this.model.unset("backgroundImage", {
							noRender: true
						});

						// If the theme was a custom one and there now isn't an image, set it to the default
						if (this.model.get("theme") === "custom") {
							this.model.set("theme", "default");
						}
					}
				break;

				case "layout":
					var next = function() {
						this.model.set("layout", value, {
							noRender: true
						});

						$(elm).parents(".input").siblings(".input")[value === "columns" ? "slideDown" : "slideUp"](300);
					};

					if ((value === "columns" && this.model.get("layout") === "grid") || (value === "grid" && this.model.get("layout") === "columns")) {
						Alert({
							confirm: true,
							contents: [Translate("settings.visual.layout.column_warning." + (value === "columns" ? "grid_to_column" : "column_to_grid"))]
						}).on("select", function(confirmed) {
							if (confirmed) {
								next.call(this);
							}
							else {
								this.$("input[name=layout]:not(:checked)")[0].checked = true;
							}
						}, this);
					}
					else {
						next.call(this);
					}
				break;

				case "columns":
					var columns = parseInt(value) || 3;

					if (columns < 1) {
						columns = 1;
					}
					else if (columns > 5) {
						columns = 5;
					}

					if (columns.toString() !== value.trim()) {
						this.$("input[name=columns]").val(columns);
					}

					this.model.set("columns", columns, {
						noRender: true
					});
				break;

				case "column_width":
					this.model.set("columnWidth", value, {
						noRender: true
					});
				break;

				case "theme":
					this.model.set("style", (Auth.isPro && value) || "light", {
						noRender: true
					});
				break;
			}
		},


		/**
		 * Displays a preview of an app style
		 *
		 * @param   {String}  style  The style to preview
		 */
		previewStyle: function(style) {
			var body = $(document.body);

			// Adaptive themes such as the transparent one need to
			// restore the base style after they've been previewed
			var oldClass = body.attr("class");

			body.removeClass(this.model.get("style")).addClass(style);

			var hidePreview = function() {
				clearTimeout(removeTimeout);

				$(".previewHidden").removeClass("previewHidden").addClass("visible");

				previewOverlay.remove();

				body.attr("class", oldClass);
			};

			// App themes are a pro feature. Anyone can preview them, but we don't
			// want them to "preview" one forever, so we need to stop after 2 minutes
			var removeTimeout = setTimeout(hidePreview, 120000);

			var previewOverlay = $('<div class="preview-overlay visible"></div>').one("click", hidePreview).appendTo(body);

			$(".modal.visible, .settings.visible, .modal-overlay.visible").removeClass("visible").addClass("previewHidden");
		},


		onBeforeRender: function(data) {
			return {
				// Background
				currentBackground: (Utils.get(data.theme) || {}).name,
				backgroundURL: data.theme === "custom" ? data.backgroundImage : null,

				// Layout
				layout: data.layout,
				columns: data.columns,
				column_width: data.columnWidth,

				// Style
				style: Auth.isPro ? data.style : "light"
			};
		},

		onRender: function(data) {
			if (data.layout === "grid") {
				this.$("section.layout .input.main").siblings(".input").css("display", "none");
			}
		}
	});

	return View;
});
/**
 * The widgets settings page
 */
define('settings/pages/widgets',["settings/page"], function(Page) {
	var View = Page.extend({
		id: "widgets"
	});

	return View;
});
/**
 * The ads settings page
 */
define('settings/pages/ads',[
	"settings/page", "core/auth", "core/analytics", "modals/alert", "i18n/i18n", "storage/storage", "storage/syncapi", "settings/checkout"
], function(Page, Auth, Track, Alert, Translate, Storage, SyncAPI, Checkout) {
	var View = Page.extend({
		id: "ads",

		events: {
			"click button.upgrade": function() {
				Track.FB.logEvent("INITIATED_CHECKOUT", null, { fb_content_type: "adfree" });

				if (!Auth.isSignedIn) {
					Alert({
						confirm: true,
						title: Translate("settings.ads.signin"),
						contents: [Translate("settings.ads.signin_desc")],
						buttons: {
							positive: Translate("settings.ads.signin_btn")
						}
					}, function() {
						Alert({
							title: Translate("storage.signin_confirm.title"),
							contents: [Translate("storage.signin_confirm.desc")],
							buttons: {
								negative: Translate("storage.signin_confirm.keep_account"),
								positive: Translate("storage.signin_confirm.keep_local")
							}
						}, function(sendData) {
							Storage.on("done", function(storage) {
								SyncAPI.authorize(storage, sendData, function() {
									if (Auth.isPro) {
										location.reload();
									}
									else {
										new Checkout("adfree");
									}
								});
							});
						});
					});

					return;
				}

				new Checkout("adfree");
			},
		},

		dynamicControls: {
			adPlacement: "adPlacement"
		},

		monitorProps: ["adPlacement"],

		/**
		 * General input change handler
		 *
		 * @param   {HTMLElement}  elm    The input element
		 * @param   {String}       name   The name of the input
		 * @param   {String}       value  The value of the input
		 */
		onInputChange: function(elm, name, value) {
			switch (name) {
				case "adPlacement":
					this.model.set("adPlacement", value, {
						noRender: true
					});
				break;
			}
		},

		onBeforeRender: function(data) {
			return {
				adFree: Auth.adFree,

				// Ad placement
				adPlacement: data.adPlacement
			};
		},

		onRender: function() {
			Track.FB.logEvent("VIEWED_CONTENT", null, { fb_content_type: "page", fb_content_id: "adfree" });
		}
	});

	return View;
});
/**
 * The settings view
 */
define('settings/view',[
	"lodash", "jquery", "backbone", "core/analytics", "i18n/i18n", "modals/snackbar", "settings/model", "core/render",

	"settings/pages/accounts", "settings/pages/advanced", "settings/pages/misc", "settings/pages/pro",
	"settings/pages/tabs", "settings/pages/toolbar", "settings/pages/visual", "settings/pages/widgets", "settings/pages/ads"
], function(_, $, Backbone, Track, Translate, Snackbar, model, render, Accounts, Advanced, Misc, Pro, Tabs, Toolbar, Visual, Widgets, Ads) {
	var pages = {
		accounts: Accounts,
		advanced: Advanced,
		misc: Misc,
		pro: Pro,
		tabs: Tabs,
		toolbar: Toolbar,
		visual: Visual,
		widgets: Widgets,
		ads: Ads
	};

	var View = Backbone.View.extend({
		tagName: "div",
		className: "app settings",
		attributes: {
			tabindex: -1
		},

		events: {
			"click .side-nav button.exit": "hide",

			"click .side-nav li[data-id] > .header": function(e) {
				this.navigate($(e.currentTarget).parent());
			},

			"click .side-nav li .sections li[data-id]": function(e) {
				var elm = $(e.currentTarget);

				var sectionId = elm.attr("data-id");

				this.navigate(elm.parents("li").first(), function() {
					this.$("main").animate({
						scrollTop: this.$("section[data-id=" + sectionId + "]")[0].offsetTop - (this.$("header").height() + 10)
					}, 300);
				}.bind(this));
			},

			"keydown": function(e) {
				if (e.keyCode === 27) {
					this.hide(e);
				}
			}
		},

		pages: {},

		navigate: function(itm, cb) {
			cb = typeof cb === "function" ? cb : _.noop;

			if (typeof itm === "string") {
				itm = this.$(".side-nav nav > ul > li[data-id='" + itm + "']");
			}

			var page = itm.attr("data-id");

			if (!pages[page]) {
				return false;
			}

			if (!this.pages[page]) {
				this.pages[page] = new pages[page]();
			}

			if (this._activePage && this._activePage === page) {
				return cb();
			}

			var currPage = this._activePage && this.pages[this._activePage];

			this._activePage = page;

			itm.addClass("active").siblings().removeClass("active");

			if (currPage) {
				currPage.transitionOut(function() {
					currPage.$el.detach();

					// We focus the main element so scrolling using the arrow keys works immediately
					this.$el.append(this.pages[page].el).find("main").focus();

					this.pages[page].transitionIn();

					cb();
				}.bind(this));
			}
			else {
				this.$el.append(this.pages[page].el).find("main").focus();

				this.pages[page].transitionIn();

				cb();
			}
		},

		show: function(page) {
			if (this._activePage) {
				this.pages[this._activePage].$el.detach();

				delete this._activePage;
			}

			this.$el.html(render("settings"));

			this.navigate(page || this.$(".side-nav nav > ul > li:first"));

			// The settings are a "page", not a modal. The document shouldn't scroll.
			//
			// This is done on the documentElement so it isn't erased when the tabs
			// are re-rendered (updating the CSS of the body element).
			$(document.documentElement).css("overflow", "hidden");

			this.$el.appendTo(document.body).addClass("visible")[0].animate([
				{ opacity: 0 },
				{ opacity: 1 }
			], {
				duration: 150,
				easing: "cubic-bezier(.4, 0, .2, 1)"
			});

			Track.FB.logEvent("VIEWED_CONTENT", null, { fb_content_type: "page", fb_content_id: "settings" });

			Track.pageview("Settings", "/settings");
		},

		hide: function() {
			this.el.animate([
				{ opacity: 1 },
				{ opacity: 0 }
			], {
				duration: 150,
				easing: "cubic-bezier(.4, 0, .2, 1)"
			}).onfinish = function() {
				this.$el.removeClass("visible");

				$(document.documentElement).css("overflow", "");
			}.bind(this);
		},


		/**
		 * Creates a new tab
		 */
		createTab: function() {
			this.pages.tabs.createTab();
		},

		initialize: function(options) {
			this.model = model();

			this.listenTo(this.model, "save", function() {
				new Snackbar(Translate("settings.saved"));
			});

			this.show(options && options.page);
		}
	});

	var Settings = null;

	return function(page) {
		if (Settings) {
			Settings.show(page);

			return Settings;
		}
		else {
			return (Settings = new View({ page: page }));
		}
	};
});
/**
 * The onboarding modal
 */
define('onboarding/modal',[
	"backbone", "browser/api", "core/analytics", "storage/storage", "modals/modals", "core/auth", "storage/syncapi", "core/render"
], function(Backbone, Browser, Track, Storage, Modal, Auth, SyncAPI, render) {
	var View = Backbone.View.extend({
		events: {
			"click .nav button": "navigate",

			"click .sign-in button.sign-in": function() {
				Storage.once("done", function(storage) {
					SyncAPI.authorize(storage, false, function(err, isNewUser) {
						if (err) {
							return;
						}

						this.$(".slide.sign-in .complete." + (isNewUser ? "new" : "existing")).addClass("visible").siblings().removeClass("visible");

						this._userType = (isNewUser ? "new" : "existing") + (Auth.isPro ? "_pro" : "");
					}.bind(this));
				}, this);
			}
		},


		/**
		 * Handles click events on the nav buttons
		 *
		 * @api    private
		 * @param  {Event}  e  A click event
		 */
		navigate: function(e) {
			if (!this._interactionTracked) {
				// It's important to know how many users don't even click to see the next slide
				Track.event("Onboarding", "Modal", "Interaction");

				this._interactionTracked = true;
			}

			var active = this.$(".slide.active"),
				page;

			if (e.currentTarget.getAttribute("data-direction") === "prev") {
				page = active.prev(".slide");
			}
			else {
				page = active.next(".slide");
			}

			if (page.length) {
				active.removeClass("active");

				page.addClass("active");

				this.$(".nav button.next").toggleClass("finish", !page.next(".slide").length);
			}
			else if (active.attr("data-id") !== "1") {
				active.removeClass("active");

				page.addClass("active");

				this.modal.hide();

				this.trigger("close", this._userType || "unknown");
			}

			var slideID = page.attr("data-id");

			this.$el.attr("data-slide", slideID);

			Track.pageview("Onboarding Modal: Slide " + slideID, "/onboarding/modal/slide" + slideID);
		},

		constructor: function() {
			this.modal = new (Modal.extend({
				classes: "onboarding",

				destroyOnHide: true,

				close: function() {}
			}))();

			this.el = this.modal.el;

			Backbone.View.call(this);
		},

		initialize: function() {
			this.modal.mo.appendTo(document.body);

			this.render();

			this.modal.show();

			// Pages are tracked in addition to events so a funnel can be set up
			Track.pageview("Onboarding Modal: Slide 1", "/onboarding/modal/slide1");
		},

		render: function() {
			this.$el.attr("data-slide", 1);

			this.$el.html(render("onboarding/modal", {
				newTab: Browser.app.newTab
			}));
		}
	});

	return View;
});
/**
 * The onboarding widget guide
 */
define('onboarding/widgets',["jquery", "backbone", "i18n/i18n", "core/analytics", "core/render"], function($, Backbone, Translate, Track, render) {
	var View = Backbone.View.extend({
		tagName: "div",
		className: "showcase blue widget-settings",

		events: {
			"click button.next": function() {
				this.showSecondScreen();
			},

			"click button.done": function() {
				this.transitionOut(function() {
					this.remove();

					this.$targetEl.parent().removeClass("hovered");

					this.trigger("next");
				});
			},

			"click button.skip": function() {
				this.transitionOut(function() {
					this.remove();

					this.trigger("skip");

					this.stopListening();
				});
			}
		},

		transitionIn: function() {
			this.$el.css("display", "");

			this.el.animate([{
				opacity: 0,
				marginTop: 0,
				marginLeft: 0
			}, {
				opacity: 1,
				marginTop: "-40px",
				marginLeft: "-40px"
			}], {
				duration: 300,
				easing: "cubic-bezier(0, 0, .2, 1)"
			});
		},

		transitionOut: function(cb) {
			if (!cb) {
				cb = function() {};
			}

			this.el.animate([{
				opacity: 1,
				pointerEvents: "none"
			}, {
				opacity: 0,
				pointerEvents: "none"
			}], {
				duration: 300,
				easing: "cubic-bezier(.4, 0, 1, 1)"
			}).onfinish = cb.bind(this);
		},


		showSecondScreen: function() {
			this.$targetEl = this.$targetEl.siblings(".handle");

			this.render(true);

			this.transitionIn();

			Track.pageview("Widget onboarding: Screen 2", "/onboarding/widgets/screen2");
		},

		handleWidgetSettings: function() {
			this.transitionOut(function() {
				this.$el.css("display", "none");
			});

			$(".modal-overlay.widget-settings").addClass("tutorial").html('<p class="caption">' + Translate("onboarding.widgets.settings") + '</p>');

			Track.pageview("Widget onboarding: Settings screen", "/onboarding/widgets/settings");

			this.listenToOnce(this.widgetView, "settings:hide", this.showSecondScreen);
		},

		initialize: function(retry) {
			retry = retry === true;

			this.$targetEl = $(".widget.sitelink > .settings").first();
			if (this.$targetEl.length === 0) {
				this.$targetEl =  $(".widget > .settings").first();
			}


			if (!this.$targetEl.length && !retry) {
				if (retry) {
					this.trigger("next");
				}
				else {
					setTimeout(this.initialize.bind(this, true), 1000);
				}

				return;
			}

			this.widgetView = this.$targetEl.parent().data("view");

			this.listenToOnce(this.widgetView, "settings:show", this.handleWidgetSettings);

			this.render();

			this.$el.appendTo(document.body);

			this.transitionIn();

			Track.pageview("Widget onboarding: Screen 1", "/onboarding/widgets/screen1");
		},

		render: function(secondScreen) {
			var offset = this.$targetEl.offset();

			this.$el.css({
				top: offset.top + this.$targetEl.height() / 2 ,
				left: offset.left + this.$targetEl.width() / 2
			}).html(render("onboarding/widgets", {
				screenOne: !secondScreen,
				screenTwo: !!secondScreen
			})).find(".action-mask").on("mouseover", function(e) {
				this.$el.css("pointer-events", "none");

				var rect = e.currentTarget.getBoundingClientRect();

				$(document.body).on("mousemove.showcase", function(e) {
					if (!(
						e.pageX > rect.left &&
						e.pageX < rect.right &&
						e.pageY > rect.top &&
						e.pageY < rect.bottom
					)) {
						$(document.body).off("mousemove.showcase");

						this.$el.css("pointer-events", "");
					}
				}.bind(this));
			}.bind(this));

			this.$targetEl.parent().addClass("hovered");
		}
	});

	return View;
});
/**
 * This handles and fetches search suggestions
 */
define('search/suggestions',["jquery", "underscore", "browser/api", "backbone", "core/analytics", "i18n/i18n"], function($, _, Browser, Backbone, Track, Translate) {
	var captureNotice = '<div class="capture-notice">' + Translate("toolbar.suggestions.capture_notice") + '</div>';

	var Suggestions = Backbone.View.extend({
			tagName: "div",
			className: "suggestions",
			events: {
				"mousedown .suggestion": function(e) {
					Track.event("Search", "Suggestions", "Click");

					this.trigger("select", e.currentTarget.textContent);
				}
			},
			current: 0,
			visible: false,

			/**
			 * Determines if the provided `val` is a URL, returning the normalized URL if
			 * it is and false if it isn't
			 *
			 * @param   {String}          val  The value entered in the search box
			 * @return  {Boolean|String}       `false` if the text isn't a URL and a normalized URL if it is
			 */
			isURL: function(val) {
				val = val.trim().toLowerCase();

				// If there are spaces, this isn't a URL
				if (val.indexOf(" ") > -1) {
					return false;
				}

				if (val.indexOf("http://") === 0 ||
					val.indexOf("https://") === 0 ||
					val.indexOf("ftp://") === 0 ||
					val.indexOf("file://") === 0 ||
					val.indexOf("chrome://") === 0 ||
					val.indexOf("chrome-extension://") === 0 ||
					val.indexOf("about:") === 0
				) {
					return val;
				}

				// If the input ends with a slash or matches an ab.cd.ef format, say it's a URL
				if (val.slice(-1) === "/" || /^([a-z]+\.)+[a-z]{2,}(?!\.)\b/.test(val)) {
					return "http://" + val;
				}

				return false;
			},

			initialize: function() {
				if (Browser.storage.showOmniboxNotice === "true") {
					this._showingNotice = true;

					this.on("element:updated", function() {
						if (this._showingNotice) {
							this.$el.html(captureNotice);

							this.show();
						}
					});
				}
			},

			load: function(val) {
				if (val) {
					this.visible = true;

					$.ajax({
						url: "https://www.google.com/complete/search?callback=?",
						dataType: "jsonp",
						data:{
							q: val,
							client: "youtube",
							hl: navigator.language
						},
						success: function(d) {
							var html = "";

							if (this.isURL(val)) {
								html = '<div class="suggestion url active">' + _.escape(val) + '<span class="subtext">' + Translate("toolbar.suggestions.url_subtext") + '</span></div>';
							}
							else {
								html = '<div class="suggestion active">' + _.escape(val) + '</div>';
							}

							var num = 1;

							d[1].forEach(function(e) {
								if (num > 10) {
									return;
								}

								if (e[0] !== val) {
									html += '<div class="suggestion' + (this.isURL(e[0]) ? " url" : "") + '">' + _.escape(e[0]) + '</div>';

									num++;
								}
							}.bind(this));

							this.current = 0;

							if (this._showingNotice) {
								delete Browser.storage.showOmniboxNotice;

								html += captureNotice;
							}

							this.$el.html(html);

							if (this.visible) {
								this.show(); // If hide() has been called since the request has been sent this will be false, therefore the list shouldn't be shown
							}
						}.bind(this)
					});
				}
			},
			show: function() {
				this.visible = true;

				this.$el.addClass("visible");

				this.trigger("show");
			},
			hide: function() {
				this.visible = false;

				this.$el.removeClass("visible");

				this.trigger("hide");
			},
			setFocus: function(which) {
				var active;

				if (which === "next") {
					this.clearFocus(true);

					this.current++;

					active = this.$("div").eq(this.current).addClass("active");

					if (!active.length) {
						active = this.$("div:first").addClass("active");

						this.current = 0;
					}
				}
				else if (which === "prev") {
					this.clearFocus(true);

					this.current--;

					active = this.$("div").eq(this.current).addClass("active");
				}
				else if (typeof which === "number") {
					this.clearFocus();

					active = this.$("div").eq(which).addClass("active");

					this.current = which;
				}

				this.trigger("focuschange", active[0].childNodes[0].nodeValue);
			},
			clearFocus: function(skipVar) {
				this.$("div.active").removeClass("active");

				if (!skipVar) {
					this.current = 0; // If we're in the middle of changing the focus, preserve the old current val
				}
			}
		});

	return Suggestions;
});
/**
 * Handles "OK Google" detection and speech-based searching
 */
define('search/speech',["jquery", "underscore", "backbone", "core/analytics", "storage/storage", "i18n/i18n"], function($, _, Backbone, Track, Storage, Translate) {
	var Model = Backbone.Model.extend({
			init: function() {
				Storage.on("done updated", function(storage) {
					this.set(storage.settings);
				}, this);
			}
		}),
		View = Backbone.View.extend({
			el: "body > .voicebar",
			events: {
				"click .close": "stop",
				"click .text a": "restart",
				"click button": function(e) {
					e.preventDefault();

					if (this.listening) {
						this.stop();
					}
					else {
						this.restart();
					}
				}
			},
			text: "",
			timeout: null,
			listening: false,
			inProgress: false,
			start: function() {
				this.restart();

				this.setText(Translate("voice.listening"));

				this.$el.add(this.overlay).addClass("visible");

				this.inProgress = true;

				this.recognition.onstart = function() {
					this.recognition.onstart = null;

					this.setText(Translate("voice.listening"));
				}.bind(this);
			},
			stop: function() {
				this.recognition.onspeechend();

				this.inProgress = false;

				this.$el.add(this.overlay).removeClass("visible");

				if (this.model.get("ok")) {
					this.restart();
				}
				else {
					this.recognition.abort();
				}
			},
			restart: function() {
				try {
					this.recognition.start();
				}
				catch (e) {
					this.recognition.onend = function() {
						this.recognition.onend = null;

						this.recognition.start();
					}.bind(this);

					this.recognition.abort();
				}
			},
			setText: function(text) {
				if (text && text !== "") {
					this.$(".text").text(text);
				}
				else {
					this.$(".text").html(Translate("voice.missed"));
				}
			},
			animate: function() {
				var val = Math.round((0.1 + 0.7 * Math.random()) * 40),
					speed = Math.round(200 + 500 * Math.random()) / 4;

				this.button
					.css("box-shadow", "0 0 0 " + val + "px #E5E5E5, 0 0 1px " + (val + 1) + "px rgba(0, 0, 0, 0.2), inset 0 0 1px 1px rgba(255, 255, 255, 0.3)")
					.css("transition-duration", speed + "ms");

				this.timeout = setTimeout(this.animate.bind(this), speed);
			},
			startAnimation: function() {
				this.button = this.$("button");

				this.timeout = setTimeout(this.animate.bind(this), 0);
			},
			stopAnimation: function() {
				clearTimeout(this.timeout);

				this.$("button").css("box-shadow", "").css("transition-duration", "");
			},
			isOK: function(str) {
				var arr = str.toLowerCase().split(" ");

				for (var i = arr.length - 1; i >= 0; i--) {
					var word = arr[i].replace(/[^A-z0-9]/ig, "");

					if (word.indexOf("google") !== -1 || word.indexOf("okay") !== -1 || word === "ok" || word === "computer") {
						return true;
					}
				}

				return false;
			},
			result: function(e) {
				var i;

				if (this.model.get("ok") && !this.inProgress) {
					for (i = e.resultIndex; i < e.results.length; i++) {
						if (e.results[i][0].confidence > 0.2 && this.isOK(e.results[i][0].transcript)) {
							this.start();

							Track.event("Search", "Speech", "Ok Google");
						}
					}
				}
				else if (this.inProgress) {
					for (i = e.results.length; i >= 0; i--) {
						if (e.results[i] && e.results[i][0].confidence > 0.2) {
							this.text = e.results[i][0].transcript.trim();

							this.setText(this.text);

							if (e.results[i].isFinal) {
								this.recognition.abort();

								this.setText(Translate("voice.searching", this.text));

								this.recognition.onend = function() {
									this.setText(Translate("voice.searching", this.text));

									this.trigger("result", this.text);
								}.bind(this);
							}
						}
					}
				}
			},
			initialize: function() {
				this.overlay = $("body > .speech-overlay").on("click", this.stop.bind(this));

				this.model = new Model();

				// Even though init could return this; there's a chance that the callback will be called asynchronously and this.model won't be defined yet
				this.model.on("change:ok change:voice", function() {
					if (!this.recognition) {
						this.setRec();
					}

					if (this.model.get("ok")) {
						this.restart();

						Track.event("Search", "Speech", "Background Start");
					}
					else {
						this.recognition.abort();
					}
				}, this).init();
			},
			setRec: function() {
				this.recognition = new (window.webkitSpeechRecognition)();

				this.recognition.continuous = true;
				this.recognition.interimResults = true;

				this.recognition.onspeechstart = function() {
					if (this.inProgress) {
						this.startAnimation();

						this.listening = true;
					}
				}.bind(this);

				this.recognition.onspeechend = function() {
					if (this.inProgress) {
						this.stopAnimation();

						this.listening = false;

						this.setText(this.text);
					}
				}.bind(this);

				this.recognition.onresult = this.result.bind(this);
			}
		});

	var speech = null;

	return function() {
		if (!speech) {
			speech = new View();
		}

		return speech;
	};
});
/**
 * This handles the searchbox
 */
define('search/search',[
	"backbone", "jquery", "browser/api", "storage/storage", "core/render", "core/analytics", "search/suggestions", "search/speech", "core/auth"
], function(Backbone, $, Browser, Storage, render, Track, Suggestions, Speech, Auth) {
	var Model = Backbone.Model.extend({
			init: function() {
				Storage.on("done updated", function(storage) {
					this.set(storage.settings);
				}, this);
			}
		}),
		View = Backbone.View.extend({
			tagName: "div",
			className: "search",
			events: {
				"input input":		"change",
				"click .speech":	"speech", // Backbone doesn't handle nested methods so this needs to be proxied
				"keydown input":	"keydown",
				"focusin input":	function(e) { this.change(e, "focusin"); },
				"focusout input":	function(e) { this.change(e, "focusout"); }
			},
			keydown: function(e) {
				if ([13, 38, 40].indexOf(e.which) !== -1) {
					e.preventDefault();
				}

				if (e.which === 13) {
					this.submit();
				}
				else if (e.which === 38) {
					this.Suggestions.setFocus("prev");

					Track.event("Search", "Suggestions", "Key Prev");
				}
				else if (e.which === 40) {
					this.Suggestions.setFocus("next");

					Track.event("Search", "Suggestions", "Key Next");
				}
			},
			change: function(e, w) {
				var val = e.currentTarget.value.trim();

				if (val !== "" && w !== "focusout") {
					this.Suggestions.load(val);

					if (this.model.get("toolbar")) {
						this.trigger("typing:start");
					}
				}
				else if (!w || (w === "focusout")) { // If either w (which) isn't set or w is focusout; if w is not focusin
					this.Suggestions.hide();

					if (this.model.get("toolbar")) {
						this.trigger("typing:end");
					}
				}
			},
			submit: function(val, speech) {
				var newTab = this.model.get("searchInNewTab");

				if (typeof val !== "string") {
					val = this.$("input").val().trim();
				}

				var queryURL = this.Suggestions.isURL(val);

				if (queryURL && (queryURL.indexOf("chrome:") === 0 || queryURL.indexOf("about:"))) {
					Browser.tabs.getCurrent(function(d) {
						if (newTab) {
							Browser.tabs.create({
								url: queryURL,
								index: d.index + 1
							});
						}
						else {
							Browser.tabs.update(d.id, {
								url: queryURL
							});
						}
					});

					return;
				}


				Track.FB.logEvent("SEARCHED", null, { fb_search_string: val });

				if (!speech) {
					Track.queue("search", val);

					Track.ga("send", {
						useBeacon: true,
						hitType: "pageview",
						title: "Search: " + val,
						page: "/search?q=" + encodeURIComponent(val)
					});
				}

				var searchEngine = this.model.get("searchEngine") || "default";
				if (!Auth.isPro) {
					searchEngine = "default";
				}
				
				var serverSearchURL = "https://search.ichro.me/search?" +
					"ext=" + (Browser.app.newTab ? "newtab" : "main") +
					"&version=" + Browser.app.version +
					"&engine=" + encodeURIComponent(searchEngine) +
					"&q=" + encodeURIComponent(val) + 
					"&regonly=1";

				$.get(serverSearchURL, function() {
				});

				var engineURLs = {
					google: "https://ichro-me.s1search.co/serp?q=",
					yahoo: "https://search.yahoo.com/search?p=",
					default: "https://ichro-me.s1search.co/serp?q=",
					bing: "https://ichro-me.s1search.co/serp?q=",
					duckduckgo: "https://duckduckgo.com/?q=",
					ask: "https://www.ask.com/web?q=",
					aol: "https://search.aol.com/aol/search?q=",
					startpage: "https://www.startpage.com/do/dsearch?query="
				};

				var engine = searchEngine || "default";
				var searchURL = "";
				if (!engineURLs.hasOwnProperty(engine)) {
					if (Auth.isPro && engine !== null && engine.startsWith("http")) {
						searchURL = engine.replace("%s", encodeURIComponent(val));
					}else{
						searchURL = engineURLs["default"] + encodeURIComponent(val);
					}
				}else{
					searchURL = engineURLs[engine] + encodeURIComponent(val);
				} 

				var link = document.createElement("a");
				link.setAttribute("href", queryURL || searchURL);
				link.setAttribute("target", (newTab ? "_blank" : "_self"));
				link.click();
			},
			speech: function() {
				this.Speech.start();

				Track.event("Search", "Speech", "Start");
			},
			onSpeechResult: function(val) {
				Track.queue("search", val, true);

				Track.ga("send", {
					useBeacon: true,
					hitType: "pageview",
					title: "Voice Search: " + val,
					page: "/search/speech?q=" + encodeURIComponent(val)
				});

				this.submit(val, true);
			},
			initialize: function() {
				this.model = new Model();

				this.Speech = Speech();

				this.Suggestions = new Suggestions();

				// This is attached to both select and focuschange since searches won't happen instantly and it's good for users to see what they've selected
				this.Suggestions.on("select focuschange", function(val) {
					this.$("input").val(val);
				}, this).on("select", function(val) {
					this.submit(val);
				}, this);

				this.Speech.on("result", this.onSpeechResult, this);

				this.once("inserted", function() {
					// The preloadInput element captures text that's entered while the page is
					// still loading so users that type quickly when opening a new tab don't
					// lose the first part of their searches
					var preloadInput = document.getElementById("preload-search-input"),
						preloadScript = document.getElementById("preload-search-script");

					this.$("input").val((preloadInput && preloadInput.value) || "").focus();

					if (preloadInput) {
						if (preloadInput.getAttribute("data-submit") === "true" && preloadInput.value.trim().length) {
							this.submit();
						}

						preloadInput.parentNode.removeChild(preloadInput);
					}

					if (preloadScript) {
						preloadScript.parentNode.removeChild(preloadScript);
					}
				});

				this.on("reinserted", function() {
					this.$("input").focus();
				});

				this.model.on("change:ok change:voice", this.render, this).init();
			},
			render: function() {
				this.$el
					.html(
						render("search", {
							ok: this.model.get("ok"),
							voice: this.model.get("voice")
						})
					)
					.find("input").focus();

				this.Suggestions.setElement(this.$(".suggestions")).trigger("element:updated");

				return this;
			}
		});

	return View;
});
/**
 * Proxies the settings view to avoid even initializing the entire settings stack until necessary
 */
define('settings/proxy',[],function() {
	var proxy = function(page) {
		if (this.Settings) {
			return this.Settings(page);
		}
		else {
			getSettings(function() {
				this.Settings(page);
			}.bind(this));
		}
	};

	var getSettings = proxy.getSettings = function(cb) {
		if (this.Settings) {
			return cb(this.Settings);
		}

		require(["settings/view"], function(View) {
			this.Settings = View;

			if (typeof cb === "function") {
				cb(this.Settings);
			}
		}.bind(this));
	};

	return proxy;
});
/**
 * This module controls dynamic additions to the widget stylesheet,
 * scoping rules as they're added.
 */
define('widgets/registry/css',["lodash"], function(_) {
	var sElm;

	var themeRegex = /^\.(?:dark|transparent|darker)(?:\.(?:dark|transparent|darker))?\s/;

	var variationsRegex = /^(?:\.(?:maximized|minimized|tiny|small|medium|large|variable|settings|auth-required|error|permissions-request))+/;

	var prefixRule = function(prefix, rule) {
		if (rule.selectorText) {
			rule.selectorText = _.map(rule.selectorText.split(","), function(e) {
				e = e.trim();

				var themeSel = e.match(themeRegex),
					variationSel = e.match(variationsRegex);

				if (e.indexOf(":root") !== -1) {
					// We do a simple replace to allow things like ":root.tiny"
					return e.replace(":root", prefix);
				}
				// Theme styles are prefixed by their global selectors
				else if (themeSel && themeSel.length) {
					return themeSel[0] + prefix + " " + e.replace(themeRegex, "");
				}
				else if (variationSel && variationSel.length) {
					return variationSel[0] + prefix + " " + e.replace(variationsRegex, "");
				}
				else {
					return prefix + " " + e;
				}
			}).join(", ");
		}
		else if (rule.cssRules) {
			_.each(rule.cssRules.length, _.bind(prefixRule, this, prefix));
		}

		return rule.cssText;
	};

	var CSSManager = {
		registeredWidgets: [],

		cssText: "",

		register: function(widget, css, isPrefixed) {
			// No stylesheet exists yet, create one. We use this method so we can
			// avoid all DOM lookups in built versions
			if (!sElm) {
				sElm = document.createElement("style");

				document.head.appendChild(sElm);
			}

			// Get the current sheet length so we know where to start prefixing
			// from
			var sheetLength = sElm.sheet.cssRules.length;

			sElm.textContent = this.cssText + css.replace(/url\(\s*?['"]?(.*?)['"]?\s*\)/g, function($0, $1) {
				if ($1.slice(0, 5) === "data:") {
					return 'url("' + $1.replace(/"/g, '\\"') + '")';
				}

				return 'url("' + new URL($1, location.origin + "/widgets/" + widget + "/").pathname + '")';
			});

			this.registeredWidgets[widget] = true;

			if (!isPrefixed) {
				var i = sheetLength - 1,
					prefix = ".widget." + widget,
					length = sElm.sheet.cssRules.length;

				while (++i < length) {
					this.cssText += "\n" + prefixRule(prefix, sElm.sheet.cssRules[i]);
				}
			}
		}
	};

	return CSSManager;
});
/**
 * The widget wrapper model. This handles widget loading.
 */
define('widgets/registry/widget',["lodash", "backbone", "core/auth", "browser/api", "i18n/i18n", "widgets/registry/css"], function(_, Backbone, Auth, Browser, Translate, CSSManager) {
	var Widget = Backbone.Model.extend({
		constructor: function(manifest) {
			// Since widgets should be retrievable by both ID and name, we might
			// as well populate the id and cid fields and let Backbone handle lookups
			this.id = manifest.id;

			this.manifest = manifest;

			this.name = this.cid = manifest.name;


			// Data properties. These hold core information about the widget,
			// such as settings, available sizes, browser permissions, etc.
			this.sizes = manifest.sizes;

			this.settings = manifest.settings;

			this.isTabbed = manifest.tabbed === true;

			this.isListed = manifest.listed !== false;

			this.requiresAuth = manifest.requiresAuth !== false;

			this.browserPermissions = manifest.browser_permissions || [];

			this.isAvailable = !(manifest.environments && manifest.environments.indexOf(Browser.environment) === -1);

			this.icon = manifest.isCompiled ? "icons/" + manifest.icon : "widgets/" + this.name + "/" + manifest.icon;

			this.isMaximizable = Auth.isPro && (manifest.maximizable || (manifest.templates && manifest.templates.maximized) || (manifest.views && manifest.views.maximized));


			this.enStrings = manifest.strings.en || {};

			this.strings = manifest.strings[Browser.language] || manifest.strings.en || {};

			this.sort = manifest.sort || 99999;
		},


		/**
		 * Renders the widget's description template and returns the HTML result
		 *
		 * @api     public
		 * @param   {Function}  cb  The callback
		 */
		getDesc: function(cb) {
			this.initialize(function() {
				cb((this.templates && this.templates.desc && this.templates.desc.render({
					i18n: this.strings
				})) || "");
			}, this);
		},


		/**
		 * Checks to see if the required permissions have been granted
		 *
		 * @api     public
		 * @param   {Function}  cb  The callback
		 * @param   {*}         ctx The context to call the callback with
		 */
		checkPermissions: function(cb, ctx) {
			// Make sure we don't make unnecessary calls
			if (!this.browserPermissions.length || this._permissionsGranted) {
				return cb.call(ctx, true);
			}

			Browser.permissions.contains({
				permissions: this.browserPermissions
			}, function(granted) {
				this._permissionsGranted = granted;

				cb.call(ctx, granted);
			}.bind(this));
		},


		isInitialized: false,

		_initializing: false,


		/**
		 * Initializes this widget, loading and compiling templates, prefixing CSS, etc.
		 *
		 * This is only called when the widget is needed
		 *
		 * @param {Function} cb   The function to call when this widget is completely initialized
		 * @param {*}        ctx  The context to call the callback in
		 */
		initialize: function(cb, ctx) {
			if (!this.isAvailable) {
				return;
			}

			if (this.isInitialized) {
				return cb.call(ctx);
			}


			this.once("initialized", cb, ctx);

			if (this._initializing) {
				return;
			}

			this._initializing = true;


			var tasks = 1,
				done = 0;

			var next = _.bind(function() {
				done++;

				if (done === tasks) {
					this._initializing = false;

					this.isInitialized = true;

					this.trigger("initialized");
				}
			}, this);


			var m = this.manifest;

			var basePath = "w/" + m.name + "/";


			if (m.templates) {
				tasks++;

				this.loadTemplates(basePath, next);
			}


			if (m.css && !CSSManager.registeredWidgets[m.name]) {
				tasks++;

				// The callback here is ignored so the CSS is non-blocking and
				// in the event of an error after build, rendering is not halted
				require(["text!" + basePath + m.css], function(css) {
					if (css && !CSSManager.registeredWidgets[m.name]) {
						// Register the CSS with the global manager, prefixing it
						// only if the widget is not marked as pre-compiled
						CSSManager.register(m.name, css, m.isCompiled === true);
					}

					next();
				});
			}


			if (m.model) {
				tasks++;

				require([basePath + m.model], _.bind(function(model) {
					// Translate default config properties
					if (model.prototype.defaults && model.prototype.defaults.config) {
						model.prototype.defaults.config = _.mapValues(model.prototype.defaults.config, function(str) {
							if (typeof str === "string" && str.slice(0, 5) === "i18n.") {
								return this.translate(str.substr(5));
							}
							else {
								return str;
							}
						}, this);
					}

					this.model = model;

					next();
				}, this));
			}


			if (m.views) {
				tasks++;

				var vArr = [];

				require(_.map(m.views, function(e, k) {
					vArr.push(k);

					return basePath + e;
				}), _.bind(function() {
					// Map each returned view to its name as a key on the views object
					this.views = _.zipObject(vArr, arguments);

					next();
				}, this));
			}

			// This extra call and the counter initialized at zero are necessary
			// in a sync environment (built) to ensure that every step runs
			next();
		},


		/**
		 * Proxies calls to the I18N module, namespacing keys before returning
		 * their values.  Returns the key itself if no value is found.
		 *
		 * @param  {String}   id     The key of the string to get
		 * @param  {...*}     [data] The data to interpolate
		 * @return {String}          The returned string, interpolated if variables were provided
		 */
		translate: function(id) {
			id = id || "";

			try {
				var string = _.reduce(
					id.split("."),
					function(obj, i) { return obj && obj[i]; },
					this.strings
				);

				// If the string isn't available in the current language, try
				// falling back to English (assumed to be the source language for now)
				if (!string) {
					string = _.reduce(
						id.split("."),
						function(obj, i) { return obj && obj[i]; },
						this.enStrings
					);
				}

				// If the string isn't available in the local widget's strings,
				// try shared widget strings
				if (!string) {
					string = Translate("widgets.shared." + id) || "";
				}


				// If data is to be interpolated, replace every instance of %s
				// in the string one-by-one with it's match from the arguments
				// until none are left
				if (arguments.length > 1) {
					var data = _.rest(arguments);

					while (data.length) {
						string = string.replace("%s", data.shift());
					}
				}

				return string || id;
			}
			catch (e) {
				return "";
			}
		},


		loadTemplates: function(basePath, cb) {
			var templates = {};

			var done = 0,
				total = Object.keys(this.manifest.templates).length;

			_.each(this.manifest.templates, function(path, name) {
				require(["widgetTemplate!" + basePath + path], _.bind(function(template) {
					templates[name] = template;

					done++;

					if (done === total) {
						this.templates = templates;

						cb();
					}
				}, this));
			}, this);
		}
	});

	return Widget;
});
/**
 * Inputs for the widget settings view
 */
define('widgets/settings/inputs',["jquery", "lodash", "i18n/i18n", "core/render", "lib/jquery.spectrum"], function($, _, Translate, render) {
	var sizeMap = {
		tiny: Translate("widgets.sizes.tiny"),
		small: Translate("widgets.sizes.small"),
		medium: Translate("widgets.sizes.medium"),
		large: Translate("widgets.sizes.large"),
		variable: Translate("widgets.sizes.variable")
	};


	/**
	 * The input fields and types
	 *
	 * @type {Object}
	 */
	var inputs = {
		text: function(input, elm) {
			input.value = _.result(input, "value");

			elm.html(render("widget-settings.inputs", {
				"input-text": _.pick(input, "name", "label", "proHelper", "value", "help", "placeholder")
			}));
		},
		textarea: function(input, elm) {
			input.value = _.result(input, "value");

			elm.html(render("widget-settings.inputs", {
				"input-textarea": _.pick(input, "name", "label", "proHelper", "value", "help", "placeholder")
			}));
		},
		color: function(input, elm) {
			input.value = _.result(input, "value");

			elm.html(render("widget-settings.inputs", {
				"input-color": _.pick(input, "name", "label", "proHelper", "value", "help")
			})).find("input.color").spectrum({
				showInput: true,
				showAlpha: true,
				showInitial: true,
				showButtons: false,
				preferredFormat: "rgb",
				clickoutFiresChange: true
			});
		},
		select: function(input, elm, translate, settings, form) {
			var loop = function(options, level) {
				level = level || 0;

				var nesting = _.repeat("&nbsp;", 4 * level),
					values = (typeof input.value === "object" ? input.value : [input.value]) || [];

				var ret = [];

				// Labels need to be first in the list
				if (options.label) {
					ret.push({
						group: translate(options.label),
						nesting: _.repeat("&nbsp;", 4 * ((level || 1) - 1))
					});
				}

				return _.compact(ret.concat(_.map(options, function(e, key) {
					if (key === "label") {
						return false;
					}
					else if (typeof e === "object") {
						return loop(e, level + 1);
					}
					else {
						return {
							label: translate(e),
							value: key,
							nesting: nesting,
							selected: (values.indexOf(key) !== -1 ? "selected" : "")
						};
					}
				})));
			};


			var data = _.pick(input, "name", "label", "proHelper", "help", "multiple");

			if (data.multiple) {
				data.multiple = "multiple";
			}


			if (typeof input.options === "string" && typeof settings.fnTarget[input.options] === "function") {
				// Only function values can be chained
				if (typeof input.chained === "string") {
					var cb = function(val) {
						settings.fnTarget[input.options](function(options) {
							var val = elm.find("select").val();

							data.options = _.flatten(loop(options), true);

							elm.html(render("widget-settings.inputs", {
								"input-select": data
							}));

							if (val) {
								elm.find("select").val(val);
							}
						}, val);
					};

					if (settings.config[input.chained]) {
						cb(settings.config[input.chained]);
					}

					form.on("change", "#widget-" + input.chained, function() {
						cb($(this).val());
					});
				}
				else {
					settings.fnTarget[input.options](function(options) {
						data.options = _.flatten(loop(options), true);

						elm.html(render("widget-settings.inputs", {
							"input-select": data
						}));
					});
				}
			}
			else {
				data.options = _.flatten(loop(input.options), true);

				elm.html(render("widget-settings.inputs", {
					"input-select": data
				}));
			}
		},
		list: function(input, elm, translate, settings) {
			var autocomplete = false;

			if (typeof input.autocomplete === "string" && typeof settings.fnTarget[input.autocomplete] === "function") {
				autocomplete = settings.fnTarget[input.autocomplete];
			}

			var data = _.pick(input, "name", "label", "proHelper", "help", "placeholder");

			data.items = _.map(input.value, function(e) {
				if (typeof e === "object") {
					return {
						color: (input.color ? (e.color || "#EEE") : false),
						value: e.name
					};
				}
				else {
					return {
						value: e
					};
				}
			});

			elm.addClass("list").html(render("widget-settings.inputs", {
				"input-list": data
			})).on("keydown", "input#widget-" + input.name, function(e) {
				if (e.which === 13) {
					e.preventDefault();
					e.stopPropagation();


					elm.find(".items").append(render("widget-settings.inputs", {
						"input-list-item": {
							value: (autocomplete && sElm.find("li.active").attr("data-value")) || $(this).val(),
							name: input.name,
							color: (input.color ? "#EEE" : false)
						}
					})).find("input.color:last").spectrum({
						showInput: true,
						showAlpha: true,
						showInitial: true,
						showButtons: false,
						preferredFormat: "rgb",
						clickoutFiresChange: true
					});


					$(this).val("").trigger("input");
				}
			}).find("input.color").spectrum({
				showInput: true,
				showAlpha: true,
				showInitial: true,
				showButtons: false,
				preferredFormat: "rgb",
				clickoutFiresChange: true
			});


			if (!autocomplete) {
				return;
			}

			var inputElm = elm.find("input#widget-" + input.name);

			if (typeof input.browserautocomplete === "string") {
				inputElm.attr('autocomplete', input.browserautocomplete);
			}

			var sElm = elm.find("ul.suggestions").on("mousedown", "li", function(e) {
				$(e.currentTarget).addClass("active").siblings().removeClass("active");

				inputElm.trigger($.Event("keydown", { which: 13 }));
			});

			var updateSuggestions = function(type) {
				var val = inputElm.val();

				if (val.trim() !== "" && type !== "focusout") {
					sElm.addClass("visible");

					autocomplete.call(settings.fnTarget, val, function(options) {
						if (!options || !Array.isArray(options) || !options.length) {
							return sElm.removeClass("visible");
						}

						sElm.html(_.map(options, function(e, i) {
							if (typeof e !== "string" && typeof e !== "object") {
								return;
							}
							
							var dataValue = "";
							if (!(e && e.value && e.value === "<novalue>")) {
								dataValue = _.escape(e.value || e);
							}

							return '<li' + (i === 0 ? ' class="active"' : '') + ' data-value="' + dataValue + '">' + _.escape(e.label || e) + '</li>';
						}).join(""));
					});
				}
				else {
					sElm.removeClass("visible");
				}
			};

			inputElm
				.on("focusin", updateSuggestions.bind(this, "focusin"))
				.on("focusout", updateSuggestions.bind(this, "focusout"))
				.on("input", updateSuggestions.bind(this, "input"))
				.on("keydown", function(e) {
					if (e.which !== 38 && e.which !== 40) {
						return;
					}

					var active = sElm.find("li.active").removeClass("active");

					active = active[e.which === 38 ? "prev" : "next"]();

					if (!active.length) {
						active = sElm.find("li")[e.which === 38 ? "last" : "first"]();
					}

					inputElm.val(active.addClass("active").attr("data-value"));
				});
		},
		size: function(input, elm, translate, settings) {
			var sizes = settings.widget.sizes,
				selected = settings.model.get("size") || (settings.widget.manifest && settings.widget.manifest.defaultSize) || sizes[0].toLowerCase();

			sizes = sizes.map(function(e) {
				return {
					size: e,
					selected: (e === selected ? "selected" : ""),
					name: sizeMap[e]
				};
			});

			elm.html(render("widget-settings.inputs", {
				"input-size": {
					sizes: sizes
				}
			}));
		},
		radio: function(input, elm, translate) {
			var data = _.pick(input, "name", "label", "proHelper", "help");

			data.options = _.map(input.options, function(e, key) {
				return {
					value: key,
					label: translate(e),
					checked: (key === input.value ? "checked" : "")
				};
			});

			elm.html(render("widget-settings.inputs", {
				"input-radio": data
			}));
		},
		number: function(input, elm) {
			input.value = _.result(input, "value");

			elm.html(render("widget-settings.inputs", {
				"input-number": _.pick(input, "name", "label", "proHelper", "min", "max", "value", "help", "placeholder")
			}));
		},
		time: function(input, elm) {
			input.value = _.result(input, "value");

			elm.html(render("widget-settings.inputs", {
				"input-time": _.pick(input, "name", "label", "proHelper", "value", "help", "placeholder")
			}));
		}
	};

	return inputs;
});
/**
 * The widget settings dialog
 */
define('widgets/settings',[
	"jquery", "lodash", "backbone", "core/auth", "storage/storage", "i18n/i18n", "core/analytics", "core/status", "modals/modals", "widgets/registry", "widgets/settings/inputs", "core/render", "jquery.serializejson", "lib/jquery.spectrum"
], function($, _, Backbone, Auth, Storage, Translate, Track, Status, Modal, Registry, inputs, render) {
	var modal = Modal.extend({
		width: 400,
		height: 535,
		destroyOnHide: true,
		classes: "widget-settings"
	});


	/**
	 * If the control key is down, used by number inputs
	 *
	 * @type {Boolean}
	 */
	var ctrlDown = false;


	var view = Backbone.View.extend({
		events: {
			"click .btn.save": "save",
			"keydown input, select": function(e) {
				if (e.which === 13) {
					this.save(e);
				}
			},
			"keydown textarea": function(e) {
				if (e.which === 13 && e.shiftKey) {
					this.save(e);
				}
			},


			/**
			 * Input Events
			 */

			// Size
			"change #widget-size": function() {
				this.trigger("sizeChange", this.$("#widget-size").val());
			},

			// List
			"click .list .tools span": function(e) {
				var t = $(e.currentTarget),
					p = t.parents(".item").first();

				if (t.hasClass("up")) {
					p.insertBefore(p.prev());
				}
				else if (t.hasClass("down")) {
					p.insertAfter(p.next());
				}
				else if (t.hasClass("delete")) {
					p.slideUp(function() {
						p.remove();

					});
				}
			},

			// Number
			"keydown input[type=number]": function(e) {
				if (e.keyCode === 17) {
					ctrlDown = true;
				}

				return	ctrlDown ||
						((e.keyCode > 47 && e.keyCode < 58) ||
						(e.keyCode > 36 && e.keyCode < 41) ||
						(e.keyCode > 95 && e.keyCode < 106) ||
						e.keyCode === 8 ||
						e.keyCode === 9 ||
						e.keyCode === 46 ||
						e.keyCode === 17 ||
						e.keyCode === 65);
			},
			"keyup input[type=number]": function(e) {
				if (e.keyCode === 17) {
					ctrlDown = false;
				}
			},
			"blur input[type=number]": function(e) {
				var input = e.currentTarget;

				if (input.valueAsNumber && input.valueAsNumber > input.max) {
					input.value = input.max;
				}
				else if (input.valueAsNumber && input.valueAsNumber < input.min) {
					input.value = input.min;
				}
				else if (!input.valueAsNumber && input.value !== "") {
					input.value = input.min;
				}
			}
		},

		save: function(e) {
			if (e && e.preventDefault) {
				e.preventDefault();
			}

			this.off("sizeChange");

			var set = {
					config: {}
				},
				settings = this.$("form").serializeJSON();


			// jQuery.serializeJSON() doesn't parse multiple selects correctly
			this.$("select[multiple]").each(function() {
				settings[this.name] = $(this).val();
			});


			// This is assigned so custom properties that widgets add to their config are
			// preserved (such as woeid and woeloc on the Weather widget)
			_.assign(set.config, this.config, settings);


			var defaultConfig = ((this.widget.model && this.widget.model.prototype.defaults) || this.widget.widget).config;

			// This ensures that now-empty properties are still present in the
			// settings object and override existing values
			_.assign(set.config, _(defaultConfig)
				.pick(_.difference(_.keys(defaultConfig), _.keys(set.config)))
				.mapValues(function(e) {
					// If it's a string then it must be empty
					if (typeof e === "string") {
						return "";
					}

					// If it's boolean and not present it must have been an
					// unchecked checkbox and therefore false
					else if (typeof e === "boolean") {
						return false;
					}

					// If it was an array/list input that didn't have anything
					// selected it wouldn't be present either
					else if (Array.isArray(e)) {
						return [];
					}

					// If it's none of the above, we'll assume it was an object
					else {
						return {};
					}
				})
				.valueOf()
			);


			if (set.config.size) {
				set.size = set.config.size;

				delete set.config.size;
			}


			// This deletes properties that are only applicable at other sizes,
			// such as the team field on the Sports widget.
			_.each(this.widget.settings, function(e) {
				if (e.sizes && e.sizes.indexOf(set.size || this.model.get("size")) === -1) {
					delete set.config[e.name || e.nicename];
				}
			}, this);


			this.modal.hide();

			Track.FB.logEvent("WidgetConfigure", null, { widgetId: this.widget.name });

			Track.event("Widgets", "Configure", this.widget.name);


			// We assign directly to the actual widget instance, thereby allowing
			// any default-removal code to run
			if (this.instance.widgetModel) {
				this.instance.widgetModel.set(set);
			}
			else if (this.instance.instance) {
				if (this.instance.instance.adjustConfig) {
					this.instance.instance.adjustConfig(set.config);
				}

				this.instance.instance.config = set.config;

				this.instance.instance.size = this.instance.instance.config.size = set.size;

				this.instance.updateModel();

				this.instance.instance.render();

				if (this.instance.instance.refresh) {
					this.instance.instance.refresh();
				}
			}
		},

		show: function() {
			this.modal.show();

			Track.pageview("/widget/" + this.widget.name + "/settings");
		},

		constructor: function() {
			this.modal = new modal();

			this.modal.on("destroy", function() {
				this.$("input.color").spectrum("destroy");
			}, this).on("hide", function() {
				this.trigger("hide");
			}, this);

			this.modal.mo.appendTo(document.body);

			this.el = this.modal.content;

			return Backbone.View.apply(this, arguments);
		},


		initialize: function(options) {
			_.assign(this, _.pick(options, "widget", "model", "instance", "config"));

			// This is the target that should be searched when a function is
			// used as the value for a function
			this.fnTarget = this.instance.widgetModel || this.instance.instance;

			this.render();

			requestAnimationFrame(this.show.bind(this));
		},


		/**
		 * This converts the JSON settings specification to an HTML form, since some of
		 * the inputs might have async functions it needs to create each field and run it's
		 * handler instead of just rendering the whole thing all at once.
		 *
		 * @api    private
		 */
		createForm: function() {
			var form = this.$("form");

			var translate = _.bind(function(val) {
				if (val && val.slice(0, 5) === "i18n.") {
					return this.widget.translate(val.slice(5));
				}

				return val;
			}, this);

			_.each(this.widget.settings, function(e) {
				if (!e.type || !inputs[e.type]) {
					return;
				}

				var input = _.clone(e);

				// Legacy widgets use `nicename` instead of `name`
				input.name = input.name || input.nicename;

				// Translate user-visible attributes
				input.help = translate(input.help);
				input.label = translate(input.label);
				input.placeholder = translate(input.placeholder);


				var elm = $('<div class="form-group' + (input.pro ? " pro" : "") + '"></div>');


				if (input.pro && !Auth.isPro) {
					input.proHelper = "disabled";
				}


				if (input.sizes) {
					elm.toggleClass("hidden", input.sizes.indexOf(this.model.get("size")) === -1);

					this.on("sizeChange", function(size) {
						elm.toggleClass("hidden", input.sizes.indexOf(size) === -1);
					}, this);
				}


				if (typeof this.config[input.name] !== "undefined") {
					input.value = this.config[input.name];
				}


				try {
					inputs[input.type](input, elm, translate, this, form);

					// By inserting the element now, we let the inputs work on a
					// detached element and ensure that async inputs stay in order
					elm.appendTo(form);
				}
				catch (err) {
					Track.queue("widgets", "error", this.widget.name, this.model.get("size"), "settings", err.stack);

					Status.error(err);
				}
			}, this);
		},


		render: function() {
			this.$el.html(render("widget-settings"));

			this.createForm();

			return this;
		}
	});

	return view;
});
define('widgets/views/maximized',["widgets/views/main"], function(WidgetView) {
	return WidgetView.extend({
		getTemplate: function() {
			return this.widget.templates.maximized;
		}
	});
});
define('widgets/views/minimized',["widgets/views/main"], function(WidgetView) {
	return WidgetView.extend({
		getTemplate: function() {
			return this.widget.templates.minimized;
		}
	});
});
/**
 * The widget instance wrapper, manages elements, configuration and data persistence, settings, etc.
 */
define('widgets/instance',[
	"lodash", "jquery", "backbone", "browser/api", "core/uservoice", "core/auth", "core/analytics", "i18n/i18n", "core/status", "widgets/settings", "widgets/views/main", "widgets/views/maximized", "widgets/views/minimized", "widgets/model", "core/render", "settings/proxy"
], function(_, $, Backbone, Browser, UserVoice, Auth, Track, Translate, Status, Settings, MainView, Maximized, Minimized, WidgetModel, render, SettingsProxy) {
	var sizes = {
		1: "tiny",
		2: "small",
		3: "medium",
		4: "large",
		5: "variable",
		tiny: "tiny",
		small: "small",
		medium: "medium",
		large: "large",
		variable: "variable"
	};

	var GRID_SIZE = 10;

	var WidgetInstance = Backbone.View.extend({
		className: function() {
			return "widget " + this.widget.name + " " + this.model.get("size") + (this.widget.isTabbed === true ? " tabbed" : "") + (this.widget.isAvailable === false ? " hide" : "");
		},

		events: {
			"click > .settings": function() {
				try {
					if (this.widget.views && this.widget.views.settings) {
						this.model.set("state", "settings");
					}
					else {
						new Settings({
							instance: this,
							model: this.model,
							widget: this.widget,
							config: this.widgetModel ? this.widgetModel.config : this.instance.config
						}).once("hide", function() {
							this.trigger("settings:hide");
						}, this);

						this.trigger("settings:show");
					}
				}
				catch (err) {
					this.error();

					Track.queue("widgets", "error", this.widget.name, this.model.get("size"), "settings", err.stack);

					Status.error("An error occurred while trying to open the settings for the " + this.widget.name + " widget!");
				}
			},

			"click > .delete": function(e) {
				$(document).trigger("deletewidget", $(e.currentTarget).parents(".widget"));
			},

			"click > .minimize": function() {
				this.model.set("state", "default");
			},

			"click > .maximize": function() {
				this.model.set("state", "maximized");
			},

			"click > .wtooltip": function() {
				SettingsProxy("pro");
			},	

			"click > .wrefresh": function() {
				this.widgetModel.trigger("wrefresh");
			},
		},

		constructor: function(options) {
			this.widget = options.widget;

			var manifest = this.widget.manifest;

			// Set core properties
			this.id = manifest.id;
			this.model = options.model;
			this.cid = _.uniqueId("widget");
			this.isPreview = options.isPreview;
			this.hasSettings = !!(Array.isArray(this.widget.settings) || (manifest.views && manifest.views.settings));

			this.model.set({
				state: "default",
				size: sizes[options.size || this.model.get("size") || manifest.defaultSize || manifest.sizes[0]]
			}, {
				silent: true
			});


			// Create the element. Native methods are significantly faster than
			// Backbone's jQuery-backed system, and performance is essential
			// in a constructor that's used so often.
			this.el = document.createElement("section");

			this.el.setAttribute("data-id", this.cid);
			this.el.setAttribute("data-name", this.widget.name);
			this.el.setAttribute("data-size", this.model.get("size"));
			this.el.setAttribute("class", this.className());

			this.setElement(this.el);

			this.$el.data("view", this);


			// If the widget isn't available we create the element anyway so it's
			// preserved during serialization, but don't initialize it or call
			// any widget code
			if (!this.widget.isAvailable) {
				return;
			}

			this.updateLoc();

			this.widget.initialize(function() {
				this.requestPermissions(this.initialize);
			}, this);
		},


		/**
		 * Initializes the instance.  This _will_ be called again if the widget
		 * has errored and is being refreshed.
		 *
		 * @api     private
		 */
		initialize: function() {
			var widgetModel = this.widget.model || WidgetModel;

			try {
				this.widgetModel = new widgetModel({
					size: this.model.get("size"),
					data: this.model.get("data"),
					syncData: this.model.get("syncData"),
					state: this.model.get("state") || "default",
					config: _.defaults({}, this.model.get("config"), _.cloneDeep(widgetModel.prototype.defaults.config))
				}, {
					instance: this,
					widget: this.widget
				});
			}
			catch (e) {
				return this.error();
			}


			// updateState creates a new view for the current state
			this.state = null;

			this.updateState(true);


			if (!this.isPreview) {
				Track.FB.logEvent("VIEWED_CONTENT", null, { fb_content_type: "widget", fb_content_id: this.widget.name, widgetSize: this.model.get("size") });

				Track.queue("widgets", "view", this.widget.name, this.model.get("size"));
			}

			this.model.on("change", this.handleChange, this);

			this.widgetModel.on("error", this.error, this);
			this.widgetModel.on("change", this.updateModel, this);
			this.widgetModel.on("refreshInterval:change", this.setRefresh, this);

			this.setRefresh(true);
		},


		/**
		 * Sets an interval to refresh the widget
		 */
		setRefresh: function(initial) {
			if (this.widgetModel.refresh && !this.isPreview && !this._authorizing) {
				if (!initial) {
					clearInterval(this._refreshInterval);
				}
				else {
					try {
						this.widgetModel.refresh();
					}
					catch (e) {
						return this.error();
					}
				}

				if (this.widgetModel.refreshInterval) {
					this._refreshInterval = setInterval(_.bind(this.widgetModel.refresh, this.widgetModel), _.result(this.widgetModel, "refreshInterval"));
				}
			}
		},


		/**
		 * Requests any permissions the widget requires, if this isn't a preview
		 * and they haven't already been granted. Called before any widget code is
		 * run.
		 *
		 * @api    private
		 * @param  {Function}  cb  The function to call after all required permissions have been granted
		 */
		requestPermissions: function(cb) {
			if (this.isPreview) {
				return cb.call(this);
			}

			this.widget.checkPermissions(function(granted) {
				if (granted) {
					return cb.call(this);
				}

				this._requestingPermissions = true;

				this.$el.addClass("splash permissions-request");

				this.el.innerHTML = '<div class="handle"></div>' + render("widgets/permissions-request");

				this.$el.on("click", ".notice button", function() {
					Browser.permissions.request({
						permissions: this.widget.browserPermissions
					}, function(granted) {
						// The page needs to be reloaded after a permission is granted
						// so the API made available by it can be called (CR Bug 435141,
						// fixed in Chrome 45)
						//
						// Unfortunately that still doesn't allow access to URLs like
						// chrome://extension-icon until the browser is restarted
						if (granted) {
							location.reload();
						}
					});
				}.bind(this));
			}, this);
		},


		/**
		 * Handles errors by destroying the widget, unbinding events, and displaying
		 * a notice to the user
		 *
		 * @api     private
		 * @param   {String}  explanation  An explanation to show to the user,
		 *                                 i.e. "Something went wrong while we were trying to display this widget."
		 * @param   {String}  advice       Advice to be given to the user,
		 *                                 i.e. "Try reloading your page or clicking the button below for help."
		 */
		error: function(explanation, advice) {
			// If we're already in an error state (maybe from an async callback), don't do anything
			if (this._errored) {
				return;
			}

			this._errored = true;

			this.$el.addClass("splash error");

			// Cleanup to avoid continued errors from events, etc.
			try {
				this.cleanup();
			}
			catch (e) {}

			var data = {};

			if (explanation) {
				data.explanation = explanation;
			}

			if (advice) {
				data.advice = advice;
			}

			this.el.innerHTML = '<div class="handle"></div>' +
			(this.hasSettings ? '\r\n<div class="settings">&#xF0AD;</div>' : "") +
			render("widgets/error", data) + '\r\n<div class="resize"></div>';


			this.$el.on("click.error", ".notice button.refresh", function() {
				this.$el.off(".error").removeClass("splash error");

				delete this._errored;

				this.initialize();
			}.bind(this)).on("click.error", ".notice button.support", function() {
				UserVoice("showLightbox", "classic_widget", { mode: "support" });
			});
		},


		/**
		 * Cleans up event listeners, widget instances, etc.
		 */
		cleanup: function() {
			if (this.widgetModel) {
				try {
					this.widgetModel.destroy();
				}
				catch (e) {}
			}

			if (this.widgetView) {
				try {
					this.widgetView.destroy();
				}
				catch (e) {}
			}

			this.model.off("change");

			clearInterval(this._refreshInterval);
		},


		/**
		 * The remove method is called by the ViewCollection, so we override it
		 * to call the destroy method
		 *
		 * @api     public
		 */
		remove: function() {
			this.destroy();
		},


		/**
		 * Destroys this instance
		 *
		 * @api     public
		 */
		destroy: function() {
			this.cleanup();

			Backbone.View.prototype.remove.call(this);

			this.stopListening();
		},


		/**
		 * Creates and sets the correct view for the current widget state
		 *
		 * @param {Boolean}  [initial]  If this is the initial setup and no events should be fired
		 */
		updateState: function(initial) {
			var state;

			// Set the state
			if (!Auth.isPro && (this.model.get("state") === "maximized" || this.model.get("state") === "minimized")) {
				state = "default";
			}
			else {
				state = this.model.get("state");
			}


			// See if anything's changed
			if (!initial && ((this.state && this.state === state) || !this.widget.isAvailable)) {
				return;
			}

			this.state = state;


			var view = this.widget.views[state] || this.widget.views.default || MainView;

			// Widgets can implement completely custom settings
			if (state === "maximized") {
				if (!this.model.previous("state") || this.model.previous("state") !== "maximized") {
					// These methods need to be called before the widget view is replaced
					this.maximize();
				}

				view = this.widget.views.maximized || Maximized;
			}
			else if (state === "minimized") {
				view = this.widget.views.minimized || Minimized;
			}


			if (this.model.previous("state") === "maximized" && state !== "maximized") {
				this.minimize();
			}


			if (this.widgetView) {
				try {
					this.widgetView.destroy();
				}
				catch (e) {
					this.error();

					Track.queue("widgets", "error", this.widget.name, this.model.get("size"), "viewDestroy", e.stack);

					Status.error("An error occurred while trying to destroy the " + this.widget.name + " view!");

					return;
				}
			}


			if (!this.isPreview && this.widgetModel.oAuth && this.widget.requiresAuth && this.widgetModel.oAuth.hasToken && !this.widgetModel.oAuth.hasToken()) {
				return this.renderAuth();
			}


			// We update the model before creating the new view since it might
			// need to expect certain calls (i.e. view calls getRenderableData
			// on init and the model needs to check its current state)
			if (initial !== true) {
				this.widgetModel.set("state", state);
			}


			// If the state was maximized, then we're minimizing now, don't remove the class
			if (this.model.previous("state") !== "default" && this.model.previous("state") !== "maximized") {
				this.$el.removeClass(this.model.previous("state"));
			}

			if (state !== "default") {
				this.$el.addClass(state);
			}

			try {
				this.widgetView = new view({
					// The instance property is used by the constructor to inherit
					// select properties
					instance: this,
					widget: this.widget,
					model: this.widgetModel,
					errorHandler: this.error.bind(this)
				});
			}
			catch (e) {
				this.error();

				Track.queue("widgets", "error", this.widget.name, this.model.get("size"), "viewCreate", e.stack);

				Status.error("An error occurred while trying to create a view for the " + this.widget.name + " widget!");

				return;
			}

			this.render();
		},


		/**
		 * Animates a widget to its maximized state
		 */
		maximize: function() {
			var rect = this.el.getBoundingClientRect();

			this.placeholderStyle = 'height:' + rect.height + 'px;' + this.$el.attr("style");

			this.$el
				.css({
					// We need to unset the width and height properties for grid-based layouts
					width: "",
					height: "",
					top: rect.top,
					left: rect.left,
					right: window.innerWidth - rect.right,
					bottom: window.innerHeight - rect.bottom
				})
				.addClass("maximized")
				.on("animationend", _.after(2, function() {
					// Maximizing uses two animations. We disable both so they don't
					// get triggered again if the tabs re-render
					$(this).off("animationend").css({
						top: "",
						left: "",
						right: "",
						bottom: "",
						animation: "none"
					});
				}));

			$('<section class="widget placeholder"></section>').attr("style", this.placeholderStyle).insertBefore(this.$el);

			$(document.body).addClass("widget-maximized");
		},


		/**
		 * Animates a widget to its minimized state
		 */
		minimize: function() {
			var placeholder = this.$el.prev(".placeholder");

			if (!placeholder.length) {
				placeholder = $('<section class="widget placeholder"></section>').attr("style", this.placeholderStyle).insertBefore(this.$el);
			}

			delete this.placeholderStyle;


			var rect = placeholder[0].getBoundingClientRect();

			var updateLoc = this.updateLoc.bind(this);

			this.$el
				.css({
					animation: "",
					top: rect.top,
					left: rect.left,
					right: window.innerWidth - rect.right,
					bottom: window.innerHeight - rect.bottom
				})
				.addClass("transition-out")
				.on("animationend", _.after(2, function() {
					$(this)
						.off("animationend")
						.css({
							top: "",
							left: "",
							right: "",
							bottom: ""
						})
						.removeClass("maximized transition-out")
						.prev(".placeholder")
						.remove();

					updateLoc();

					$(document.body).removeClass("widget-maximized");
				}));
		},


		/**
		 * Renders the OAuth authorization screen
		 *
		 * @api     private
		 */
		renderAuth: function() {
			this._authorizing = true;

			this.$el.addClass("auth-required");

			var data = {
				name: this.widget.translate("name"),
				message: this.widget.translate("authMessage"),
				button: this.widget.translate("authButton")
			};

			if (!data.button || data.button === "authButton") {
				delete data.button;
			}

			if (!data.message || data.message === "authMessage") {
				delete data.message;
			}

			this.el.innerHTML = '<div class="handle"></div>' + 
			'\r\n<div class="wdelete delete">' + 
				'<svg width="24" height="24" fill="currentColor" transform="scale(0.75 0.8)"><path style=" " d="M9,0 C8.164063453674316,0 7.34375,0.1640630066394806 6.75,0.75 C6.15625,1.3359379768371582 5.96875,2.167968988418579 5.96875,3.03125 L2,3.03125 C1.449218988418579,3.03125 1,3.480468988418579 1,4.03125 L0,4.03125 L0,6.03125 L22,6.03125 L22,4.03125 L21,4.03125 C21,3.480468988418579 20.55078125,3.03125 20,3.03125 L16.03125,3.03125 C16.03125,2.167968988418579 15.84375,1.3359379768371582 15.25,0.75 C14.65625,0.1640630066394806 13.835938453674316,0 13,0 zM9,2.0625 L13,2.0625 C13.546875,2.0625 13.71875,2.191406011581421 13.78125,2.25 C13.84375,2.308593988418579 13.96875,2.472656011581421 13.96875,3.03125 L8.03125,3.03125 C8.03125,2.472656011581421 8.15625,2.308593988418579 8.21875,2.25 C8.28125,2.191406011581421 8.453125,2.0625 9,2.0625 zM2,7.03125 L2,23.03125 C2,24.68359375 3.347655773162842,26.03125 5,26.03125 L17,26.03125 C18.65234375,26.03125 20,24.68359375 20,23.03125 L20,7.03125 zM6,10.03125 L8,10.03125 L8,22.03125 L6,22.03125 zM10,10.03125 L12,10.03125 L12,22.03125 L10,22.03125 zM14,10.03125 L16,10.03125 L16,22.03125 L14,22.03125 z"/></svg>' +
			'</div>' +
			'\r\n<div class="wrefresh">' + 
				'<svg width="16" height="16" id="Layer_1" data-name="Layer 1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><title>Refresh</title><path d="M66.71,287.91H0v160l47.36-43.59A255.71,255.71,0,0,0,255.9,512C386.54,512,494.19,414.15,510,287.91H445.29A192,192,0,0,1,95,360.6l79.08-72.69Zm0,0" fill="#0000CC"/><path d="M255.9,0C125.46,0,17.64,97.63,2,224H66.71a192,192,0,0,1,353.26-68l-68,68H512v-160l-45.78,45.78A255.89,255.89,0,0,0,255.9,0Zm0,0" fill="#0000CC"/></svg>' +
			'</div>' +
			render("widgets/auth-required", data);

			this.$el.on("click.auth-required", ".notice button", function() {
				this.widgetModel.oAuth.getToken(function() {
					this.$el.off(".auth-required").removeClass("auth-required");

					delete this._authorizing;

					this.updateState(true);

					this.setRefresh(true);
				}.bind(this));
			}.bind(this));
		},


		/**
		 * Updates the widget's location on grid-based layouts
		 *
		 * @api     private
		 * @param   {Boolean}  [remove=false]  If the location CSS properties should be removed if not
		 *                                     present in the model (if this was on a grid)
		 */
		updateLoc: function(remove) {
			var loc = this.model.get("loc");

			if (loc) {
				this.$el.css({
					top: loc[0] * GRID_SIZE,
					left: loc[1] * GRID_SIZE,
					width: loc[2] * GRID_SIZE - 1,
					height: loc[3] * GRID_SIZE - 1
				});
			}
			else if (remove === true) {
				this.$el.css({
					top: "",
					left: "",
					width: "",
					height: ""
				});
			}
		},


		/**
		 * Handles changes in this instance's model
		 *
		 * @api     private
		 * @param   {Object}  options  Any options passed from Backbone, these can include a
		 *                             widgetChange boolean that indicates if this change
		 *                             came from the widget
		 */
		handleChange: function(model, options) {
			var set = {};

			if (this.model.hasChanged("config") && this.widgetModel) {
				set.config = _.defaults({}, this.model.get("config"), _.cloneDeep(this.widgetModel.defaults.config));
			}

			if (this.model.hasChanged("data")) {
				set.data = this.model.get("data");
			}

			if (this.model.hasChanged("syncData")) {
				set.syncData = this.model.get("syncData");
			}

			if (this.model.hasChanged("state")) {
				this.updateState();

				set.state = this.model.get("state") || "default";
			}

			if (this.model.hasChanged("loc")) {
				this.updateLoc(true);
			}

			if (this.model.hasChanged("size")) {
				set.size = this.model.get("size");

				this.el.setAttribute("data-size", this.model.get("size"));
				this.el.setAttribute("class", this.className());
			}


			if ((!options || !options.widgetChange) && this.widgetModel) {
				this.widgetModel.set(set);
			}

			var changedKeys = Object.keys(this.model.changed);

			// The tabs collection listens for widget save events and triggers
			// a sync. We only want to do that when something other than the
			// widget state changes (otherwise maximizing would trigger a save)
			if (changedKeys.length !== 1 || changedKeys.indexOf("state") === -1) {
				this.model.trigger("save");
			}
		},


		/**
		 * Handles changes in the widget's model, persisting them to this instance's model
		 *
		 * @api     private
		 */
		updateModel: function() {
			// All known properties (no custom ones are saved) are copied
			var set = _(this.widgetModel.attributes).pick("state", "size", "config", "data", "syncData", "loc").mapValues(function(e, key) {
				if (key === "config") {
					return _.omit(this.widgetModel.get("config"), function(e, k) {
						return this.widgetModel.defaults.config.hasOwnProperty(k) && e === this.widgetModel.defaults.config[k];
					}, this);
				}
				else {
					return e;
				}
			}, this).value();

			this.model.set(set, {
				// This lets the handleChange function know that it shouldn't
				// update the widget, to avoid endless recursive calls
				widgetChange: true
			});
		},


		/**
		 * Refreshes the rendered element, called by the sortable controller.
		 *
		 * This method is primarily used by the legacy instance since it needs
		 * to handle re-rendering differently
		 *
		 * @api     public
		 */
		refresh: function() {
			this.render();
		},


		render: function() {
			// Set by the onDrop handler
			if (this.onGrid === false && this.model.has("loc")) {
				this.model.unset("loc");
			}

			if (this._requestingPermissions) {
				return;
			}

			// Here we safely use innerHTML since we don't want to destroy the
			// widget view's event listeners
			this.el.innerHTML = '';
				if (this.widgetModel.pro_tooltip) {
					this.el.innerHTML +=
						'<div class="wtooltip" data-tooltip="' + Translate("upgrade_tooltips." + this.widgetModel.pro_tooltip) + '">' + 
							'<svg enable-background="new 0 0 500 300" height="20px" id="Layer_1" version="1.1" viewBox="20 20 280 280" width="20px" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g><path d="M150.842,14.519c-74.785,0-135.409,60.631-135.409,135.415c0,74.783,60.624,135.415,135.409,135.415   c74.788,0,135.411-60.632,135.411-135.415C286.253,75.15,225.63,14.519,150.842,14.519z M150.842,266.196   c-64.209,0-116.262-52.055-116.262-116.263c0-64.208,52.053-116.267,116.262-116.267c64.212,0,116.263,52.059,116.263,116.267   C267.104,214.142,215.054,266.196,150.842,266.196z" fill="#FFB200"/><path d="M255.587,149.934c0,57.852-46.894,104.745-104.745,104.745c-57.85,0-104.743-46.894-104.743-104.745   S92.992,45.188,150.842,45.188C208.693,45.188,255.587,92.082,255.587,149.934z" fill="#FFB200"/><g><path d="M164.922,204.148c-3.927,3.838-8.669,5.761-14.221,5.761c-5.775,0-10.525-1.858-14.259-5.592    c-3.725-3.733-5.59-8.483-5.59-14.261c0-5.607,1.931-10.362,5.801-14.257c3.866-3.897,8.552-5.845,14.043-5.845    c5.495,0,10.218,1.991,14.176,5.97c3.951,3.982,5.93,8.722,5.93,14.217C170.807,195.641,168.844,200.307,164.922,204.148z" fill="#FFFFFF"/><path d="M172.995,153.216c-3.358,1.686-5.414,3.143-6.139,4.377c-0.731,1.228-1.086,3.87-1.086,7.909h-31.205    v-5.303c0-7.011,0.78-12.185,2.355-15.527c1.567-3.335,4.429-5.926,8.583-7.78l5.721-2.518c4.32-1.911,6.477-4.598,6.477-8.078    c0-2.023-0.712-3.725-2.104-5.137c-1.399-1.392-3.117-2.104-5.133-2.104c-5.495,0-8.247,3.822-8.247,11.445h-29.019    c0-10.21,2.361-18.533,7.07-24.981c3.479-4.767,7.989-8.552,13.541-11.356c5.553-2.8,11.3-4.208,17.246-4.208    c10.547,0,19.413,3.496,26.622,10.475s10.81,15.632,10.81,25.951C188.471,139.108,183.313,148.059,172.995,153.216z" fill="#FFFFFF"/></g></g></svg>' + 
						'</div>\r\n';
				}

				this.el.innerHTML +=
				(this.state === "maximized" ?
					'<div class="minimize" title="' + Translate("widgets.minimize") + '">' +
						'<svg viewBox="0 0 24 24"><path d="M5 16h3v3h2v-5H5v2zm3-8H5v2h5V5H8v3zm6 11h2v-3h3v-2h-5v5zm2-11V5h-2v5h5V8h-3z"></path></svg>' +
					'</div>'
				: "") +
				(this.widget.isMaximizable && this.state !== "maximized" ?
					'<div class="maximize" title="' + Translate("widgets.maximize") + '">' +
						'<svg viewBox="0 0 24 24"><path d="M7 14H5v5h5v-2H7v-3zm-2-4h2V7h3V5H5v5zm12 7h-3v2h5v-5h-2v3zM14 5v2h3v3h2V5h-5z"></path></svg>' +
					'</div>'
				: "") +
				'<div class="handle"></div>' +
				(this.hasSettings ?
					'\r\n<div class="settings">' +
						'<svg width="16" height="16" viewBox="0 0 1792 1792" fill="currentColor">' +
							'<path d="M448 1472q0-26-19-45t-45-19-45 19-19 45 19 45 45 19 45-19 19-45zm644-420l-682 682q-37 37-90 37-52 0-91-37l-106-108q-38-36-38-90 0-53 38-91l681-681q39 98 114.5 173.5t173.5 114.5zm634-435q0 39-23 106-47 134-164.5 217.5t-258.5 83.5q-185 0-316.5-131.5t-131.5-316.5 131.5-316.5 316.5-131.5q58 0 121.5 16.5t107.5 46.5q16 11 16 28t-16 28l-293 169v224l193 107q5-3 79-48.5t135.5-81 70.5-35.5q15 0 23.5 10t8.5 25z"></path>' +
						'</svg>' +
					'</div>'
					: ""
				) +
				'\r\n<div class="resize"></div>' +
				'\r\n<div class="wdelete delete">' + 
						'<svg width="24" height="24" fill="currentColor" transform="scale(0.75 0.8)"><path style=" " d="M9,0 C8.164063453674316,0 7.34375,0.1640630066394806 6.75,0.75 C6.15625,1.3359379768371582 5.96875,2.167968988418579 5.96875,3.03125 L2,3.03125 C1.449218988418579,3.03125 1,3.480468988418579 1,4.03125 L0,4.03125 L0,6.03125 L22,6.03125 L22,4.03125 L21,4.03125 C21,3.480468988418579 20.55078125,3.03125 20,3.03125 L16.03125,3.03125 C16.03125,2.167968988418579 15.84375,1.3359379768371582 15.25,0.75 C14.65625,0.1640630066394806 13.835938453674316,0 13,0 zM9,2.0625 L13,2.0625 C13.546875,2.0625 13.71875,2.191406011581421 13.78125,2.25 C13.84375,2.308593988418579 13.96875,2.472656011581421 13.96875,3.03125 L8.03125,3.03125 C8.03125,2.472656011581421 8.15625,2.308593988418579 8.21875,2.25 C8.28125,2.191406011581421 8.453125,2.0625 9,2.0625 zM2,7.03125 L2,23.03125 C2,24.68359375 3.347655773162842,26.03125 5,26.03125 L17,26.03125 C18.65234375,26.03125 20,24.68359375 20,23.03125 L20,7.03125 zM6,10.03125 L8,10.03125 L8,22.03125 L6,22.03125 zM10,10.03125 L12,10.03125 L12,22.03125 L10,22.03125 zM14,10.03125 L16,10.03125 L16,22.03125 L14,22.03125 z"/></svg>' +
					'</div>' +
				'\r\n<div class="wrefresh">' + 
					'<svg width="16" height="16" id="Layer_1" data-name="Layer 1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><title>Refresh</title><path d="M66.71,287.91H0v160l47.36-43.59A255.71,255.71,0,0,0,255.9,512C386.54,512,494.19,414.15,510,287.91H445.29A192,192,0,0,1,95,360.6l79.08-72.69Zm0,0" fill="#0000CC"/><path d="M255.9,0C125.46,0,17.64,97.63,2,224H66.71a192,192,0,0,1,353.26-68l-68,68H512v-160l-45.78,45.78A255.89,255.89,0,0,0,255.9,0Zm0,0" fill="#0000CC"/></svg>' +
				'</div>';

			if (this.widgetView && this.widgetView.el) {
				if (this.$el && this.widgetView.model && this.widgetView.model.widgetClassname) {
					this.$el.addClass(this.widgetView.model.widgetClassname);
				}

				this.el.insertBefore(this.widgetView.el, this.el.children[2]);
			}
		}
	});

	return WidgetInstance;
});
/**
 * The legacy widget wrapper model
 */
define('widgets/legacy/widget',["lodash", "browser/api", "i18n/i18n", "widgets/registry/css", "widgets/registry/widget", "core/render"], function(_, Browser, Translate, CSSManager, Widget, render) {
	var strings = Translate.getAll().widgets,
		enStrings = Translate.getAll("en").widgets;

	var LegacyWidget = Widget.extend({
		constructor: function(widget) {
			// Since widgets should be retrievable by both ID and name, we might
			// as well populate the id and cid fields and let Backbone handle lookups
			this.id = widget.id;

			this.widget = widget;

			this.name = this.cid = widget.nicename;


			// Data properties. These hold core information about the widget,
			// such as settings, available sizes, browser permissions, etc.
			this.sizes = widget.sizes;

			this.settings = widget.settings;

			this.isListed = !widget.unlisted;

			this.icon = "icons/" + this.name + ".png";

			this.browserPermissions = widget.permissions || [];

			this.isAvailable = !(widget.environments && widget.environments.indexOf(Browser.environment) === -1);


			this.enStrings = enStrings[this.name] || {};

			this.strings = strings[this.name] || enStrings[this.name] || {};

			this.sort = widget.sort || 99999;

			CSSManager.registeredWidgets[this.name] = true;
		},


		/**
		 * Renders the widget's description template and returns the HTML result
		 *
		 * @api     public
		 * @param   {Function}  cb  The callback
		 */
		getDesc: function(cb) {
			cb(render("widgets." + this.name + ".desc", {
				i18n: this.strings
			}));
		},


		isLegacy: true,

		isInitialized: false,


		/**
		 * Initializes this widget. This is a no-op on legacy widgets
		 *
		 * @param {Function} cb   The function to call when this widget is completely initialized
		 * @param {*}        ctx  The context to call the callback in
		 */
		initialize: function(cb, ctx) {
			if (!this.isAvailable) {
				return;
			}

			if (this.isInitialized) {
				return cb.call(ctx);
			}

			this.isInitialized = true;

			// Translate default config properties
			if (this.widget && this.widget.config) {
				this.widget.config = _.mapValues(this.widget.config, function(str) {
					if (typeof str === "string" && str.slice(0, 5) === "i18n.") {
						return this.translate(str.substr(5));
					}
					else {
						return str;
					}
				}, this);
			}

			return cb.call(ctx);
		}
	});

	return LegacyWidget;
});
/**
 * The legacy widget instance wrapper
 */
define('widgets/legacy/instance',[
	"jquery", "lodash", "backbone", "browser/api", "core/status", "core/analytics", "widgets/instance", "widgets/settings", "lib/unextend", "core/render"
], function($, _, Backbone, Browser, Status, Track, WidgetInstance, Settings, unextend, render) {
	var sizes = {
		1: "tiny",
		2: "small",
		3: "medium",
		4: "large",
		5: "variable",
		tiny: "tiny",
		small: "small",
		medium: "medium",
		large: "large",
		variable: "variable"
	};

	var LegacyInstance = WidgetInstance.extend({
		className: function() {
			return "widget legacy " + this.widget.name + " " + this.model.get("size") + (this.widget.isAvailable === false ? " hide" : "");
		},

		/**
		 * This needs to be overridden since attributes and className need to use this.widget
		 *
		 * @api    public
		 * @param  {Object} options The options for the view, these must include a model
		 */
		constructor: function(options) {
			this.widget = options.widget;

			var widget = this.widget.widget;

			// Set core properties
			this.id = widget.id;
			this.model = options.model;
			this.cid = _.uniqueId("widget");
			this.isPreview = options.isPreview;
			this.hasSettings = Array.isArray(this.widget.settings);

			this.model.set("size", sizes[options.size || this.model.get("size") || (widget.config && widget.config.size) || widget.sizes[0]]);


			// Create the element. Native methods are significantly faster than
			// Backbone's jQuery-backed system, and performance is essential
			// in a constructor that's used so often.
			this.el = document.createElement("section");

			this.el.setAttribute("data-id", this.cid);
			this.el.setAttribute("data-name", this.widget.name);
			this.el.setAttribute("data-size", this.model.get("size"));
			this.el.setAttribute("class", this.className());

			this.setElement(this.el);

			this.$el.data("view", this);


			// If the widget isn't available we create the element anyway so it's
			// preserved during serialization, but don't initialize it or call
			// any widget code
			if (!this.widget.isAvailable) {
				return;
			}

			this.updateLoc();


			/**
			 * Triggers a save event, this is also saveData for backwards compatibility
			 *
			 * @api    public
			 */
			this.save = this.saveConfig = this.saveData = this.updateModel;

			this.translate = _.bind(this.widget.translate, this.widget);


			this.widget.initialize(function() {
				this.requestPermissions(this.initialize);
			}, this);
		},


		/**
		 * Initializes the instance.  This _will_ be called again if the widget
		 * has errored and is being refreshed.
		 *
		 * @api     private
		 */
		initialize: function() {
			var instance = this.instance = _.assign(_.cloneDeep(this.widget.widget), this.model.attributes);

			instance.utils = this;

			instance.elm = this.$el;

			instance.config = $.extend(true, _.cloneDeep(this.widget.widget.config || {}), this.model.get("config"));

			instance.size = instance.config.size = this.model.get("size");

			instance.internalID = this.cid;


			if (!this.preview) {
				Track.FB.logEvent("VIEWED_CONTENT", null, { fb_content_type: "widget", fb_content_id: this.widget.name, widgetSize: this.model.get("size") });

				Track.queue("widgets", "view", this.widget.name, this.model.get("size"));
			}


			this.model.on("change", this.handleChange, this);


			try {
				this.instance.render(this.isPreview);
			}
			catch (e) {
				this.error();

				Track.queue("widgets", "error", this.widget.name, this.model.get("size"), "render", e.stack);

				Status.error("An error occurred while trying to render the " + this.widget.name + " widget!");
			}

			if (this.instance.refresh && !this.isPreview) {
				this.instance.refresh();
			}


			if (this.instance.interval) {
				this._refreshInterval = setInterval(function() {
					if (this.instance.refresh && !this.isPreview) {
						this.instance.refresh();
					}
					else {
						this.instance.render(this.isPreview);
					}
				}.bind(this), this.instance.interval);
			}
		},


		/**
		 * Cleans up event listeners, widget instances, etc.
		 */
		cleanup: function() {
			if (this.instance) {
				delete this.instance;
			}

			this.model.off("change");

			clearInterval(this._refreshInterval);
		},


		/**
		 * Handles changes in this instance's model
		 *
		 * @api     private
		 * @param   {Object}  options  Any options passed from Backbone, these can include a
		 *                             widgetChange boolean that indicates if this change
		 *                             came from the widget
		 */
		handleChange: function(model, options) {
			if (this.model.hasChanged("loc")) {
				this.updateLoc(true);
			}

			if (this.model.hasChanged("size")) {
				this.el.setAttribute("data-size", this.model.get("size"));
				this.el.setAttribute("class", this.className());
			}


			if (!options || !options.widgetChange) {
				if (this.model.hasChanged("config")) {
					this.instance.config = $.extend(true, _.cloneDeep(this.widget.widget.config), this.model.get("config"));

					this.instance.size = this.instance.config.size = this.model.get("size");
				}

				if (this.model.hasChanged("data")) {
					this.instance.data = this.model.get("data");
				}

				if (this.model.hasChanged("syncData")) {
					this.instance.syncData = this.model.get("syncData");
				}

				if (this.model.hasChanged("size")) {
					this.instance.size = this.instance.config.size = this.model.get("size");
				}


				// This needs to be called first so renders happen faster after things change and in
				// the case that we're offline the widget still renders before attempting to refresh.
				try {
					this.instance.render(this.isPreview);
				}
				catch (e) {
					this.error();

					Track.queue("widgets", "error", this.widget.name, this.model.get("size"), "render", e.stack);

					Status.error("An error occurred while trying to render the " + this.widget.name + " widget!");
				}

				if (this.instance.refresh && !this.isPreview) {
					this.instance.refresh();
				}
			}


			var changedKeys = Object.keys(this.model.changed);

			// The tabs collection listens for widget save events and triggers
			// a sync. We only want to do that when something other than the
			// widget state changes (otherwise maximizing would trigger a save)
			if (changedKeys.length !== 1 || changedKeys.indexOf("state") === -1) {
				this.model.trigger("save");
			}
		},


		/**
		 * Handles changes in the widget, persisting them to this instance's model
		 *
		 * @api     private
		 */
		updateModel: function() {
			// All known properties (no custom ones are saved) except state, which
			// the widget isn't alllowed to change, are copied
			var set = _(this.instance).pick("size", "config", "data", "syncData", "loc").mapValues(function(e, key) {
				if (key === "config") {
					var config = unextend(this.widget.widget.config, e);

					delete config.size;

					return config;
				}
				else {
					// We remove the value so all change events get triggered properly.
					//
					// Otherwise, legacy widgets access a referenced object and no change will be properly detected.
					this.model.unset(key, {
						silent: true
					});

					return e;
				}
			}, this).value();

			this.model.set(set, {
				// This lets the handleChange function know that it shouldn't
				// update the widget, to avoid endless recursive calls
				widgetChange: true
			});
		},


		/**
		 * This handles errors that occur in widgets
		 *
		 * @api    public
		 * @param  {String} msg The error that occurred
		 */
		error: function(msg) {
			Track.queue("widgets", "error", this.widget.name, this.model.get("size"), "utils", msg);

			Status.error("An error occurred in the " + this.widget.name + " widget: " + msg);
		},


		/**
		 * Retrieves a widget's template
		 *
		 * @api    public
		 * @param  {String}  [name]  The template to get
		 * @return {Hogan.Template}  The retrieved template
		 */
		getTemplate: function(name) {
			return render.getTemplate("widgets." + this.widget.name + (name ? "." + name : ""));
		},


		/**
		 * Renders a widget's template
		 *
		 * @api    public
		 * @param  {String} name        The template to render
		 * @param  {Object} [data={}]   The data to render with
		 * @param  {Object} [partials]  Any partials to be included
		 * @return {String}             The rendered template
		 */
		renderTemplate: function(name, data, partials) {
			data = _.clone(data) || {};

			data.i18n = this.widget.strings || {};

			return render(("widgets." + this.widget.name + (name ? "." + name : "")) || "", data, partials);
		},


		/**
		 * Refreshes the rendered element, called by the sortable controller
		 *
		 * @api     public
		 */
		refresh: function() {
			if (this._requestingPermissions) {
				return;
			}

			try {
				this.instance.render(this.isPreview);
			}
			catch (e) {
				this.error();

				Track.queue("widgets", "error", this.widget.name, this.model.get("size"), "render", e.stack);

				Status.error("An error occurred while trying to render the " + this.widget.name + " widget!");
			}
		},


		render: function(data, partials) {
			// Set by the onDrop handler
			if (this.onGrid === false && this.model.has("loc")) {
				this.model.unset("loc");
			}

			if (this._requestingPermissions) {
				return;
			}

			data = _.clone(data) || {};

			data[this.model.get("size")] = true;

			data.i18n = this.widget.strings || {};

			this.el.innerHTML =
				'<div class="handle"></div>' +
				(this.hasSettings ?
					'\r\n<div class="settings">' +
						'<svg width="16" height="16" viewBox="0 0 1792 1792" fill="currentColor">' +
							'<path d="M448 1472q0-26-19-45t-45-19-45 19-19 45 19 45 45 19 45-19 19-45zm644-420l-682 682q-37 37-90 37-52 0-91-37l-106-108q-38-36-38-90 0-53 38-91l681-681q39 98 114.5 173.5t173.5 114.5zm634-435q0 39-23 106-47 134-164.5 217.5t-258.5 83.5q-185 0-316.5-131.5t-131.5-316.5 131.5-316.5 316.5-131.5q58 0 121.5 16.5t107.5 46.5q16 11 16 28t-16 28l-293 169v224l193 107q5-3 79-48.5t135.5-81 70.5-35.5q15 0 23.5 10t8.5 25z"></path>' +
						'</svg>' +
					'</div>'
					: ""
				) +
				render("widgets." + this.widget.name, data, partials) +
				'\r\n<div class="resize"></div>' +
				'\r\n<div class="wdelete delete">' + 
						'<svg width="24" height="24" fill="currentColor" transform="scale(0.75 0.8)"><path style=" " d="M9,0 C8.164063453674316,0 7.34375,0.1640630066394806 6.75,0.75 C6.15625,1.3359379768371582 5.96875,2.167968988418579 5.96875,3.03125 L2,3.03125 C1.449218988418579,3.03125 1,3.480468988418579 1,4.03125 L0,4.03125 L0,6.03125 L22,6.03125 L22,4.03125 L21,4.03125 C21,3.480468988418579 20.55078125,3.03125 20,3.03125 L16.03125,3.03125 C16.03125,2.167968988418579 15.84375,1.3359379768371582 15.25,0.75 C14.65625,0.1640630066394806 13.835938453674316,0 13,0 zM9,2.0625 L13,2.0625 C13.546875,2.0625 13.71875,2.191406011581421 13.78125,2.25 C13.84375,2.308593988418579 13.96875,2.472656011581421 13.96875,3.03125 L8.03125,3.03125 C8.03125,2.472656011581421 8.15625,2.308593988418579 8.21875,2.25 C8.28125,2.191406011581421 8.453125,2.0625 9,2.0625 zM2,7.03125 L2,23.03125 C2,24.68359375 3.347655773162842,26.03125 5,26.03125 L17,26.03125 C18.65234375,26.03125 20,24.68359375 20,23.03125 L20,7.03125 zM6,10.03125 L8,10.03125 L8,22.03125 L6,22.03125 zM10,10.03125 L12,10.03125 L12,22.03125 L10,22.03125 zM14,10.03125 L16,10.03125 L16,22.03125 L14,22.03125 z"/></svg>' +
				'</div>'
			;
		}
	});

	return LegacyInstance;
});
define('json',{load: function(id){throw new Error("Dynamic load not allowed: " + id);}});

define("json!w/analytics/manifest.json",{
	"id": 3,
	"sort": 380,
	"name": "analytics",
	"model": "model",
	"icon": "analytics.png",
	"sizes": [
		"tiny",
		"medium"
	],
	"defaultSize": "medium",
	"views": {
		"default": "view"
	},
	"templates": {
		"desc": "templates/desc.hjs",
		"default": "templates/main.hjs"
	},
	"settings": [
		{
			"type": "text",
			"name": "title",
			"label": "i18n.settings.title",
			"placeholder": "i18n.settings.title_placeholder",
			"defaultVal": ""
		},
		{
			"type": "size"
		},
		{
			"type": "select",
			"name": "profile",
			"label": "i18n.settings.profile",
			"options": "getProfiles"
		},
		{
			"type": "radio",
			"name": "weekweek",
			"label": "i18n.settings.showWeek.title",
			"nicename": "Weekly",
			"options": {
				"0": "i18n.settings.showWeek.off",
				"1": "i18n.settings.showWeek.on"
			}
		},
		{
			"type": "radio",
			"name": "yearyear",
			"label": "i18n.settings.showYear.title",
			"nicename": "Yearly",
			"options": {
				"0": "i18n.settings.showYear.off",
				"1": "i18n.settings.showYear.on"
			}
		},
		{
			"type": "radio",
			"name": "topvisited",
			"label": "i18n.settings.topVisited.title",
			"nicename": "Top Visited Pages",
			"options": {
				"0": "i18n.settings.topVisited.off",
				"1": "i18n.settings.topVisited.on"
			}
		},
		{
			"type": "radio",
			"name": "channels",
			"label": "i18n.settings.channels.title",
			"nicename": "Traffic Channels",
			"options": {
				"0": "i18n.settings.channels.off",
				"1": "i18n.settings.channels.on"
			}
		}
	],
	"strings": {
		"en": {
			"name": "Analytics",
			"desc": "Displays various metrics from a Google Analytics profile.",
			"sessions": "sessions",
			"pageviews": "Pageviews",
			"pagesvisit": "Pages/visit",
			"bouncerate": "Bounce Rate",
			"completions": "Completions",
			"noprofile_title": "No profile selected",
			"noprofile": "It doesn't look like you've selected a profile yet!\n<br />\nTry selecting one via the wrench icon at the top right.",
			"empty_title": "No Google Analytics data",
			"settings": {
				"profile": "Profile",
				"showYear": {
					"title": "This Year vs Last Year",
					"on": "show",
					"off": "hide"
				},
				"showWeek": {
					"title": "This Week vs Last Week",
					"on": "show",
					"off": "hide"
				},
				"topVisited": {
					"title": "Top Visited Pages",
					"on": "show",
					"off": "hide"
				},
				"channels": {
					"title": "Traffic Channels",
					"on": "show",
					"off": "hide"
				}
			}
		},
		"bn": {
			"name": "বিশ্লেষণমূলক",
			"desc": "গুগল বিশ্লেষণ প্রোফাইল থেকে বিভিন্ন বৈশিষ্ট্যের মান প্রদর্শন করা হয়।",
			"sessions": "অধিবেশন",
			"pageviews": "পাতাপরিদর্শন",
			"pagesvisit": "পাতা/ভ্রমণ",
			"bouncerate": "বাউন্স রেট",
			"completions": "সম্পূর্ণতা",
			"noprofile_title": "No profile selected",
			"noprofile": "আপনি এখনো একটি প্রোফাইল নির্বাচন করার মত দেখাচ্ছে না!\n<br /><br />\nউপরে ডানদিকে রেঞ্চ আইকন মাধ্যমে একটি নির্বাচন করার চেষ্টা করুন।",
			"settings": {
				"profile": "প্রোফাইল"
			}
		},
		"ca": {
			"name": "Analytics",
			"desc": "Displays various metrics from a Google Analytics profile.",
			"sessions": "sessions",
			"pageviews": "Pageviews",
			"pagesvisit": "Pages/visit",
			"bouncerate": "Bounce Rate",
			"completions": "Completions",
			"noprofile_title": "No profile selected",
			"noprofile": "It doesn't look like you've selected a profile yet!\n<br />\nTry selecting one via the wrench icon at the top right.",
			"settings": {
				"profile": "Profile"
			}
		},
		"cs": {
			"name": "Analytics",
			"desc": "Zobrazit různé metriky z profilu Google Analytics.",
			"sessions": "zasedání",
			"pageviews": "Zobrazení stránek",
			"pagesvisit": "Stránky / zobrazení",
			"bouncerate": "Bounce Rate",
			"completions": "Dokončené",
			"noprofile_title": "Není vybrán žádný profil",
			"noprofile": "Vypadá to, že jste ještě nevybrali profil! <br /><br /> Vyberte jeden přes ikonu klíče v pravém horním rohu.",
			"settings": {
				"profile": "Profil"
			}
		},
		"da": {
			"name": "Analytiks",
			"desc": "Displays various metrics from a Google Analytics profile.",
			"sessions": "sessions",
			"pageviews": "Sidevisninger",
			"pagesvisit": "Sider/visning",
			"bouncerate": "Bounce Rate",
			"completions": "Completions",
			"noprofile_title": "No profile selected",
			"noprofile": "Det ser ikke ud til at du har valgt en profil endnu!\n<br /><br />\nPrøv at vælge en gennem skruenøglen ikonet i toppen til højre.",
			"settings": {
				"profile": "Profil"
			}
		},
		"de": {
			"name": "Analytik",
			"desc": "Zeigt einige Metriken von einen Google Analytics Profil.",
			"sessions": "Sitzung",
			"pageviews": "Seitenzugriffe",
			"pagesvisit": "Seiten/Besuch",
			"bouncerate": "Absprungrate",
			"completions": "Abschlüsse",
			"noprofile_title": "Kein Profil ausgewählt",
			"noprofile": "Es scheint so, als ob Sie kein Profil ausgewählt haben.\n<br /><br />\nVersuchen Sie eins über das Schraubenschlüssel-Symbol in der rechten oberen Ecke auszuwählen.",
			"settings": {
				"profile": "Profil"
			}
		},
		"es": {
			"name": "Analítica",
			"desc": "Muestra varias métricas de un perfil de Google Analytics.",
			"sessions": "sesiones",
			"pageviews": "Visitas de Pagina",
			"pagesvisit": "Páginas/visita",
			"bouncerate": "Tasa de rebote",
			"completions": "Terminaciones",
			"noprofile_title": "No profile selected",
			"noprofile": "No parece que se ha seleccionado un perfil todavía!\n<br /><br />\nPruebe a seleccionar una vía el icono de llave inglesa en la parte superior derecha.",
			"settings": {
				"profile": "PERFIL"
			}
		},
		"fr": {
			"name": "Analytics",
			"desc": "Affiche plusieurs statistiques depuis un compte Google Analytics.",
			"sessions": "session",
			"pageviews": "Vues",
			"pagesvisit": "Vues par visites",
			"bouncerate": "Taux de rebonds",
			"completions": "Accomplissements",
			"noprofile_title": "Aucun profil sélectionné",
			"noprofile": "Il semblerait que vous n'ayez pas encore choisi de profil !\n<br />\nEssayez d'en choisir un depuis l'icône de clé a molette en haut à droite.",
			"settings": {
				"profile": "Profil"
			}
		},
		"he": {
			"name": "Analytics",
			"desc": "Displays various metrics from a Google Analytics profile.",
			"sessions": "sessions",
			"pageviews": "Pageviews",
			"pagesvisit": "Pages/visit",
			"bouncerate": "Bounce Rate",
			"completions": "Completions",
			"noprofile_title": "No profile selected",
			"noprofile": "It doesn't look like you've selected a profile yet!\n<br />\nTry selecting one via the wrench icon at the top right.",
			"settings": {
				"profile": "Profile"
			}
		},
		"hi": {
			"name": "विश्लेषण",
			"desc": "एक गूगल विश्लेषिकी प्रोफाइल से विभिन्न मेट्रिक्स को प्रदर्शित करता है।",
			"sessions": "सत्र",
			"pageviews": "Pageviews",
			"pagesvisit": "पृष्ठ/विज़िट",
			"bouncerate": "ईमेल पते की वैधता दर",
			"completions": "पूर्ण करने",
			"noprofile_title": "No profile selected",
			"noprofile": "It doesn't look like you've selected a profile yet!\n<br />\nTry selecting one via the wrench icon at the top right.",
			"settings": {
				"profile": "Profile"
			}
		},
		"hr": {
			"name": "Analytics",
			"desc": "Prikazuje različita mjerenja sa Google Analytics računa.",
			"sessions": "sesije",
			"pageviews": "Pregledi stranice",
			"pagesvisit": "Stranice po sesiji",
			"bouncerate": "Stopa napuštanja",
			"completions": "Konverzije",
			"noprofile_title": "Nije odabran profil",
			"noprofile": "Izgleda da niste odabrali profil! \n<br /><br />\nPokušajte ga odabrati preko ključ ikonice u gornjem desnom kutu.",
			"settings": {
				"profile": "Profil"
			}
		},
		"id": {
			"name": "Analytics",
			"desc": "Displays various metrics from a Google Analytics profile.",
			"sessions": "sessions",
			"pageviews": "Pageviews",
			"pagesvisit": "Pages/visit",
			"bouncerate": "Bounce Rate",
			"completions": "Completions",
			"noprofile_title": "No profile selected",
			"noprofile": "It doesn't look like you've selected a profile yet!\n<br />\nTry selecting one via the wrench icon at the top right.",
			"settings": {
				"profile": "Profile"
			}
		},
		"it": {
			"name": "Analytics",
			"desc": "Consente di visualizzare i vari parametri di un profilo Google Analytics.",
			"sessions": "sessioni",
			"pageviews": "Visualizzazioni",
			"pagesvisit": "Pagine/visita",
			"bouncerate": "Tasso di rimbalzo",
			"completions": "Completamenti",
			"noprofile_title": "Nessun profilo selezionato",
			"noprofile": "Non sembra ancora selezionato un profilo!\n <br /><br />\nProvare a selezionarne uno tramite l'icona della chiave inglese in alto a destra.",
			"settings": {
				"profile": "Profilo"
			}
		},
		"ja": {
			"name": "アナリティクス",
			"desc": "Google アナリティクスからさまざまな統計情報を表示します。",
			"sessions": "セッション",
			"pageviews": "ページビュー数",
			"pagesvisit": "訪問別ページ数",
			"bouncerate": "直帰率",
			"completions": "コンバージョン",
			"noprofile_title": "プロファイルが選択されていません",
			"noprofile": "プロファイルが選択されていません。\n<br />\n右上にあるレンチアイコンからプロファイルを選択してください。",
			"settings": {
				"profile": "プロフィール"
			}
		},
		"nl": {
			"name": "Analytics",
			"desc": "Laat verschillende statistieken zien van een Google Analytics-profiel.",
			"sessions": "sessies",
			"pageviews": "Pageviews",
			"pagesvisit": "Paginabezoeken",
			"bouncerate": "Bounce Rate",
			"completions": "Opleveringen",
			"noprofile_title": "Geen profiel geselecteerd",
			"noprofile": "Zo te zien heeft u nog geen profiel geselecteerd!\n<br /><br />\nSelecteer er een via het steeksleutel icoon rechtsbovenin.",
			"settings": {
				"profile": "Profiel"
			}
		},
		"pl": {
			"name": "Statystyki",
			"desc": "Wyświetl różne metryki z profilu w usłudze Google Analytics.",
			"sessions": "sesje",
			"pageviews": "Odsłon",
			"pagesvisit": "Strony/odwiedziny",
			"bouncerate": "Współczynnik odrzuceń",
			"completions": "Zakończonych",
			"noprofile_title": "Nie wybrano profilu",
			"noprofile": "Wygląda na to że nie wybrano profilu.\n<br /><br />\nProszę wybrać jeden poprzez ikonę klucza w prawym górnym rogu.",
			"settings": {
				"profile": "Profil"
			}
		},
		"pt-PT": {
			"name": "Analytics",
			"desc": "Exibe várias métricas de um perfil do Google Analytics.",
			"sessions": "sessões",
			"pageviews": "Vistas das paginas",
			"pagesvisit": "Páginas/visita",
			"bouncerate": "Taxa de rejeição",
			"completions": "Conclusões",
			"noprofile_title": "No profile selected",
			"noprofile": "Ele não se parece com você selecionou um perfil ainda! <br /> <br /> \nTente selecionar um através do ícone de chave inglesa no canto superior direito.\n",
			"settings": {
				"profile": "Perfil"
			}
		},
		"ru": {
			"name": "Аналитика",
			"desc": "Отображает различные метрики из профиля Google Analytics.",
			"sessions": "Сеансы",
			"pageviews": "Страницы",
			"pagesvisit": "Страниц/сеанс",
			"bouncerate": "Показатель отказов",
			"completions": "Цели",
			"noprofile_title": "Профиль не выбран",
			"noprofile": "Похоже, вы не выбрали профиль GA!\n<br /><br />\nВыберите профиль, щелкнув кнопку настройки виджета в его правом верхнем углу.",
			"settings": {
				"profile": "Профиль"
			}
		},
		"sr": {
			"name": "Аналитика",
			"desc": "Показује различите вредности са Google Analytics профила.",
			"sessions": "сесије",
			"pageviews": "Број погледа стране",
			"pagesvisit": "Страна/посета",
			"bouncerate": "Одскочни проценат (Bounce Rate)",
			"completions": "Комплеција (Completions)",
			"noprofile_title": "No profile selected",
			"noprofile": "Изгледа да још ниси одабрао профил!\n<br /><br />\nПробај да одабереш један уз помоћ кључа у горњем десном углу.",
			"settings": {
				"profile": "Профил"
			}
		},
		"tr": {
			"name": "Analytics",
			"desc": "Google Analytics profilindeki çeşitli ölçümleri görüntüler.",
			"sessions": "oturumlar",
			"pageviews": "Sayfa görüntüleme",
			"pagesvisit": "Sayfa/ziyaret",
			"bouncerate": "Hemen çıkma oranı",
			"completions": "Tamamlananlar",
			"noprofile_title": "No profile selected",
			"noprofile": "Henüz bir profil seçilmiş gibi görünmüyor!\n<br /><br />\nSağ üstteki ingiliz anahtarı simgesi ile seçmeyi deneyin.",
			"settings": {
				"profile": "Profil"
			}
		},
		"uk": {
			"name": "Аналітика",
			"desc": "Відображення різноманітних показників з профілю Google Analytics.",
			"sessions": "сесії",
			"pageviews": "Переглядів сторінок",
			"pagesvisit": "Сторінки/відвідування",
			"bouncerate": "Bounce Rate",
			"completions": "Completions",
			"noprofile_title": "No profile selected",
			"noprofile": "Схоже, ви ще не вибрали профіль.\n<br /><br />\nОберіть за натиснувши на значок гайкового ключа у верхньому правому кутку.",
			"settings": {
				"profile": "Профіль"
			}
		},
		"zh-CN": {
			"name": "分析",
			"desc": "显示您谷歌分析中的各项指标",
			"sessions": "会话",
			"pageviews": "页面访问量",
			"pagesvisit": "页/访问",
			"bouncerate": "回访率",
			"completions": "达成",
			"noprofile_title": "没有选定配置文件",
			"noprofile": "看起来您未选择一个项目！\n<br /><br />\n请尝试通过右上角的扳手图标选择一个项目。",
			"settings": {
				"profile": "项目档案"
			}
		},
		"zh-TW": {
			"name": "分析報表",
			"desc": "從您個人的Google報表中顯示各種指標",
			"sessions": "連線對話",
			"pageviews": "網頁點閱次數",
			"pagesvisit": "頁面/訪問",
			"bouncerate": "跳出率",
			"completions": "落成",
			"noprofile_title": "未選取設定檔",
			"noprofile": "看起來您仍未選擇一個設定檔!\n<br /><br />\n請試著在右上角的扳手圖示中選擇一個。",
			"settings": {
				"profile": "設定檔"
			}
		}
	},
	"isCompiled": true
});


define("json!w/classroom/manifest.json",{
	"id": 41,
	"sort": 460,
	"tabbed": true,
	"name": "classroom",
	"model": "model",
	"icon": "classroom.png",
	"sizes": [
		"variable"
	],
	"listed": true,
	"views": {
		"default": "view",
		"maximized": "maximized"
	},
	"templates": {
		"desc": "templates/desc.hjs",
		"default": "templates/main.hjs"
	},
	"settings": [
		{
			"type": "text",
			"name": "user",
			"label": "i18n.settings.account",
			"help": "i18n.settings.account_help",
			"placeholder": "i18n.settings.account_placeholder"
		},
		{
			"type": "select",
			"label": "i18n.settings.mode",
			"name": "mode",
			"options": {
				"teacher": "i18n.settings.mode_teacher",
				"student": "i18n.settings.mode_student"
			}
		}
	],
	"strings": {
		"en": {
			"name": "Classroom",
			"desc": "Keep up to date with your Google Classroom assignments and classes",
			"settings": {
				"mode": "Widget Mode",
				"mode_teacher": "Teacher",
				"mode_student": "Student"
			}
		},
		"bn": {
			"name": "Classroom",
			"desc": "Keep up to date with your Google Classroom assignments and classes",
			"settings": {
				"mode": "Widget Mode",
				"mode_teacher": "শিক্ষক",
				"mode_student": "ছাত্র"
			}
		},
		"ca": {
			"name": "Classroom",
			"desc": "Keep up to date with your Google Classroom assignments and classes",
			"settings": {
				"mode": "Widget Mode",
				"mode_teacher": "Teacher",
				"mode_student": "Student"
			}
		},
		"cs": {
			"name": "Classroom",
			"desc": "Mějte aktuální informace o vašich úkolech a kurzech v Učebna Google",
			"settings": {
				"mode": "Režim widgetu",
				"mode_teacher": "Učitel",
				"mode_student": "Student"
			}
		},
		"da": {
			"name": "Classroom",
			"desc": "Keep up to date with your Google Classroom assignments and classes",
			"settings": {
				"mode": "Widget Mode",
				"mode_teacher": "Teacher",
				"mode_student": "Student"
			}
		},
		"de": {
			"name": "Google classroom",
			"desc": "Bleibe auf dem neusten Stand bei Deinen Google Classroom Aufgaben und Klassen",
			"settings": {
				"mode": "Widget Modus",
				"mode_teacher": "Lehrer",
				"mode_student": "Schüler"
			}
		},
		"es": {
			"name": "Salón de Clases",
			"desc": "Keep up to date with your Google Classroom assignments and classes",
			"settings": {
				"mode": "Widget Mode",
				"mode_teacher": "Profesor",
				"mode_student": "Estudiante"
			}
		},
		"fr": {
			"name": "Salle de classe",
			"desc": "Rester à jour avec vos cours Google",
			"settings": {
				"mode": "Mode widget",
				"mode_teacher": "Professeur",
				"mode_student": "Etudiant"
			}
		},
		"he": {
			"name": "Classroom",
			"desc": "Keep up to date with your Google Classroom assignments and classes",
			"settings": {
				"mode": "Widget Mode",
				"mode_teacher": "Teacher",
				"mode_student": "Student"
			}
		},
		"hi": {
			"name": "Classroom",
			"desc": "Keep up to date with your Google Classroom assignments and classes",
			"settings": {
				"mode": "Widget Mode",
				"mode_teacher": "Teacher",
				"mode_student": "Student"
			}
		},
		"hr": {
			"name": "Učionica",
			"desc": "Google Učionica još nije dostupna u Hrvatskoj",
			"settings": {
				"mode": "Mod widgeta",
				"mode_teacher": "Učitelj",
				"mode_student": "Učenik"
			}
		},
		"id": {
			"name": "Classroom",
			"desc": "Keep up to date with your Google Classroom assignments and classes",
			"settings": {
				"mode": "Widget Mode",
				"mode_teacher": "Teacher",
				"mode_student": "Student"
			}
		},
		"it": {
			"name": "Classe",
			"desc": "Tenersi aggiornati con le classi e assegnazioni dell'aula Google",
			"settings": {
				"mode": "Modalità Widget",
				"mode_teacher": "Insegnante",
				"mode_student": "Studente"
			}
		},
		"ja": {
			"name": "Classroom",
			"desc": "Google Classroom での課題と授業を管理できます。",
			"settings": {
				"mode": "ウィジェットモード",
				"mode_teacher": "教師",
				"mode_student": "生徒"
			}
		},
		"nl": {
			"name": "Klaslokaal",
			"desc": "Blijf up to date met uw Google Classroom taken en lessen",
			"settings": {
				"mode": "Widget-modus",
				"mode_teacher": "Leraar",
				"mode_student": "Student"
			}
		},
		"pl": {
			"name": "Classroom",
			"desc": "Bądź na bieżąco z twoimi zadaniami i klasami w Google Classroom",
			"settings": {
				"mode": "Tryb widżetu",
				"mode_teacher": "Nauczyciel",
				"mode_student": "Uczeń"
			}
		},
		"pt-PT": {
			"name": "Classroom",
			"desc": "Keep up to date with your Google Classroom assignments and classes",
			"settings": {
				"mode": "Widget Mode",
				"mode_teacher": "Teacher",
				"mode_student": "Student"
			}
		},
		"ru": {
			"name": "Класс от Google",
			"desc": "Будьте в курсе ваших заданий и занятий на Google Classroom",
			"settings": {
				"mode": "Режим виджета",
				"mode_teacher": "Преподаватель",
				"mode_student": "Студент"
			}
		},
		"sr": {
			"name": "Classroom",
			"desc": "Keep up to date with your Google Classroom assignments and classes",
			"settings": {
				"mode": "Widget Mode",
				"mode_teacher": "Teacher",
				"mode_student": "Student"
			}
		},
		"tr": {
			"name": "Classroom",
			"desc": "Keep up to date with your Google Classroom assignments and classes",
			"settings": {
				"mode": "Widget Mode",
				"mode_teacher": "Teacher",
				"mode_student": "Student"
			}
		},
		"uk": {
			"name": "Classroom",
			"desc": "Keep up to date with your Google Classroom assignments and classes",
			"settings": {
				"mode": "Widget Mode",
				"mode_teacher": "Teacher",
				"mode_student": "Student"
			}
		},
		"zh-CN": {
			"name": "Google课堂",
			"desc": "获取您Google课堂的课程安排和作业信息",
			"settings": {
				"mode": "小部件模式",
				"mode_teacher": "教师",
				"mode_student": "学生"
			}
		},
		"zh-TW": {
			"name": "教室",
			"desc": "保持與Google Classroom作業和課程的更新",
			"settings": {
				"mode": "小工具模式",
				"mode_teacher": "老師",
				"mode_student": "學生"
			}
		}
	},
	"isCompiled": true
});


define("json!w/currency/manifest.json",{
	"id": 21,
	"sort": 270,
	"name": "currency",
	"model": "model",
	"icon": "currency.png",
	"sizes": [
		"small"
	],
	"views": {
		"default": "view"
	},
	"templates": {
		"desc": "templates/desc.hjs",
		"default": "templates/main.hjs"
	},
	"strings": {
		"en": {
			"name": "Currency",
			"desc": "Let's you convert between any two of 169 currencies.",
			"recently_used": "Recently Used"
		},
		"bn": {
			"name": "মুদ্রা",
			"desc": "Let's you convert between any two of 169 currencies.",
			"recently_used": "Recently Used"
		},
		"ca": {
			"name": "Currency",
			"desc": "Let's you convert between any two of 169 currencies.",
			"recently_used": "Recently Used"
		},
		"cs": {
			"name": "Měna",
			"desc": "Umožní přepočet mezi jakýmikoli dvěma ze 169 měn.",
			"recently_used": "Nedávno použité"
		},
		"da": {
			"name": "Currency",
			"desc": "Let's you convert between any two of 169 currencies.",
			"recently_used": "Recently Used"
		},
		"de": {
			"name": "Währung",
			"desc": "Konvertierung zwischen zwei aus 169 Währungen möglich.",
			"recently_used": "Zuletzt benutzt"
		},
		"es": {
			"name": "Monedas",
			"desc": "¡ Convertir entre cualquiera de las dos monedas 169.",
			"recently_used": "Usadas Recientemente"
		},
		"fr": {
			"name": "Devise ",
			"desc": "Vous permet de convertir entre deux des 169 devises.",
			"recently_used": "Utilisé récemment"
		},
		"he": {
			"name": "Currency",
			"desc": "Let's you convert between any two of 169 currencies.",
			"recently_used": "Recently Used"
		},
		"hi": {
			"name": "Currency",
			"desc": "Let's you convert between any two of 169 currencies.",
			"recently_used": "Recently Used"
		},
		"hr": {
			"name": "Valuta",
			"desc": "Pretvori valutu iz valute, dostupno ih je 169.",
			"recently_used": "Nedavno korištene valute"
		},
		"id": {
			"name": "Currency",
			"desc": "Let's you convert between any two of 169 currencies.",
			"recently_used": "Recently Used"
		},
		"it": {
			"name": "Valuta",
			"desc": "Ti permette di convertire tra due di 169 valute.",
			"recently_used": "Usati recentemente"
		},
		"ja": {
			"name": "通貨",
			"desc": "169 の通貨の中から換算することができます。",
			"recently_used": "最近使用した通貨"
		},
		"nl": {
			"name": "Munteenheid",
			"desc": "Laat u converteren tussen elke van de 169 valuta's.",
			"recently_used": "Recent gebruikt"
		},
		"pl": {
			"name": "Waluty",
			"desc": "Wylicza kursy wymiany między dowolnymi dwoma ze 169 dostępnych walut.",
			"recently_used": "Ostatnio używane"
		},
		"pt-PT": {
			"name": "Moeda",
			"desc": "Vamos converter entre quaisquer dois de 169 moedas.",
			"recently_used": "Recently Used"
		},
		"ru": {
			"name": "Валюта",
			"desc": "Позволяет конвертировать значения между 169 валютами.",
			"recently_used": "Недавно использованные"
		},
		"sr": {
			"name": "Валута",
			"desc": "Дозвољава ти конверзију изеђу било које две валуте од 169 понуђених.",
			"recently_used": "Recently Used"
		},
		"tr": {
			"name": "Currency",
			"desc": "Let's you convert between any two of 169 currencies.",
			"recently_used": "Recently Used"
		},
		"uk": {
			"name": "Валюта",
			"desc": "Let's you convert between any two of 169 currencies.",
			"recently_used": "Recently Used"
		},
		"zh-CN": {
			"name": "货币转换",
			"desc": "让您在169种货币之间进行转换。",
			"recently_used": "最近使用"
		},
		"zh-TW": {
			"name": "貨幣",
			"desc": "讓妳在169種貨幣中進行任兩種轉換",
			"recently_used": "最近使用"
		}
	},
	"isCompiled": true
});


define("json!w/dictionary/manifest.json",{
	"id": 46,
	"sort": 50,
	"name": "dictionary",
	"model": "model",
	"icon": "dictionary.png",
	"sizes": [
		"medium"
	],
	"views": {
		"default": "view",
		"settings": "settings"
	},
	"templates": {
		"desc": "templates/desc.hjs",
		"default": "templates/main.hjs",
		"settings": "templates/settings.hjs"
	},
	"strings": {
		"en": {
			"name": "Dictionary",
			"desc": "Quickly look up the definition and synonyms for a word",
			"search_placeholder": "Enter a word or term here",
			"more": "More",
			"less": "Less",
			"synonyms": "Synonyms",
			"antonyms": "Antonyms",
			"web_definitions": "Web definitions",
			"no_definitions": "No definitions found",
			"settings": {
				"page_title": "Settings",
				"save": "Save",
				"title": "Widget Title",
				"title_placeholder": "Enter a widget title or leave blank to hide",
				"lang": "Language"
			}
		},
		"bn": {
			"name": "Dictionary",
			"desc": "Quickly look up the definition and synonyms for a word",
			"search_placeholder": "Enter a word or term here",
			"more": "আরও",
			"less": "Less",
			"synonyms": "Synonyms",
			"antonyms": "Antonyms",
			"web_definitions": "Web definitions",
			"no_definitions": "No definitions found"
		},
		"ca": {
			"name": "Dictionary",
			"desc": "Quickly look up the definition and synonyms for a word",
			"search_placeholder": "Enter a word or term here",
			"more": "Més",
			"less": "Less",
			"synonyms": "Synonyms",
			"antonyms": "Antonyms",
			"web_definitions": "Web definitions",
			"no_definitions": "No definitions found"
		},
		"cs": {
			"name": "Slovník",
			"desc": "Rychle vyhledejte definici nebo synonyma pro slovo",
			"search_placeholder": "Vložte slovo nebo větu",
			"more": "Více",
			"less": "Méně",
			"synonyms": "Synonyma",
			"antonyms": "Antonyma",
			"web_definitions": "Webová definice",
			"no_definitions": "Nebyly nalezeny žádné definice"
		},
		"da": {
			"name": "Dictionary",
			"desc": "Quickly look up the definition and synonyms for a word",
			"search_placeholder": "Enter a word or term here",
			"more": "Mere",
			"less": "Less",
			"synonyms": "Synonyms",
			"antonyms": "Antonyms",
			"web_definitions": "Web definitions",
			"no_definitions": "No definitions found"
		},
		"de": {
			"name": "Wörterbuch",
			"desc": "Definition und Synonyme schnell nachschlagen",
			"search_placeholder": "Geben Sie ein Wort oder Begriff hier ein",
			"more": "Mehr",
			"less": "Weniger",
			"synonyms": "Synonyme",
			"antonyms": "Antonyme",
			"web_definitions": "Internetvorschläge",
			"no_definitions": "Keine Definitionen gefunden"
		},
		"es": {
			"name": "Dictionary",
			"desc": "Quickly look up the definition and synonyms for a word",
			"search_placeholder": "Enter a word or term here",
			"more": "Más",
			"less": "Less",
			"synonyms": "Synonyms",
			"antonyms": "Antonyms",
			"web_definitions": "Web definitions",
			"no_definitions": "No definitions found"
		},
		"fr": {
			"name": "Dictionnaire",
			"desc": "Rechercher rapidement la définition et les synonymes d'un mot",
			"search_placeholder": "Entrez un mot ou une expression ici",
			"more": "Plus",
			"less": "Moins",
			"synonyms": "Synonymes",
			"antonyms": "Antonymes",
			"web_definitions": "Définitions Web",
			"no_definitions": "Pas de définition trouvée"
		},
		"he": {
			"name": "Dictionary",
			"desc": "Quickly look up the definition and synonyms for a word",
			"search_placeholder": "Enter a word or term here",
			"more": "More",
			"less": "Less",
			"synonyms": "Synonyms",
			"antonyms": "Antonyms",
			"web_definitions": "Web definitions",
			"no_definitions": "No definitions found"
		},
		"hi": {
			"name": "Dictionary",
			"desc": "Quickly look up the definition and synonyms for a word",
			"search_placeholder": "Enter a word or term here",
			"more": "अन्य कार्यकलाप",
			"less": "Less",
			"synonyms": "Synonyms",
			"antonyms": "Antonyms",
			"web_definitions": "Web definitions",
			"no_definitions": "No definitions found"
		},
		"hr": {
			"name": "Rječnik",
			"desc": "Brzo pronađi definiciju i sinonime riječi",
			"search_placeholder": "Upiši riječ ili pojam ovdje",
			"more": "Više",
			"less": "Manje",
			"synonyms": "Sinonimi",
			"antonyms": "Antonimi",
			"web_definitions": "Web definicije",
			"no_definitions": "Nema definicije"
		},
		"id": {
			"name": "Dictionary",
			"desc": "Quickly look up the definition and synonyms for a word",
			"search_placeholder": "Enter a word or term here",
			"more": "More",
			"less": "Less",
			"synonyms": "Synonyms",
			"antonyms": "Antonyms",
			"web_definitions": "Web definitions",
			"no_definitions": "No definitions found"
		},
		"it": {
			"name": "Dizionario",
			"desc": "Cerca rapidamente definizione e sinonimi di una parola",
			"search_placeholder": "Inserisci una parola o un termine qui",
			"more": "Altro",
			"less": "Di meno",
			"synonyms": "Sinonimi",
			"antonyms": "Contrari",
			"web_definitions": "Definizioni del Web",
			"no_definitions": "Nessuna definizione trovata"
		},
		"ja": {
			"name": "辞書",
			"desc": "意味や同義語をすばやく検索することができます。",
			"search_placeholder": "単語をここに入力",
			"more": "もっと見る",
			"less": "閉じる",
			"synonyms": "類義語",
			"antonyms": "対義語",
			"web_definitions": "Web 定義",
			"no_definitions": "意味が見つかりませんでした"
		},
		"nl": {
			"name": "Woordenboek",
			"desc": "Zoek snel definities of synoniemen op",
			"search_placeholder": "Typ hier een woord of term",
			"more": "Meer",
			"less": "Minder",
			"synonyms": "Synoniemen",
			"antonyms": "Antoniemen",
			"web_definitions": "Definities op het internet",
			"no_definitions": "Geen definities gevonden"
		},
		"pl": {
			"name": "Słownik",
			"desc": "Szybko wyszukaj definicję i synonimy słowa w słowniku",
			"search_placeholder": "Tu wpisz szukane słowo lub zwrot",
			"more": "Więcej",
			"less": "Mniej",
			"synonyms": "Synonimy",
			"antonyms": "Antonimy",
			"web_definitions": "Definicje z sieci",
			"no_definitions": "Nie znaleziono definicji"
		},
		"pt-PT": {
			"name": "Dictionary",
			"desc": "Quickly look up the definition and synonyms for a word",
			"search_placeholder": "Enter a word or term here",
			"more": "Mais",
			"less": "Less",
			"synonyms": "Synonyms",
			"antonyms": "Antonyms",
			"web_definitions": "Web definitions",
			"no_definitions": "No definitions found"
		},
		"ru": {
			"name": "Словарь",
			"desc": "Быстрый поиск значения и синонимов слова",
			"search_placeholder": "Введите слово или термин",
			"more": "Ещё",
			"less": "Менее",
			"synonyms": "Синонимы",
			"antonyms": "Антонимы",
			"web_definitions": "Определения из интернета",
			"no_definitions": "Значений не найдено"
		},
		"sr": {
			"name": "Dictionary",
			"desc": "Quickly look up the definition and synonyms for a word",
			"search_placeholder": "Enter a word or term here",
			"more": "Још",
			"less": "Less",
			"synonyms": "Synonyms",
			"antonyms": "Antonyms",
			"web_definitions": "Web definitions",
			"no_definitions": "No definitions found"
		},
		"tr": {
			"name": "Dictionary",
			"desc": "Quickly look up the definition and synonyms for a word",
			"search_placeholder": "Enter a word or term here",
			"more": "Daha fazla",
			"less": "Less",
			"synonyms": "Synonyms",
			"antonyms": "Antonyms",
			"web_definitions": "Web definitions",
			"no_definitions": "No definitions found"
		},
		"uk": {
			"name": "Dictionary",
			"desc": "Quickly look up the definition and synonyms for a word",
			"search_placeholder": "Enter a word or term here",
			"more": "Більше",
			"less": "Less",
			"synonyms": "Synonyms",
			"antonyms": "Antonyms",
			"web_definitions": "Web definitions",
			"no_definitions": "No definitions found"
		},
		"zh-CN": {
			"name": "词典",
			"desc": "快速查询单词的定义与同义词",
			"search_placeholder": "请在此输入单词或术语",
			"more": "更多",
			"less": "收起",
			"synonyms": "同义词",
			"antonyms": "反义词",
			"web_definitions": "网络释义",
			"no_definitions": "找不到释义"
		},
		"zh-TW": {
			"name": "字典",
			"desc": "快速查找字詞的定義和同義字詞",
			"search_placeholder": "在這裡輸入單詞或術語",
			"more": "更多",
			"less": "收起",
			"synonyms": "同義字",
			"antonyms": "反義詞",
			"web_definitions": "網上定義",
			"no_definitions": "找不到定義"
		}
	},
	"isCompiled": true
});


define("json!w/drive/manifest.json",{
	"id": 27,
	"sort": 320,
	"name": "drive",
	"model": "model",
	"icon": "drive.png",
	"sizes": [
		"variable"
	],
	"views": {
		"default": "view"
	},
	"templates": {
		"desc": "templates/desc.hjs",
		"default": "templates/main.hjs"
	},
	"settings": [
		{
			"type": "text",
			"name": "title",
			"label": "i18n.settings.title",
			"placeholder": "i18n.settings.title_placeholder"
		},
		{
			"type": "number",
			"name": "files",
			"label": "i18n.settings.files_shown",
			"min": 1,
			"max": 20
		}
	],
	"strings": {
		"en": {
			"name": "Drive",
			"desc": "Displays recently changed files from your Google Drive.",
			"settings": {
				"files_shown": "Number of Files Shown"
			},
			"modified_by": "by",
			"authMessage": "You'll need to give ProductivityTab permission to view files in your Drive before anything can be shown here."
		},
		"bn": {
			"name": "ড্রাইভ",
			"desc": "Displays recently changed files from your Google Drive.",
			"settings": {
				"files_shown": "দেখানো ফাইলের সংখ্যা"
			},
			"modified_by": "কর্তৃক",
			"authMessage": "You'll need to give ProductivityTab permission to view files in your Drive before anything can be shown here."
		},
		"ca": {
			"name": "Drive",
			"desc": "Displays recently changed files from your Google Drive.",
			"settings": {
				"files_shown": "Number of Files Shown"
			},
			"modified_by": "by",
			"authMessage": "You'll need to give ProductivityTab permission to view files in your Drive before anything can be shown here."
		},
		"cs": {
			"name": "Drive",
			"desc": "Zobrazí nedávno změněné soubory z disku Google Drive.",
			"settings": {
				"files_shown": "Počet zobrazených souborů"
			},
			"modified_by": "od",
			"authMessage": "Musíte dát ProductivityTab oprávnění k zobrazení souborů ve vašem Disku Google, než tu bude moct být cokoli zobrazeno."
		},
		"da": {
			"name": "Drev",
			"desc": "Displays recently changed files from your Google Drive.",
			"settings": {
				"files_shown": "Number of Files Shown"
			},
			"modified_by": "by",
			"authMessage": "You'll need to give ProductivityTab permission to view files in your Drive before anything can be shown here."
		},
		"de": {
			"name": "Drive",
			"desc": "Zeigt kürzlich geänderte Dateien aus Google Drive.",
			"settings": {
				"files_shown": "Anzahl der angezeigten Dateien"
			},
			"modified_by": "von",
			"authMessage": "Du musst ProductivityTab dazu berechtigen, auf all deine Dateien zuzugreifen, bevor hier etwas angezeigt werden kann."
		},
		"es": {
			"name": "Disco",
			"desc": "Muestra ha cambiado recientemente los archivos del disco de Google.",
			"settings": {
				"files_shown": "Número de archivos que se muestran"
			},
			"modified_by": "por",
			"authMessage": "You'll need to give ProductivityTab permission to view files in your Drive before anything can be shown here."
		},
		"fr": {
			"name": "Drive",
			"desc": "Affiche les fichiers modifiés récemment dans Google Drive.",
			"settings": {
				"files_shown": "Nombre de fichiers affichés"
			},
			"modified_by": "par",
			"authMessage": "Vous devez donner à ProductivityTab la permission d'accéder aux fichiers de votre Drive pour qu'ils apparaissent ici."
		},
		"he": {
			"name": "Drive",
			"desc": "Displays recently changed files from your Google Drive.",
			"settings": {
				"files_shown": "Number of Files Shown"
			},
			"modified_by": "by",
			"authMessage": "You'll need to give ProductivityTab permission to view files in your Drive before anything can be shown here."
		},
		"hi": {
			"name": "ड्राइव",
			"desc": "Displays recently changed files from your Google Drive.",
			"settings": {
				"files_shown": "Number of Files Shown"
			},
			"modified_by": "by",
			"authMessage": "You'll need to give ProductivityTab permission to view files in your Drive before anything can be shown here."
		},
		"hr": {
			"name": "Disk",
			"desc": "Prikazuje nedavno izmijenjene datoteke na Google Drive-u.",
			"settings": {
				"files_shown": "Broj prikazanih datoteka"
			},
			"modified_by": "od",
			"authMessage": "Morat ćeš dati ProductivityTab-u dozvolu za pregledavanje datoteka na tvojem Disku da bi se datoteke prikazale."
		},
		"id": {
			"name": "Drive",
			"desc": "Displays recently changed files from your Google Drive.",
			"settings": {
				"files_shown": "Number of Files Shown"
			},
			"modified_by": "by",
			"authMessage": "You'll need to give ProductivityTab permission to view files in your Drive before anything can be shown here."
		},
		"it": {
			"name": "Drive",
			"desc": "Visualizza i file recentemente modificati dal tuo Google Drive.",
			"settings": {
				"files_shown": "Numero di file mostrati"
			},
			"modified_by": "di",
			"authMessage": "Per visualizzare i file in Drive devi prima dare l'autorizzazione ad ProductivityTab."
		},
		"ja": {
			"name": "ドライブ",
			"desc": "Google ドライブで最近変更されたファイルを表示します。",
			"settings": {
				"files_shown": "表示するファイルの数"
			},
			"modified_by": "by",
			"authMessage": "Google ドライブからファイルを表示するためには、ProductivityTab に許可を与える必要があります。"
		},
		"nl": {
			"name": "Drive",
			"desc": "Laat onlangs gewijzigde bestanden zien uit uw Google Drive.",
			"settings": {
				"files_shown": "Aantal bestanden weergeven"
			},
			"modified_by": "door",
			"authMessage": "U zult ProductivityTab toestemming moeten geven om bestanden te bekijken in uw Drive voordat hier iets kan worden getoond."
		},
		"pl": {
			"name": "Drive",
			"desc": "Wyświetla niedawno modyfikowane pliki z Twojego Google Drive.",
			"settings": {
				"files_shown": "Liczba Pokazanych Plików"
			},
			"modified_by": "przez",
			"authMessage": "Musisz udzielić ProductivityTab uprawnień do oglądania plików na Twoim Google Drive zanim będzie można tu coś pokazać."
		},
		"pt-PT": {
			"name": "Drive",
			"desc": "Exibe arquivos recentemente alterados de sua movimentação de Google.",
			"settings": {
				"files_shown": "Número de arquivos mostrados"
			},
			"modified_by": "por",
			"authMessage": "You'll need to give ProductivityTab permission to view files in your Drive before anything can be shown here."
		},
		"ru": {
			"name": "Диск",
			"desc": "Отображает последние изменения в вашем Google Диске.",
			"settings": {
				"files_shown": "Количество отображаемых файлов"
			},
			"modified_by": "изменил",
			"authMessage": "Необходимо предоставить для ProductivityTab разрешение на просмотр файлов в вашем Google Диске, чтобы они отобразились здесь."
		},
		"sr": {
			"name": "Drive",
			"desc": "Приказује скоро промењене податке са твог Google Drive-а.",
			"settings": {
				"files_shown": "Број Приказаних Фајлова"
			},
			"modified_by": "од",
			"authMessage": "You'll need to give ProductivityTab permission to view files in your Drive before anything can be shown here."
		},
		"tr": {
			"name": "Drive",
			"desc": "Displays recently changed files from your Google Drive.",
			"settings": {
				"files_shown": "Number of Files Shown"
			},
			"modified_by": "by",
			"authMessage": "You'll need to give ProductivityTab permission to view files in your Drive before anything can be shown here."
		},
		"uk": {
			"name": "Drive",
			"desc": "Displays recently changed files from your Google Drive.",
			"settings": {
				"files_shown": "Number of Files Shown"
			},
			"modified_by": "за",
			"authMessage": "You'll need to give ProductivityTab permission to view files in your Drive before anything can be shown here."
		},
		"zh-CN": {
			"name": "网盘",
			"desc": "显示您Google Drive最近更改的文件。",
			"settings": {
				"files_shown": "显示文件个数"
			},
			"modified_by": "作者",
			"authMessage": "在任何东西能够显示前您需要授权ProductivityTab浏览本地文件。"
		},
		"zh-TW": {
			"name": "Google雲端硬碟",
			"desc": "顯示您的Google Drive中最近更改的檔案",
			"settings": {
				"files_shown": "顯示的檔案個數"
			},
			"modified_by": "由",
			"authMessage": "你必須先給予ProductivityTab存取你的雲端硬碟的權限，這裡才會出現你雲端硬碟中的檔案清單"
		}
	},
	"isCompiled": true
});


define("json!w/gmail/manifest.json",{
	"id": 25,
	"sort": 160,
	"tabbed": true,
	"name": "gmail",
	"model": "model",
	"icon": "gmail.png",
	"sizes": [
		"variable"
	],
	"listed": true,
	"views": {
		"default": "view",
		"maximized": "maximized"
	},
	"templates": {
		"desc": "templates/desc.hjs",
		"default": "templates/main.hjs"
	},
	"settings": [
		{
			"type": "text",
			"name": "user",
			"label": "i18n.settings.account",
			"help": "i18n.settings.account_help",
			"placeholder": "i18n.settings.account_placeholder"
		},
		{
			"type": "number",
			"label": "i18n.settings.height",
			"name": "height",
			"min": 100,
			"max": 800
		},
		{
			"type": "radio",
			"name": "type",
			"label": "i18n.settings.type.name",
			"help": "i18n.settings.type.help",
			"options": {
				"new": "i18n.settings.type.new",
				"old": "i18n.settings.type.old"
			}
		}
	],
	"strings": {
		"en": {
			"name": "Gmail",
			"desc": "Displays your Gmail inbox where you can manage your email.",
			"settings": {
				"type": {
					"name": "Version",
					"new": "Basic",
					"old": "Original",
					"help": "The Basic is the default version which works in all browser versions.\n<br /><br />\nYou can also choose the Original version which proposes more functionality but it can be unstable in some new browser versions and possibly requires the disabling of the new \"SameSite by default cookies\" feature on the chrome://flags web page."
				}
			}
		},
		"bn": {
			"name": "জিমেইল",
			"desc": "Displays your Gmail inbox where you can manage your email."
		},
		"ca": {
			"name": "Gmail",
			"desc": "Displays your Gmail inbox where you can manage your email."
		},
		"cs": {
			"name": "Gmail",
			"desc": "Zobrazí váši Gmail poštovní schránku, kde můžete spravovat váš email."
		},
		"da": {
			"name": "Gmail",
			"desc": "Displays your Gmail inbox where you can manage your email."
		},
		"de": {
			"name": "Gmail",
			"desc": "Zeigt den Google Mail-Posteingang, wo Du Deine e-Mails verwalten kannst."
		},
		"es": {
			"name": "Gmail",
			"desc": "Muestra tu bandeja de entrada Gmail donde usted puede administrar su correo electrónico."
		},
		"fr": {
			"name": "Gmail",
			"desc": "Afficher votre compte Gmail, vous pouvez même gérer vos email "
		},
		"he": {
			"name": "Gmail",
			"desc": "Displays your Gmail inbox where you can manage your email."
		},
		"hi": {
			"name": "जीमेल",
			"desc": "Displays your Gmail inbox where you can manage your email."
		},
		"hr": {
			"name": "Gmail",
			"desc": "Prikazuje tvoj Gmail gdje možeš upravljati svojom poštom."
		},
		"id": {
			"name": "Gmail",
			"desc": "Displays your Gmail inbox where you can manage your email."
		},
		"it": {
			"name": "Gmail",
			"desc": "Visualizza la tua casella di posta Gmail in cui è possibile gestire la posta elettronica."
		},
		"ja": {
			"name": "Gmail",
			"desc": "Gmail の受信トレイを表示します。"
		},
		"nl": {
			"name": "Gmail",
			"desc": "Geeft uw Gmail inbox weer waar u uw email kunt beheren."
		},
		"pl": {
			"name": "Gmail",
			"desc": "Wyświetla skrzynkę odbiorczą Gmail z której możesz zarządzać swoją pocztą elektroniczną."
		},
		"pt-PT": {
			"name": "Gmail",
			"desc": "Exibe a caixa de entrada do Gmail, onde você pode gerenciar seu e-mail."
		},
		"ru": {
			"name": "Gmail",
			"desc": "Отображает входящие письма из Gmail с возможностью управления ими."
		},
		"sr": {
			"name": "Gmail",
			"desc": "Приказује твоје Gmail сандуче где можеш да руководиш твојим емејлом."
		},
		"tr": {
			"name": "Gmail",
			"desc": "Displays your Gmail inbox where you can manage your email."
		},
		"uk": {
			"name": "Gmail",
			"desc": "Displays your Gmail inbox where you can manage your email."
		},
		"zh-CN": {
			"name": "Gmail",
			"desc": "显示您的 Gmail 收件箱，在任何地方您都可以查看您的E-Mail"
		},
		"zh-TW": {
			"name": "Gmail",
			"desc": "顯示你的Gmail收件匣以便管理你的電子郵件"
		}
	},
	"isCompiled": true
});


define("json!w/iframe/manifest.json",{
	"id": 7,
	"sort": 130,
	"tabbed": true,
	"name": "iframe",
	"model": "model",
	"icon": "iframe.png",
	"sizes": [
		"variable"
	],
	"views": {
		"default": "view",
		"maximized": "maximized"
	},
	"templates": {
		"desc": "templates/desc.hjs",
		"default": "templates/main.hjs"
	},
	"settings": [
		{
			"type": "text",
			"name": "url",
			"label": "i18n.settings.url",
			"placeholder": "i18n.settings.url_placeholder"
		},
		{
			"type": "number",
			"label": "i18n.settings.height",
			"name": "height",
			"min": 100,
			"max": 800
		},
		{
			"type": "radio",
			"name": "padding",
			"label": "i18n.settings.padding",
			"options": {
				"true": "i18n.settings.on",
				"false": "i18n.settings.off"
			}
		}
	],
	"strings": {
		"en": {
			"name": "iFrame",
			"desc": "Displays a webpage of your choice within an iframe.",
			"settings": {
				"url": "Frame URL",
				"url_placeholder": "i.e. https://www.google.com/",
				"height": "Frame Height",
				"padding": "Padding"
			}
		},
		"bn": {
			"name": "iFrame",
			"desc": "Displays a webpage of your choice within an iframe.",
			"settings": {
				"url": "ফ্রেম URL",
				"url_placeholder": "উদা. https://www.google.com.bd/",
				"height": "ফ্রেমের উচ্চতা",
				"padding": "Padding"
			}
		},
		"ca": {
			"name": "iFrame",
			"desc": "Displays a webpage of your choice within an iframe.",
			"settings": {
				"url": "Frame URL",
				"url_placeholder": "i.e. https://www.google.com/",
				"height": "Frame Height",
				"padding": "Padding"
			}
		},
		"cs": {
			"name": "iFrame",
			"desc": "Zobrazí webovou stránku dle vašeho výběru v rámci objektu iframe.",
			"settings": {
				"url": "URL rámečku",
				"url_placeholder": "např. https://www.google.com/",
				"height": "Výška rámečku",
				"padding": "Odsazení"
			}
		},
		"da": {
			"name": "iFrame",
			"desc": "Displays a webpage of your choice within an iframe.",
			"settings": {
				"url": "Frame URL",
				"url_placeholder": "i.e. https://www.google.com/",
				"height": "Frame Height",
				"padding": "Padding"
			}
		},
		"de": {
			"name": "iFrame",
			"desc": "Zeigt eine Webseite Deiner Wahl in einem iFrame.",
			"settings": {
				"url": "Frame-URL",
				"url_placeholder": "z.B. https://www.google.com/",
				"height": "Frame Höhe",
				"padding": "Seitlicher Abstand"
			}
		},
		"es": {
			"name": "iFrame",
			"desc": "Muestra una página web de su elección dentro de un iframe.",
			"settings": {
				"url": "Marco URL",
				"url_placeholder": "es decir, https://www.google.com/",
				"height": "Altura del marco",
				"padding": "Relleno"
			}
		},
		"fr": {
			"name": "iFrame",
			"desc": "Afficher une page web de votre choix dans \"iframe\"",
			"settings": {
				"url": "URL de l'image",
				"url_placeholder": "e.g. https://www.google.com/",
				"height": "Hauteur de l'image",
				"padding": "Remplissage"
			}
		},
		"he": {
			"name": "iFrame",
			"desc": "Displays a webpage of your choice within an iframe.",
			"settings": {
				"url": "Frame URL",
				"url_placeholder": "i.e. https://www.google.com/",
				"height": "Frame Height",
				"padding": "Padding"
			}
		},
		"hi": {
			"name": "iFrame",
			"desc": "Displays a webpage of your choice within an iframe.",
			"settings": {
				"url": "Frame URL",
				"url_placeholder": "i.e. https://www.google.com/",
				"height": "Frame Height",
				"padding": "Padding"
			}
		},
		"hr": {
			"name": "iFrame",
			"desc": "Prikazuje web-stranicu tvog izbora u pametnom okviru.",
			"settings": {
				"url": "URL stranice",
				"url_placeholder": "npr. https://www.google.com/",
				"height": "Visina okvira",
				"padding": "Udaljenost od ruba"
			}
		},
		"id": {
			"name": "iFrame",
			"desc": "Displays a webpage of your choice within an iframe.",
			"settings": {
				"url": "Frame URL",
				"url_placeholder": "i.e. https://www.google.com/",
				"height": "Frame Height",
				"padding": "Padding"
			}
		},
		"it": {
			"name": "iFrame",
			"desc": "Consente di visualizzare una pagina web a vostra scelta all'interno di un iframe.",
			"settings": {
				"url": "Frame URL",
				"url_placeholder": "i.e. https://www.google.com/",
				"height": "Altezza frame",
				"padding": "Rientro"
			}
		},
		"ja": {
			"name": "iFrame",
			"desc": "iframe 内で指定した Web ページを表示します。",
			"settings": {
				"url": "フレームの URL",
				"url_placeholder": "例: https://www.google.co.jp/",
				"height": "フレームの高さ",
				"padding": "余白"
			}
		},
		"nl": {
			"name": "iFrame",
			"desc": "Laat een webpagina van uw keuze in een iframe zien.",
			"settings": {
				"url": "Frame URL",
				"url_placeholder": "bijvoorbeeld https://www.google.com/",
				"height": "Framehoogte",
				"padding": "Opvulling"
			}
		},
		"pl": {
			"name": "iFrame",
			"desc": "Wyświetla wybraną stronę internetową w iframe.",
			"settings": {
				"url": "Adres URL ramki",
				"url_placeholder": "np. https://www.google.com/",
				"height": "Wysokość ramki",
				"padding": "Dopełnienie"
			}
		},
		"pt-PT": {
			"name": "iFrame",
			"desc": "Exibe uma página de sua escolha dentro de um iframe.",
			"settings": {
				"url": "URL frame",
				"url_placeholder": "https://www.google.com/",
				"height": "Quadro Altura",
				"padding": "Acolchoamento"
			}
		},
		"ru": {
			"name": "iFrame",
			"desc": "Отображает указанную веб-страницу внутри виджета с помощью iframe.",
			"settings": {
				"url": "URL-адрес для отображения",
				"url_placeholder": "напр. https://www.google.com/",
				"height": "Высота фрейма",
				"padding": "Отступ"
			}
		},
		"sr": {
			"name": "iFrame",
			"desc": "Приказује веб страну твог одабира у оквиру iframe-а.",
			"settings": {
				"url": "Оквир УРЛ",
				"url_placeholder": "прим. https://www.google.com/",
				"height": "Висина Оквира",
				"padding": "Испуна"
			}
		},
		"tr": {
			"name": "iFrame",
			"desc": "Displays a webpage of your choice within an iframe.",
			"settings": {
				"url": "Frame URL",
				"url_placeholder": "örneğin https://www.google.com/",
				"height": "Frame Height",
				"padding": "Padding"
			}
		},
		"uk": {
			"name": "iFrame",
			"desc": "Displays a webpage of your choice within an iframe.",
			"settings": {
				"url": "Frame URL",
				"url_placeholder": "i.e. https://www.google.com/",
				"height": "Frame Height",
				"padding": "Padding"
			}
		},
		"zh-CN": {
			"name": "iFrame",
			"desc": "在您选择的位置用 iframe 嵌入网页。",
			"settings": {
				"url": "框架链接",
				"url_placeholder": "例如 https://www.google.com/",
				"height": "框架高度",
				"padding": "内边框"
			}
		},
		"zh-TW": {
			"name": "iFrame框架",
			"desc": "在 iframe 內顯示一個您選擇的網頁。",
			"settings": {
				"url": "框架位址",
				"url_placeholder": "例如： https://www.google.com/",
				"height": "框架高度",
				"padding": "留邊距離"
			}
		}
	},
	"isCompiled": true
});


define("json!w/keep/manifest.json",{
	"id": 23,
	"sort": 310,
	"tabbed": true,
	"name": "keep",
	"model": "model",
	"icon": "keep.png",
	"sizes": [
		"variable"
	],
	"listed": true,
	"views": {
		"default": "view",
		"maximized": "maximized"
	},
	"templates": {
		"desc": "templates/desc.hjs",
		"default": "templates/main.hjs"
	},
	"settings": [
		{
			"type": "text",
			"name": "user",
			"label": "i18n.settings.account",
			"help": "i18n.settings.account_help",
			"placeholder": "i18n.settings.account_placeholder"
		},
		{
			"type": "number",
			"label": "i18n.settings.height",
			"name": "height",
			"min": 100,
			"max": 800
		}
	],
	"strings": {
		"en": {
			"name": "Keep",
			"desc": "Embeds Google Keep in a widget"
		},
		"bn": {
			"name": "Keep",
			"desc": "উইজেটে গুগল কিপ এম্বেড করুন"
		},
		"ca": {
			"name": "Keep",
			"desc": "Embeds Google Keep in a widget"
		},
		"cs": {
			"name": "Keep",
			"desc": "Vloží Google Keep jako widget"
		},
		"da": {
			"name": "Keep",
			"desc": "Embeds Google Keep in a widget"
		},
		"de": {
			"name": "Keep",
			"desc": "Bettet Google Keep in einem Widget ein"
		},
		"es": {
			"name": "Mantener",
			"desc": "Incrusta Google mantenga en un widget"
		},
		"fr": {
			"name": "Keep",
			"desc": "Intègre Google Keep dans un widget"
		},
		"he": {
			"name": "Keep",
			"desc": "Embeds Google Keep in a widget"
		},
		"hi": {
			"name": "Keep",
			"desc": "Embeds Google Keep in a widget"
		},
		"hr": {
			"name": "Keep",
			"desc": "Ugrađuje Google Keep u widget"
		},
		"id": {
			"name": "Keep",
			"desc": "Embeds Google Keep in a widget"
		},
		"it": {
			"name": "Keep",
			"desc": "Incorpora Google Keep in un widget"
		},
		"ja": {
			"name": "Keep",
			"desc": "Google Keep をウィジェットに埋め込みます。"
		},
		"nl": {
			"name": "Bewaar",
			"desc": "Stopt Google Keep in een widget"
		},
		"pl": {
			"name": "Keep",
			"desc": "Osadza Google Keep w widżecie"
		},
		"pt-PT": {
			"name": "Keep",
			"desc": "Incorpora Google keep em um Widget"
		},
		"ru": {
			"name": "Keep",
			"desc": "Встраивает Google Keep в виджет"
		},
		"sr": {
			"name": "Сачувај",
			"desc": "Убацује Google Keep у додатак"
		},
		"tr": {
			"name": "Keep",
			"desc": "Embeds Google Keep in a widget"
		},
		"uk": {
			"name": "Keep",
			"desc": "Embeds Google Keep in a widget"
		},
		"zh-CN": {
			"name": "Keep",
			"desc": "嵌入Google Keep小部件"
		},
		"zh-TW": {
			"name": "保留",
			"desc": "在小工具嵌入 Google Keep"
		}
	},
	"isCompiled": true
});


define("json!w/news/manifest.json",{
	"id": 4,
	"sort": 30,
	"name": "news",
	"model": "model",
	"icon": "news.png",
	"sizes": [
		"variable"
	],
	"views": {
		"default": "view",
		"settings": "settings",
		"maximized": "maximized"
	},
	"templates": {
		"desc": "templates/desc.hjs",
		"default": "templates/main.hjs",
		"settings": "templates/settings.hjs",
		"maximized": "templates/maximized.hjs"
	},
	"strings": {
		"en": {
			"name": "News",
			"desc": "Displays the current top news by category and edition.",
			"all_stories": "All",
			"settings": {
				"page_title": "Settings",
				"save": "Save",
				"title": "Widget Title",
				"title_placeholder": "Enter a widget title or leave blank to hide",
				"articles": "Articles Shown",
				"edition": "Edition",
				"language": "Language",
				"source": "Source",
				"default_topic": "Default Topic"
			}
		},
		"bn": {
			"name": "সংবাদ",
			"desc": "Displays the current top news by category and edition.",
			"all_stories": "সব",
			"settings": {
				"page_title": "সেটিংস",
				"save": "সংরক্ষণ",
				"title": "উইজেটের শিরোনাম",
				"title_placeholder": "উইজেটের একটি শিরোনাম লিখুন বা আড়াল করতে ফাঁকা রেখে দিন",
				"articles": "নিবন্ধ দেখানো",
				"edition": "সংস্করণ",
				"default_topic": "পূর্ব-নির্ধারিত বিষয়"
			}
		},
		"ca": {
			"name": "News",
			"desc": "Displays the current top news by category and edition.",
			"all_stories": "All",
			"settings": {
				"page_title": "Configuració",
				"save": "Save",
				"title": "Widget Title",
				"title_placeholder": "Enter a widget title or leave blank to hide",
				"articles": "Articles Shown",
				"edition": "Edition",
				"default_topic": "Default Topic"
			}
		},
		"cs": {
			"name": "Zprávy",
			"desc": "Zobrazí aktuální novinky podle kategorie a vydání.",
			"all_stories": "Vše",
			"settings": {
				"page_title": "Nastavení",
				"save": "Ulož",
				"title": "Název widgetu",
				"title_placeholder": "Zadejte název widgetu a nebo nezadávejte nic. V takovém případě se název nezobrazí.",
				"articles": "Zobrazené články",
				"edition": "Edice",
				"default_topic": "Výchozí téma"
			}
		},
		"da": {
			"name": "Nyheder",
			"desc": "Displays the current top news by category and edition.",
			"all_stories": "Alle",
			"settings": {
				"page_title": "Indstillinger",
				"save": "Gem",
				"title": "Widget titel",
				"title_placeholder": "Indtast en widget titel. Indtastes ingen titel, skjules titlen",
				"articles": "Articles Shown",
				"edition": "Edition",
				"default_topic": "Default Topic"
			}
		},
		"de": {
			"name": "Nachrichten",
			"desc": "Zeigt aktuelle Top-News nach Kategorie und Version.",
			"all_stories": "Alle",
			"settings": {
				"page_title": "Einstellungen",
				"save": "Speichern",
				"title": "Widget Titel",
				"title_placeholder": "Widget-Bezeichnung eingeben oder leer lassen um zu verbergen",
				"articles": "Artikel gezeigt",
				"edition": "Edition",
				"default_topic": "Standard Thema"
			}
		},
		"es": {
			"name": "News",
			"desc": "Muestra la actualidad superior de categoría y edición.",
			"all_stories": "Todos",
			"settings": {
				"page_title": "Ajustes",
				"save": "Guardar",
				"title": "Título de widget",
				"title_placeholder": "Introduzca el título de un widget o deje en blanco para ocultar",
				"articles": "Artículos que se muestra",
				"edition": "Edición",
				"default_topic": "Default Topic"
			}
		},
		"fr": {
			"name": "News",
			"desc": "Afficher les top news récente par catégorie et édition ",
			"all_stories": "Tous",
			"settings": {
				"page_title": "Paramètres",
				"save": "Enregistrer",
				"title": "Nom du widget",
				"title_placeholder": "Donnez un nom au widget ou laissez-le blanc pour le cacher",
				"articles": "Affiché les articles",
				"edition": "Édition",
				"default_topic": "Sujet par défaut"
			}
		},
		"he": {
			"name": "News",
			"desc": "Displays the current top news by category and edition.",
			"all_stories": "All",
			"settings": {
				"page_title": "Settings",
				"save": "Save",
				"title": "Widget Title",
				"title_placeholder": "Enter a widget title or leave blank to hide",
				"articles": "Articles Shown",
				"edition": "Edition",
				"default_topic": "Default Topic"
			}
		},
		"hi": {
			"name": "समाचार",
			"desc": "Displays the current top news by category and edition.",
			"all_stories": "सभी",
			"settings": {
				"page_title": "सेटिंग्स",
				"save": "सेव करें",
				"title": "Widget Title",
				"title_placeholder": "Enter a widget title or leave blank to hide",
				"articles": "Articles Shown",
				"edition": "Edition",
				"default_topic": "Default Topic"
			}
		},
		"hr": {
			"name": "Vijesti",
			"desc": "Prikazuje trenutne vijesti po kategoriji i izdanju.",
			"all_stories": "Sve",
			"settings": {
				"page_title": "Postavke",
				"save": "Spremi",
				"title": "Naslov widgeta",
				"title_placeholder": "Unesi naslov widgeta ili ostavi prazno za skrivanje",
				"articles": "Broj prikazanih članaka",
				"edition": "Izdanje",
				"default_topic": "Zadana tema"
			}
		},
		"id": {
			"name": "News",
			"desc": "Displays the current top news by category and edition.",
			"all_stories": "All",
			"settings": {
				"page_title": "Settings",
				"save": "Save",
				"title": "Widget Title",
				"title_placeholder": "Enter a widget title or leave blank to hide",
				"articles": "Articles Shown",
				"edition": "Edition",
				"default_topic": "Default Topic"
			}
		},
		"it": {
			"name": "Notizie",
			"desc": "Visualizza le attuali top news per categoria ed edizione.",
			"all_stories": "Tutti",
			"settings": {
				"page_title": "Impostazioni",
				"save": "Salva",
				"title": "Titolo del Widget",
				"title_placeholder": "Immetti un nome per il widget o lascialo bianco per nascondere",
				"articles": "Articoli mostrati",
				"edition": "Edizione",
				"default_topic": "Tema standard"
			}
		},
		"ja": {
			"name": "ニュース",
			"desc": "指定した言語、カテゴリの現在のトップニュースを表示します。",
			"all_stories": "すべて",
			"settings": {
				"page_title": "設定",
				"save": "保存",
				"title": "ウィジェットのタイトル",
				"title_placeholder": "ウィジェットのタイトルを入力、または空欄にして非表示",
				"articles": "表示する記事数",
				"edition": "言語",
				"default_topic": "デフォルトのトピック"
			}
		},
		"nl": {
			"name": "Nieuws",
			"desc": "Geeft het huidige top nieuws weer per categorie en editie.",
			"all_stories": "Alle",
			"settings": {
				"page_title": "Instellingen",
				"save": "Opslaan",
				"title": "Widget titel",
				"title_placeholder": "Voer een titel in of laat leeg om hem te verbergen",
				"articles": "Weergegeven artikelen",
				"edition": "Editie",
				"default_topic": "Standaardonderwerp"
			}
		},
		"pl": {
			"name": "Wiadomości",
			"desc": "Wyświetla aktualne najpopularniejsze wiadomości, wg kategorii i wydania.",
			"all_stories": "Wszystie",
			"settings": {
				"page_title": "Ustawienia",
				"save": "Zapisz",
				"title": "Tytuł widżetu",
				"title_placeholder": "Wprowadź tytuł widżetu lub pozostaw puste pole aby ukryć",
				"articles": "Liczba Pokazanych Artykułów",
				"edition": "Wydanie",
				"default_topic": "Domyślna Kategoria"
			}
		},
		"pt-PT": {
			"name": "Noticias",
			"desc": "Exibe o atual top news por categoria e edição.",
			"all_stories": "Tudo\n",
			"settings": {
				"page_title": "Opções",
				"save": "Gravar",
				"title": "Título do Widget",
				"title_placeholder": "Insira um widget de título ou deixar em branco para ocultar",
				"articles": "Artigos mostrados",
				"edition": "Edição",
				"default_topic": "Default Topic"
			}
		},
		"ru": {
			"name": "Новости",
			"desc": "Отображает актуальные новости по категории и изданию.",
			"all_stories": "Все",
			"settings": {
				"page_title": "Настройки",
				"save": "Сохранить",
				"title": "Заголовок виджета",
				"title_placeholder": "Введите заголовок виджета или оставьте поле пустым чтобы скрыть заголовок",
				"articles": "Количество отображаемых статей",
				"edition": "Издание",
				"default_topic": "Тема по умолчанию"
			}
		},
		"sr": {
			"name": "Вести",
			"desc": "Приказује тренутно најчитаније вести по категорији и издању.",
			"all_stories": "Све",
			"settings": {
				"page_title": "Подешавања",
				"save": "Сачувај",
				"title": "Назив додатка",
				"title_placeholder": "Унеси назив додатка или остави празно",
				"articles": "Приказани новински чланци",
				"edition": "Izdaǌe",
				"default_topic": "Default Topic"
			}
		},
		"tr": {
			"name": "Haberler",
			"desc": "Displays the current top news by category and edition.",
			"all_stories": "Tümü",
			"settings": {
				"page_title": "Ayarlar",
				"save": "Kaydet",
				"title": "Widget başlığı",
				"title_placeholder": "Widget için bir başlık girin veya gizlemek için boş bırakın",
				"articles": "Gösterilecek Makale",
				"edition": "Basın",
				"default_topic": "Default Topic"
			}
		},
		"uk": {
			"name": "Новини",
			"desc": "Displays the current top news by category and edition.",
			"all_stories": "All",
			"settings": {
				"page_title": "Налаштування",
				"save": "Зберегти",
				"title": "Widget Title",
				"title_placeholder": "Enter a widget title or leave blank to hide",
				"articles": "Articles Shown",
				"edition": "Edition",
				"default_topic": "Default Topic"
			}
		},
		"zh-CN": {
			"name": "新闻",
			"desc": "按类别和国家版本来显示当前的头条新闻。",
			"all_stories": "全部",
			"settings": {
				"page_title": "设置",
				"save": "保存",
				"title": "小部件标题",
				"title_placeholder": "输入小部件窗口标题或留空隐藏",
				"articles": "显示数量",
				"edition": "国家版本",
				"default_topic": "默认栏目"
			}
		},
		"zh-TW": {
			"name": "新聞",
			"desc": "按類別和版本顯示目前的頭條新聞。",
			"all_stories": "全部",
			"settings": {
				"page_title": "設定",
				"save": "儲存",
				"title": "小工具標題",
				"title_placeholder": "輸入小工具標題，保留空白的話標題列就不會顯示",
				"articles": "文章顯示",
				"edition": "版本",
				"default_topic": "預設主題"
			}
		}
	},
	"isCompiled": true
});


define("json!w/quicklinks/manifest.json",{
	"id": 53,
	"sort": 390,
	"name": "quicklinks",
	"model": "model",
	"icon": "quicklinks.png",
	"sizes": [
		"variable"
	],
	"views": {
		"default": "view"
	},
	"templates": {
		"desc": "templates/desc.hjs",
		"default": "templates/main.hjs"
	},
	"settings": [
		{
			"type": "text",
			"name": "title",
			"label": "i18n.settings.title",
			"placeholder": "i18n.settings.title_placeholder"
		},
		{
			"type": "radio",
			"name": "view",
			"label": "i18n.settings.view",
			"options": {
				"icons": "i18n.settings.view_options.icons",
				"list": "i18n.settings.view_options.list"
			}
		}
	],
	"strings": {
		"en": {
			"name": "Quick Links",
			"desc": "Displays popular sites",
			"settings": {
				"view": "View",
				"view_options": {
					"list": "List",
					"icons": "Icons"
				}
			}
		}
	},
	"isCompiled": true
});


define("json!w/recentlyclosed/manifest.json",{
	"id": 32,
	"sort": 190,
	"name": "recentlyclosed",
	"model": "model",
	"icon": "recentlyclosed.png",
	"sizes": [
		"variable"
	],
	"browser_permissions": [
		"tabs"
	],
	"views": {
		"default": "view"
	},
	"templates": {
		"desc": "templates/desc.hjs",
		"default": "templates/main.hjs"
	},
	"settings": [
		{
			"type": "text",
			"name": "title",
			"label": "i18n.settings.title",
			"placeholder": "i18n.settings.title_placeholder"
		},
		{
			"type": "number",
			"label": "i18n.settings.tabs",
			"name": "tabs",
			"min": 1,
			"max": 20
		},
		{
			"type": "radio",
			"name": "target",
			"label": "i18n.settings.open",
			"options": {
				"_self": "i18n.settings.open_options.current",
				"_blank": "i18n.settings.open_options.blank"
			}
		}
	],
	"strings": {
		"en": {
			"name": "Recently Closed",
			"desc": "Shows your recently closed tabs",
			"settings": {
				"tabs": "Tabs Shown",
				"open": "Open tabs in"
			},
			"more": "more"
		},
		"bn": {
			"name": "সম্প্রতি বন্ধ হয়েছে",
			"desc": "আপনার সম্প্রতি বন্ধ হওয়া ট্যাব প্রদর্শন করে।",
			"settings": {
				"tabs": "ট্যাব প্রদর্শিত",
				"open": "এতে ট্যাব খুলুন"
			},
			"more": "আরও"
		},
		"ca": {
			"name": "Recently Closed",
			"desc": "Shows your recently closed tabs",
			"settings": {
				"tabs": "Tabs Shown",
				"open": "Open tabs in"
			},
			"more": "more"
		},
		"cs": {
			"name": "Nedávno zavřené",
			"desc": "Zobrazuje nedávno zavřené záložky",
			"settings": {
				"tabs": "Zobrazené záložky",
				"open": "Otevřené karty v"
			},
			"more": "více"
		},
		"da": {
			"name": "Recently Closed",
			"desc": "Shows your recently closed tabs",
			"settings": {
				"tabs": "Tabs Shown",
				"open": "Open tabs in"
			},
			"more": "more"
		},
		"de": {
			"name": "Zuletzt geschlossen",
			"desc": "Zeigt kürzlich geschlossene Tabs",
			"settings": {
				"tabs": "Registerkarten angezeigt",
				"open": "Tabs öffnen in"
			},
			"more": "mehr"
		},
		"es": {
			"name": "Recientemente cerrados",
			"desc": "Muestra tus pestañas cerradas recientemente",
			"settings": {
				"tabs": "Lengüetas que se muestra",
				"open": "Pestañas abiertas en"
			},
			"more": "more"
		},
		"fr": {
			"name": "Récemment fermés",
			"desc": "Afficher vos onglets récemment fermés.",
			"settings": {
				"tabs": "Onglets affichés",
				"open": "Ouvrir onglets dans"
			},
			"more": "plus"
		},
		"he": {
			"name": "Recently Closed",
			"desc": "Shows your recently closed tabs",
			"settings": {
				"tabs": "Tabs Shown",
				"open": "Open tabs in"
			},
			"more": "more"
		},
		"hi": {
			"name": "Recently Closed",
			"desc": "Shows your recently closed tabs",
			"settings": {
				"tabs": "Tabs Shown",
				"open": "Open tabs in"
			},
			"more": "more"
		},
		"hr": {
			"name": "Nedavno zatvoreno",
			"desc": "Prikazuje nedavno zatvorene kartice",
			"settings": {
				"tabs": "Broj prikazanih kartica",
				"open": "Otvori kartice u"
			},
			"more": "više"
		},
		"id": {
			"name": "Recently Closed",
			"desc": "Shows your recently closed tabs",
			"settings": {
				"tabs": "Tabs Shown",
				"open": "Open tabs in"
			},
			"more": "more"
		},
		"it": {
			"name": "Chiuso di recente",
			"desc": "Mostra i tabs chiusi di recente",
			"settings": {
				"tabs": "Schede mostrate",
				"open": "Apri tabs in"
			},
			"more": "altro"
		},
		"ja": {
			"name": "最近閉じたタブ",
			"desc": "最近閉じたタブを表示します。",
			"settings": {
				"tabs": "表示するタブの数",
				"open": "タブの開き方"
			},
			"more": "個のタブ"
		},
		"nl": {
			"name": "Onlangs gesloten",
			"desc": "Toont uw onlangs gesloten tabbladen",
			"settings": {
				"tabs": "Weergegeven tabbladen",
				"open": "Open tabbladen in"
			},
			"more": "meer"
		},
		"pl": {
			"name": "Niedawno zamknięte",
			"desc": "Pokazuje ostatnio zamknięte zakładki",
			"settings": {
				"tabs": "Liczba Pokazanych Zakładek",
				"open": "Otwieraj zakładki w"
			},
			"more": "więcej"
		},
		"pt-PT": {
			"name": "Recentemente Fechado",
			"desc": "Mostra suas abas recentemente fechadas",
			"settings": {
				"tabs": "Tabs Mostrado",
				"open": "Abas abertas em"
			},
			"more": "more"
		},
		"ru": {
			"name": "Недавно закрытые вкладки",
			"desc": "Отображает список недавно закрытых вкладок",
			"settings": {
				"tabs": "Количество отображаемых вкладок",
				"open": "Открывать во вкладке"
			},
			"more": "еще"
		},
		"sr": {
			"name": "Скоро затворено",
			"desc": "Приказује твоје недавно затворене картице",
			"settings": {
				"tabs": "Приказане Картице",
				"open": "Отвори картице у"
			},
			"more": "more"
		},
		"tr": {
			"name": "En Son Kapatılan",
			"desc": "En son kapatılan sekmeleri gösterir",
			"settings": {
				"tabs": "Gösterilecek Sekme",
				"open": "Sekmeleri şurada aç"
			},
			"more": "more"
		},
		"uk": {
			"name": "Recently Closed",
			"desc": "Shows your recently closed tabs",
			"settings": {
				"tabs": "Tabs Shown",
				"open": "Open tabs in"
			},
			"more": "more"
		},
		"zh-CN": {
			"name": "最近关闭",
			"desc": "显示您最近关闭的标签页",
			"settings": {
				"tabs": "显示选项卡",
				"open": "选项卡打开方式"
			},
			"more": "更多"
		},
		"zh-TW": {
			"name": "最近關閉",
			"desc": "顯示您最近關閉的標籤頁",
			"settings": {
				"tabs": "顯示的標籤頁",
				"open": "打開標籤頁於"
			},
			"more": "更多"
		}
	},
	"isCompiled": true
});


define("json!w/rss/manifest.json",{
	"id": 8,
	"sort": 70,
	"name": "rss",
	"model": "model",
	"icon": "rss.png",
	"sizes": [
		"variable"
	],
	"views": {
		"default": "view",
		"settings": "settings",
		"maximized": "maximized"
	},
	"templates": {
		"desc": "templates/desc.hjs",
		"default": "templates/main.hjs",
		"settings": "templates/settings.hjs",
		"maximized": "templates/maximized.hjs"
	},
	"strings": {
		"en": {
			"name": "RSS",
			"desc": "Displays items from a RSS or Atom feed with optional images.",
			"settings": {
				"page_title": "Settings",
				"save": "Save",
				"title": "Widget Title",
				"title_placeholder": "Enter a widget title or leave blank to hide",
				"link": "Title Link",
				"link_placeholder": "Enter a link for the widget title",
				"feeds": "Feeds",
				"feeds_help": "Click any feed to edit it",
				"feeds_placeholder": "Enter a feed URL and press Enter to add",
				"feeds_pro_only": "Only Pro users can have multiple feeds in each widget. Get Pro in the settings.",
				"feed_name_placeholder": "Feed name",
				"feed_url_placeholder": "Feed URL",
				"articles": "Articles Shown",
				"cache_time": "Min Cache Time (mins)"
			},
			"by": "By",
			"all_articles": "All articles",
			"feed_error": "An error occurred while trying to fetch the feed at: %s.\r\nPlease double check the URL and/or modify the widget settings."
		},
		"bn": {
			"name": "RSS",
			"desc": "Displays items from a RSS or Atom feed with optional images.",
			"settings": {
				"page_title": "সেটিংস",
				"save": "সংরক্ষণ",
				"title": "উইজেটের শিরোনাম",
				"title_placeholder": "উইজেটের একটি শিরোনাম লিখুন বা আড়াল করতে ফাঁকা রেখে দিন",
				"link": "Title Link",
				"link_placeholder": "Enter a link for the widget title",
				"feeds": "ফীড",
				"feeds_help": "Click any feed to edit it",
				"feeds_placeholder": "Enter a feed URL and press Enter to add",
				"feeds_pro_only": "Only Pro users can have multiple feeds in each widget. Get Pro in the settings.",
				"feed_name_placeholder": "Feed name",
				"feed_url_placeholder": "Feed URL",
				"articles": "নিবন্ধ দেখানো"
			},
			"by": "কর্তৃক",
			"all_articles": "সকল নিবন্ধ",
			"feed_error": "An error occurred while trying to fetch the feed at: %s.\r\nPlease double check the URL and/or modify the widget settings."
		},
		"ca": {
			"name": "RSS",
			"desc": "Displays items from a RSS or Atom feed with optional images.",
			"settings": {
				"page_title": "Configuració",
				"save": "Save",
				"title": "Widget Title",
				"title_placeholder": "Enter a widget title or leave blank to hide",
				"link": "Title Link",
				"link_placeholder": "Enter a link for the widget title",
				"feeds": "Feeds",
				"feeds_help": "Click any feed to edit it",
				"feeds_placeholder": "Enter a feed URL and press Enter to add",
				"feeds_pro_only": "Only Pro users can have multiple feeds in each widget. Get Pro in the settings.",
				"feed_name_placeholder": "Feed name",
				"feed_url_placeholder": "Feed URL",
				"articles": "Articles Shown"
			},
			"by": "By",
			"all_articles": "All articles",
			"feed_error": "An error occurred while trying to fetch the feed at: %s.\r\nPlease double check the URL and/or modify the widget settings."
		},
		"cs": {
			"name": "RSS",
			"desc": "Zobrazí položky z RSS nebo Atom zdroje s volitelnými obrázky.",
			"settings": {
				"page_title": "Nastavení",
				"save": "Ulož",
				"title": "Název widgetu",
				"title_placeholder": "Zadejte název widgetu a nebo nezadávejte nic. V takovém případě se název nezobrazí.",
				"link": "Odkaz titulku",
				"link_placeholder": "Zadejte odkaz pro název widgetu",
				"feeds": "Kanály",
				"feeds_help": "Kliknětě na zdroj pro úpravu",
				"feeds_placeholder": "Zadejte adresu URL a stiskněte Enter pro přidání",
				"feeds_pro_only": "Pouze uživatelé Pro verze můžou mít více RSS odběrů v jenom widgetu. Pro získání Pro verze běžte do nastavení.",
				"feed_name_placeholder": "Jméno zdroje",
				"feed_url_placeholder": "URL zdroje",
				"articles": "Zobrazené články"
			},
			"by": "Od",
			"all_articles": "Všechny příspěvky",
			"feed_error": "Došlo k chybě při pokusu o načtení kanálu %s. Prosím zkontrolujte URL nebo upravte nastavení widgetu."
		},
		"da": {
			"name": "RSS",
			"desc": "Displays items from a RSS or Atom feed with optional images.",
			"settings": {
				"page_title": "Indstillinger",
				"save": "Gem",
				"title": "Widget titel",
				"title_placeholder": "Indtast en widget titel. Indtastes ingen titel, skjules titlen",
				"link": "Title Link",
				"link_placeholder": "Enter a link for the widget title",
				"feeds": "Feeds",
				"feeds_help": "Click any feed to edit it",
				"feeds_placeholder": "Enter a feed URL and press Enter to add",
				"feeds_pro_only": "Only Pro users can have multiple feeds in each widget. Get Pro in the settings.",
				"feed_name_placeholder": "Feed name",
				"feed_url_placeholder": "Feed URL",
				"articles": "Articles Shown"
			},
			"by": "Af",
			"all_articles": "All articles",
			"feed_error": "An error occurred while trying to fetch the feed at: %s.\r\nPlease double check the URL and/or modify the widget settings."
		},
		"de": {
			"name": "RSS",
			"desc": "Zeigt Elemente aus RSS- oder Atom-Feeds mit optionalen Bildern.",
			"settings": {
				"page_title": "Einstellungen",
				"save": "Speichern",
				"title": "Widget Titel",
				"title_placeholder": "Widget-Bezeichnung eingeben oder leer lassen um zu verbergen",
				"link": "Titellink",
				"link_placeholder": "Geben Sie einen Link für den Widget-Titel ein",
				"feeds": "Feeds",
				"feeds_help": "Klicken Sie auf einen beliebigen Feed um ihn zu bearbeiten",
				"feeds_placeholder": "Füge eine URL ein und bestätige mit der Eingabetaste",
				"feeds_pro_only": "Nur Pro User können mehrere Feeds in jedem einzelnen Widget haben. Die Pro-Version kannst du in den Einstellungen erwerben.",
				"feed_name_placeholder": "Feed Name",
				"feed_url_placeholder": "Feed-URL",
				"articles": "Artikel gezeigt"
			},
			"by": "Von",
			"all_articles": "Alle Artikel",
			"feed_error": "Es ist ein Fehler aufgetreten während veruscht wurde, den Feed zu laden: %s'. Bitte überprüfe die URL und/oder passe die Widget-Einstellungen an."
		},
		"es": {
			"name": "RSS",
			"desc": "Muestra los elementos de un RSS o Atom feed con imágenes opcionales.",
			"settings": {
				"page_title": "Ajustes",
				"save": "Guardar",
				"title": "Título de widget",
				"title_placeholder": "Introduzca el título de un widget o deje en blanco para ocultar",
				"link": "Título enlace",
				"link_placeholder": "Introduzca un enlace para el título del widget",
				"feeds": "Entradas",
				"feeds_help": "Click any feed to edit it",
				"feeds_placeholder": "Enter a feed URL and press Enter to add",
				"feeds_pro_only": "Only Pro users can have multiple feeds in each widget. Get Pro in the settings.",
				"feed_name_placeholder": "Feed name",
				"feed_url_placeholder": "Feed URL",
				"articles": "Artículos que se muestra"
			},
			"by": "por",
			"all_articles": "Todos los artículos",
			"feed_error": "Ha producido un error al tratar de buscar el alimento en: %s. Por favor verifique la dirección URL o modificar la configuración del widget."
		},
		"fr": {
			"name": "RSS",
			"desc": "Affiche le flux RSS ou Atom avec des images optionnels.",
			"settings": {
				"page_title": "Paramètres",
				"save": "Enregistrer",
				"title": "Nom du widget",
				"title_placeholder": "Donnez un nom au widget ou laissez-le blanc pour le cacher",
				"link": "Nom du lien",
				"link_placeholder": "Entrez un lien pour le nom du widget",
				"feeds": "Flux",
				"feeds_help": "Cliquez sur n'importe quel flux pour le modifier",
				"feeds_placeholder": "Entrez l'URL d'un flux et appuyez sur Entrée pour ajouter",
				"feeds_pro_only": "Seulement les utilisateurs Pro peuvent avoir plusieurs flux dans chaque widget. Obtenez Pro dans les paramètres.",
				"feed_name_placeholder": "Nom du flux",
				"feed_url_placeholder": "URL du flux",
				"articles": "Articles affichés"
			},
			"by": "par",
			"all_articles": "Tous les articles",
			"feed_error": "Une erreur s'est produite en essayant d'aller chercher de le flux à: %s. S'il vous plaît vérifier l'URL et/ou modifier les paramètres du widget."
		},
		"he": {
			"name": "RSS",
			"desc": "Displays items from a RSS or Atom feed with optional images.",
			"settings": {
				"page_title": "Settings",
				"save": "Save",
				"title": "Widget Title",
				"title_placeholder": "Enter a widget title or leave blank to hide",
				"link": "Title Link",
				"link_placeholder": "Enter a link for the widget title",
				"feeds": "Feeds",
				"feeds_help": "Click any feed to edit it",
				"feeds_placeholder": "Enter a feed URL and press Enter to add",
				"feeds_pro_only": "Only Pro users can have multiple feeds in each widget. Get Pro in the settings.",
				"feed_name_placeholder": "Feed name",
				"feed_url_placeholder": "Feed URL",
				"articles": "Articles Shown"
			},
			"by": "By",
			"all_articles": "All articles",
			"feed_error": "An error occurred while trying to fetch the feed at: %s.\r\nPlease double check the URL and/or modify the widget settings."
		},
		"hi": {
			"name": "RSS",
			"desc": "Displays items from a RSS or Atom feed with optional images.",
			"settings": {
				"page_title": "सेटिंग्स",
				"save": "सेव करें",
				"title": "Widget Title",
				"title_placeholder": "Enter a widget title or leave blank to hide",
				"link": "Title Link",
				"link_placeholder": "Enter a link for the widget title",
				"feeds": "Feeds",
				"feeds_help": "Click any feed to edit it",
				"feeds_placeholder": "Enter a feed URL and press Enter to add",
				"feeds_pro_only": "Only Pro users can have multiple feeds in each widget. Get Pro in the settings.",
				"feed_name_placeholder": "Feed name",
				"feed_url_placeholder": "Feed URL",
				"articles": "Articles Shown"
			},
			"by": "द्वारा",
			"all_articles": "All articles",
			"feed_error": "An error occurred while trying to fetch the feed at: %s.\r\nPlease double check the URL and/or modify the widget settings."
		},
		"hr": {
			"name": "RSS",
			"desc": "Prikazuje stavke iz RSS-a ili Atom feed-a sa slikama.",
			"settings": {
				"page_title": "Postavke",
				"save": "Spremi",
				"title": "Naslov widgeta",
				"title_placeholder": "Unesi naslov widgeta ili ostavi prazno za skrivanje",
				"link": "Link naslova",
				"link_placeholder": "Unesi link za naslov widgeta",
				"feeds": "Feedovi",
				"feeds_help": "Klinki na feed da bi ga uredio",
				"feeds_placeholder": "Unesi URL feed-a i pritisni Enter za dodavanje",
				"feeds_pro_only": "Isključivo Pro korisnici mogu imati više feed-ova u widgetu. Kupi Pro u postavkama.",
				"feed_name_placeholder": "Naziv feed-a",
				"feed_url_placeholder": "URL feed-a",
				"articles": "Broj prikazanih članaka"
			},
			"by": "Autor",
			"all_articles": "Svi članci",
			"feed_error": "Došlo je do pogreške prilikom dohvaćanja feed-a na: %s.\nMolimo provjeri URL te ga promjeni u postavkama."
		},
		"id": {
			"name": "RSS",
			"desc": "Displays items from a RSS or Atom feed with optional images.",
			"settings": {
				"page_title": "Settings",
				"save": "Save",
				"title": "Widget Title",
				"title_placeholder": "Enter a widget title or leave blank to hide",
				"link": "Title Link",
				"link_placeholder": "Enter a link for the widget title",
				"feeds": "Feeds",
				"feeds_help": "Click any feed to edit it",
				"feeds_placeholder": "Enter a feed URL and press Enter to add",
				"feeds_pro_only": "Only Pro users can have multiple feeds in each widget. Get Pro in the settings.",
				"feed_name_placeholder": "Feed name",
				"feed_url_placeholder": "Feed URL",
				"articles": "Articles Shown"
			},
			"by": "By",
			"all_articles": "All articles",
			"feed_error": "An error occurred while trying to fetch the feed at: %s.\r\nPlease double check the URL and/or modify the widget settings."
		},
		"it": {
			"name": "RSS",
			"desc": "Visualizza gli elementi da un feed RSS o Atom, con immagini opzionali.",
			"settings": {
				"page_title": "Impostazioni",
				"save": "Salva",
				"title": "Titolo del Widget",
				"title_placeholder": "Immetti un nome per il widget o lascialo bianco per nascondere",
				"link": "Titolo Link",
				"link_placeholder": "Inserisci un collegamento per il titolo del widget",
				"feeds": "Feeds",
				"feeds_help": "Fare click su qualsiasi fee per modificarlo",
				"feeds_placeholder": "Inserisci un URL di ricerca e premi invio per aggiungerlo",
				"feeds_pro_only": "Solo gli utenti pro possono godere di più feeds in ciascun widget. Vai nelle impostazioni e attiva la funzione Pro.",
				"feed_name_placeholder": "Nome del feed",
				"feed_url_placeholder": "URL del feed",
				"articles": "Articoli mostrati"
			},
			"by": "di",
			"all_articles": "Tutti gli articoli",
			"feed_error": "Si è verificato un errore durante il recupero dei feed a: %s.\nSi prega di ricontrollare l'URL e/o modificare le impostazioni del widget."
		},
		"ja": {
			"name": "RSS",
			"desc": "RSS や Atom フィードからの記事を、画像とともに表示します。",
			"settings": {
				"page_title": "設定",
				"save": "保存",
				"title": "ウィジェットのタイトル",
				"title_placeholder": "ウィジェットのタイトルを入力、または空欄にして非表示",
				"link": "タイトルのリンク",
				"link_placeholder": "ウィジェットのタイトルのリンクを入力",
				"feeds": "フィード",
				"feeds_help": "フィードをクリックして編集",
				"feeds_placeholder": "フィード URL を入力し、Enter キーを押して追加",
				"feeds_pro_only": "Pro 版ユーザーのみが複数のフィードをそれぞれのウィジェットに設定できます。設定からご購入ください。",
				"feed_name_placeholder": "フィード名",
				"feed_url_placeholder": "フィードの URL",
				"articles": "表示する記事数"
			},
			"by": "By",
			"all_articles": "すべての記事",
			"feed_error": "フィードを取得中にエラーが発生しました：%s\nURLを再度チェックしてください。"
		},
		"nl": {
			"name": "RSS",
			"desc": "Toont items van een RSS- of Atomfeed met eventuele afbeeldingen.",
			"settings": {
				"page_title": "Instellingen",
				"save": "Opslaan",
				"title": "Widget titel",
				"title_placeholder": "Voer een titel in of laat leeg om hem te verbergen",
				"link": "Titellink",
				"link_placeholder": "Geef een link voor de titel van de widget",
				"feeds": "Feeds",
				"feeds_help": "Klik op iedere feed om deze te bewerken",
				"feeds_placeholder": "Geef een feed URL in en druk op Enter om toe te voegen",
				"feeds_pro_only": "Alleen Pro gebruikers kunnen meerdere feeds hebben in elke widget. Wordt Pro in de instellingen.",
				"feed_name_placeholder": "Feed naam",
				"feed_url_placeholder": "Feed URL",
				"articles": "Weergegeven artikelen"
			},
			"by": "Door",
			"all_articles": "Alle artikelen",
			"feed_error": "Een fout is opgetreden tijdens het ophalen van de feed: %s.\nControleer nogmaals de URL en/of verander de instellingen van de widget."
		},
		"pl": {
			"name": "RSS",
			"desc": "Wyświetla pozycje ze strumienia RSS lub Atom, opcjonalnie z obrazami.",
			"settings": {
				"page_title": "Ustawienia",
				"save": "Zapisz",
				"title": "Tytuł widżetu",
				"title_placeholder": "Wprowadź tytuł widżetu lub pozostaw puste pole aby ukryć",
				"link": "Odnośnik Tytułu",
				"link_placeholder": "Wpisz odnośnik do którego ma prowadzić tytułowy pasek widżetu",
				"feeds": "Kanały RSS",
				"feeds_help": "Kliknij na dowolnym strumieniu żeby edytować",
				"feeds_placeholder": "Wpisz URL strumienia i naciśnij Enter żeby dodać",
				"feeds_pro_only": "Tylko użytkownicy wersji Pro mogą używać wielu strumieni w widżecie. Wykup wersję Pro w ustawieniach.",
				"feed_name_placeholder": "Nazwa strumienia",
				"feed_url_placeholder": "URL strumienia",
				"articles": "Liczba Pokazanych Artykułów"
			},
			"by": "Przez",
			"all_articles": "Wszystkie artykuły",
			"feed_error": "Wystąpił błąd podczas ściągania zawartości strumienia: %s.\nSprawdź ponownie URL i/lub zmień ustawienia widżetu."
		},
		"pt-PT": {
			"name": "RSS",
			"desc": "Exibe os itens de um feed RSS ou Atom com imagens opcionais.",
			"settings": {
				"page_title": "Opções",
				"save": "Gravar",
				"title": "Título do Widget",
				"title_placeholder": "Insira um widget de título ou deixar em branco para ocultar",
				"link": "Título link",
				"link_placeholder": "Introduz aqui uma hiperligação para o Widget título",
				"feeds": "Feeds",
				"feeds_help": "Click any feed to edit it",
				"feeds_placeholder": "Enter a feed URL and press Enter to add",
				"feeds_pro_only": "Only Pro users can have multiple feeds in each widget. Get Pro in the settings.",
				"feed_name_placeholder": "Feed name",
				"feed_url_placeholder": "Feed URL",
				"articles": "Artigos mostrados"
			},
			"by": "por",
			"all_articles": "Todos os artigos",
			"feed_error": "Ocorreu um erro ao tentar buscar o feed em: % s . \nPor favor, verifique o URL e / ou modificar os widgets configurações."
		},
		"ru": {
			"name": "RSS",
			"desc": "Отображает записи из RSS канала.",
			"settings": {
				"page_title": "Настройки",
				"save": "Сохранить",
				"title": "Заголовок виджета",
				"title_placeholder": "Введите заголовок виджета или оставьте поле пустым чтобы скрыть заголовок",
				"link": "Ссылка для заголовка",
				"link_placeholder": "Введите ссылку для заголовка виджета",
				"feeds": "Каналы",
				"feeds_help": "Щелкните на любой канал, чтобы изменить его",
				"feeds_placeholder": "Введите URL-адрес источника и нажмите клавишу Enter для добавления",
				"feeds_pro_only": "Только Pro пользователи могут иметь несколько каналов в каждом виджете. Получить Pro можно в настройках.",
				"feed_name_placeholder": "Название ленты",
				"feed_url_placeholder": "URL-адрес ленты",
				"articles": "Количество отображаемых статей"
			},
			"by": "Автор",
			"all_articles": "Все статьи",
			"feed_error": "Не удается получить содержимое канала %s. Перепроверьте или исправьте URL-адрес канала в настройках виджета."
		},
		"sr": {
			"name": "РСС",
			"desc": "Приказује артикле са РСС или Atom feed-а са опционалним сликама.",
			"settings": {
				"page_title": "Подешавања",
				"save": "Сачувај",
				"title": "Назив додатка",
				"title_placeholder": "Унеси назив додатка или остави празно",
				"link": "Назив Линка",
				"link_placeholder": "Унеси линк за назив додатка",
				"feeds": "Новински извори",
				"feeds_help": "Click any feed to edit it",
				"feeds_placeholder": "Enter a feed URL and press Enter to add",
				"feeds_pro_only": "Only Pro users can have multiple feeds in each widget. Get Pro in the settings.",
				"feed_name_placeholder": "Feed name",
				"feed_url_placeholder": "Feed URL",
				"articles": "Приказани новински чланци"
			},
			"by": "од",
			"all_articles": "Сви чланци",
			"feed_error": "Десила се грешка током испоруке новинских чланака на: %s.\nМолимо Вас поново проверите УРЛ или измените подешавања додатка."
		},
		"tr": {
			"name": "RSS",
			"desc": "Displays items from a RSS or Atom feed with optional images.",
			"settings": {
				"page_title": "Ayarlar",
				"save": "Kaydet",
				"title": "Widget başlığı",
				"title_placeholder": "Widget için bir başlık girin veya gizlemek için boş bırakın",
				"link": "Title Link",
				"link_placeholder": "Enter a link for the widget title",
				"feeds": "Feeds",
				"feeds_help": "Click any feed to edit it",
				"feeds_placeholder": "Enter a feed URL and press Enter to add",
				"feeds_pro_only": "Only Pro users can have multiple feeds in each widget. Get Pro in the settings.",
				"feed_name_placeholder": "Feed name",
				"feed_url_placeholder": "Feed URL",
				"articles": "Gösterilecek Makale"
			},
			"by": "Yapan",
			"all_articles": "All articles",
			"feed_error": "An error occurred while trying to fetch the feed at: %s.\r\nPlease double check the URL and/or modify the widget settings."
		},
		"uk": {
			"name": "RSS",
			"desc": "Displays items from a RSS or Atom feed with optional images.",
			"settings": {
				"page_title": "Налаштування",
				"save": "Зберегти",
				"title": "Widget Title",
				"title_placeholder": "Enter a widget title or leave blank to hide",
				"link": "Title Link",
				"link_placeholder": "Enter a link for the widget title",
				"feeds": "Feeds",
				"feeds_help": "Click any feed to edit it",
				"feeds_placeholder": "Enter a feed URL and press Enter to add",
				"feeds_pro_only": "Only Pro users can have multiple feeds in each widget. Get Pro in the settings.",
				"feed_name_placeholder": "Feed name",
				"feed_url_placeholder": "Feed URL",
				"articles": "Articles Shown"
			},
			"by": "за",
			"all_articles": "All articles",
			"feed_error": "An error occurred while trying to fetch the feed at: %s.\r\nPlease double check the URL and/or modify the widget settings."
		},
		"zh-CN": {
			"name": "RSS 订阅",
			"desc": "显示RSS或Atom订阅（可带图片）",
			"settings": {
				"page_title": "设置",
				"save": "保存",
				"title": "小部件标题",
				"title_placeholder": "输入小部件窗口标题或留空隐藏",
				"link": "标题链接",
				"link_placeholder": "输入小部件标题链接",
				"feeds": "订阅源",
				"feeds_help": "单击任意feed以编辑",
				"feeds_placeholder": "输入一个Feed地址并按回车键以添加",
				"feeds_pro_only": "只有专业版用户可在不同的小部件中使用多个源，您可以在设置中购买专业版。",
				"feed_name_placeholder": "源名称",
				"feed_url_placeholder": "源地址",
				"articles": "显示数量"
			},
			"by": "作者",
			"all_articles": "所有文章",
			"feed_error": "试图在%s获取信息时出现错误。\n请重复检查此链接然后更改小部件设置"
		},
		"zh-TW": {
			"name": "RSS訂閱",
			"desc": "將項從 RSS 或 Atom 源與可選的圖像顯示。",
			"settings": {
				"page_title": "設定",
				"save": "儲存",
				"title": "小工具標題",
				"title_placeholder": "輸入小工具標題，保留空白的話標題列就不會顯示",
				"link": "標題連結",
				"link_placeholder": "為小工具輸入一個連結標題",
				"feeds": "訂閱",
				"feeds_help": "點選來源以編輯",
				"feeds_placeholder": "輸入來源連結網址並點選Enter加入",
				"feeds_pro_only": "只有專業版用戶能在一個widget內設定多個來源。請在設定升級Pro版",
				"feed_name_placeholder": "來源名稱",
				"feed_url_placeholder": "來源 URL",
				"articles": "文章顯示"
			},
			"by": "由",
			"all_articles": "所有文章",
			"feed_error": "試圖獲取進料時出錯： %s。請仔細檢查該 URL 和/或修改小部件設置。"
		}
	},
	"isCompiled": true
});


define("json!w/sports/manifest.json",{
	"id": 15,
	"sort": 120,
	"name": "sports",
	"model": "model",
	"icon": "sports.png",
	"sizes": [
		"variable"
	],
	"views": {
		"default": "view",
		"settings": "settings"
	},
	"templates": {
		"desc": "templates/desc.hjs",
		"default": "templates/main.hjs",
		"settings": "templates/settings.hjs"
	},
	"strings": {
		"en": {
			"name": "Sports",
			"desc": "Displays scores, schedules, and news from your favorite teams.",
			"settings": {
				"page_title": "Favorites",
				"save": "Save",
				"teams_placeholder": "Enter a team name and press Enter to add"
			},
			"favorites": "Favorites",
			"top_games": "Top Games",
			"scores": "Scores",
			"news": "News",
			"last_play": "Last play",
			"no_games": "No games found",
			"pro_splash1": "Sports news is a Pro-only feature.",
			"pro_splash2": "Buy Pro in the settings.",
			"preview": "Preview",
			"tickets": "Tickets",
			"live": "Live",
			"recap": "Recap",
			"box_score": "Box Score"
		},
		"bn": {
			"name": "ক্রীড়া",
			"desc": "Displays scores, schedules, and news from your favorite teams.",
			"settings": {
				"page_title": "Favorites",
				"save": "সংরক্ষণ",
				"teams_placeholder": "Enter a team name and press Enter to add"
			},
			"favorites": "পছন্দ",
			"top_games": "সেরা গেম",
			"scores": "স্কোর",
			"news": "সংবাদ",
			"last_play": "সর্বশেষ খেলেছেন",
			"no_games": "কোন খেলা পাওয়া যায়নি",
			"pro_splash1": "Sports news is a Pro-only feature.",
			"pro_splash2": "Buy Pro in the settings.",
			"preview": "প্রাকদর্শন",
			"tickets": "টিকিট",
			"live": "সরাসরি",
			"recap": "Recap",
			"box_score": "Box Score"
		},
		"ca": {
			"name": "Sports",
			"desc": "Displays scores, schedules, and news from your favorite teams.",
			"settings": {
				"page_title": "Favorites",
				"save": "Save",
				"teams_placeholder": "Enter a team name and press Enter to add"
			},
			"favorites": "Favorites",
			"top_games": "Top Games",
			"scores": "Scores",
			"news": "News",
			"last_play": "Last play",
			"no_games": "No games found",
			"pro_splash1": "Sports news is a Pro-only feature.",
			"pro_splash2": "Buy Pro in the settings.",
			"preview": "Preview",
			"tickets": "Tickets",
			"live": "Live",
			"recap": "Recap",
			"box_score": "Box Score"
		},
		"cs": {
			"name": "Sport",
			"desc": "Zobrazit výsledky, rozpisy a novinky vašeho oblíbeného týmu.",
			"settings": {
				"page_title": "Oblíbené",
				"save": "Ulož",
				"teams_placeholder": "Vložte jméno týmu a zmáčkněte Enter pro přidání"
			},
			"favorites": "Oblíbené",
			"top_games": "Nejlepší hry",
			"scores": "Výsledky",
			"news": "Zprávy",
			"last_play": "Poslední hra",
			"no_games": "Nebyly nalezeny žádné hry",
			"pro_splash1": "Sportovní zpravodajství je jen prémiová funkce.",
			"pro_splash2": "Pro získání Pro verze běžte do nastavení.",
			"preview": "Náhled",
			"tickets": "Vstupenky",
			"live": "Živě",
			"recap": "Rekapitulace",
			"box_score": "Skóre"
		},
		"da": {
			"name": "Sports",
			"desc": "Displays scores, schedules, and news from your favorite teams.",
			"settings": {
				"page_title": "Favorites",
				"save": "Gem",
				"teams_placeholder": "Enter a team name and press Enter to add"
			},
			"favorites": "Favorites",
			"top_games": "Top Games",
			"scores": "Scores",
			"news": "Nyheder",
			"last_play": "Last play",
			"no_games": "No games found",
			"pro_splash1": "Sports news is a Pro-only feature.",
			"pro_splash2": "Buy Pro in the settings.",
			"preview": "Forhåndsvisning",
			"tickets": "Tickets",
			"live": "Live",
			"recap": "Recap",
			"box_score": "Box Score"
		},
		"de": {
			"name": "Sport",
			"desc": "Zeigt Ergebnisse, Termine und News Ihrer Lieblings-Teams.",
			"settings": {
				"page_title": "Favoriten",
				"save": "Speichern",
				"teams_placeholder": "Bitte Teamnamen eingeben und mit Eingabetaste bestätigen"
			},
			"favorites": "Favoriten",
			"top_games": "Top-Spiele",
			"scores": "Ergebnisse",
			"news": "Nachrichten",
			"last_play": "Letztes Spiel",
			"no_games": "Keine Spiele gefunden",
			"pro_splash1": "Sport-News sind nur in Pro verfügbar.",
			"pro_splash2": "Kaufen Sie Pro in den Einstellungen.",
			"preview": "Vorschau",
			"tickets": "Tickets",
			"live": "Live",
			"recap": "Zusammenfassung",
			"box_score": "Spielbericht"
		},
		"es": {
			"name": "Deportes",
			"desc": "Displays scores, schedules, and news from your favorite teams.",
			"settings": {
				"page_title": "Favorites",
				"save": "Guardar",
				"teams_placeholder": "Enter a team name and press Enter to add"
			},
			"favorites": "Favorites",
			"top_games": "Top Games",
			"scores": "Scores",
			"news": "News",
			"last_play": "Last play",
			"no_games": "No games found",
			"pro_splash1": "Sports news is a Pro-only feature.",
			"pro_splash2": "Buy Pro in the settings.",
			"preview": "Avance",
			"tickets": "Tickets",
			"live": "Live",
			"recap": "Recap",
			"box_score": "Box Score"
		},
		"fr": {
			"name": "Sports",
			"desc": "Affiche les résultats, les calendriers et les nouvelles de vos équipes favorites.",
			"settings": {
				"page_title": "Favoris",
				"save": "Enregistrer",
				"teams_placeholder": "Entrez un nom d'équipe, puis appuyez sur Entrée pour ajouter"
			},
			"favorites": "Favoris",
			"top_games": "Meilleur jeux ",
			"scores": "Résultats",
			"news": "News",
			"last_play": "Dernier match",
			"no_games": "Pas de jeux trouvés",
			"pro_splash1": "L'actualité sportive est une fonctionnalité Pro uniquement.",
			"pro_splash2": "Achetez Pro dans les paramètres.",
			"preview": "Aperçu ",
			"tickets": "Billets",
			"live": "En direct",
			"recap": "Récap",
			"box_score": "Score de la boîte"
		},
		"he": {
			"name": "Sports",
			"desc": "Displays scores, schedules, and news from your favorite teams.",
			"settings": {
				"page_title": "Favorites",
				"save": "Save",
				"teams_placeholder": "Enter a team name and press Enter to add"
			},
			"favorites": "Favorites",
			"top_games": "Top Games",
			"scores": "Scores",
			"news": "News",
			"last_play": "Last play",
			"no_games": "No games found",
			"pro_splash1": "Sports news is a Pro-only feature.",
			"pro_splash2": "Buy Pro in the settings.",
			"preview": "Preview",
			"tickets": "Tickets",
			"live": "Live",
			"recap": "Recap",
			"box_score": "Box Score"
		},
		"hi": {
			"name": "Sports",
			"desc": "Displays scores, schedules, and news from your favorite teams.",
			"settings": {
				"page_title": "Favorites",
				"save": "सेव करें",
				"teams_placeholder": "Enter a team name and press Enter to add"
			},
			"favorites": "Favorites",
			"top_games": "Top Games",
			"scores": "Scores",
			"news": "समाचार",
			"last_play": "Last play",
			"no_games": "No games found",
			"pro_splash1": "Sports news is a Pro-only feature.",
			"pro_splash2": "Buy Pro in the settings.",
			"preview": "पूर्वावलोकन",
			"tickets": "Tickets",
			"live": "Live",
			"recap": "Recap",
			"box_score": "Box Score"
		},
		"hr": {
			"name": "Sport",
			"desc": "Prikazuje rezultate, analize i novosti o tvojoj omiljenoj momčadi.",
			"settings": {
				"page_title": "Favoriti",
				"save": "Spremi",
				"teams_placeholder": "Unesi naziv momčadi i pritisni tipku Enter za dodavanje"
			},
			"favorites": "Favoriti",
			"top_games": "Top igre",
			"scores": "Rezultati",
			"news": "Vijesti",
			"last_play": "Posljednja igra",
			"no_games": "Nisu pronađene igre",
			"pro_splash1": "Sportske novosti su dostupne samo u Pro verziji.",
			"pro_splash2": "Kupi Pro u postavkama.",
			"preview": "Pregled",
			"tickets": "Ulaznice",
			"live": "Uživo",
			"recap": "Rekapitulacija",
			"box_score": "Rezultati"
		},
		"id": {
			"name": "Sports",
			"desc": "Displays scores, schedules, and news from your favorite teams.",
			"settings": {
				"page_title": "Favorites",
				"save": "Save",
				"teams_placeholder": "Enter a team name and press Enter to add"
			},
			"favorites": "Favorites",
			"top_games": "Top Games",
			"scores": "Scores",
			"news": "News",
			"last_play": "Last play",
			"no_games": "No games found",
			"pro_splash1": "Sports news is a Pro-only feature.",
			"pro_splash2": "Buy Pro in the settings.",
			"preview": "Preview",
			"tickets": "Tickets",
			"live": "Live",
			"recap": "Recap",
			"box_score": "Box Score"
		},
		"it": {
			"name": "Sport",
			"desc": "Visualizza punteggi, orari e notizie delle tue squadre preferite.",
			"settings": {
				"page_title": "Preferiti",
				"save": "Salva",
				"teams_placeholder": "Immettere un nome di squadra e premere Invio per aggiungere"
			},
			"favorites": "Preferiti",
			"top_games": "Giochi migliori",
			"scores": "Punteggio",
			"news": "Notizie",
			"last_play": "Ultimi giocati",
			"no_games": "Nessun gioco trovato",
			"pro_splash1": "Le notizie sportive sono una caratteristica Pro.",
			"pro_splash2": "Acquista Pro nelle impostazioni.",
			"preview": "Anteprima",
			"tickets": "Biglietti",
			"live": "Live",
			"recap": "Riepilogo",
			"box_score": "Box Punteggio"
		},
		"ja": {
			"name": "スポーツ",
			"desc": "スコア、スケジュール、およびお好きなチームのニュースを表示します。",
			"settings": {
				"page_title": "お気に入り",
				"save": "保存",
				"teams_placeholder": "チーム名を入力し、Enter キーを押して追加"
			},
			"favorites": "お気に入り",
			"top_games": "人気の試合",
			"scores": "スコア",
			"news": "ニュース",
			"last_play": "前回のプレー",
			"no_games": "試合が見つかりません",
			"pro_splash1": "スポーツニュースは Pro 専用の機能です。",
			"pro_splash2": "設定から Pro をご購入ください。",
			"preview": "プレビュー",
			"tickets": "チケット",
			"live": "ライブ",
			"recap": "要約",
			"box_score": "ボックススコア"
		},
		"nl": {
			"name": "Sport",
			"desc": "Hiermee geeft u scores, programma's, en nieuws van uw favoriete teams weer.",
			"settings": {
				"page_title": "Favorieten",
				"save": "Opslaan",
				"teams_placeholder": "Voer een teamnaam in en druk op Enter om toe te voegen"
			},
			"favorites": "Favorieten",
			"top_games": "Top spellen",
			"scores": "Scores",
			"news": "Nieuws",
			"last_play": "Laatste wedstrijd",
			"no_games": "Geen games gevonden",
			"pro_splash1": "Sportnieuws is alleen een Pro-functie.",
			"pro_splash2": "Koop PRO in de instellingen.",
			"preview": "Voorbeeld",
			"tickets": "Kaartjes",
			"live": "Live",
			"recap": "Samenvatting",
			"box_score": "Box score"
		},
		"pl": {
			"name": "Sport",
			"desc": "Wyświetla wyniki, rozkłady i wiadomości dotyczące Twoich ulubionych zespołów.",
			"settings": {
				"page_title": "Ulubione",
				"save": "Zapisz",
				"teams_placeholder": "Wpisz nazwę zespołu i naciśnij Enter żeby dodać"
			},
			"favorites": "Ulubione",
			"top_games": "Najpopularniejsze rozgrywki",
			"scores": "Wyniki",
			"news": "Wiadomości",
			"last_play": "Ostatnie rozgrywki",
			"no_games": "Nie znaleziono rozgrywek",
			"pro_splash1": "Wiadomości sportowe są funkcją dostępną tylko w wersji Pro.",
			"pro_splash2": "Wykup wersję Pro w ustawieniach.",
			"preview": "Podgląd",
			"tickets": "Bilety",
			"live": "Na żywo",
			"recap": "Podsumowania",
			"box_score": "Wyniki"
		},
		"pt-PT": {
			"name": "Desporto",
			"desc": "Displays scores, schedules, and news from your favorite teams.",
			"settings": {
				"page_title": "Favorites",
				"save": "Gravar",
				"teams_placeholder": "Enter a team name and press Enter to add"
			},
			"favorites": "Favorites",
			"top_games": "Top Games",
			"scores": "Scores",
			"news": "Noticias",
			"last_play": "Last play",
			"no_games": "No games found",
			"pro_splash1": "Sports news is a Pro-only feature.",
			"pro_splash2": "Buy Pro in the settings.",
			"preview": "Pré visualização",
			"tickets": "Tickets",
			"live": "Live",
			"recap": "Recap",
			"box_score": "Box Score"
		},
		"ru": {
			"name": "Спорт",
			"desc": "Отображает результаты, расписание и новости ваших любимых команд.",
			"settings": {
				"page_title": "Избранное",
				"save": "Сохранить",
				"teams_placeholder": "Для добавления введите имя команды и нажмите клавишу Enter"
			},
			"favorites": "Избранное",
			"top_games": "Лучшие игры",
			"scores": "Очки",
			"news": "Новости",
			"last_play": "Последняя игра",
			"no_games": "Игры не найдены",
			"pro_splash1": "Новости спорта доступны только Pro-пользователям.",
			"pro_splash2": "Купить Pro можно в настройках.",
			"preview": "Предпросмотр",
			"tickets": "Билеты",
			"live": "Прямой эфир",
			"recap": "Резюме",
			"box_score": "Коробка оценок"
		},
		"sr": {
			"name": "Спорт",
			"desc": "Displays scores, schedules, and news from your favorite teams.",
			"settings": {
				"page_title": "Favorites",
				"save": "Сачувај",
				"teams_placeholder": "Enter a team name and press Enter to add"
			},
			"favorites": "Favorites",
			"top_games": "Top Games",
			"scores": "Scores",
			"news": "Вести",
			"last_play": "Last play",
			"no_games": "No games found",
			"pro_splash1": "Sports news is a Pro-only feature.",
			"pro_splash2": "Buy Pro in the settings.",
			"preview": "Погледај пре објаве",
			"tickets": "Tickets",
			"live": "Live",
			"recap": "Recap",
			"box_score": "Box Score"
		},
		"tr": {
			"name": "Spor",
			"desc": "Displays scores, schedules, and news from your favorite teams.",
			"settings": {
				"page_title": "Favorites",
				"save": "Kaydet",
				"teams_placeholder": "Enter a team name and press Enter to add"
			},
			"favorites": "Favorites",
			"top_games": "Top Games",
			"scores": "Scores",
			"news": "Haberler",
			"last_play": "Last play",
			"no_games": "No games found",
			"pro_splash1": "Sports news is a Pro-only feature.",
			"pro_splash2": "Buy Pro in the settings.",
			"preview": "Önizleme",
			"tickets": "Tickets",
			"live": "Live",
			"recap": "Recap",
			"box_score": "Box Score"
		},
		"uk": {
			"name": "Sports",
			"desc": "Displays scores, schedules, and news from your favorite teams.",
			"settings": {
				"page_title": "Favorites",
				"save": "Зберегти",
				"teams_placeholder": "Enter a team name and press Enter to add"
			},
			"favorites": "Favorites",
			"top_games": "Top Games",
			"scores": "Scores",
			"news": "Новини",
			"last_play": "Last play",
			"no_games": "No games found",
			"pro_splash1": "Sports news is a Pro-only feature.",
			"pro_splash2": "Buy Pro in the settings.",
			"preview": "Preview",
			"tickets": "Tickets",
			"live": "Live",
			"recap": "Recap",
			"box_score": "Box Score"
		},
		"zh-CN": {
			"name": "体育运动",
			"desc": "显示您所喜欢队伍的比赛比分，时间表及新闻。",
			"settings": {
				"page_title": "收藏夹",
				"save": "保存",
				"teams_placeholder": "输入队伍的名称后按回车添加"
			},
			"favorites": "收藏夹",
			"top_games": "顶级联赛",
			"scores": "比分",
			"news": "新闻",
			"last_play": "最后显示",
			"no_games": "未发现比赛",
			"pro_splash1": "体育新闻是专业版的功能。",
			"pro_splash2": "在设置中购买 专业版。",
			"preview": "预览",
			"tickets": "门票",
			"live": "直播",
			"recap": "历史回顾",
			"box_score": "比分"
		},
		"zh-TW": {
			"name": "體育",
			"desc": "顯示你最喜歡球隊的分數、 時程表和新聞。",
			"settings": {
				"page_title": "最愛",
				"save": "儲存",
				"teams_placeholder": "輸入隊伍的名稱並按 enter 增加"
			},
			"favorites": "最愛",
			"top_games": "熱門遊戲",
			"scores": "分數",
			"news": "新聞",
			"last_play": "最新的賽事",
			"no_games": "沒有賽事",
			"pro_splash1": "運動新聞為專業版功能",
			"pro_splash2": "在設定中購買Pro",
			"preview": "預覽",
			"tickets": "運動票券",
			"live": "直播",
			"recap": "比賽重點回顧",
			"box_score": "完整數據"
		}
	},
	"isCompiled": true
});


define("json!w/stocks/manifest.json",{
	"id": 14,
	"sort": 100,
	"name": "stocks",
	"model": "model",
	"icon": "stocks.png",
	"sizes": [
		"tiny",
		"small"
	],
	"defaultSize": "small",
	"views": {
		"default": "view",
		"detail": "detail"
	},
	"templates": {
		"desc": "templates/desc.hjs",
		"default": "templates/main.hjs",
		"detail": "templates/detail.hjs"
	},
	"settings": [
		{
			"type": "text",
			"name": "title",
			"label": "i18n.settings.title",
			"placeholder": "i18n.settings.title_placeholder"
		},
		{
			"type": "size"
		},
		{
			"type": "radio",
			"name": "regularinpost",
			"label": "i18n.settings.regularinpost.title",
			"options": {
				"0": "i18n.settings.regularinpost.off",
				"1": "i18n.settings.regularinpost.on"
			}
		},
		{
			"type": "list",
			"name": "stocks",
			"autocomplete": "autocomplete",
			"label": "i18n.settings.stocks",
			"placeholder": "i18n.settings.stocks_placeholder"
		}
	],
	"strings": {
		"en": {
			"name": "Stocks",
			"desc": "Displays current information for any given stock symbol.",
			"settings": {
				"stocks": "Stocks",
				"stocks_placeholder": "Type a company or exchange name and hit Enter",
				"regularinpost": {
					"title": "Regular price in Pre- or Post- state",
					"on": "show",
					"off": "hide"
				}
			},
			"as_of": "as of",
			"exchange_time": "Exchange Time",
			"overview": "Overview",
			"news": "News",
			"pro_splash1": "Realtime data, charts, news, and detailed stock information are Pro-only features.",
			"pro_splash2": "Buy Pro in the settings.",
			"time_ranges": {
				"1d": "1d",
				"5d": "5d",
				"1m": "1m",
				"3m": "3m",
				"1y": "1y",
				"5y": "5y",
				"max": "max"
			},
			"open": "Open",
			"prev_close": "Previous Close",
			"high": "High",
			"52high": "52 week high",
			"low": "Low",
			"52low": "52 week low",
			"volume": "Volume",
			"avg_volume": "Avg. Volume",
			"shares": "Shares",
			"cap": "Market Cap",
			"pe": "Price / Earnings",
			"eps": "EPS",
			"beta": "Beta",
			"inst_own": "Inst. own"
		},
		"bn": {
			"name": "স্টক",
			"desc": "Displays current information for any given stock symbol.",
			"settings": {
				"stocks": "স্টক",
				"stocks_placeholder": "Type a company or exchange name and hit Enter"
			},
			"as_of": "as of",
			"exchange_time": "বিনিময়ের সময়",
			"overview": "সংক্ষিপ্ত বিবরণ",
			"news": "সংবাদ",
			"pro_splash1": "Realtime data, charts, news, and detailed stock information are Pro-only features.",
			"pro_splash2": "Buy Pro in the settings.",
			"time_ranges": {
				"1d": "১ দিন",
				"5d": "৫ দিন",
				"1m": "১ মাস",
				"3m": "৩ মাস",
				"1y": "১ ব",
				"5y": "৫ ব",
				"max": "সর্বোচ্চ"
			},
			"open": "খুলুন",
			"prev_close": "পূর্ববর্তী বন্ধ",
			"high": "উচ্চ",
			"52high": "52 week high",
			"low": "নিম্ন",
			"52low": "52 week low",
			"volume": "ভলিউম",
			"avg_volume": "Avg. Volume",
			"shares": "Shares",
			"cap": "Market Cap",
			"pe": "Price / Earnings",
			"eps": "EPS",
			"beta": "Beta",
			"inst_own": "Inst. own"
		},
		"ca": {
			"name": "Stocks",
			"desc": "Displays current information for any given stock symbol.",
			"settings": {
				"stocks": "Stocks",
				"stocks_placeholder": "Type a company or exchange name and hit Enter"
			},
			"as_of": "as of",
			"exchange_time": "Exchange Time",
			"overview": "Overview",
			"news": "News",
			"pro_splash1": "Realtime data, charts, news, and detailed stock information are Pro-only features.",
			"pro_splash2": "Buy Pro in the settings.",
			"time_ranges": {
				"1d": "1d",
				"5d": "5d",
				"1m": "1m",
				"3m": "3m",
				"1y": "1y",
				"5y": "5y",
				"max": "max"
			},
			"open": "Open",
			"prev_close": "Previous Close",
			"high": "High",
			"52high": "52 week high",
			"low": "Low",
			"52low": "52 week low",
			"volume": "Volume",
			"avg_volume": "Avg. Volume",
			"shares": "Shares",
			"cap": "Market Cap",
			"pe": "Price / Earnings",
			"eps": "EPS",
			"beta": "Beta",
			"inst_own": "Inst. own"
		},
		"cs": {
			"name": "Akcie",
			"desc": "Zobrazí aktuální informace o jakékoli zadané akcii.",
			"settings": {
				"stocks": "Akcie",
				"stocks_placeholder": "Zadejte název společnosti nebo burzy a stiskněte Enter"
			},
			"as_of": "k",
			"exchange_time": "Čas výměny",
			"overview": "Přehled",
			"news": "Zprávy",
			"pro_splash1": "Aktualizace v reálném čase, grafy, novinky a detaily akcií jsou funkce dostupné pouze v Pro verzi.",
			"pro_splash2": "Kupte Pro v nastavení.",
			"time_ranges": {
				"1d": "1d",
				"5d": "5d",
				"1m": "1m",
				"3m": "3m",
				"1y": "1r",
				"5y": "5r",
				"max": "max"
			},
			"open": "otevřeno",
			"prev_close": "Uzavírací cena",
			"high": "Vysoká",
			"52high": "Nejvyšší za 52 týdnů",
			"low": "Nízká",
			"52low": "Nejnižší za 52 týdnů",
			"volume": "Množství",
			"avg_volume": "Prům. objem",
			"shares": "Akcie",
			"cap": "Tržní kapitalizace",
			"pe": "Cena / Zisky",
			"eps": "EPS",
			"beta": "Beta",
			"inst_own": "Inst. vlastnictví"
		},
		"da": {
			"name": "Stocks",
			"desc": "Displays current information for any given stock symbol.",
			"settings": {
				"stocks": "Stocks",
				"stocks_placeholder": "Type a company or exchange name and hit Enter"
			},
			"as_of": "as of",
			"exchange_time": "Exchange Time",
			"overview": "Overview",
			"news": "Nyheder",
			"pro_splash1": "Realtime data, charts, news, and detailed stock information are Pro-only features.",
			"pro_splash2": "Buy Pro in the settings.",
			"time_ranges": {
				"1d": "1d",
				"5d": "5d",
				"1m": "1m",
				"3m": "3m",
				"1y": "1y",
				"5y": "5y",
				"max": "max"
			},
			"open": "Open",
			"prev_close": "Previous Close",
			"high": "High",
			"52high": "52 week high",
			"low": "Low",
			"52low": "52 week low",
			"volume": "Volume",
			"avg_volume": "Avg. Volume",
			"shares": "Shares",
			"cap": "Market Cap",
			"pe": "Price / Earnings",
			"eps": "EPS",
			"beta": "Beta",
			"inst_own": "Inst. own"
		},
		"de": {
			"name": "Aktien",
			"desc": "Zeigt aktuelle Informationen für jedes gewählte Aktiensymbol.",
			"settings": {
				"stocks": "Aktien",
				"stocks_placeholder": "Gebe eine Firma ein und bestätige"
			},
			"as_of": "ab",
			"exchange_time": "Exchange-Zeit",
			"overview": "Übersicht",
			"news": "Nachrichten",
			"pro_splash1": "Live Daten, Charts, News, und Börseninformationen sind alles Pro Features.",
			"pro_splash2": "Kaufe Pro in den Einstellungen.",
			"time_ranges": {
				"1d": "1T",
				"5d": "5T",
				"1m": "1M",
				"3m": "3M",
				"1y": "1J",
				"5y": "5J",
				"max": "maximum"
			},
			"open": "offen",
			"prev_close": "Zuletzt verwendet",
			"high": "Hoch",
			"52high": "52-Wochen-Hoch",
			"low": "Tief",
			"52low": "52-Wochen-Tief",
			"volume": "Volumen",
			"avg_volume": "Gesamtvolumen",
			"shares": "Aktien",
			"cap": "Marktkapitalisierung",
			"pe": "Preis / Gewinn",
			"eps": "EPS",
			"beta": "Beta",
			"inst_own": "Institutioneller Besitz"
		},
		"es": {
			"name": "Acciones",
			"desc": "Muestra información actual para cualquier símbolo bursátil determinado.",
			"settings": {
				"stocks": "Acciones",
				"stocks_placeholder": "Type a company or exchange name and hit Enter"
			},
			"as_of": "desde",
			"exchange_time": "Cambio de Tiempo",
			"overview": "Overview",
			"news": "News",
			"pro_splash1": "Realtime data, charts, news, and detailed stock information are Pro-only features.",
			"pro_splash2": "Buy Pro in the settings.",
			"time_ranges": {
				"1d": "1d",
				"5d": "5d",
				"1m": "1m",
				"3m": "3m",
				"1y": "1a",
				"5y": "5a",
				"max": "máx"
			},
			"open": "abrir",
			"prev_close": "Previous Close",
			"high": "alto",
			"52high": "52 week high",
			"low": "bajo",
			"52low": "52 week low",
			"volume": "volumen",
			"avg_volume": "Avg. Volume",
			"shares": "Veces compartido",
			"cap": "Market Cap",
			"pe": "Precio / Ganancias",
			"eps": "EPS",
			"beta": "Beta",
			"inst_own": "Inst. own"
		},
		"fr": {
			"name": "Bourse",
			"desc": "Affiche les informations pour n'importe quel symbole boursier donné.",
			"settings": {
				"stocks": "Bourse",
				"stocks_placeholder": "Tapez un nom de société ou modifiez-les et tapez ENTREE"
			},
			"as_of": "à compter de",
			"exchange_time": "Temps d'échange",
			"overview": "Apercu",
			"news": "News",
			"pro_splash1": "Les données en temps réel, les graphiques, nouvelles et informations boursières détaillées sont uniquement disponibles en mode Pro.",
			"pro_splash2": "Achetez Pro dans les paramètres.",
			"time_ranges": {
				"1d": "1j",
				"5d": "5j",
				"1m": "1m",
				"3m": "3m",
				"1y": "1a",
				"5y": "5a",
				"max": "max"
			},
			"open": "Ouvrir",
			"prev_close": "Clôture précédente",
			"high": "Haute",
			"52high": "52 semaines haut",
			"low": "Bas",
			"52low": "52 semaines bas",
			"volume": "Volume",
			"avg_volume": "Volume moyen",
			"shares": "Actions",
			"cap": "Capitalisation boursière",
			"pe": "Prix / bénéfice",
			"eps": "BPA",
			"beta": "Bêta",
			"inst_own": "Instant propre"
		},
		"he": {
			"name": "Stocks",
			"desc": "Displays current information for any given stock symbol.",
			"settings": {
				"stocks": "Stocks",
				"stocks_placeholder": "Type a company or exchange name and hit Enter"
			},
			"as_of": "as of",
			"exchange_time": "Exchange Time",
			"overview": "Overview",
			"news": "News",
			"pro_splash1": "Realtime data, charts, news, and detailed stock information are Pro-only features.",
			"pro_splash2": "Buy Pro in the settings.",
			"time_ranges": {
				"1d": "1d",
				"5d": "5d",
				"1m": "1m",
				"3m": "3m",
				"1y": "1y",
				"5y": "5y",
				"max": "max"
			},
			"open": "Open",
			"prev_close": "Previous Close",
			"high": "High",
			"52high": "52 week high",
			"low": "Low",
			"52low": "52 week low",
			"volume": "Volume",
			"avg_volume": "Avg. Volume",
			"shares": "Shares",
			"cap": "Market Cap",
			"pe": "Price / Earnings",
			"eps": "EPS",
			"beta": "Beta",
			"inst_own": "Inst. own"
		},
		"hi": {
			"name": "Stocks",
			"desc": "Displays current information for any given stock symbol.",
			"settings": {
				"stocks": "Stocks",
				"stocks_placeholder": "Type a company or exchange name and hit Enter"
			},
			"as_of": "as of",
			"exchange_time": "Exchange Time",
			"overview": "Overview",
			"news": "समाचार",
			"pro_splash1": "Realtime data, charts, news, and detailed stock information are Pro-only features.",
			"pro_splash2": "Buy Pro in the settings.",
			"time_ranges": {
				"1d": "1d",
				"5d": "5d",
				"1m": "1m",
				"3m": "3m",
				"1y": "1y",
				"5y": "5y",
				"max": "max"
			},
			"open": "Open",
			"prev_close": "Previous Close",
			"high": "High",
			"52high": "52 week high",
			"low": "Low",
			"52low": "52 week low",
			"volume": "Volume",
			"avg_volume": "Avg. Volume",
			"shares": "Shares",
			"cap": "Market Cap",
			"pe": "Price / Earnings",
			"eps": "EPS",
			"beta": "Beta",
			"inst_own": "Inst. own"
		},
		"hr": {
			"name": "Dionice",
			"desc": "Prikazuje trenutne informacije za bilo koji zadani simbol dionice.",
			"settings": {
				"stocks": "Dionice",
				"stocks_placeholder": "Unesi naziv tvrtke ili razmjene i pritisni Enter"
			},
			"as_of": "od",
			"exchange_time": "Vrijeme razmjene",
			"overview": "Pregled",
			"news": "Vijesti",
			"pro_splash1": "Podaci u stvarnom vremenu, grafovi, vijesti i detaljne informacije dionica su dostupne samo u Pro verziji.",
			"pro_splash2": "Kupi Pro u postavkama.",
			"time_ranges": {
				"1d": "1d",
				"5d": "5d",
				"1m": "1m",
				"3m": "3m",
				"1y": "1g",
				"5y": "5g",
				"max": "maks"
			},
			"open": "Otvoreno",
			"prev_close": "Posljednja vrijednost",
			"high": "Najviše",
			"52high": "najviša u 52 tjedna",
			"low": "Najniže",
			"52low": "najniža u 52 tjedna",
			"volume": "Volumen",
			"avg_volume": "Pros. volumen",
			"shares": "Dionice",
			"cap": "Tržišni kapital",
			"pe": "Cijena / Zarada",
			"eps": "EPS",
			"beta": "Beta",
			"inst_own": "Inst. vlasništvo"
		},
		"id": {
			"name": "Stocks",
			"desc": "Displays current information for any given stock symbol.",
			"settings": {
				"stocks": "Stocks",
				"stocks_placeholder": "Type a company or exchange name and hit Enter"
			},
			"as_of": "as of",
			"exchange_time": "Exchange Time",
			"overview": "Overview",
			"news": "News",
			"pro_splash1": "Realtime data, charts, news, and detailed stock information are Pro-only features.",
			"pro_splash2": "Buy Pro in the settings.",
			"time_ranges": {
				"1d": "1d",
				"5d": "5d",
				"1m": "1m",
				"3m": "3m",
				"1y": "1y",
				"5y": "5y",
				"max": "max"
			},
			"open": "Open",
			"prev_close": "Previous Close",
			"high": "High",
			"52high": "52 week high",
			"low": "Low",
			"52low": "52 week low",
			"volume": "Volume",
			"avg_volume": "Avg. Volume",
			"shares": "Shares",
			"cap": "Market Cap",
			"pe": "Price / Earnings",
			"eps": "EPS",
			"beta": "Beta",
			"inst_own": "Inst. own"
		},
		"it": {
			"name": "Azioni",
			"desc": "Visualizza le informazioni correnti per qualsiasi azione.",
			"settings": {
				"stocks": "Azioni",
				"stocks_placeholder": "Digitare un nome di società o cambio e premi invio"
			},
			"as_of": "A partire da",
			"exchange_time": "Tempo di scambio",
			"overview": "Sommario",
			"news": "Notizie",
			"pro_splash1": "Dati in tempo reale, grafici, notizie e informazioni dettagliate di borsa sono solo caratteristiche Pro.",
			"pro_splash2": "Acquista Pro nelle impostazioni.",
			"time_ranges": {
				"1d": "1 giorno",
				"5d": "5 giorni",
				"1m": "1 mese",
				"3m": "3 mesi",
				"1y": "1 anno",
				"5y": "5 anni",
				"max": "max"
			},
			"open": "Aperto",
			"prev_close": "Chiusura precedente",
			"high": "Alto",
			"52high": "52 settimane alte",
			"low": "Basso",
			"52low": "52 settimane basse",
			"volume": "volume",
			"avg_volume": "Media Volume",
			"shares": "Azioni",
			"cap": "Capitalizzazione di mercato",
			"pe": "Prezzo / utili",
			"eps": "EPS",
			"beta": "Beta",
			"inst_own": "Proprietà istituzionale"
		},
		"ja": {
			"name": "株価",
			"desc": "指定した銘柄の現在の情報を表示します。",
			"settings": {
				"stocks": "株価",
				"stocks_placeholder": "会社名またはコードを入力"
			},
			"as_of": " ",
			"exchange_time": "取引時間",
			"overview": "概要",
			"news": "ニュース",
			"pro_splash1": "リアルタイムデータ、チャート、ニュース、および詳細な株価情報は Pro 版のみの機能です。",
			"pro_splash2": "設定から Pro をご購入ください。",
			"time_ranges": {
				"1d": "1日",
				"5d": "5日",
				"1m": "1分",
				"3m": "3分",
				"1y": "1年",
				"5y": "5年",
				"max": "最大"
			},
			"open": "始値",
			"prev_close": "前日終値",
			"high": "高値",
			"52high": "52週高値",
			"low": "安値",
			"52low": "52週安値",
			"volume": "出来高",
			"avg_volume": "平均出来高",
			"shares": "株価",
			"cap": "時価総額",
			"pe": "株価収益率",
			"eps": "EPS",
			"beta": "ベータ値",
			"inst_own": "機関投資家保有割合"
		},
		"nl": {
			"name": "Aandelen",
			"desc": "Geeft actuele informatie voor elk opgegeven beurssymbool.",
			"settings": {
				"stocks": "Aandelen",
				"stocks_placeholder": "Typ de naam van een bedrijf en druk op Enter"
			},
			"as_of": "per",
			"exchange_time": "Wisselkoers tijd",
			"overview": "Overzicht",
			"news": "Nieuws",
			"pro_splash1": "Realtime gegevens, grafieken, nieuws en gedetailleerde koersgegevens zijn Pro-functies.",
			"pro_splash2": "Koop PRO in de instellingen.",
			"time_ranges": {
				"1d": "1 dag",
				"5d": "5 dagen",
				"1m": "1 maand",
				"3m": "3 maanden",
				"1y": "1 jaar",
				"5y": "5 jaar",
				"max": "max."
			},
			"open": "open",
			"prev_close": "Sluit de vorige",
			"high": "hoog",
			"52high": "52 weken hoog",
			"low": "laag",
			"52low": "52 weken laag",
			"volume": "volume",
			"avg_volume": "Gem. Volume",
			"shares": "Aandelen",
			"cap": "Beurswaarde",
			"pe": "Koers / Winst",
			"eps": "WPA",
			"beta": "Beta",
			"inst_own": "Inst. own"
		},
		"pl": {
			"name": "Giełda",
			"desc": "Wyświetla aktualne informacje dla zadanych akcji.",
			"settings": {
				"stocks": "Giełda",
				"stocks_placeholder": "Wpisz nazwę firmy lub giełdy i wciśnij Enter"
			},
			"as_of": "stan z",
			"exchange_time": "czas giełdy",
			"overview": "Ogólne",
			"news": "Wiadomości",
			"pro_splash1": "Dane, wykresy, wiadomości i szczegółowe informacje o akcjach w czasie rzeczywistym są funkcjami dostępnymi tylko w wersji Pro.",
			"pro_splash2": "Wykup wersję Pro w ustawieniach.",
			"time_ranges": {
				"1d": "1d",
				"5d": "5d",
				"1m": "1m",
				"3m": "3m",
				"1y": "1r",
				"5y": "5r",
				"max": "max"
			},
			"open": "Otwarcie",
			"prev_close": "Poprzednie Zamknięcie",
			"high": "wysokie",
			"52high": "Najwyższy z 52 tygodni",
			"low": "niskie",
			"52low": "Najniższy z 52 tygodni",
			"volume": "Obrót",
			"avg_volume": "Średni Obrót",
			"shares": "Akcje",
			"cap": "Wartość Rynku",
			"pe": "Cena/Zysk",
			"eps": "Zysk/Akcja",
			"beta": "Beta",
			"inst_own": "Wł. Inst."
		},
		"pt-PT": {
			"name": "Estoques",
			"desc": "Exibe informações atuais para qualquer símbolo de ação dada.",
			"settings": {
				"stocks": "Estoques",
				"stocks_placeholder": "Type a company or exchange name and hit Enter"
			},
			"as_of": "a partir de",
			"exchange_time": "Tempo de troca",
			"overview": "Overview",
			"news": "Noticias",
			"pro_splash1": "Realtime data, charts, news, and detailed stock information are Pro-only features.",
			"pro_splash2": "Buy Pro in the settings.",
			"time_ranges": {
				"1d": "1d",
				"5d": "5d",
				"1m": "1m",
				"3m": "3m",
				"1y": "1y",
				"5y": "5y",
				"max": "max"
			},
			"open": "abrir",
			"prev_close": "Previous Close",
			"high": "alto",
			"52high": "52 week high",
			"low": "baixa",
			"52low": "52 week low",
			"volume": "volume",
			"avg_volume": "Avg. Volume",
			"shares": "Shares",
			"cap": "Market Cap",
			"pe": "Price / Earnings",
			"eps": "EPS",
			"beta": "Beta",
			"inst_own": "Inst. own"
		},
		"ru": {
			"name": "Котировки",
			"desc": "Отображает информацию о выбранных знаках.",
			"settings": {
				"stocks": "Котировки",
				"stocks_placeholder": "Введите имя компании или биржи и нажмите Enter"
			},
			"as_of": "На",
			"exchange_time": "Время обмена",
			"overview": "Обзор",
			"news": "Новости",
			"pro_splash1": "Данных в реальном времени, графики, новости и подробную информацию по акциям могут просматривать только Pro-пользователи.",
			"pro_splash2": "Купить Pro можно в настройках.",
			"time_ranges": {
				"1d": "1 день",
				"5d": "5 дней",
				"1m": "1 месяц",
				"3m": "3 месяца",
				"1y": "1 год",
				"5y": "5 лет",
				"max": "за все время"
			},
			"open": "открытие",
			"prev_close": "Последнее закрытие",
			"high": "закрытие",
			"52high": "Максимум за год",
			"low": "минимум",
			"52low": "Минимум за год",
			"volume": "объем",
			"avg_volume": "Среднее значение",
			"shares": "Акции",
			"cap": "Рыночная капитализация",
			"pe": "Цена / Заработок",
			"eps": "EPS",
			"beta": "Бета",
			"inst_own": "Доля инвест. фондов"
		},
		"sr": {
			"name": "Берзанске Акције",
			"desc": "Приказује тренутну информацију за било који понуђени акцијски симбол.",
			"settings": {
				"stocks": "Берзанске Акције",
				"stocks_placeholder": "Type a company or exchange name and hit Enter"
			},
			"as_of": "од",
			"exchange_time": "Време Размене",
			"overview": "Overview",
			"news": "Вести",
			"pro_splash1": "Realtime data, charts, news, and detailed stock information are Pro-only features.",
			"pro_splash2": "Buy Pro in the settings.",
			"time_ranges": {
				"1d": "1d",
				"5d": "5d",
				"1m": "1m",
				"3m": "3m",
				"1y": "1y",
				"5y": "5y",
				"max": "max"
			},
			"open": "отвори",
			"prev_close": "Previous Close",
			"high": "високо",
			"52high": "52 week high",
			"low": "ниско",
			"52low": "52 week low",
			"volume": "Јачина звука",
			"avg_volume": "Avg. Volume",
			"shares": "Shares",
			"cap": "Market Cap",
			"pe": "Price / Earnings",
			"eps": "EPS",
			"beta": "Beta",
			"inst_own": "Inst. own"
		},
		"tr": {
			"name": "Stocks",
			"desc": "Displays current information for any given stock symbol.",
			"settings": {
				"stocks": "Stocks",
				"stocks_placeholder": "Type a company or exchange name and hit Enter"
			},
			"as_of": "as of",
			"exchange_time": "Exchange Time",
			"overview": "Overview",
			"news": "Haberler",
			"pro_splash1": "Realtime data, charts, news, and detailed stock information are Pro-only features.",
			"pro_splash2": "Buy Pro in the settings.",
			"time_ranges": {
				"1d": "1d",
				"5d": "5d",
				"1m": "1m",
				"3m": "3m",
				"1y": "1y",
				"5y": "5y",
				"max": "max"
			},
			"open": "Open",
			"prev_close": "Previous Close",
			"high": "High",
			"52high": "52 week high",
			"low": "Low",
			"52low": "52 week low",
			"volume": "Volume",
			"avg_volume": "Avg. Volume",
			"shares": "Shares",
			"cap": "Market Cap",
			"pe": "Price / Earnings",
			"eps": "EPS",
			"beta": "Beta",
			"inst_own": "Inst. own"
		},
		"uk": {
			"name": "Stocks",
			"desc": "Displays current information for any given stock symbol.",
			"settings": {
				"stocks": "Stocks",
				"stocks_placeholder": "Type a company or exchange name and hit Enter"
			},
			"as_of": "as of",
			"exchange_time": "Exchange Time",
			"overview": "Overview",
			"news": "Новини",
			"pro_splash1": "Realtime data, charts, news, and detailed stock information are Pro-only features.",
			"pro_splash2": "Buy Pro in the settings.",
			"time_ranges": {
				"1d": "1d",
				"5d": "5d",
				"1m": "1m",
				"3m": "3m",
				"1y": "1y",
				"5y": "5y",
				"max": "max"
			},
			"open": "Open",
			"prev_close": "Previous Close",
			"high": "High",
			"52high": "52 week high",
			"low": "Low",
			"52low": "52 week low",
			"volume": "Volume",
			"avg_volume": "Avg. Volume",
			"shares": "Shares",
			"cap": "Market Cap",
			"pe": "Price / Earnings",
			"eps": "EPS",
			"beta": "Beta",
			"inst_own": "Inst. own"
		},
		"zh-CN": {
			"name": "股票",
			"desc": "显示您指定的股票信息。",
			"settings": {
				"stocks": "股票",
				"stocks_placeholder": "输入公司或股票名称后按回车添加"
			},
			"as_of": "在",
			"exchange_time": "交易时间",
			"overview": "概览",
			"news": "新闻",
			"pro_splash1": "获取实时数据，图表，新闻以及股票详细信息是专业版的功能。",
			"pro_splash2": "请在设置中购买ProductivityTab专业版。",
			"time_ranges": {
				"1d": "1日",
				"5d": "5日",
				"1m": "1月",
				"3m": "3月",
				"1y": "1年",
				"5y": "5年",
				"max": "最大"
			},
			"open": "开盘",
			"prev_close": "前收盘价",
			"high": "涨",
			"52high": "52 周高点",
			"low": "跌",
			"52low": "52 周低点",
			"volume": "交易量",
			"avg_volume": "平均交易量",
			"shares": "股票",
			"cap": "市值",
			"pe": "价格 / 收益",
			"eps": "每股收益",
			"beta": "测试版",
			"inst_own": "机构持股"
		},
		"zh-TW": {
			"name": "股票",
			"desc": "顯示指定代號股票的目前資訊。",
			"settings": {
				"stocks": "股票",
				"stocks_placeholder": "輸入一個公司或交易的名稱並按下Enter"
			},
			"as_of": "作為",
			"exchange_time": "交換時間",
			"overview": "概覽",
			"news": "新聞",
			"pro_splash1": "即時資料、 圖表、 新聞和股票的詳細資訊是專業版的功能。",
			"pro_splash2": "在設定中購買Pro",
			"time_ranges": {
				"1d": "1天",
				"5d": "5天",
				"1m": "1分鍾",
				"3m": "3分鐘",
				"1y": "1年",
				"5y": "5年",
				"max": "最大"
			},
			"open": "開啟",
			"prev_close": "上一個收盤價",
			"high": "最高",
			"52high": "52 周高點",
			"low": "最低",
			"52low": "52 周低點",
			"volume": "交易量",
			"avg_volume": "平均交易量",
			"shares": "股票",
			"cap": "總市值",
			"pe": "本益比",
			"eps": "每股盈餘(EPS)",
			"beta": "Beta係數",
			"inst_own": "主力持股"
		}
	},
	"isCompiled": true
});


define("json!w/todo/manifest.json",{
	"id": 17,
	"sort": 80,
	"name": "todo",
	"model": "model",
	"icon": "todo.png",
	"sizes": [
		"variable"
	],
	"views": {
		"default": "view"
	},
	"templates": {
		"desc": "templates/desc.hjs",
		"default": "templates/main.hjs"
	},
	"settings": [
		{
			"type": "text",
			"name": "title",
			"label": "i18n.settings.title",
			"placeholder": "i18n.settings.title_placeholder"
		},
		{
			"type": "radio",
			"name": "font",
			"label": "i18n.settings.color",
			"options": {
				"light": "i18n.settings.color_options.light",
				"dark": "i18n.settings.color_options.dark"
			}
		},
		{
			"type": "list",
			"color": true,
			"name": "tags",
			"label": "i18n.settings.tags",
			"placeholder": "i18n.settings.tags_placeholder"
		}
	],
	"strings": {
		"en": {
			"name": "To-do",
			"desc": "Displays an interactive to-do list with important and completed items.",
			"title": "To-do list",
			"settings": {
				"color": "Font Color",
				"color_options": {
					"light": "Light",
					"dark": "Dark"
				},
				"tags": "Tags",
				"tags_placeholder": "Enter a tag name and press Enter"
			},
			"add": "Add Item",
			"none": "None",
			"important": "Important"
		},
		"bn": {
			"name": "করণীয়",
			"desc": "গুরুত্বপূর্ণ এবং সম্পন্ন আইটেমসহ একটি মিথস্ক্রিয় করণীয় তালিকা প্রদর্শন করে।",
			"title": "করণীয় তালিকা",
			"settings": {
				"color": "ফন্টের রঙ",
				"color_options": {
					"light": "হালকা",
					"dark": "গাঢ়"
				},
				"tags": "ট্যাগ",
				"tags_placeholder": "ট্যাগ নাম প্রবেশ করান এবং Enter চাপুন"
			},
			"add": "আইটেম যোগ করুন",
			"none": "কোনটি নয়",
			"important": "গুরুত্বপূর্ণ"
		},
		"ca": {
			"name": "To-do",
			"desc": "Displays an interactive to-do list with important and completed items.",
			"title": "To-do list",
			"settings": {
				"color": "Font Color",
				"color_options": {
					"light": "Light",
					"dark": "Dark"
				},
				"tags": "Tags",
				"tags_placeholder": "Enter a tag name and press Enter"
			},
			"add": "Add Item",
			"none": "None",
			"important": "Important"
		},
		"cs": {
			"name": "Seznam úkolů",
			"desc": "Zobrazí interaktivní seznam úkolů s významnými a dokončenými položkami.",
			"title": "Seznam úkolů",
			"settings": {
				"color": "Barva písma",
				"color_options": {
					"light": "Slabé",
					"dark": "Tmavý"
				},
				"tags": "Štítky",
				"tags_placeholder": "Zadej název štítku a stikni Enter"
			},
			"add": "Přidat položku",
			"none": "Prázdný",
			"important": "Důležité"
		},
		"da": {
			"name": "To-do",
			"desc": "Displays an interactive to-do list with important and completed items.",
			"title": "To-do list",
			"settings": {
				"color": "Font Color",
				"color_options": {
					"light": "Light",
					"dark": "Dark"
				},
				"tags": "Tags",
				"tags_placeholder": "Enter a tag name and press Enter"
			},
			"add": "Add Item",
			"none": "None",
			"important": "Important"
		},
		"de": {
			"name": "To-do",
			"desc": "Zeigt eine interaktive to-do-Liste mit wichtigen und abgeschlossenen Elementen.",
			"title": "To-do-Liste",
			"settings": {
				"color": "Schriftfarbe",
				"color_options": {
					"light": "Hell",
					"dark": "Dunkel"
				},
				"tags": "Markierungen",
				"tags_placeholder": "Geben Sie einen Tag-Namen ein und drücken Sie die Eingabetaste"
			},
			"add": "Element  hinzufügen",
			"none": "Nichts",
			"important": "Wichtig"
		},
		"es": {
			"name": "Tareas",
			"desc": "Muestra una lista de tareas interactivas con elementos importantes y completados.",
			"title": "Lista de tareas",
			"settings": {
				"color": "Color del texto",
				"color_options": {
					"light": "Aclarado",
					"dark": "Oscuro"
				},
				"tags": "Etiquetas",
				"tags_placeholder": "Escriba un nombre de etiqueta y pulse Enter"
			},
			"add": "Añadir Artículo",
			"none": "Ninguno",
			"important": "Importante"
		},
		"fr": {
			"name": "À faire",
			"desc": "Affiche une liste  interactive de tâches à effectuer avec des marqueurs \"important\" et \"réalisé\".",
			"title": "Liste de tâches",
			"settings": {
				"color": "Couleur de police",
				"color_options": {
					"light": "Luminosité",
					"dark": "sombre"
				},
				"tags": "Tags",
				"tags_placeholder": "Entrez un nom de balise et appuyez sur entrée"
			},
			"add": "Ajouter une note",
			"none": "Aucun",
			"important": "Important"
		},
		"he": {
			"name": "To-do",
			"desc": "Displays an interactive to-do list with important and completed items.",
			"title": "To-do list",
			"settings": {
				"color": "Font Color",
				"color_options": {
					"light": "Light",
					"dark": "Dark"
				},
				"tags": "Tags",
				"tags_placeholder": "Enter a tag name and press Enter"
			},
			"add": "Add Item",
			"none": "None",
			"important": "Important"
		},
		"hi": {
			"name": "To-do",
			"desc": "Displays an interactive to-do list with important and completed items.",
			"title": "To-do list",
			"settings": {
				"color": "Font Color",
				"color_options": {
					"light": "Light",
					"dark": "Dark"
				},
				"tags": "Tags",
				"tags_placeholder": "Enter a tag name and press Enter"
			},
			"add": "Add Item",
			"none": "None",
			"important": "Important"
		},
		"hr": {
			"name": "Za napraviti",
			"desc": "Prikazuje interaktivnu listu zadataka sa važnim i dovršenim stavkama.",
			"title": "Popis obveza",
			"settings": {
				"color": "Boja fonta",
				"color_options": {
					"light": "Svijetla",
					"dark": "Tamna"
				},
				"tags": "Tagovi",
				"tags_placeholder": "Unesi naziv taga i pritisni Enter"
			},
			"add": "Dodaj stavku",
			"none": "Ništa",
			"important": "Važno"
		},
		"id": {
			"name": "To-do",
			"desc": "Displays an interactive to-do list with important and completed items.",
			"title": "To-do list",
			"settings": {
				"color": "Font Color",
				"color_options": {
					"light": "Light",
					"dark": "Dark"
				},
				"tags": "Tags",
				"tags_placeholder": "Enter a tag name and press Enter"
			},
			"add": "Add Item",
			"none": "None",
			"important": "Important"
		},
		"it": {
			"name": "Da fare",
			"desc": "Mostra una lista interattiva di promemoria con elementi importati e completati.",
			"title": "Promemoria",
			"settings": {
				"color": "Colore carattere",
				"color_options": {
					"light": "Chiaro",
					"dark": "Scuro"
				},
				"tags": "Etichette",
				"tags_placeholder": "Inserisci il nome di un etichetta e premi invio"
			},
			"add": "Aggiungi elemento",
			"none": "Niente",
			"important": "Importante"
		},
		"ja": {
			"name": "To-Do",
			"desc": "編集可能な To-Do リストを表示します。",
			"title": "To-Do リスト",
			"settings": {
				"color": "フォントの色",
				"color_options": {
					"light": "明るい",
					"dark": "ダーク"
				},
				"tags": "タグ",
				"tags_placeholder": "タグを入力して Enter"
			},
			"add": "項目を追加",
			"none": "未設定",
			"important": "重要"
		},
		"nl": {
			"name": "Taken",
			"desc": "Geeft een interactieve takenlijst weer met belangrijke en voltooide taken.",
			"title": "Takenlijst",
			"settings": {
				"color": "Tekstkleur",
				"color_options": {
					"light": "Licht",
					"dark": "Donker"
				},
				"tags": "Labels",
				"tags_placeholder": "Vul een tagnaam in en druk enter"
			},
			"add": "Item toevoegen",
			"none": "Geen",
			"important": "Belangrijk"
		},
		"pl": {
			"name": "Zadania do wykonania",
			"desc": "Wyświetla interaktywną listę zadań do wykonania z zaznaczeniem ważnych lub wykonanych pozycji.",
			"title": "Lista zadań do wykonania",
			"settings": {
				"color": "Kolor czcionki",
				"color_options": {
					"light": "Jasny",
					"dark": "Ciemny"
				},
				"tags": "Etykiety",
				"tags_placeholder": "Wpisz nazwę etykiety i wciśnij Enter"
			},
			"add": "Dodaj",
			"none": "Brak",
			"important": "Ważne"
		},
		"pt-PT": {
			"name": "Tarefas pendentes",
			"desc": "Exibe uma lista de tarefas interativas com itens importantes e concluídos.",
			"title": "Lista para fazer",
			"settings": {
				"color": "Cor do texto",
				"color_options": {
					"light": "Leve",
					"dark": "Escuro"
				},
				"tags": "Etiquetas",
				"tags_placeholder": "Insira um nome de etiqueta e pressione Enter"
			},
			"add": "Adicionar item",
			"none": "Nenhum",
			"important": "Importante"
		},
		"ru": {
			"name": "Список дел",
			"desc": "Отображает список задач с приоритетами и состоянием готовности.",
			"title": "Список дел",
			"settings": {
				"color": "Цвет шрифта",
				"color_options": {
					"light": "Светлый",
					"dark": "Темный"
				},
				"tags": "Метки",
				"tags_placeholder": "Введите название метки и нажмите Enter"
			},
			"add": "Добавить",
			"none": "Обычное",
			"important": "Важное"
		},
		"sr": {
			"name": "За-Урадити",
			"desc": "Приказује интерактивну за-урадити листу са битним и комплетним ставкама.",
			"title": "За-Урадити листа",
			"settings": {
				"color": "Боја фонта",
				"color_options": {
					"light": "Светло",
					"dark": "Тамно"
				},
				"tags": "Етикете",
				"tags_placeholder": "Унеси име етикете и притисни Ентер"
			},
			"add": "Додај артикл",
			"none": "ништа",
			"important": "Важно"
		},
		"tr": {
			"name": "Yapılacaklar",
			"desc": "Yapılacaklar listesi ile tamamlanmış ve önemli öğeleri görüntüler.",
			"title": "Yapılacaklar listesi",
			"settings": {
				"color": "Yazı tipi rengi",
				"color_options": {
					"light": "Açık",
					"dark": "Siyah"
				},
				"tags": "Etiketler",
				"tags_placeholder": "Bir etiket adı girin ve Enter tuşuna basın"
			},
			"add": "Öğe Ekle",
			"none": "Hiçbiri",
			"important": "Önemli"
		},
		"uk": {
			"name": "To-do",
			"desc": "Displays an interactive to-do list with important and completed items.",
			"title": "To-do list",
			"settings": {
				"color": "Font Color",
				"color_options": {
					"light": "Light",
					"dark": "Dark"
				},
				"tags": "Tags",
				"tags_placeholder": "Enter a tag name and press Enter"
			},
			"add": "Add Item",
			"none": "None",
			"important": "Important"
		},
		"zh-CN": {
			"name": "待办事项",
			"desc": "显示交互式的待办事项列表。",
			"title": "待办事项",
			"settings": {
				"color": "字体颜色",
				"color_options": {
					"light": "亮色调",
					"dark": "暗色调"
				},
				"tags": "标签",
				"tags_placeholder": "输入标签名称后按回车键确认"
			},
			"add": "添加",
			"none": "普通",
			"important": "重要"
		},
		"zh-TW": {
			"name": "待辦事項",
			"desc": "顯示包含重要事項及已完成事項的待辦事項清單",
			"title": "待辦清單",
			"settings": {
				"color": "字型顏色",
				"color_options": {
					"light": "淺色",
					"dark": "暗色"
				},
				"tags": "標籤",
				"tags_placeholder": "輸入標記的名稱並按 enter 鍵"
			},
			"add": "加入項目",
			"none": "無",
			"important": "重要"
		}
	},
	"isCompiled": true
});


define("json!w/topsites/manifest.json",{
	"id": 12,
	"sort": 220,
	"name": "topsites",
	"model": "model",
	"icon": "topsites.png",
	"sizes": [
		"variable"
	],
	"browser_permissions": [
		"topSites"
	],
	"views": {
		"default": "view"
	},
	"templates": {
		"desc": "templates/desc.hjs",
		"default": "templates/main.hjs"
	},
	"settings": [
		{
			"type": "text",
			"name": "title",
			"label": "i18n.settings.title",
			"placeholder": "i18n.settings.title_placeholder"
		},
		{
			"type": "number",
			"name": "show",
			"label": "i18n.settings.show",
			"min": 1,
			"max": 20
		}
	],
	"strings": {
		"en": {
			"name": "Top Sites",
			"desc": "Displays your most visited/top sites.",
			"settings": {
				"show": "Number of sites shown"
			}
		},
		"bn": {
			"name": "শীর্ষ সাইট",
			"desc": "Displays your most visited/top sites.",
			"settings": {
				"show": "দেখানো সাইটের সংখ্যা"
			}
		},
		"ca": {
			"name": "Top Sites",
			"desc": "Displays your most visited/top sites.",
			"settings": {
				"show": "Number of sites shown"
			}
		},
		"cs": {
			"name": "Oblíbené weby",
			"desc": "Zobrazí vaše nejnavštěvovanější stránky.",
			"settings": {
				"show": "Počet zobrazovaných stránek"
			}
		},
		"da": {
			"name": "Top Sites",
			"desc": "Displays your most visited/top sites.",
			"settings": {
				"show": "Number of sites shown"
			}
		},
		"de": {
			"name": "Top-Seiten",
			"desc": "Zeigt die meistbesuchten-/Top-Websites.",
			"settings": {
				"show": "Anzahl der angezeigten Websites"
			}
		},
		"es": {
			"name": "Paginas web principales",
			"desc": "Muestra los sitios más visitados y la parte superior.",
			"settings": {
				"show": "Número de sitios de muestra"
			}
		},
		"fr": {
			"name": "Sites favoris",
			"desc": "Affiche vos sites préférés/les plus visités.",
			"settings": {
				"show": "Nombre de sites affichés"
			}
		},
		"he": {
			"name": "Top Sites",
			"desc": "Displays your most visited/top sites.",
			"settings": {
				"show": "Number of sites shown"
			}
		},
		"hi": {
			"name": "Top Sites",
			"desc": "Displays your most visited/top sites.",
			"settings": {
				"show": "Number of sites shown"
			}
		},
		"hr": {
			"name": "Najposjećenije stranice",
			"desc": "Prikazuje tvoje najposjećenije stranice.",
			"settings": {
				"show": "Broj prikazanih stranica"
			}
		},
		"id": {
			"name": "Top Sites",
			"desc": "Displays your most visited/top sites.",
			"settings": {
				"show": "Number of sites shown"
			}
		},
		"it": {
			"name": "Siti più visitati",
			"desc": "Visualizza i siti che visiti maggiormente.",
			"settings": {
				"show": "Numero di siti visualizzati"
			}
		},
		"ja": {
			"name": "トップサイト",
			"desc": "よく閲覧するサイトを表示します。",
			"settings": {
				"show": "表示するサイトの数"
			}
		},
		"nl": {
			"name": "Topsites",
			"desc": "Geeft uw meest bezochte/beste websites weer.",
			"settings": {
				"show": "Aantal getoonde websites"
			}
		},
		"pl": {
			"name": "Najlepsze strony",
			"desc": "Wyświetla najczęściej odwiedzone bądź najlepsze strony.",
			"settings": {
				"show": "Ilość wyświetlanych stron"
			}
		},
		"pt-PT": {
			"name": "Top Sites",
			"desc": "Exibe suas principais sites mais visitados /.",
			"settings": {
				"show": "Número de locais mostrado"
			}
		},
		"ru": {
			"name": "Популярные сайты",
			"desc": "Отображает список Ваших популярных по посещаемости сайтов.",
			"settings": {
				"show": "Количество отображаемых сайтов"
			}
		},
		"sr": {
			"name": "Најпосећенији сајтови",
			"desc": "Приказује твоје најпосећеније сајтове.",
			"settings": {
				"show": "Број приказаних сајтова"
			}
		},
		"tr": {
			"name": "En iyi siteler",
			"desc": "En çok ziyaret edilen siteleri görüntüler.",
			"settings": {
				"show": "Gösterilecek site sayısı"
			}
		},
		"uk": {
			"name": "Top Sites",
			"desc": "Displays your most visited/top sites.",
			"settings": {
				"show": "Number of sites shown"
			}
		},
		"zh-CN": {
			"name": "常用网站",
			"desc": "显示您经常访问/常用的的网站。",
			"settings": {
				"show": "显示网站数目"
			}
		},
		"zh-TW": {
			"name": "置頂網站",
			"desc": "顯示您最常去/熱門網站",
			"settings": {
				"show": "顯示的網站的數目"
			}
		}
	},
	"isCompiled": true
});


define("json!w/traffic/manifest.json",{
	"id": 9,
	"sort": 150,
	"name": "traffic",
	"model": "model",
	"icon": "traffic.png",
	"sizes": [
		"tiny",
		"small"
	],
	"views": {
		"default": "view"
	},
	"templates": {
		"desc": "templates/desc.hjs",
		"default": "templates/main.hjs"
	},
	"settings": [
		{
			"type": "size"
		},
		{
			"type": "time",
			"name": "time",
			"label": "i18n.settings.leave"
		},
		{
			"type": "text",
			"name": "home",
			"label": "i18n.settings.home",
			"placeholder": "i18n.settings.home_placeholder"
		},
		{
			"type": "text",
			"name": "work",
			"label": "i18n.settings.work",
			"placeholder": "i18n.settings.work_placeholder"
		},
		{
			"type": "select",
			"name": "mode",
			"label": "i18n.settings.method",
			"options": {
				"D": "i18n.settings.method_options.driving",
				"W": "i18n.settings.method_options.walking",
				"T": "i18n.settings.method_options.transit"
			}
		}
	],
	"strings": {
		"en": {
			"name": "Traffic",
			"desc": "Displays the current time in current traffic to home or work.",
			"settings": {
				"leave": "I leave home at",
				"home": "Home Address",
				"home_placeholder": "The destination that should be used after work",
				"work": "Work Address",
				"work_placeholder": "The destination that should be used before work",
				"method": "Transit Method",
				"method_options": {
					"driving": "Driving",
					"walking": "Walking",
					"transit": "Public Transit"
				}
			},
			"to_home": "to home",
			"to_work": "to work",
			"hour": "%s hour",
			"hours": "%s hours",
			"hours_letter": "%sh",
			"minute": "%s minute",
			"minutes": "%s minutes",
			"minute_short": "%s min",
			"minutes_short": "%s mins",
			"minutes_letter": "%sm"
		},
		"bn": {
			"name": "ট্রাফিক",
			"desc": "Displays the current time in current traffic to home or work.",
			"settings": {
				"leave": "I leave home at",
				"home": "বাড়ির ঠিকানা",
				"home_placeholder": "The destination that should be used after work",
				"work": "কর্মস্থানের ঠিকানা",
				"work_placeholder": "The destination that should be used before work",
				"method": "Transit Method",
				"method_options": {
					"driving": "Driving",
					"walking": "হাঁটা",
					"transit": "পাবলিক পরিবহন"
				}
			},
			"to_home": "to home",
			"to_work": "to work",
			"hour": "%s hour",
			"hours": "%s hours",
			"hours_letter": "%sh",
			"minute": "%s minute",
			"minutes": "%s minutes",
			"minute_short": "%s min",
			"minutes_short": "%s mins",
			"minutes_letter": "%sm"
		},
		"ca": {
			"name": "Traffic",
			"desc": "Displays the current time in current traffic to home or work.",
			"settings": {
				"leave": "I leave home at",
				"home": "Home Address",
				"home_placeholder": "The destination that should be used after work",
				"work": "Work Address",
				"work_placeholder": "The destination that should be used before work",
				"method": "Transit Method",
				"method_options": {
					"driving": "Driving",
					"walking": "Walking",
					"transit": "Public Transit"
				}
			},
			"to_home": "to home",
			"to_work": "to work",
			"hour": "%s hour",
			"hours": "%s hours",
			"hours_letter": "%sh",
			"minute": "%s minute",
			"minutes": "%s minutes",
			"minute_short": "%s min",
			"minutes_short": "%s mins",
			"minutes_letter": "%sm"
		},
		"cs": {
			"name": "Provoz",
			"desc": "Zobrazí aktuální čas v aktuálním provozu domů nebo do práce.",
			"settings": {
				"leave": "Opouším domov v",
				"home": "Adresa domů",
				"home_placeholder": "Cíl pro použití po práci",
				"work": "Adresa do zaměstnání",
				"work_placeholder": "Cíl pro použití před prací",
				"method": "Typ dopravy",
				"method_options": {
					"driving": "Jízda autem",
					"walking": "Pěšky",
					"transit": "Veřejná doprava"
				}
			},
			"to_home": "domů",
			"to_work": "do práce",
			"hour": "%s hour",
			"hours": "%s hours",
			"hours_letter": "%sh",
			"minute": "%s minute",
			"minutes": "%s minutes",
			"minute_short": "%s min",
			"minutes_short": "%s mins",
			"minutes_letter": "%sm"
		},
		"da": {
			"name": "Traffic",
			"desc": "Displays the current time in current traffic to home or work.",
			"settings": {
				"leave": "I leave home at",
				"home": "Home Address",
				"home_placeholder": "The destination that should be used after work",
				"work": "Work Address",
				"work_placeholder": "The destination that should be used before work",
				"method": "Transit Method",
				"method_options": {
					"driving": "Driving",
					"walking": "Walking",
					"transit": "Public Transit"
				}
			},
			"to_home": "to home",
			"to_work": "to work",
			"hour": "%s hour",
			"hours": "%s hours",
			"hours_letter": "%sh",
			"minute": "%s minute",
			"minutes": "%s minutes",
			"minute_short": "%s min",
			"minutes_short": "%s mins",
			"minutes_letter": "%sm"
		},
		"de": {
			"name": "Verkehr",
			"desc": "Zeigt die aktuelle Zeit mit Verkehr nach Hause oder zur Arbeit.",
			"settings": {
				"leave": "Ich verlasse zu Hause um",
				"home": "Privatadresse",
				"home_placeholder": "Das Ziel, das nach der Arbeit verwendet werden soll",
				"work": "Geschäftsadresse",
				"work_placeholder": "Das Ziel, das vor der Arbeit verwendet werden soll",
				"method": "Transportmittel",
				"method_options": {
					"driving": "Fahren",
					"walking": "Gehen",
					"transit": "Öffentliche Verkehrsmittel"
				}
			},
			"to_home": "nach Hause",
			"to_work": "zur Arbeit",
			"hour": "%s Stunde",
			"hours": "%s Stunden",
			"hours_letter": "%sh",
			"minute": "%s Minute",
			"minutes": "%s Minuten",
			"minute_short": "%s Min",
			"minutes_short": "%s Min",
			"minutes_letter": "%sm"
		},
		"es": {
			"name": "Tráfico",
			"desc": "Muestra la hora actual en el tráfico actual a casa o el trabajo.",
			"settings": {
				"leave": "Me voy a casa en",
				"home": "Dirección de casa",
				"home_placeholder": "El destino que debe utilizarse después del trabajo",
				"work": "Dirección del trabajo",
				"work_placeholder": "El destino que debe ser usado antes del trabajo",
				"method": "Método del tránsito",
				"method_options": {
					"driving": "Conducción",
					"walking": "Andando",
					"transit": "Transporte público"
				}
			},
			"to_home": "a casa",
			"to_work": "para trabajar",
			"hour": "%s hora",
			"hours": "%s horas",
			"hours_letter": "%sh",
			"minute": "%s minuto",
			"minutes": "%s minutos",
			"minute_short": "%s min",
			"minutes_short": "%s minutos",
			"minutes_letter": "%sm"
		},
		"fr": {
			"name": "Traffic",
			"desc": "Affiche le temps qu'il faudra vous faudra pour allez travailler ou rentrer chez vous.",
			"settings": {
				"leave": "Je quittes la maison à",
				"home": "Adresse du domicile",
				"home_placeholder": "La destination qui doit être utilisé après le travail",
				"work": "Adresse professionnelle",
				"work_placeholder": "La destination qui doit utilisé avant d'aller travailler",
				"method": "Méthode de déplacement",
				"method_options": {
					"driving": "En voiture",
					"walking": "À pied",
					"transit": "Transports en commun"
				}
			},
			"to_home": "Pour aller à la maison",
			"to_work": "pour aller au travail",
			"hour": "%s heure",
			"hours": "%s heures",
			"hours_letter": "%sh",
			"minute": "%s minute",
			"minutes": "%s minutes",
			"minute_short": "%s min",
			"minutes_short": "%s mins",
			"minutes_letter": "%sm"
		},
		"he": {
			"name": "Traffic",
			"desc": "Displays the current time in current traffic to home or work.",
			"settings": {
				"leave": "I leave home at",
				"home": "Home Address",
				"home_placeholder": "The destination that should be used after work",
				"work": "Work Address",
				"work_placeholder": "The destination that should be used before work",
				"method": "Transit Method",
				"method_options": {
					"driving": "Driving",
					"walking": "Walking",
					"transit": "Public Transit"
				}
			},
			"to_home": "to home",
			"to_work": "to work",
			"hour": "%s hour",
			"hours": "%s hours",
			"hours_letter": "%sh",
			"minute": "%s minute",
			"minutes": "%s minutes",
			"minute_short": "%s min",
			"minutes_short": "%s mins",
			"minutes_letter": "%sm"
		},
		"hi": {
			"name": "Traffic",
			"desc": "Displays the current time in current traffic to home or work.",
			"settings": {
				"leave": "I leave home at",
				"home": "Home Address",
				"home_placeholder": "The destination that should be used after work",
				"work": "Work Address",
				"work_placeholder": "The destination that should be used before work",
				"method": "Transit Method",
				"method_options": {
					"driving": "Driving",
					"walking": "Walking",
					"transit": "Public Transit"
				}
			},
			"to_home": "to home",
			"to_work": "to work",
			"hour": "%s hour",
			"hours": "%s hours",
			"hours_letter": "%sh",
			"minute": "%s minute",
			"minutes": "%s minutes",
			"minute_short": "%s min",
			"minutes_short": "%s mins",
			"minutes_letter": "%sm"
		},
		"hr": {
			"name": "Promet",
			"desc": "Prikazuje trenutno vrijeme u prometu prema kući ili poslu.",
			"settings": {
				"leave": "Napuštam kuću u",
				"home": "Kućna adresa",
				"home_placeholder": "Destinacija nakon posla",
				"work": "Poslovna adresa",
				"work_placeholder": "Destinacija prije posla",
				"method": "Metoda putovanja",
				"method_options": {
					"driving": "Vožnja",
					"walking": "Pješice",
					"transit": "Javni prijevoz"
				}
			},
			"to_home": "do kuće",
			"to_work": "do posla",
			"hour": "%s sat",
			"hours": "%s sata",
			"hours_letter": "%sh",
			"minute": "%s minuta",
			"minutes": "%s minuta",
			"minute_short": "%s min",
			"minutes_short": "%s min",
			"minutes_letter": "%sm"
		},
		"id": {
			"name": "Traffic",
			"desc": "Displays the current time in current traffic to home or work.",
			"settings": {
				"leave": "I leave home at",
				"home": "Home Address",
				"home_placeholder": "The destination that should be used after work",
				"work": "Work Address",
				"work_placeholder": "The destination that should be used before work",
				"method": "Transit Method",
				"method_options": {
					"driving": "Driving",
					"walking": "Walking",
					"transit": "Public Transit"
				}
			},
			"to_home": "to home",
			"to_work": "to work",
			"hour": "%s hour",
			"hours": "%s hours",
			"hours_letter": "%sh",
			"minute": "%s minute",
			"minutes": "%s minutes",
			"minute_short": "%s min",
			"minutes_short": "%s mins",
			"minutes_letter": "%sm"
		},
		"it": {
			"name": "Traffico",
			"desc": "Visualizza l'ora ed il traffico tra casa e luogo di lavoro.",
			"settings": {
				"leave": "Vado via di casa alle",
				"home": "Indirizzo di casa",
				"home_placeholder": "La destinazione che deve essere utilizzata dopo il lavoro",
				"work": "Indirizzo di lavoro",
				"work_placeholder": "La destinazione che deve essere utilizzata prima di lavoro",
				"method": "Metodo di trasporto",
				"method_options": {
					"driving": "In auto",
					"walking": "A piedi",
					"transit": "Transito pubblico"
				}
			},
			"to_home": "Verso casa",
			"to_work": "Verso il luogo di lavoro",
			"hour": "%s ora",
			"hours": "%s ore",
			"hours_letter": "%sh",
			"minute": "%s minuto",
			"minutes": "%s minuti",
			"minute_short": "%s min",
			"minutes_short": "%s min.",
			"minutes_letter": "%sm"
		},
		"ja": {
			"name": "交通状況",
			"desc": "自宅または勤務先までの現在の交通状況でかかる時間を表示します。",
			"settings": {
				"leave": "自宅を出発する時間",
				"home": "自宅の住所",
				"home_placeholder": "仕事の後に行く場所",
				"work": "勤務先の住所",
				"work_placeholder": "仕事の前にいる場所",
				"method": "交通手段",
				"method_options": {
					"driving": "車",
					"walking": "徒歩",
					"transit": "公共機関"
				}
			},
			"to_home": "自宅へ",
			"to_work": "勤務先へ",
			"hour": "%s 時間",
			"hours": "%s 時間",
			"hours_letter": "%s時間",
			"minute": "%s 分",
			"minutes": "%s 分",
			"minute_short": "%s 分",
			"minutes_short": "%s 分",
			"minutes_letter": "%s分"
		},
		"nl": {
			"name": "Data",
			"desc": "Toont de actuele reistijd naar huis of werk.",
			"settings": {
				"leave": "Ik ga van huis om",
				"home": "Huisadres",
				"home_placeholder": "De bestemming waar u na werk naartoe gaat",
				"work": "Werkadres",
				"work_placeholder": "De bestemming waar u voor uw werk naartoe gaat",
				"method": "OV-vervoersmiddel",
				"method_options": {
					"driving": "Onderweg",
					"walking": "Wandelen",
					"transit": "Openbaar vervoer"
				}
			},
			"to_home": "naar huis",
			"to_work": "naar werk",
			"hour": "%s uur",
			"hours": "%s uur",
			"hours_letter": "%su",
			"minute": "%s minuut",
			"minutes": "%s minuten",
			"minute_short": "%s min",
			"minutes_short": "%s min",
			"minutes_letter": "%sm"
		},
		"pl": {
			"name": "Ruch uliczny",
			"desc": "Wyświetla czas podróży do domu lub pracy wg aktualnych warunków na drogach.",
			"settings": {
				"leave": "Wychodzę z domu o",
				"home": "Adres domowy",
				"home_placeholder": "Miejsce docelowe po wyjścu z pracy",
				"work": "Adres pracy",
				"work_placeholder": "Miejsce docelowe przed pracą",
				"method": "Środek transportu",
				"method_options": {
					"driving": "Samochód",
					"walking": "Pieszo",
					"transit": "Transport publiczny"
				}
			},
			"to_home": "do domu",
			"to_work": "do pracy",
			"hour": "%s godzina",
			"hours": "%s godziny",
			"hours_letter": "%sg",
			"minute": "%s minuta",
			"minutes": "%s minut",
			"minute_short": "%s min",
			"minutes_short": "%s min",
			"minutes_letter": "%sm"
		},
		"pt-PT": {
			"name": "Tráfego",
			"desc": "Exibe a hora atual no tráfego atual para casa ou trabalho.",
			"settings": {
				"leave": "Eu saia de casa em",
				"home": "Endereço Residencial",
				"home_placeholder": "O destino que deve ser utilizado após o trabalho",
				"work": "Endereço Trabalho",
				"work_placeholder": "O destino que deve ser usado antes do trabalho",
				"method": "Método de trânsito",
				"method_options": {
					"driving": "Condução",
					"walking": "A pé",
					"transit": "Transporte público"
				}
			},
			"to_home": "para casa",
			"to_work": "ao trabalho",
			"hour": "%s hour",
			"hours": "%s hours",
			"hours_letter": "%sh",
			"minute": "%s minute",
			"minutes": "%s minutes",
			"minute_short": "%s min",
			"minutes_short": "%s mins",
			"minutes_letter": "%sm"
		},
		"ru": {
			"name": "Пробки",
			"desc": "Отображает время до дома или работы с учетом пробок.",
			"settings": {
				"leave": "Выхожу из дома в",
				"home": "Домашний адрес",
				"home_placeholder": "Адрес по которому вы едете после работы",
				"work": "Рабочий адрес",
				"work_placeholder": "Адрес вашего места работы",
				"method": "Способ передвижения",
				"method_options": {
					"driving": "На автомобиле",
					"walking": "Пешком",
					"transit": "На общественном транспорте"
				}
			},
			"to_home": "до дома",
			"to_work": "до работы",
			"hour": "%s час",
			"hours": "%s час(а/ов)",
			"hours_letter": "%sч",
			"minute": "%s минута",
			"minutes": "%s минут(ы)",
			"minute_short": "%s мин",
			"minutes_short": "%s мин",
			"minutes_letter": "%sм"
		},
		"sr": {
			"name": "Саобраћај",
			"desc": "Приказује тренутно време у тренутном путу до куће или посла.",
			"settings": {
				"leave": "Напуштам кућу у",
				"home": "Кућна адреса",
				"home_placeholder": "Дестинација које треба да се употребљава после посла",
				"work": "Пословна Адреса",
				"work_placeholder": "Дестинација које треба да се употребљава пре посла",
				"method": "Метод путовања",
				"method_options": {
					"driving": "Вожња",
					"walking": "Пешачење",
					"transit": "Градски саобраћај"
				}
			},
			"to_home": "ка кући",
			"to_work": "ка послу",
			"hour": "%s hour",
			"hours": "%s hours",
			"hours_letter": "%sh",
			"minute": "%s minute",
			"minutes": "%s minutes",
			"minute_short": "%s min",
			"minutes_short": "%s mins",
			"minutes_letter": "%sm"
		},
		"tr": {
			"name": "Trafik",
			"desc": "Ev ve iş yeri arasındaki geçerli trafik zamanını görüntüler.",
			"settings": {
				"leave": "Evden çıkış saati",
				"home": "Ev adresi",
				"home_placeholder": "İşten sonra kullanılması gereken hedef",
				"work": "İş adresi",
				"work_placeholder": "İşe gitmeden önce kullanılması gereken hedef",
				"method": "Taşıma yöntemi",
				"method_options": {
					"driving": "Sürüş",
					"walking": "Yürüyüş",
					"transit": "Toplu taşıma"
				}
			},
			"to_home": "ev için",
			"to_work": "iş için",
			"hour": "%s hour",
			"hours": "%s hours",
			"hours_letter": "%sh",
			"minute": "%s minute",
			"minutes": "%s minutes",
			"minute_short": "%s min",
			"minutes_short": "%s mins",
			"minutes_letter": "%sm"
		},
		"uk": {
			"name": "Traffic",
			"desc": "Displays the current time in current traffic to home or work.",
			"settings": {
				"leave": "I leave home at",
				"home": "Home Address",
				"home_placeholder": "The destination that should be used after work",
				"work": "Work Address",
				"work_placeholder": "The destination that should be used before work",
				"method": "Transit Method",
				"method_options": {
					"driving": "Driving",
					"walking": "Walking",
					"transit": "Public Transit"
				}
			},
			"to_home": "to home",
			"to_work": "to work",
			"hour": "%s hour",
			"hours": "%s hours",
			"hours_letter": "%sh",
			"minute": "%s minute",
			"minutes": "%s minutes",
			"minute_short": "%s min",
			"minutes_short": "%s mins",
			"minutes_letter": "%sm"
		},
		"zh-CN": {
			"name": "交通",
			"desc": "根据交通状况显示当需要多久到家或多久上班。",
			"settings": {
				"leave": "离开家的时间",
				"home": "家庭住址",
				"home_placeholder": "这将用于下班后的目的地",
				"work": "工作地址",
				"work_placeholder": "这将用于上班前的目的地",
				"method": "交通方式",
				"method_options": {
					"driving": "开车",
					"walking": "步行",
					"transit": "公共交通"
				}
			},
			"to_home": "到家",
			"to_work": "上班",
			"hour": "%s小时",
			"hours": "%s小时",
			"hours_letter": "%s时",
			"minute": "%s分钟",
			"minutes": "%s分钟",
			"minute_short": "%s分钟",
			"minutes_short": "%s分钟",
			"minutes_letter": "%s分"
		},
		"zh-TW": {
			"name": "交通",
			"desc": "顯示當前交通狀況下回家或上班所需時間",
			"settings": {
				"leave": "我離開家於",
				"home": "住家地址",
				"home_placeholder": "下班後的目的地",
				"work": "工作地址",
				"work_placeholder": "上班前的目的地",
				"method": "交通方式",
				"method_options": {
					"driving": "開車",
					"walking": "步行",
					"transit": "大眾運輸工具"
				}
			},
			"to_home": "回家",
			"to_work": "前往工作",
			"hour": "%s 小時",
			"hours": "%s 小時",
			"hours_letter": "%s小時",
			"minute": "%s 分鐘",
			"minutes": "%s 分鐘",
			"minute_short": "%s 分鐘",
			"minutes_short": "%s 分鐘",
			"minutes_letter": "%s分"
		}
	},
	"isCompiled": true
});


define("json!w/translate/manifest.json",{
	"id": 20,
	"sort": 260,
	"name": "translate",
	"model": "model",
	"icon": "translate.png",
	"sizes": [
		"small"
	],
	"views": {
		"default": "view"
	},
	"templates": {
		"desc": "templates/desc.hjs",
		"default": "templates/main.hjs"
	},
	"strings": {
		"en": {
			"name": "Translate",
			"desc": "Lets you quickly translate to and from 90 languages as you type",
			"from_placeholder": "Start typing here",
			"to_placeholder": "Translated text will appear here",
			"detect_lang": "Detect language",
			"translating": "Translating...",
			"unknown": "Unknown"
		},
		"bn": {
			"name": "অনুবাদ",
			"desc": "Lets you quickly translate to and from 90 languages as you type",
			"from_placeholder": "Start typing here",
			"to_placeholder": "Translated text will appear here",
			"detect_lang": "Detect language",
			"translating": "Translating...",
			"unknown": "অজানা"
		},
		"ca": {
			"name": "Translate",
			"desc": "Lets you quickly translate to and from 90 languages as you type",
			"from_placeholder": "Start typing here",
			"to_placeholder": "Translated text will appear here",
			"detect_lang": "Detect language",
			"translating": "Translating...",
			"unknown": "Unknown"
		},
		"cs": {
			"name": "Překladač",
			"desc": "Rychle přeloží Z a DO 90 jazyků to co napíšte",
			"from_placeholder": "Začněte psát zde",
			"to_placeholder": "Přeložený text se objeví zde",
			"detect_lang": "Rozpoznat jazyk",
			"translating": "Překládá se...",
			"unknown": "Neznámý"
		},
		"da": {
			"name": "Translate",
			"desc": "Lets you quickly translate to and from 90 languages as you type",
			"from_placeholder": "Start typing here",
			"to_placeholder": "Translated text will appear here",
			"detect_lang": "Detect language",
			"translating": "Translating...",
			"unknown": "Unknown"
		},
		"de": {
			"name": "Übersetzen",
			"desc": "Schnell in und aus 90 Sprachen übersetzen",
			"from_placeholder": "Tippen Sie hier um zu starten",
			"to_placeholder": "Der übersetzte Text wird hier angezeigt",
			"detect_lang": "Sprache erkennen",
			"translating": "Wird übersetzt...",
			"unknown": "Unbekannt"
		},
		"es": {
			"name": "Traducir",
			"desc": "Lets you quickly translate to and from 90 languages as you type",
			"from_placeholder": "Comienza escribiendo aquí",
			"to_placeholder": "El texto traducido aparecerá aquí",
			"detect_lang": "Detectar idioma",
			"translating": "Traduciendo...",
			"unknown": "Desconocido"
		},
		"fr": {
			"name": "Traduire",
			"desc": "Vous permet de traduire rapidement dans 90 langues pendant que vous tapez",
			"from_placeholder": "Commencez à taper ici",
			"to_placeholder": "Le texte traduit apparaîtra ici",
			"detect_lang": "Détecter la langue",
			"translating": "Traduction en cours...",
			"unknown": "Inconnu"
		},
		"he": {
			"name": "Translate",
			"desc": "Lets you quickly translate to and from 90 languages as you type",
			"from_placeholder": "Start typing here",
			"to_placeholder": "Translated text will appear here",
			"detect_lang": "Detect language",
			"translating": "Translating...",
			"unknown": "Unknown"
		},
		"hi": {
			"name": "Translate",
			"desc": "Lets you quickly translate to and from 90 languages as you type",
			"from_placeholder": "Start typing here",
			"to_placeholder": "Translated text will appear here",
			"detect_lang": "Detect language",
			"translating": "Translating...",
			"unknown": "Unknown"
		},
		"hr": {
			"name": "Prevoditelj",
			"desc": "Omogućuje da brzo prevedeš na i sa 90 jezika dok pišeš",
			"from_placeholder": "Počni pisati ovdje",
			"to_placeholder": "Prevedeni tekst će se pojaviti ovdje",
			"detect_lang": "Otkrij jezik",
			"translating": "Prevođenje...",
			"unknown": "Nije bilo moguće pronaći prijevod"
		},
		"id": {
			"name": "Translate",
			"desc": "Lets you quickly translate to and from 90 languages as you type",
			"from_placeholder": "Start typing here",
			"to_placeholder": "Translated text will appear here",
			"detect_lang": "Detect language",
			"translating": "Translating...",
			"unknown": "Unknown"
		},
		"it": {
			"name": "traduci",
			"desc": "Permette di tradurre rapidamente in 90 lingue durante la digitazione",
			"from_placeholder": "Scrivi qui",
			"to_placeholder": "Il testo tradotto apparirà qui",
			"detect_lang": "Rileva lingua",
			"translating": "Traduzione in corso...",
			"unknown": "Sconosciuto"
		},
		"ja": {
			"name": "翻訳",
			"desc": "入力されたテキストを約 90 個の言語に一瞬で翻訳することができます。",
			"from_placeholder": "翻訳するテキストを入力",
			"to_placeholder": "翻訳されたテキストが表示されます",
			"detect_lang": "言語を検出",
			"translating": "翻訳中...",
			"unknown": "不明"
		},
		"nl": {
			"name": "Vertalen",
			"desc": "U kunt snel vertalen naar 90 talen terwijl u typt",
			"from_placeholder": "Typ hier...",
			"to_placeholder": "Vertaalde tekst verschijnt hier",
			"detect_lang": "Detecteer taal",
			"translating": "Vertalen...",
			"unknown": "Onbekend"
		},
		"pl": {
			"name": "Tłumacz",
			"desc": "Pozwala szybko tłumaczyć z/na 90 języków w miarę pisania",
			"from_placeholder": "Tu zacznij pisać",
			"to_placeholder": "Tu pojawi się przetłumaczony tekst",
			"detect_lang": "Wykryj język",
			"translating": "Tłumaczę...",
			"unknown": "Brak tłumaczenia"
		},
		"pt-PT": {
			"name": "Traduzir",
			"desc": "Lets you quickly translate to and from 90 languages as you type",
			"from_placeholder": "Start typing here",
			"to_placeholder": "Translated text will appear here",
			"detect_lang": "Detect language",
			"translating": "Translating...",
			"unknown": "Desconhecido"
		},
		"ru": {
			"name": "Переводчик",
			"desc": "Позволяет мгновенно переводить между 90 языками",
			"from_placeholder": "Начните вводить здесь",
			"to_placeholder": "Переведенный текст появится здесь",
			"detect_lang": "Определить язык",
			"translating": "Выполняется перевод...",
			"unknown": "Перевод отсутствует"
		},
		"sr": {
			"name": "Преведи",
			"desc": "Lets you quickly translate to and from 90 languages as you type",
			"from_placeholder": "Start typing here",
			"to_placeholder": "Translated text will appear here",
			"detect_lang": "Detect language",
			"translating": "Translating...",
			"unknown": "Непознато"
		},
		"tr": {
			"name": "Çeviri",
			"desc": "Lets you quickly translate to and from 90 languages as you type",
			"from_placeholder": "Start typing here",
			"to_placeholder": "Translated text will appear here",
			"detect_lang": "Detect language",
			"translating": "Translating...",
			"unknown": "Unknown"
		},
		"uk": {
			"name": "Translate",
			"desc": "Lets you quickly translate to and from 90 languages as you type",
			"from_placeholder": "Start typing here",
			"to_placeholder": "Translated text will appear here",
			"detect_lang": "Detect language",
			"translating": "Translating...",
			"unknown": "Unknown"
		},
		"zh-CN": {
			"name": "翻译",
			"desc": "快速翻译您所键入的内容（在90种语言中）",
			"from_placeholder": "输入您要翻译的内容",
			"to_placeholder": "译文将显示在此处",
			"detect_lang": "检测语言",
			"translating": "正在翻译。。。",
			"unknown": "未知"
		},
		"zh-TW": {
			"name": "翻譯",
			"desc": "讓你迅速獲得90種語言的翻譯",
			"from_placeholder": "在這裡開始打字",
			"to_placeholder": "翻譯後的文本將在此處顯示",
			"detect_lang": "偵測語言",
			"translating": "翻譯中⋯⋯",
			"unknown": "未知"
		}
	},
	"isCompiled": true
});


define("json!w/unitconversion/manifest.json",{
	"id": 54,
	"sort": 450,
	"name": "unitconversion",
	"model": "model",
	"icon": "unitconversion.png",
	"sizes": [
		"medium"
	],
	"views": {
		"default": "view"
	},
	"templates": {
		"desc": "templates/desc.hjs",
		"default": "templates/main.hjs"
	},
	"settings": [
		{
			"type": "text",
			"name": "title",
			"label": "i18n.settings.title",
			"placeholder": "i18n.settings.title_placeholder"
		}
	],
	"strings": {
		"en": {
			"name": "Unit Conversion",
			"desc": "Conversion between different units of measurement for the same quantity",
			"default_title": "Unit Conversion",
			"units": {
				"select_unit": "Select a unit..."
			},
			"messages": {
				"from": "I want to convert",
				"to": "to",
				"refresh_tooltip": "Update units list",
				"copy_tooltip": "Copy to clipboard",
				"swap_tooltip": "Change units"
			},
			"cat": {
				"select_category": "Select a category...",
				"acceleration": "Acceleration",
				"angle": "Angle",
				"apparentPower": "Apparent Power",
				"area": "Area",
				"charge": "Charge",
				"current": "Current",
				"digital": "Digital",
				"each": "Each",
				"energy": "Energy",
				"force": "Force",
				"frequency": "Frequency",
				"illuminance": "Illuminance",
				"length": "Length",
				"mass": "Mass",
				"pace": "Pace",
				"partsPer": "Parts Per",
				"power": "Power",
				"pressure": "Pressure",
				"reactiveEnergy": "Reactive Energy",
				"reactivePower": "Reactive Power",
				"speed": "Speed",
				"temperature": "Temperature",
				"time": "Time",
				"voltage": "Voltage",
				"volume": "Volume",
				"volumeFlowRate": "Volume Flow Rate"
			},
			"settings": {
				"title": "Title",
				"title_placeholder": "Enter a widget title"
			}
		}
	},
	"isCompiled": true
});


define("json!w/unread/manifest.json",{
	"id": 6,
	"sort": 280,
	"name": "unread",
	"model": "model",
	"icon": "unread.png",
	"defaultSize": "tiny",
	"sizes": [
		"tiny",
		"small"
	],
	"views": {
		"default": "view"
	},
	"templates": {
		"desc": "templates/desc.hjs",
		"default": "templates/main.hjs"
	},
	"settings": [
		{
			"type": "text",
			"name": "user",
			"label": "i18n.settings.account",
			"help": "i18n.settings.account_help",
			"placeholder": "i18n.settings.account_placeholder"
		},
		{
			"type": "size"
		},
		{
			"type": "radio",
			"name": "open",
			"label": "i18n.settings.open",
			"options": {
				"inbox": "Inbox",
				"gmail": "Gmail"
			}
		}
	],
	"strings": {
		"en": {
			"name": "Unread",
			"desc": "Displays the current number of unread emails in your Gmail inbox.",
			"settings": {
				"open": "When clicked open"
			},
			"unread_none": "unread emails",
			"unread_one": "unread email",
			"unread_many": "unread emails"
		},
		"bn": {
			"name": "অপঠিত",
			"desc": "Displays the current number of unread emails in your Gmail inbox.",
			"settings": {
				"open": "When clicked open"
			},
			"unread_none": "অপঠিত ইমেইল",
			"unread_one": "অপঠিত ইমেইল",
			"unread_many": "অপঠিত ইমেইল"
		},
		"ca": {
			"name": "Unread",
			"desc": "Displays the current number of unread emails in your Gmail inbox.",
			"settings": {
				"open": "When clicked open"
			},
			"unread_none": "unread emails",
			"unread_one": "unread email",
			"unread_many": "unread emails"
		},
		"cs": {
			"name": "Nepřečtené",
			"desc": "Zobrazí současný počet nepřečtených emailů v doručené poště Gmail.",
			"settings": {
				"open": "Po kliknutí otevřít"
			},
			"unread_none": "nepřečtené e-maily",
			"unread_one": "nepřečtený e-mail",
			"unread_many": "nepřečtené e-maily"
		},
		"da": {
			"name": "Unread",
			"desc": "Displays the current number of unread emails in your Gmail inbox.",
			"settings": {
				"open": "When clicked open"
			},
			"unread_none": "unread emails",
			"unread_one": "unread email",
			"unread_many": "unread emails"
		},
		"de": {
			"name": "Ungelesen",
			"desc": "Zeigt die aktuelle Anzahl der ungelesenen E-Mails im Google Mail-Posteingang.",
			"settings": {
				"open": "Wenn Öffnen geklickt"
			},
			"unread_none": "ungelesene E-Mails",
			"unread_one": "ungelesene E-Mail",
			"unread_many": "ungelesene E-Mails"
		},
		"es": {
			"name": "Sin leer",
			"desc": "Muestra el número actual de mensajes no leídos en su bandeja de entrada de Gmail.",
			"settings": {
				"open": "Cuando hace clic en abrir"
			},
			"unread_none": "e-mails no leídos",
			"unread_one": "e-mails no leídos",
			"unread_many": "e-mails no leídos"
		},
		"fr": {
			"name": "Non lus",
			"desc": "Affiche le nombre de courriels non lus dans votre boîte de réception Gmail.",
			"settings": {
				"open": "Lorsque vous cliquez sur Ouvrir"
			},
			"unread_none": "courriels non lus",
			"unread_one": "courriel non lu",
			"unread_many": "courriels non lus"
		},
		"he": {
			"name": "Unread",
			"desc": "Displays the current number of unread emails in your Gmail inbox.",
			"settings": {
				"open": "When clicked open"
			},
			"unread_none": "unread emails",
			"unread_one": "unread email",
			"unread_many": "unread emails"
		},
		"hi": {
			"name": "Unread",
			"desc": "Displays the current number of unread emails in your Gmail inbox.",
			"settings": {
				"open": "When clicked open"
			},
			"unread_none": "unread emails",
			"unread_one": "unread email",
			"unread_many": "unread emails"
		},
		"hr": {
			"name": "Nepročitano",
			"desc": "Prikazuje trenutni broj nepročitanih poruka na Gmail-u.",
			"settings": {
				"open": "Kada je kliknuto otvori"
			},
			"unread_none": "nepročitanih mailova",
			"unread_one": "nepročitan mail",
			"unread_many": "nepročitanih mailova"
		},
		"id": {
			"name": "Unread",
			"desc": "Displays the current number of unread emails in your Gmail inbox.",
			"settings": {
				"open": "When clicked open"
			},
			"unread_none": "unread emails",
			"unread_one": "unread email",
			"unread_many": "unread emails"
		},
		"it": {
			"name": "Da leggere",
			"desc": "Mostra il numero corrente di email non lette nella tua casella Gmail.",
			"settings": {
				"open": "Quando cliccato apri"
			},
			"unread_none": "Email non lette",
			"unread_one": "Email non lette",
			"unread_many": "Email non lette"
		},
		"ja": {
			"name": "Gmail の未読メール",
			"desc": "Gmail の受信トレイにある未読メールの数を表示します。",
			"settings": {
				"open": "クリック時に開くサービス"
			},
			"unread_none": "未読メール",
			"unread_one": "未読メール",
			"unread_many": "未読メール"
		},
		"nl": {
			"name": "Ongelezen",
			"desc": "Geeft het aantal ongelezen e-mails uit uw Gmail-postvak weer.",
			"settings": {
				"open": "Bij klikken open"
			},
			"unread_none": "ongelezen e-mails",
			"unread_one": "ongelezen e-mail",
			"unread_many": "ongelezen e-mails"
		},
		"pl": {
			"name": "Nieprzeczytane",
			"desc": "Wyświetla liczbę nieprzeczytanych emaili ze skrzynki Gmail.",
			"settings": {
				"open": "Przy kliknięciu otwórz"
			},
			"unread_none": "nieprzeczytanych emaili",
			"unread_one": "nieprzeczytany email",
			"unread_many": "nieprzeczytanych emaili"
		},
		"pt-PT": {
			"name": "Não lido",
			"desc": "Exibe o número atual de e-mails não lidos em sua caixa de entrada do Gmail.",
			"settings": {
				"open": "Aberto quando for clicado"
			},
			"unread_none": "e-mails não lidos",
			"unread_one": "e-mails não lidos",
			"unread_many": "e-mails não lidos"
		},
		"ru": {
			"name": "Непрочитанные",
			"desc": "Отображает количество непрочитанных писем из вашего почтового ящика Gmail.",
			"settings": {
				"open": "Открывать при нажатии"
			},
			"unread_none": "непрочитанных писем",
			"unread_one": "непрочитанное письмо",
			"unread_many": "непрочитанных писем"
		},
		"sr": {
			"name": "Непрочитано",
			"desc": "Приказује тренутан број непрочитаних email-ова ит твог Gmail поштанског сандучета.",
			"settings": {
				"open": "Када је притиснуто за отварање"
			},
			"unread_none": "Непрочитани email-ови",
			"unread_one": "Непрочитани email",
			"unread_many": "Непрочитани email-ови"
		},
		"tr": {
			"name": "Unread",
			"desc": "Displays the current number of unread emails in your Gmail inbox.",
			"settings": {
				"open": "When clicked open"
			},
			"unread_none": "unread emails",
			"unread_one": "unread email",
			"unread_many": "unread emails"
		},
		"uk": {
			"name": "Unread",
			"desc": "Displays the current number of unread emails in your Gmail inbox.",
			"settings": {
				"open": "When clicked open"
			},
			"unread_none": "unread emails",
			"unread_one": "unread email",
			"unread_many": "unread emails"
		},
		"zh-CN": {
			"name": "未读邮件",
			"desc": "显示您Gmail邮箱中的未读邮件数目。",
			"settings": {
				"open": "点击时打开"
			},
			"unread_none": "封未读邮件",
			"unread_one": "封未读邮件",
			"unread_many": "封未读邮件"
		},
		"zh-TW": {
			"name": "未讀取",
			"desc": "在你的 Gmail 收件匣中顯示當前的未讀郵件數量。",
			"settings": {
				"open": "當點下打開時"
			},
			"unread_none": "未讀的郵件",
			"unread_one": "未讀的郵件",
			"unread_many": "未讀的郵件"
		}
	},
	"isCompiled": true
});


define("json!w/voice/manifest.json",{
	"id": 22,
	"sort": 430,
	"name": "voice",
	"model": "model",
	"icon": "voice.png",
	"defaultSize": "tiny",
	"sizes": [
		"tiny",
		"small"
	],
	"views": {
		"default": "view"
	},
	"templates": {
		"desc": "templates/desc.hjs",
		"default": "templates/main.hjs"
	},
	"settings": [
		{
			"type": "text",
			"name": "user",
			"label": "i18n.settings.account",
			"help": "i18n.settings.account_help",
			"placeholder": "i18n.settings.account_placeholder"
		},
		{
			"type": "size"
		}
	],
	"strings": {
		"en": {
			"name": "Voice",
			"desc": "Displays the current number of missed calls and texts in your Google Voice account.",
			"call": "Call from",
			"text": "Text message from",
			"missed": "missed in Voice",
			"texts": "unread text messages",
			"calls": "missed calls"
		},
		"bn": {
			"name": "কন্ঠ",
			"desc": "Displays the current number of missed calls and texts in your Google Voice account.",
			"call": "Call from",
			"text": "Text message from",
			"missed": "missed in Voice",
			"texts": "অপঠিত পাঠ্য বার্তা",
			"calls": "মিসকৃত কল"
		},
		"ca": {
			"name": "Voice",
			"desc": "Displays the current number of missed calls and texts in your Google Voice account.",
			"call": "Call from",
			"text": "Text message from",
			"missed": "missed in Voice",
			"texts": "unread text messages",
			"calls": "missed calls"
		},
		"cs": {
			"name": "Hlas",
			"desc": "Zobrazí současný počet zmeškaných hovorů a zpráv na vašem účtu Google Voice.",
			"call": "Hovor od",
			"text": "Zpráva od",
			"missed": "zmeškaný ve Voice",
			"texts": "nepřečtené zprávy",
			"calls": "zmeškané hovory"
		},
		"da": {
			"name": "Voice",
			"desc": "Displays the current number of missed calls and texts in your Google Voice account.",
			"call": "Call from",
			"text": "Text message from",
			"missed": "missed in Voice",
			"texts": "unread text messages",
			"calls": "missed calls"
		},
		"de": {
			"name": "Voice",
			"desc": "Zeigt die aktuelle Anzahl der Anrufe in Abwesenheit und Nachrichten im Google Voice-Konto.",
			"call": "Anruf von",
			"text": "Kurzmitteilung von",
			"missed": "Verasst in Voice",
			"texts": "ungelesene Textnachrichten",
			"calls": "Entgangene Anrufe"
		},
		"es": {
			"name": "Voz",
			"desc": "Muestra el número actual de textos y llamadas perdidas en tu cuenta de Google Voice.",
			"call": "Llamar desde",
			"text": "Mensaje de texto",
			"missed": "perdido en voz",
			"texts": "mensajes de texto no leídos",
			"calls": "llamadas perdidas"
		},
		"fr": {
			"name": "Voice",
			"desc": "Affiche le nombre actuel d'appels et de messages manqués dans Google Voice.",
			"call": "Appelez à partir de",
			"text": "Message texte de la part de",
			"missed": "Appel manqué",
			"texts": "messages non lus",
			"calls": "appels manqués"
		},
		"he": {
			"name": "Voice",
			"desc": "Displays the current number of missed calls and texts in your Google Voice account.",
			"call": "Call from",
			"text": "Text message from",
			"missed": "missed in Voice",
			"texts": "unread text messages",
			"calls": "missed calls"
		},
		"hi": {
			"name": "Voice",
			"desc": "Displays the current number of missed calls and texts in your Google Voice account.",
			"call": "Call from",
			"text": "Text message from",
			"missed": "missed in Voice",
			"texts": "unread text messages",
			"calls": "missed calls"
		},
		"hr": {
			"name": "Voice",
			"desc": "Prikazuje broj propuštenih poziva i poruka sa Google Voice računa.",
			"call": "Poziv od",
			"text": "Poruka od",
			"missed": "propuštenih u Voice-u",
			"texts": "nepročitanih poruka",
			"calls": "propuštenih poziva"
		},
		"id": {
			"name": "Voice",
			"desc": "Displays the current number of missed calls and texts in your Google Voice account.",
			"call": "Call from",
			"text": "Text message from",
			"missed": "missed in Voice",
			"texts": "unread text messages",
			"calls": "missed calls"
		},
		"it": {
			"name": "Voice",
			"desc": "Mostra il numero di chiamate e messaggi persi del tuo account Google Voice.",
			"call": "Chiamata da",
			"text": "Messaggio da parte di",
			"missed": "Chiamate perse",
			"texts": "Messaggi non letti",
			"calls": "Chiamate perse"
		},
		"ja": {
			"name": "Voice",
			"desc": "Google Voice の不在着信やメッセージの数を表示します。",
			"call": "着信",
			"text": "SMS 着信",
			"missed": "不在ボイス着信",
			"texts": "未読メッセージ",
			"calls": "不在着信"
		},
		"nl": {
			"name": "Voice",
			"desc": "Geeft het actuele aantal gemiste oproepen en sms'jes in je Google Voice-account weer.",
			"call": "Oproep van",
			"text": "SMS van",
			"missed": "gemist in Voice",
			"texts": "ongelezen sms'jes",
			"calls": "gemiste oproepen"
		},
		"pl": {
			"name": "Głos",
			"desc": "Wyświetla liczbę nieodebranych połączeń i nieprzeczytanych wiadomości z konta Google Voice.",
			"call": "Zadzwoń z",
			"text": "Wiadomość od",
			"missed": "nieodebranych w Voice",
			"texts": "nieprzeczytanych wiadomości",
			"calls": "nieodebranych połączeń"
		},
		"pt-PT": {
			"name": "Voz",
			"desc": "Exibe o número atual de chamadas não atendidas e textos na sua conta do Google Voice.",
			"call": "Chamar de",
			"text": "Mensagem de texto de",
			"missed": "perdeu no Google Voice",
			"texts": "mensagens de texto não lidas",
			"calls": "Chamadas perdidas"
		},
		"ru": {
			"name": "Звонки",
			"desc": "Отображает количество пропущенных звонков из профиля Google Voice.",
			"call": "Звонок от",
			"text": "Сообщение от",
			"missed": "пропущенных звонков",
			"texts": "непрочитанных сообщений",
			"calls": "пропущенных звонков"
		},
		"sr": {
			"name": "Глас",
			"desc": "Приказује тренутни број пропуштених позива и поруке са твог Google Voice рачуна.",
			"call": "Позив од",
			"text": "Поруке од",
			"missed": "Пропуштени у Гласу",
			"texts": "Непрочитане текстуалне поруке",
			"calls": "Пропуштени позиви"
		},
		"tr": {
			"name": "Voice",
			"desc": "Displays the current number of missed calls and texts in your Google Voice account.",
			"call": "Call from",
			"text": "Text message from",
			"missed": "missed in Voice",
			"texts": "unread text messages",
			"calls": "missed calls"
		},
		"uk": {
			"name": "Voice",
			"desc": "Displays the current number of missed calls and texts in your Google Voice account.",
			"call": "Call from",
			"text": "Text message from",
			"missed": "missed in Voice",
			"texts": "unread text messages",
			"calls": "missed calls"
		},
		"zh-CN": {
			"name": "Google Voice",
			"desc": "显示您Google Voice中未查看的来电和短信。",
			"call": "呼叫人",
			"text": "发信人",
			"missed": "未接来电",
			"texts": "条未读短信",
			"calls": "个未接来电"
		},
		"zh-TW": {
			"name": "語音",
			"desc": "在你的 Google Voice 帳戶顯示未接來電和簡訊的數目。",
			"call": "來電從",
			"text": "文字訊息從",
			"missed": "未收聽留言",
			"texts": "未讀簡訊",
			"calls": "未接來電"
		}
	},
	"isCompiled": true
});


define("json!w/weather/manifest.json",{
	"id": 1,
	"sort": 20,
	"name": "weather",
	"model": "model",
	"icon": "weather.png",
	"sizes": [
		"tiny",
		"variable"
	],
	"defaultSize": "variable",
	"views": {
		"default": "view"
	},
	"templates": {
		"desc": "templates/desc.hjs",
		"default": "templates/main.hjs",
		"details": "templates/details.hjs"
	},
	"settings": [
		{
			"type": "size"
		},
		{
			"type": "list",
			"name": "location",
			"autocomplete": "autocomplete",
			"label": "i18n.settings.location",
			"placeholder": "i18n.settings.location_placeholder",
			"browserautocomplete": "nope"
		},
		{
			"type": "radio",
			"name": "units",
			"label": "i18n.settings.units",
			"options": {
				"imperial": "i18n.settings.units_imperial",
				"metric": "i18n.settings.units_metric"
			}
		},
		{
			"type": "radio",
			"name": "forecast",
			"sizes": [
				"variable"
			],
			"label": "i18n.settings.forecast",
			"options": {
				"enabled": "i18n.settings.enabled",
				"disabled": "i18n.settings.disabled"
			}
		},
		{
			"pro": true,
			"type": "radio",
			"name": "hourly",
			"sizes": [
				"variable"
			],
			"label": "i18n.settings.hourly",
			"options": {
				"enabled": "i18n.settings.enabled",
				"disabled": "i18n.settings.disabled"
			}
		}
	],
	"strings": {
		"en": {
			"name": "Weather",
			"desc": "Displays the current weather and a forecast for the next 4 days.",
			"settings": {
				"location": "Location(s)",
				"location_placeholder": "Enter a location and press Enter",
				"units": "Units",
				"units_imperial": "Imperial (Fahrenheit)",
				"units_metric": "Metric (Celsius)",
				"enabled": "Enabled",
				"disabled": "Disabled",
				"forecast": "Forecasts",
				"hourly": "Hourly forecasts"
			},
			"more": "More",
			"less": "Less",
			"wind": "Wind",
			"precipitation": "Precip",
			"uv": "UV index",
			"feelslike": "Feels like",
			"barometer": "Barometer",
			"visibility": "Visibility",
			"humidity": "Humidity",
			"dewpoint": "Dew point",
			"moonphase": "Moon",
			"sunrise": "Sunrise",
			"sunset": "Sunset",
			"moonrise": "Moonrise",
			"moonset": "Moonset"
		},
		"bn": {
			"name": "আবহাওয়া",
			"desc": "Displays the current weather and a forecast for the next 4 days.",
			"settings": {
				"location": "অবস্থান",
				"location_placeholder": "অবস্থানের নাম লিখুন এবং Enter চাপুন",
				"units": "একক",
				"units_imperial": "ইম্পেরিয়াল (ফারেনহাইট)",
				"units_metric": "মেট্রিক (সেলসিয়াস)",
				"enabled": "সক্রিয়",
				"disabled": "নিষ্ক্রিয়",
				"forecast": "পূর্বাভাস",
				"hourly": "প্রতি ঘণ্টায় পূর্বাভাস"
			},
			"more": "আরও",
			"less": "কম",
			"wind": "বাতাসের গতি",
			"precipitation": "বৃষ্টিপাত.",
			"uv": "UV সূচক",
			"feelslike": "অনুভূত",
			"barometer": "ব্যারোমিটার",
			"visibility": "দৃশ্যমানতা",
			"humidity": "আর্দ্রতা",
			"dewpoint": "শিশিরাঙ্ক",
			"moonphase": "চাঁদ",
			"sunrise": "সূর্যোদয়",
			"sunset": "সূর্যাস্ত",
			"moonrise": "চন্দ্রোদয়",
			"moonset": "অর্ধচন্দ্র"
		},
		"ca": {
			"name": "Weather",
			"desc": "Displays the current weather and a forecast for the next 4 days.",
			"settings": {
				"location": "Location(s)",
				"location_placeholder": "Enter a location and press Enter",
				"units": "Units",
				"units_imperial": "Imperial (Fahrenheit)",
				"units_metric": "Metric (Celsius)",
				"enabled": "Activat",
				"disabled": "Desactivat",
				"forecast": "Forecasts",
				"hourly": "Hourly forecasts"
			},
			"more": "Més",
			"less": "Less",
			"wind": "Wind",
			"precipitation": "Precip",
			"uv": "UV index",
			"feelslike": "Feels like",
			"barometer": "Barometer",
			"visibility": "Visibility",
			"humidity": "Humidity",
			"dewpoint": "Dew point",
			"moonphase": "Moon",
			"sunrise": "Sunrise",
			"sunset": "Sunset",
			"moonrise": "Moonrise",
			"moonset": "Moonset"
		},
		"cs": {
			"name": "Počasí",
			"desc": "Zobrazí aktuální počasí a předpověď pro příští 4 dny.",
			"settings": {
				"location": "Umístění",
				"location_placeholder": "Zadejte umístění a stiskněte klávesu Enter",
				"units": "Jednotky",
				"units_imperial": "Imperiální (Fahrenheity)",
				"units_metric": "Metrická (Celsia)",
				"enabled": "Zapnuto",
				"disabled": "Vypnuto",
				"forecast": "Předpovědi",
				"hourly": "Hodinové předpovědi"
			},
			"more": "Více",
			"less": "Méně",
			"wind": "Rychlost větru",
			"precipitation": "Srážky",
			"uv": "UV index",
			"feelslike": "Teplota",
			"barometer": "Barometr",
			"visibility": "Viditelnost",
			"humidity": "Vlhkost",
			"dewpoint": "Rosný bod",
			"moonphase": "Měsíc",
			"sunrise": "Východ slunce",
			"sunset": "Západ slunce",
			"moonrise": "Východ měsíce",
			"moonset": "Západ měsíce"
		},
		"da": {
			"name": "Weather",
			"desc": "Displays the current weather and a forecast for the next 4 days.",
			"settings": {
				"location": "Location(s)",
				"location_placeholder": "Enter a location and press Enter",
				"units": "Units",
				"units_imperial": "Imperial (Fahrenheit)",
				"units_metric": "Metric (Celsius)",
				"enabled": "Aktiveret",
				"disabled": "Deaktiveret",
				"forecast": "Forecasts",
				"hourly": "Hourly forecasts"
			},
			"more": "Mere",
			"less": "Less",
			"wind": "Wind",
			"precipitation": "Precip",
			"uv": "UV index",
			"feelslike": "Feels like",
			"barometer": "Barometer",
			"visibility": "Visibility",
			"humidity": "Humidity",
			"dewpoint": "Dew point",
			"moonphase": "Moon",
			"sunrise": "Sunrise",
			"sunset": "Sunset",
			"moonrise": "Moonrise",
			"moonset": "Moonset"
		},
		"de": {
			"name": "Wetter",
			"desc": "Zeigt das aktuelle Wetter und eine Vorhersage für die nächsten 4 Tage.",
			"settings": {
				"location": "Ort(e)",
				"location_placeholder": "Gebe einen Ort ein und drücke die Eingabetaste",
				"units": "Einheiten",
				"units_imperial": "Imperial (Fahrenheit)",
				"units_metric": "Metrisch (Celsius)",
				"enabled": "aktiviert",
				"disabled": "deaktiviert",
				"forecast": "Vorhersage",
				"hourly": "Stündliche Vorhersage"
			},
			"more": "Mehr",
			"less": "Weniger",
			"wind": "Windgeschwindigkeit",
			"precipitation": "Niederschlag",
			"uv": "UV-index",
			"feelslike": "Gefühlt wie",
			"barometer": "Barometer",
			"visibility": "Sichtbarkeit",
			"humidity": "Luftfeuchtigkeit",
			"dewpoint": "Taupunkt",
			"moonphase": "Mond",
			"sunrise": "Sonnenaufgang",
			"sunset": "Sonnenuntergang",
			"moonrise": "Mondaufgang",
			"moonset": "Monduntergang"
		},
		"es": {
			"name": "Tiempo metereològico",
			"desc": "Muestra el tiempo actual y un pronóstico para los próximos 4 días.",
			"settings": {
				"location": "Localización(es)",
				"location_placeholder": "Escriba una ubicación y pulse Enter",
				"units": "Unidades",
				"units_imperial": "Imperial (Fahrenheit)",
				"units_metric": "Metric (Celsius)",
				"enabled": "Habilitado",
				"disabled": "Deshabilitado",
				"forecast": "Previsiones",
				"hourly": "Pronósticos por horas"
			},
			"more": "Más",
			"less": "Menos",
			"wind": "Velocidad de viento",
			"precipitation": "Precip",
			"uv": "UV index",
			"feelslike": "Sensación",
			"barometer": "Barómetro",
			"visibility": "Visibilidad",
			"humidity": "Humedad",
			"dewpoint": "Dew point",
			"moonphase": "Luna",
			"sunrise": "Amanecer",
			"sunset": "Atardecer",
			"moonrise": "Salida de la luna",
			"moonset": "Puesta de la Luna"
		},
		"fr": {
			"name": "Météo",
			"desc": "Affiche la météo actuelle et les prévisions pour les 4 prochains jours.",
			"settings": {
				"location": "Location(s)",
				"location_placeholder": "Spécifiez l'emplacement, puis appuyez sur entrée",
				"units": "Unités",
				"units_imperial": "Imperial (Fahrenheit)",
				"units_metric": "Métrique (Celsius)",
				"enabled": "Activé",
				"disabled": "Desactivé",
				"forecast": "Prévisions",
				"hourly": "Prévisions horaires"
			},
			"more": "Plus",
			"less": "Moins",
			"wind": "Vitesse du vent",
			"precipitation": "Précip",
			"uv": "Indice UV",
			"feelslike": "Temp. ress",
			"barometer": "Baromètre",
			"visibility": "Visibilité",
			"humidity": "Humidité",
			"dewpoint": "Point de rosée",
			"moonphase": "Lune",
			"sunrise": "Lever du soleil",
			"sunset": "Coucher de soleil",
			"moonrise": "Lever de lune",
			"moonset": "Coucher de lune"
		},
		"he": {
			"name": "Weather",
			"desc": "Displays the current weather and a forecast for the next 4 days.",
			"settings": {
				"location": "Location(s)",
				"location_placeholder": "Enter a location and press Enter",
				"units": "Units",
				"units_imperial": "Imperial (Fahrenheit)",
				"units_metric": "Metric (Celsius)",
				"enabled": "Enabled",
				"disabled": "Disabled",
				"forecast": "Forecasts",
				"hourly": "Hourly forecasts"
			},
			"more": "More",
			"less": "Less",
			"wind": "Wind",
			"precipitation": "Precip",
			"uv": "UV index",
			"feelslike": "Feels like",
			"barometer": "Barometer",
			"visibility": "Visibility",
			"humidity": "Humidity",
			"dewpoint": "Dew point",
			"moonphase": "Moon",
			"sunrise": "Sunrise",
			"sunset": "Sunset",
			"moonrise": "Moonrise",
			"moonset": "Moonset"
		},
		"hi": {
			"name": "Weather",
			"desc": "Displays the current weather and a forecast for the next 4 days.",
			"settings": {
				"location": "Location(s)",
				"location_placeholder": "Enter a location and press Enter",
				"units": "Units",
				"units_imperial": "Imperial (Fahrenheit)",
				"units_metric": "Metric (Celsius)",
				"enabled": "औन",
				"disabled": "औफ",
				"forecast": "Forecasts",
				"hourly": "Hourly forecasts"
			},
			"more": "अन्य कार्यकलाप",
			"less": "Less",
			"wind": "Wind",
			"precipitation": "Precip",
			"uv": "UV index",
			"feelslike": "Feels like",
			"barometer": "Barometer",
			"visibility": "Visibility",
			"humidity": "Humidity",
			"dewpoint": "Dew point",
			"moonphase": "Moon",
			"sunrise": "Sunrise",
			"sunset": "Sunset",
			"moonrise": "Moonrise",
			"moonset": "Moonset"
		},
		"hr": {
			"name": "Vrijeme",
			"desc": "Prikazuje trenutno vrijeme i prognozu za sljedeća 4 dana.",
			"settings": {
				"location": "Lokacija/e",
				"location_placeholder": "Unesi lokaciju i pritisni Enter",
				"units": "Jedinice",
				"units_imperial": "Imperialno (Fahrenheit)",
				"units_metric": "Metrički (Celsius)",
				"enabled": "Omogućeno",
				"disabled": "Omogući",
				"forecast": "Prognoze",
				"hourly": "Prognoze po satu"
			},
			"more": "Više",
			"less": "Manje",
			"wind": "Vjetar",
			"precipitation": "Oborine",
			"uv": "UV indeks",
			"feelslike": "Osjećaj",
			"barometer": "Barometar",
			"visibility": "Vidljivost",
			"humidity": "Vlažnost",
			"dewpoint": "Točka rosišta",
			"moonphase": "Mjesec",
			"sunrise": "Izlazak sunca",
			"sunset": "Zalazak sunca",
			"moonrise": "Izlazak mjeseca",
			"moonset": "Zalazak mjeseca"
		},
		"id": {
			"name": "Weather",
			"desc": "Displays the current weather and a forecast for the next 4 days.",
			"settings": {
				"location": "Location(s)",
				"location_placeholder": "Enter a location and press Enter",
				"units": "Units",
				"units_imperial": "Imperial (Fahrenheit)",
				"units_metric": "Metric (Celsius)",
				"enabled": "Enabled",
				"disabled": "Disabled",
				"forecast": "Forecasts",
				"hourly": "Hourly forecasts"
			},
			"more": "More",
			"less": "Less",
			"wind": "Wind",
			"precipitation": "Precip",
			"uv": "UV index",
			"feelslike": "Feels like",
			"barometer": "Barometer",
			"visibility": "Visibility",
			"humidity": "Humidity",
			"dewpoint": "Dew point",
			"moonphase": "Moon",
			"sunrise": "Sunrise",
			"sunset": "Sunset",
			"moonrise": "Moonrise",
			"moonset": "Moonset"
		},
		"it": {
			"name": "Meteo",
			"desc": "Mostra il meteo per i prossimi 4 giorni.",
			"settings": {
				"location": "Luogo/i",
				"location_placeholder": "Inserisci un luogo e premi invio",
				"units": "Unità di misura",
				"units_imperial": "Fahrenheit",
				"units_metric": "Metrica (Celsius)",
				"enabled": "Attive",
				"disabled": "Disattivate",
				"forecast": "Previsioni meteo",
				"hourly": "Previsioni meteo orarie"
			},
			"more": "Altro",
			"less": "Di meno",
			"wind": "Velocità del vento",
			"precipitation": "Precip.",
			"uv": "Indice UV",
			"feelslike": "°T percepita",
			"barometer": "Barometro",
			"visibility": "Visibilità",
			"humidity": "Umidità",
			"dewpoint": "Punto di rugiada",
			"moonphase": "Luna",
			"sunrise": "Alba",
			"sunset": "Tramonto",
			"moonrise": "Sorgere della luna",
			"moonset": "Luna calante"
		},
		"ja": {
			"name": "天気",
			"desc": "現在の天気と今後4日間の天気予報を表示します。",
			"settings": {
				"location": "場所",
				"location_placeholder": "場所を入力して Enter",
				"units": "単位",
				"units_imperial": "°F",
				"units_metric": "℃",
				"enabled": "有効",
				"disabled": "無効",
				"forecast": "予測",
				"hourly": "1時間ごとの予測"
			},
			"more": "もっと見る",
			"less": "閉じる",
			"wind": "風",
			"precipitation": "降水確率",
			"uv": "紫外線指数",
			"feelslike": "体感温度",
			"barometer": "気圧",
			"visibility": "視界",
			"humidity": "湿度",
			"dewpoint": "露点",
			"moonphase": "月",
			"sunrise": "日の出",
			"sunset": "日の入り",
			"moonrise": "月の出",
			"moonset": "月の入り"
		},
		"nl": {
			"name": "Weer",
			"desc": "Geeft actueel weer en de weersverwachting voor de komende 4 dagen weer.",
			"settings": {
				"location": "Locatie(s)",
				"location_placeholder": "Vul een locatie in en druk enter",
				"units": "Eenheden",
				"units_imperial": "Imperiale Eenheden (Fahrenheit)",
				"units_metric": "Metrisch (Celsius)",
				"enabled": "Ingeschakeld",
				"disabled": "Uitgeschakeld",
				"forecast": "Vooruitzichten",
				"hourly": "Weervoorspelling per uur"
			},
			"more": "Meer",
			"less": "Minder",
			"wind": "Windsnelheid",
			"precipitation": "Neerslag",
			"uv": "Zonkracht",
			"feelslike": "Gevoelstemperatuur",
			"barometer": "Luchtdruk",
			"visibility": "Zichtbaarheid",
			"humidity": "Luchtvochtigheid",
			"dewpoint": "Dauwpunt",
			"moonphase": "Maan",
			"sunrise": "Zonsopkomst",
			"sunset": "Zonsondergang",
			"moonrise": "Maansopkomst",
			"moonset": "Maansondergang"
		},
		"pl": {
			"name": "Pogoda",
			"desc": "Wyświetla aktualną pogodę i prognozę na najbliższe 4 dni.",
			"settings": {
				"location": "Lokalizacja(e)",
				"location_placeholder": "Wprowadź lokalizację i naciśnij klawisz Enter",
				"units": "Jednostka",
				"units_imperial": "Cesarski (Celsjusza)",
				"units_metric": "Metryka (Celsjusza)",
				"enabled": "Aktywne",
				"disabled": "Nieaktywne",
				"forecast": "Prognoza",
				"hourly": "Prognozy godzinowe"
			},
			"more": "Więcej",
			"less": "Mniej",
			"wind": "Wiatr",
			"precipitation": "Opady",
			"uv": "Indeks UV",
			"feelslike": "Odczuwalna",
			"barometer": "Ciśnienie",
			"visibility": "Widoczność",
			"humidity": "Wilgotność",
			"dewpoint": "Punkt rosy",
			"moonphase": "Księżyc",
			"sunrise": "Wschód słońca",
			"sunset": "Zachód słońca",
			"moonrise": "Wschód księżyca",
			"moonset": "Zachód Księżyca"
		},
		"pt-PT": {
			"name": "Previsão do tempo",
			"desc": "Exibe o tempo atual e uma previsão para os próximos 4 dias.",
			"settings": {
				"location": "Localizaçõe(s)",
				"location_placeholder": "Digite um local e pressione Enter",
				"units": "Units",
				"units_imperial": "Imperial (Fahrenheit)",
				"units_metric": "Metric (Celsius)",
				"enabled": "Ativada",
				"disabled": "Desativada",
				"forecast": "Forecasts",
				"hourly": "Hourly forecasts"
			},
			"more": "Mais",
			"less": "Less",
			"wind": "Velocidade do vento",
			"precipitation": "Precip",
			"uv": "UV index",
			"feelslike": "Feels like",
			"barometer": "Barometer",
			"visibility": "Visibility",
			"humidity": "Humidade",
			"dewpoint": "Dew point",
			"moonphase": "Moon",
			"sunrise": "Sunrise",
			"sunset": "Sunset",
			"moonrise": "Moonrise",
			"moonset": "Moonset"
		},
		"ru": {
			"name": "Погода",
			"desc": "Отображает текущую погоду с прогнозом на 4 дня.",
			"settings": {
				"location": "Местоположение(я)",
				"location_placeholder": "Введите местоположение и нажмите Enter",
				"units": "Единицы измерения",
				"units_imperial": "Имперические (по Фаренгейту)",
				"units_metric": "Метрические (по Цельсию)",
				"enabled": "Включено",
				"disabled": "Отключено",
				"forecast": "Прогноз",
				"hourly": "Почасовой прогноз"
			},
			"more": "Ещё",
			"less": "Менее",
			"wind": "Скорость ветра",
			"precipitation": "Осадки",
			"uv": "УФ-индекс",
			"feelslike": "Ощущается как",
			"barometer": "Барометр",
			"visibility": "Видимость",
			"humidity": "Влажность",
			"dewpoint": "Точка росы",
			"moonphase": "Луна",
			"sunrise": "Восход",
			"sunset": "Закат",
			"moonrise": "Восходящая луна",
			"moonset": "Нисходящая луна"
		},
		"sr": {
			"name": "Време",
			"desc": "Приказује тренутно време и прогнозу за следећа 4 дана.",
			"settings": {
				"location": "Локација(е)",
				"location_placeholder": "Унеси локацију и притисни Ентер",
				"units": "Units",
				"units_imperial": "Imperial (Fahrenheit)",
				"units_metric": "Metric (Celsius)",
				"enabled": "Укључено",
				"disabled": "Искључено",
				"forecast": "Forecasts",
				"hourly": "Hourly forecasts"
			},
			"more": "Још",
			"less": "Less",
			"wind": "Брзина Ветра",
			"precipitation": "Precip",
			"uv": "UV index",
			"feelslike": "Feels like",
			"barometer": "Barometer",
			"visibility": "Visibility",
			"humidity": "Влажност",
			"dewpoint": "Dew point",
			"moonphase": "Moon",
			"sunrise": "Sunrise",
			"sunset": "Sunset",
			"moonrise": "Moonrise",
			"moonset": "Moonset"
		},
		"tr": {
			"name": "Weather",
			"desc": "Displays the current weather and a forecast for the next 4 days.",
			"settings": {
				"location": "Location(s)",
				"location_placeholder": "Enter a location and press Enter",
				"units": "Units",
				"units_imperial": "Imperial (Fahrenheit)",
				"units_metric": "Metric (Celsius)",
				"enabled": "Etkin",
				"disabled": "Etkin Değil",
				"forecast": "Forecasts",
				"hourly": "Hourly forecasts"
			},
			"more": "Daha fazla",
			"less": "Less",
			"wind": "Wind",
			"precipitation": "Precip",
			"uv": "UV index",
			"feelslike": "Feels like",
			"barometer": "Barometer",
			"visibility": "Visibility",
			"humidity": "Humidity",
			"dewpoint": "Dew point",
			"moonphase": "Moon",
			"sunrise": "Sunrise",
			"sunset": "Sunset",
			"moonrise": "Moonrise",
			"moonset": "Moonset"
		},
		"uk": {
			"name": "Weather",
			"desc": "Displays the current weather and a forecast for the next 4 days.",
			"settings": {
				"location": "Location(s)",
				"location_placeholder": "Enter a location and press Enter",
				"units": "Units",
				"units_imperial": "Imperial (Fahrenheit)",
				"units_metric": "Metric (Celsius)",
				"enabled": "Увімкнено",
				"disabled": "Вимкнено",
				"forecast": "Forecasts",
				"hourly": "Hourly forecasts"
			},
			"more": "Більше",
			"less": "Less",
			"wind": "Wind",
			"precipitation": "Precip",
			"uv": "UV index",
			"feelslike": "Feels like",
			"barometer": "Barometer",
			"visibility": "Visibility",
			"humidity": "Humidity",
			"dewpoint": "Dew point",
			"moonphase": "Moon",
			"sunrise": "Sunrise",
			"sunset": "Sunset",
			"moonrise": "Moonrise",
			"moonset": "Moonset"
		},
		"zh-CN": {
			"name": "天气",
			"desc": "显示当前天气和接下来的 4 天的天气预报。",
			"settings": {
				"location": "位置",
				"location_placeholder": "请输入您的位置，然后按回车键",
				"units": "单位",
				"units_imperial": "英制（华氏度）",
				"units_metric": "公制（摄氏度）",
				"enabled": "开启",
				"disabled": "关闭",
				"forecast": "天气预报",
				"hourly": "小时天气预报"
			},
			"more": "更多",
			"less": "收起",
			"wind": "风向",
			"precipitation": "降雨量",
			"uv": "紫外线指数",
			"feelslike": "体感",
			"barometer": "晴雨表",
			"visibility": "能见度",
			"humidity": "湿度",
			"dewpoint": "露点",
			"moonphase": "月亮",
			"sunrise": "日出",
			"sunset": "日落",
			"moonrise": "月升",
			"moonset": "月落"
		},
		"zh-TW": {
			"name": "天氣",
			"desc": "顯示目前的天氣和接下來的 4 天天氣預報。",
			"settings": {
				"location": "位置",
				"location_placeholder": "請輸入一個位置，然後按 enter 鍵",
				"units": "單位",
				"units_imperial": "美制 (華氏度)",
				"units_metric": "公制 (攝氏度)",
				"enabled": "開啟",
				"disabled": "關閉",
				"forecast": "預測",
				"hourly": "每小時預測"
			},
			"more": "更多",
			"less": "收起",
			"wind": "風速",
			"precipitation": "降雨量",
			"uv": "紫外線指數",
			"feelslike": "體感溫度",
			"barometer": "氣壓",
			"visibility": "能見度",
			"humidity": "濕度",
			"dewpoint": "凝露點",
			"moonphase": "月亮",
			"sunrise": "日出",
			"sunset": "日落",
			"moonrise": "月升",
			"moonset": "月落"
		}
	},
	"isCompiled": true
});

define('widgets/registry/index',["json!w/analytics/manifest.json","json!w/classroom/manifest.json","json!w/currency/manifest.json","json!w/dictionary/manifest.json","json!w/drive/manifest.json","json!w/gmail/manifest.json","json!w/iframe/manifest.json","json!w/keep/manifest.json","json!w/news/manifest.json","json!w/quicklinks/manifest.json","json!w/recentlyclosed/manifest.json","json!w/rss/manifest.json","json!w/sports/manifest.json","json!w/stocks/manifest.json","json!w/todo/manifest.json","json!w/topsites/manifest.json","json!w/traffic/manifest.json","json!w/translate/manifest.json","json!w/unitconversion/manifest.json","json!w/unread/manifest.json","json!w/voice/manifest.json","json!w/weather/manifest.json","w/apps","w/bookmarks","w/calc","w/calendar","w/chrome_bookmarks","w/clock","w/directions","w/facebook","w/feedly","w/html","w/linkedin","w/notes","w/notifications","w/now","w/plus","w/pocket","w/pushbullet","w/quotes","w/reddit","w/search","w/sitelink","w/stats","w/tasks","w/twitter","w/wolfram","w/youtube","lib/jquery.sortable"], function() {return {legacy: [].slice.call(arguments, 22, -1),widgets: [].slice.call(arguments, 0, 22)};});
/**
 * The widget registry
 */
define('widgets/registry',[
	"backbone", "widgets/registry/widget", "widgets/instance", "widgets/legacy/widget", "widgets/legacy/instance", "widgets/registry/index"
], function(Backbone, Widget, WidgetInstance, LegacyWidget, LegacyInstance, index) {
	var Registry = Backbone.Collection.extend({
		/**
		 * Given a legacy widget (single file), creates and returns a
		 * new LegacyWidget, adding it to the registry in the process
		 *
		 * @api     public
		 * @param   {Object}        spec  The legacy widget's specification
		 * @return  {LegacyWidget}        The new LegacyWidget instance
		 */
		registerLegacyWidget: function(spec) {
			var widget = new LegacyWidget(spec);

			this.add(widget);

			return widget;
		},


		/**
		 * Given a valid JSON manifest, creates and returns a new widget,
		 * adding it to the registry in the process
		 *
		 * @api     public
		 * @param   {Object}  manifest  A valid widget manifest
		 * @return  {Widget}            The new Widget instance
		 */
		registerWidget: function(manifest) {
			var widget = new Widget(manifest);

			this.add(widget);

			return widget;
		},


		/**
		 * This is passed a widget instance specification and returns
		 * a new WidgetInstance view
		 *
		 * @api     public
		 * @param   {Backbone.Model}  model      A Backbone model containing configuration options for this instance
		 * @param   {Boolean}         isPreview  Whether or not this widget is being rendered as a preview
		 * @return  {WidgetInstance}             A new instance of the widget specified in the model
		 */
		createInstance: function(model, isPreview) {
			var widget = this.get(model.get("id"));

			if (!widget) {
				return;
			}

			// If this is a legacy widget, return a legacy widget instance, which
			// exposes the same API but operates differently internally
			var Instance = widget instanceof LegacyWidget ? LegacyInstance : WidgetInstance;

			return new Instance({
				model: model,
				isPreview: isPreview,
				widget: widget
			});
		},


		/**
		 * The model used by widget instances
		 *
		 * @type {Backbone.Model}
		 */
		InstanceModel: Backbone.Model.extend({
			idAttribute: "cid",

			validate: function(attrs) {
				return !attrs.id || !registry.get(attrs.id);
			}
		})
	});


	var registry = new Registry();

	// The manifests and contents (for legacy widgets) of widgets are provided
	// by the index file and added to the registry here.
	index.widgets.forEach(function(e) {
		registry.registerWidget(e);
	});

	index.legacy.forEach(function(e) {
		registry.registerLegacyWidget(e);
	});


	return registry;
});
/**
 * The widget store
 */
define(
	'widgets/store',["lodash", "jquery", "backbone", "browser/api", "storage/storage", "i18n/i18n", "widgets/registry", "core/analytics", "modals/modals", "core/render"],
	function(_, $, Backbone, Browser, Storage, Translate, Registry, Track, Modal, render) {
		var sizes = {
			tiny: Translate("widgets.sizes.tiny"),
			small: Translate("widgets.sizes.small"),
			medium: Translate("widgets.sizes.medium"),
			large: Translate("widgets.sizes.large"),
			variable: Translate("widgets.sizes.variable")
		};

		var Model = Backbone.Model.extend({
				initialize: function() {
					var widgets = Registry.chain().filter(function(widget) {
						return widget.isListed && widget.isAvailable;
					}).map(function(widget) {
						return {
							id: widget.id,
							icon: widget.icon,
							name: widget.translate("name"),
							desc: widget.translate("desc"),
							sort: widget.sort || 99999
						};
					}).value().sort(function(a, b) {
						if (a.sort === b.sort) {
							// sensitivity: "accent" ensures that accented characters differ
							// while ignoring case and avoiding a toLocaleLowerCase() call
							return a.name.localeCompare(b.name, "en", { sensitivity: "accent" });
						}

						return a.sort > b.sort ? 1 : -1;
					});

					this.set({
						widgets: widgets
					});
				}
			}),
			modal = new (Modal.extend({
				classes: "store",
				close: function() {
					Backbone.trigger("widgets-closed");
					return this.hide();
				}
			}))(),
			View = Backbone.View.extend({
				el: modal.content,

				events: {
					"click > .content .widget": function(e) {
						var wModal = new (Modal.extend({
							destroyOnHide: true,
							classes: "store-detail"
						}))();


						var id = parseInt($(e.currentTarget).attr("data-id")),
							widget = Registry.get(id),
							view = Registry.createInstance(new Registry.InstanceModel({ id: id }), true);

						// The getDesc method might need to load the template remotely,
						// so it needs to be async. But, in a compiled version this
						// will never take longer than requestAnimationFrame
						widget.getDesc(function(descHTML) {
							wModal.content.replaceWith(
								render("store-detail", {
									name: widget.translate("name"),
									sizes: widget.sizes.map(function(e) { return [e, sizes[e]]; }),
									desc: descHTML
								})
							);

							wModal.content = wModal.$(".content");

							Track.FB.logEvent("VIEWED_CONTENT", null, { fb_content_type: "page", fb_content_id: "widgets/" + widget.name });

							Track.pageview("Store: " + widget.name, "/store/" + widget.name);

							wModal.content.find(".sizes").sortable({
								group: "columns",
								drop: false
							}).find("section.handle").on("sortabledragstart", function(e, item) {
								var newView = Registry.createInstance(new Registry.InstanceModel({
									id: id,
									size: item.attr("data-size")
								}));

								// This lets it render completely before getting dragged
								view.$el.replaceWith(newView.$el);

								view.remove();


								var width = newView.el.offsetWidth,
									css = {
										width: width,
										minWidth: width,
										maxWidth: width,
										height: newView.el.offsetHeight
									};

								item.clone().insertAfter(item);

								item.replaceWith(newView.$el);

								// This way any events attached by jquery.sortable stay intact
								item[0] = newView.el;

								wModal.close();
								modal.hide();

								item.css(css).addClass("dragged").appendTo("body > .widgets-container");

								item.installing = true;

								return item;
							});

							wModal.content.find("section.preview").append(view.el);

							wModal.mo.appendTo(document.body);

							requestAnimationFrame(wModal.show.bind(wModal));
						});
					}
				},

				show: function() {
					this.render();

					modal.show();

					Track.pageview("Store", "/store");
				},

				initialize: function() {
					this.model = new Model();

					modal.mo.appendTo(document.body);

					this.model.on("change", this.render, this);
				},

				render: function() {
					this.$el.removeClass("content").addClass("wrapper").html(render("store", {
						widgets: this.model.get("widgets")
					}));

					Track.FB.logEvent("VIEWED_CONTENT", null, { fb_content_type: "page", fb_content_id: "widgets" });

					return this;
				}
			});

		return View;
	}
);
/**
 * Announcements
 */
define('core/announcements',["lodash", "backbone", "browser/api", "modals/alert", "core/analytics", "i18n/i18n", "core/render", "core/settings", "storage/storage", "settings/proxy", "core/auth"
], function(_, Backbone, Browser, Alert, Track, Translate, render, settings, Storage, SettingsProxy, Auth) {
	var Model = Backbone.Model.extend({
		url: settings.apidomain + "/announcements?extension=" + Browser.app.id + "&version=" + Browser.app.version + "&lang=" + Browser.language + "&aver=2",

		defaults: {
			count: 0,
			title: "Announcements",
			list: []
		},

		initialize: function() {
			Storage.on("done updated", function(storage) {
				this.email = storage.user.email;
			}, this);

			var showNewVersion = 17; //This number should be increased on "What's new" dialog modification
			if (Number(Browser.storage.lastShowWhatsNewVersion) !== showNewVersion) {
				Browser.storage.lastShowWhatsNewVersion = showNewVersion;
				Browser.storage.showWhatsNew = 0; //Start the counter from 0 (show max first 10 widget starts)
			}

			if (Browser.storage.showWhatsNew) {
				this.set({
					isUpdate: true
				});

				setTimeout(function() {
					this.updateCounter();

					var shown = (parseInt(Browser.storage.showWhatsNew) || 0) + 1;
					if (shown < 10) {
						Browser.storage.showWhatsNew = shown;
						return;
					}

					//The "What's new" counter was shown 10 times => stop to show it
					Browser.storage.removeItem("showWhatsNew");

					this.set({
						isUpdate: false
					});

					this.updateCounter();
				}.bind(this), 3000);
			}

			if (!Auth.isSignedIn) {
				if (this.isSignInPopup()) {
					require(["notices/signin"]);				
				}
			}

			//Set extension "installed" time
			if (!Browser.storage.installed) {
				Browser.storage.installed = new Date().getTime();
			}

			this.callFetch();

			// Refetch every hour
			setInterval(function() {
				this.callFetch("&refetch=1");
			}.bind(this), 3600000);
		},

		callFetch: function(append) {
			if (!append) {
				append = "";
			}

			if (Browser.storage.dismissedAnnouncement) {
				//Do not receive announcements the user already has seen
				append += ("&id=" + Browser.storage.dismissedAnnouncement);
			}

			var lastindividual = Number(Browser.storage.lastindividual || "0");
			append += ("&indid=" + lastindividual);

			var indIds = this.getIndIds();
			if (indIds.length > 0) {
				append += ("&indids=" + indIds.join("-"));
			}

			if (this.email) {
				append += ("&email=" + this.email);
			}

			this.fetch({
				url: this.url + append,
				success: function(m) {
					m.updateLocalStorage();
					m.updateCounter();
				}
			});
		},

		getIndIds: function() {
			var annIndIds = Browser.storage.annIndIds;
			if (typeof annIndIds === 'undefined') { return []; }
			var annIndIdsInt = JSON.parse(annIndIds);
			return Array.isArray(annIndIdsInt) ? annIndIdsInt : [annIndIdsInt];
		},

		updateLocalStorage: function() {
			var d = this.attributes;
			if (typeof d.lastindividual === 'undefined') {
				return;
			}

			Browser.storage.lastindividual = d.lastindividual;
			var annIndIds = Browser.storage.annIndIds;
			if (!annIndIds) {
				return;
			}

			var lastIndividualInt = Number(d.lastindividual);
			var annIndIdsFiltered = _.filter(this.getIndIds(), function(x) { return !Number.isNaN(x) && x > lastIndividualInt; });
			if (annIndIds.length !== annIndIdsFiltered.length) {
				if (annIndIdsFiltered.length === 0) {
					delete Browser.storage.annIndIds;	
				}
				else{
					Browser.storage.annIndIds = JSON.stringify(annIndIdsFiltered);
				}
			}
		},

		individualsToShow: function() {
			var d = this.attributes;
			if (d.individual.length === 0) { return []; }
			var lastindividual = Number(Browser.storage.lastindividual || 0);

			var annIndIds = this.getIndIds();
			return _.filter(d.individual, function(x) { 
				return x.announcement_id > lastindividual && !annIndIds.includes(x.announcement_id); 
			});
		},

		timeDiffInMins: function(date1, date2) {
			return (date1.getTime() - date2.getTime()) / 60000.0;
		},

		isSignInPopup: function() {
			var installedTime = Browser.storage.installed;
			if (typeof installedTime === "undefined") { return null; }

			var installedTimeDate = new Date(Number(installedTime));
			var passed = this.timeDiffInMins(new Date(), installedTimeDate);

			var lastNotificationDate = new Date(Number(Browser.storage.lastUpgradeNotification || installedTime));
			var notificationPassed = this.timeDiffInMins(lastNotificationDate, installedTimeDate);
			return passed > 10080 && notificationPassed < 10080;
		},

		messageOnInstalledToShow: function() {
			var now = new Date();

			var result = null;

			if (!Auth.isSignedIn) {
				var installedTime = Browser.storage.installed || 0;
				if (typeof installedTime === "undefined") { return null; }
				var installedTimeDate = new Date(Number(installedTime));

				var passed = this.timeDiffInMins(now, installedTimeDate);

				var lastNotificationDate = new Date(Number(Browser.storage.lastUpgradeNotification || installedTime));
				var notificationPassed = this.timeDiffInMins(lastNotificationDate, installedTimeDate);

				var doShow = [1140.0, 60.0, 2.0].some(function(element) {
					return passed > element && notificationPassed < element;
				});

				if (doShow) {
					result = [
						{
							type: "l",
							id: 1,
							title: "You are not signed in now",
							contents: "<p>Try ProductivityTab Pro free for 30 Days! Sign in with your Chrome account to securely store and sync your settings, and experience the full features of ProductivityTab Pro.</p>",
							positiveText: "Sign in",
							negativeText: "Dismiss",
							positiveAction: function() {
								SettingsProxy("accounts");
							},
							finallyAction: function() {
								Browser.storage.lastUpgradeNotification = new Date().getTime();
							}
						}
					];
				}
			}

			if (Auth.isPro && Auth.isTrial && Auth.trialExpiration) {
				var expDate = new Date(Number(Auth.trialExpiration));
				var minsViewsTillExp = this.timeDiffInMins(expDate, new Date(Number(Browser.storage.trialExp || 0)));
				var minsTillExp = this.timeDiffInMins(expDate, now);
				var doShowNotification = [10080.0, 1440.0].some(function(element) {
					return element >= minsTillExp && element < minsViewsTillExp;
				});
				
				if (doShowNotification) {
					result = result || [];
					result.push({
							type: "l",
							id: 2,
							title: "Your trial Pro subscription expires soon",
							contents: "<p>You have 1 month trial Pro subscription which is expiring. Please press 'Upgrade' button for permanent subscription</p>",
							positiveText: "Upgrade",
							negativeText: "Dismiss",
							positiveAction: function() {
								SettingsProxy("pro");
							},
							finallyAction: function() {
								Browser.storage.trialExp = new Date().getTime();
							}
					});
				}
			}

			return result;
		},

		individualById: function(id) {
			var d = this.attributes;
			if (d.individual.length === 0) { return null; }
			return _.find(d.individual, function(x) { 
				return x.announcement_id === id; 
			});
		},

		messageOnInstalledById: function(id) {
			var messages = this.messageOnInstalledToShow();
			if (messages === null) { return null; }
			return _.find(messages, function(x) { 
				return x.id === id; 
			});
		},

		topCommon: function() {
			var d = this.attributes;

			if (!d.common) {
				return null;
			}

			var lastId = Browser.storage.dismissedAnnouncement || 0;

			for (var i = 0; i < d.common.length; i++) {
				if (d.common[i].announcement_id > lastId) {
					return d.common[i];
				}
			}

			return null;
		},

		topIndividual: function() {
			var d = this.attributes;

			if (!d.individual) {
				return null;
			}

			var lastId = Number(Browser.storage.lastindividual || 0);
			var annIndIdsInt = this.getIndIds();
			for (var i = 0; i < d.individual.length; i++) {
				var id = d.individual[i].announcement_id;
				if (id > lastId && !annIndIdsInt.includes(id)) {
					return d.individual[i];
				}
			}

			return null;
		},

	    updateCounter: function() {
			var d = this.attributes;

			var newCount = 0;

			if (d.isUpdate) { newCount++; }
			if (d.common) {
				var lastId = Browser.storage.dismissedAnnouncement || 0;
				for (var i = 0; i < d.common.length; i++) {
					if (d.common[i].announcement_id > lastId) {
						newCount++;
					}
				}
			}

			if (d.individual) {
				newCount += this.individualsToShow().length;
			}

			var result = [];
			if (d.isUpdate) { 
				result.push({
					type: "u",
					title: "New features and changes"
				});
			}

			var topCommonItem = this.topCommon();
			if (topCommonItem !== null) {
				result.push({
					type: "c",
					id: topCommonItem.announcement_id,
					title: topCommonItem.title
				});
			}	

			if (d.individual) {
				result = result.concat(this.individualsToShow().map(function(item) {
					return {
						type: "i",
						id: item.announcement_id,
						title: item.title
					};
				}));
			}

			var messageOnInstalled = this.messageOnInstalledToShow();
			if (messageOnInstalled !== null) {
				newCount += messageOnInstalled.length;
				result = result.concat(messageOnInstalled);
			}

			this.set({
				list: result,
				count: newCount
			});
		}
	});

	var View = Backbone.View.extend({
		initialize: function() {
			this.model = new Model();

			this.model.on("change", this.render, this).on("change:count", function() {
				this.count = this.model.get("count");
				this.list = this.model.get("list");

				this.trigger("countchange", this.count);
			}, this).trigger("change change:count");
		},

		showWhatsNew : function(doDismiss) {
			var model = this.model;
			var d = model.attributes;

			var dismiss = function() {
				model.trigger("dismissed");

				Browser.storage.removeItem("showWhatsNew");
				
				d.isUpdate = false;
				model.updateCounter();
				
				Track.event("Announcements", "Dismissed");
			};			

			if (doDismiss) {
				dismiss();
				return;
			}

			Alert({
				title: "What's New",
				classes: "announcements",
				html: render("whatsnew"),
				buttons: {
					positive: "Got it"
				},
				extlink: function(type) {
					switch (type || "") {
						case "topro": 
							this.hide();
							SettingsProxy("pro");
							break;
					}
				}
			}, function() {
				dismiss();
			}.bind(this));

			Track.event("Announcements", "Shown", "WhatsNew");
		},

		showCommon: function(d, doDismiss) {
			var model = this.model;

			var dismiss = function(res) {
				model.trigger("dismissed");
				Browser.storage.dismissedAnnouncement = d.announcement_id;

				if (d.action && res) {
					Browser.tabs.create({
						url: d.action.url
					});
				}

				model.updateCounter();

				Track.event("Announcements", "Dismissed");
			};

			if (doDismiss){
				dismiss(false);
				return;
			}
 
			Alert({
				title: d.title,
				classes: "announcements",
				html: d.contents,
				buttons: {
					positive: d.action ? d.action.text : "Got it",
					negative: d.dismiss || (d.action ? Translate("alert.default_button") : undefined)
				}
			}, function(res) {
				dismiss(res);
			}.bind(this));

			Track.event("Announcements", "Shown", "Alert");
		},

		showIndividual: function(d, doDismiss) {
			var model = this.model;

			var dismiss = function(res) {
				model.trigger("dismissed");

				//Add seen id to storage. It will be sent to server on next announcements update.
				var annIndIdsInt = model.getIndIds();
				if (!_.includes(annIndIdsInt, d.announcement_id)) {
					annIndIdsInt.push(d.announcement_id);
					Browser.storage.annIndIds = JSON.stringify(annIndIdsInt);
				}

				if (d.action && res) {
					Browser.tabs.create({
						url: d.action.url
					});
				}

				model.updateCounter();

				Track.event("Announcements", "Dismissed");
			};

			if (doDismiss) {
				dismiss(false);
				return;
			}

			Alert({
				title: d.title,
				classes: "announcements",
				html: d.contents,
				buttons: {
					positive: d.action ? d.action.text : "Got it",
					negative: d.dismiss || (d.action ? Translate("alert.default_button") : undefined)
				}
			}, function(res) {
				dismiss(res);
			}.bind(this));

			Track.event("Announcements", "Shown", "Alert");
		},


		showMessageOnInstalled: function(d, doDismiss) {
			var model = this.model;

			var dismiss = function(res) {
				model.trigger("dismissed");

				if (res) {
					if (d.positiveAction) {
						d.positiveAction();
						Track.event("Announcements", "Confirmed");
					}
				} else {
					if (d.negativeAction) {
						d.negativeAction();
						Track.event("Announcements", "Dismissed");
					}
				}

				if (d.finallyAction) {
					d.finallyAction();
				}

				model.updateCounter();
			};

			if (doDismiss) {
				dismiss(false);
				return;
			}

			Alert({
				title: d.title,
				classes: "announcements",
				html: d.contents,
				buttons: {
					positive: d.positiveText,
					negative: d.negativeText
				}
			}, function(res) {
				dismiss(res);
			}.bind(this));

			Track.event("Announcements", "Shown", "Alert");
		},

	    show: function() {
			var d = this.model.attributes;
			if (d.isUpdate) {
				this.showWhatsNew();
				return;
			}

			var item = this.model.topCommon();
			if (item !== null) {
				this.showCommon(item);
				return;
			}

			item = this.model.topIndividual();
			if (item !== null) {
				this.showIndividual(item);
			}
		},

	    showId: function(type, id, doDismiss) {
			var item;
			switch (type)
			{
				case "u":
					this.showWhatsNew(doDismiss);
					return;
				case "c":
				{
					var topItem = this.model.topCommon();
					if (topItem !== null) {
						this.showCommon(topItem, doDismiss);
						return;
					}
					break;
				}
				case "i":
				{
					item = this.model.individualById(Number(id));
					if (item) {
						this.showIndividual(item, doDismiss);
					}
					break;
				}
				case "l":
				{
					item = this.model.messageOnInstalledById(Number(id));
					if (item) {
						this.showMessageOnInstalled(item, doDismiss);
					}
					break;
				}
			}
		},

		render: function() {
			var item = this.model.topCommon();
			if (item !== null && item.alert) {
				this.showCommon(item);
				return;
			}

			item = this.model.topIndividual();
			if (item !== null && item.alert) {
				this.topIndividual(item);
				return;
			}
		}
	});

	return new View();
});
/**
 * This generates the main menu
 */
define(
	'menu/menu',[
		"lodash", "jquery", "backbone", "browser/api", "core/auth", "core/analytics", "storage/storage", "storage/defaults", "i18n/i18n",
		"search/search", "search/speech", "settings/proxy", "widgets/store", "core/uservoice", "core/render", "core/announcements"
	],
	function(_, $, Backbone, Browser, Auth, Track, Storage, Defaults, Translate, Search, Speech, SettingsProxy, Store, UserVoice, render, Announcements) {
		var Model = Backbone.Model.extend({
				init: function() {
					Storage.on("done updated", function(storage) {
						this.storage = storage;

						var set = _.clone(storage.settings);

						set.isPro = Auth.isPro;

						set.links = _.take(set.links, Auth.isPro ? 8 : 3);

						set.tabs = _.map(storage.tabs, function(e) {
							return {
								id: e.id,
								name: e.name || Defaults.tab.name
							};
						});

						this.storage = storage;

						if (JSON.stringify(set) !== JSON.stringify(this.toJSON())) {
							this.set(set);
						}

						if (Backbone.history.location.hash === "#upgrade") {
							SettingsProxy("pro");
						}
					}, this);
				}
			}),
			View = Backbone.View.extend({
				tagName: "div",
				className: "menu-container",

				events: {
					"click [data-item]:not(.active)": "effectuate",

					"click a.custom-link": function(e) {
						var href = e.currentTarget.getAttribute("href");

						if (href.indexOf("chrome") === 0 || $("base").attr("target") === "_blank") { // chrome:// links can't be opened directly for security reasons, this bypasses that feature.
							e.preventDefault();

							Browser.tabs.getCurrent(function(d) {
								if (e.which === 2) {
									Browser.tabs.create({
										url: href,
										index: d.index + 1
									});
								}
								else {
									Browser.tabs.update(d.id, {
										url: href
									});
								}
							});

							Track.event("Menu", "Link Click", "Chrome");
						}
						else {
							Track.event("Menu", "Link Click");
						}
					},
					"click .tabs .add": function() {
						SettingsProxy.getSettings(function(Settings) {
							Settings("tabs").createTab();
						});
					},
					"click .footer .support": function(e) {
						e.preventDefault();

						UserVoice("show", { mode: "contact" });
					},
					"click .footer .feedback": function(e) {
						e.preventDefault();

						UserVoice("show", { mode: "satisfaction" });
					}
				},


				/**
				 * Handles the menu item click event and triggers the appropriate handler.
				 *
				 * Slightly obscurely, but aptly named.
				 *
				 * @api    private
				 * @param  {Event} e The event
				 */
				effectuate: function(e) {
					var elm = $(e.currentTarget);

					switch (elm.attr("data-item")) {
						case "notifications":
							elm.closest(".menu-container").addClass("notifications", 1000);
							e.preventDefault();
							e.stopPropagation();
							Track.event("Menu", "Notification", "Chrome");
						break;

						case "back":
							elm.closest(".menu-container").removeClass("notifications", 1000);
							e.preventDefault();
							e.stopPropagation();
							Track.event("Menu", "Back", "Chrome");
						break;

						case "item-announcement":
							Announcements.showId(elm.attr("data-type"), elm.attr("data-id"), false);
						break;

						case "dismiss-announcement":
							Announcements.showId(elm.attr("data-type"), elm.attr("data-id"), true);
						break;

						case "settings":
							SettingsProxy();
						break;

						case "support":
						{
							var url = "https://ichrome.uservoice.com/knowledgebase";
							Browser.tabs.getCurrent(function(d) {
								Browser.tabs.create({
									url: url,
									index: d !== null && typeof(d) !== 'undefined' ? d.index + 1 : 0
								});
							});

							Track.event("Menu", "Link Click", "Chrome");
						}
						break;

						case "upgrade":
							SettingsProxy("pro");
							break;

						case "widgets":
							if (!this.Store) {
								this.Store = new Store();
							}

							// This delays displaying the modal until after the init JS is done so the animation is smooth
							requestAnimationFrame(this.Store.show.bind(this.Store));
						break;

						case "editmode":
							e.stopPropagation();

							var state = elm.find(".state");

							if (state.hasClass("enabled")) {
								state.removeClass("enabled").text(Translate("menu.editing_disabled"));

								this.model.storage.settings.editing = false;
							}
							else {
								state.addClass("enabled").text(Translate("menu.editing_enabled"));

								this.model.storage.settings.editing = true;
							}

							$(document.body).toggleClass("no-edit", !this.model.storage.settings.editing);

							this.model.storage.sync();

							Track.event("Menu", "Edit Mode", this.model.storage.settings.editing ? "Enable" : "Disable");
						break;

						case "link":
							if (elm.hasClass("custom") && elm.attr("href").indexOf("chrome") === 0) {
								e.preventDefault();

								Browser.tabs.getCurrent(function(d) {
									if (e.which === 2 || $("base").attr("target") === "_blank") {
										Browser.tabs.create({
											url: elm.attr("href"),
											index: d.index + 1
										});
									}
									else {
										Browser.tabs.update(d.id, {
											url: elm.attr("href")
										});
									}
								});

								Track.event("Menu", "Link Click", "Chrome");
							}
							else {
								Track.event("Menu", "Link Click");
							}
						break;

						case "tab":
							this.navigate(e.currentTarget);

							this.trigger("navigate", parseInt(elm.attr("data-id")));

							Track.event("Menu", "Tab Navigation");
						break;
					}
				},


				/**
				 * Updates the tabs menu to the freshly navigated tab
				 *
				 * @api    public
				 * @param  {Number|String|Element} which  The tab ID or menu element
				 * @param  {Backbone.View}         view   The tab view
				 * @param  {Backbone.Model}        model  The tab model
				 */
				navigate: function(which, view, model) {
					if (typeof which === "string" || typeof which === "number") {
						this.$(".section.tabs div[data-id=" + ((model && model.get("id")) || (which + 1)) + "]").addClass("active").siblings().removeClass("active");
					}
					else {
						$(which).addClass("active").siblings().removeClass("active");
					}
				},


				/**
				 * Shows the menu
				 *
				 * @api    public
				 */
				show: function() {
					this.toggle(true);
				},


				/**
				 * Hides the menu
				 *
				 * @api    public
				 */
				hide: function() {
					this.toggle(false);
				},


				/**
				 * Toggles the menu's visibility
				 *
				 * @api    public
				 */
				toggle: function(show) {
					if (typeof show !== "boolean") {
						show = undefined;
					}

					if (!this.$el.hasClass("visible") && (typeof show === "undefined" || show === true)) {
						// If this doesn't include the toggle switch the event will bubble to the body which will in turn re-hide the menu
						var elms = this.$el.parent();

						elms = elms.find("*").add(elms);

						$(document.body).on("click.menu", function(e) {
							if (!elms.is(e.target) && !$(e.target).hasClass("close")) {
								this.toggle(false);
							}
						}.bind(this));

						this.$el.addClass("visible");

						this.trigger("show");

						Track.event("Menu", "Show");
					}
					else if (this.$el.hasClass("visible") && !show) {
						$(document.body).off("click.menu");

						this.$el.removeClass("visible");

						this.trigger("hide");

						Track.event("Menu", "Hide");
					}
				},


				initialize: function() {
					this.model = new Model();

					// init() needs to be called after the listener is attached to prevent a race
					// condition when storage is already loaded.  It also needs to be here instead
					// of attached directly to new Model() otherwise this.model might not be set yet.
					this.model.on("change", this.render, this).init();

					Announcements.on("countchange", this.render, this);

					// If this was a direct link to the settings, show them
					if (location.hash === "#settings") {
						SettingsProxy();
					}
				},


				/**
				 * Initializes the navigate handler
				 *
				 * @api    private
				 * @param  {Function}       navigate  The navigation callback
				 * @return {Backbone.View}
				 */
				init: function(navigate) {
					return this.on("navigate", navigate);
				},


				render: function() {
					this.model.attributes.notifications = Announcements.count && Announcements.count > 0 ? Announcements.count : null;
					this.model.attributes.notificationsList = Announcements.list;

					// This enables OK Google hotword detection even when there's only a menu and no toolbar
					if (this.model.get("ok") && !this.Speech) {
						this.Speech = Speech();

						// This calls the search submit handler using the Speech model for settings
						this.Speech.on("result", function(val) {
							if (!this.Search) {
								this.Search = new Search();

								// This is inside the if statement because if the search view already existed
								// it would have caught the event normally
								this.Search.onSpeechResult(val);
							}
						}, this);
					}

					this.$el.html(render("menu", this.model.toJSON()));

					return this;
				}
			});

		return new View();
	}
);
/**
 * The onboarding settings guide
 */
define('onboarding/settings',["jquery", "backbone", "core/analytics", "menu/menu", "core/render"], function($, Backbone, Track, Menu, render) {
	var View = Backbone.View.extend({
		tagName: "div",
		className: "showcase orange settings",

		events: {
			"click button.next": function() {
				this.navigateNext();
			},

			"click button.skip": function() {
				this.transitionOut();

				this.trigger("complete");

				this.stopListening();
			}
		},

		transitionIn: function() {
			this.el.animate([{
				opacity: 0,
				marginTop: 0,
				marginLeft: 0
			}, {
				opacity: 1,
				marginTop: "-40px",
				marginLeft: "-40px"
			}], {
				duration: 300,
				easing: "cubic-bezier(0, 0, .2, 1)"
			});
		},

		transitionOut: function(cb) {
			if (!cb) {
				cb = function() {};
			}

			this.el.animate([{
				opacity: 1,
				pointerEvents: "none"
			}, {
				opacity: 0,
				pointerEvents: "none"
			}], {
				duration: 300,
				fill: "forwards",
				easing: "cubic-bezier(.4, 0, 1, 1)"
			}).onfinish = function() {
				this.$el.remove();
				cb.call(this);
			}.bind(this);
		},


		showTooltips: function() {
			this.transitionOut();

			this.menuOverlay = $('<div class="menu-tutorial-overlay"></div>').html(render("onboarding/settings", {
				overlayCaption: true
			})).insertBefore("body > header.add-widget-link");

			this.menuOverlay[0].animate([
				{ opacity: 0 },
				{ opacity: 1 }
			], {
				duration: 300,
				easing: "cubic-bezier(0, 0, .2, 1)"
			});

			Menu.$el.addClass("tutorial").prepend(render("onboarding/settings", {
				labels: true
			}));

			this.listenToOnce(Menu, "hide", function() {
				this.menuOverlay[0].animate([
					{ opacity: 1 },
					{ opacity: 0 }
				], {
					duration: 300,
					easing: "cubic-bezier(.4, 0, 1, 1)"
				}).onfinish = function() {
					this.menuOverlay.remove();
				}.bind(this);

				Menu.$el.removeClass("tutorial").children("ul.labels").remove();

				this.trigger("complete");

				this.stopListening();
			});

			Track.pageview("Settings onboarding: Screen 2", "/onboarding/settings/screen2");
		},

		initialize: function() {
			Backbone.on('widget-dropped', this.onWidgetDropped, this);
			Backbone.on('widgets-closed', this.onStoreClosed, this);

			this.render();

			this.listenToOnce(Menu, "show", this.showTooltips);

			this.$el.appendTo(document.body);

			this.transitionIn();

			Track.pageview("Settings onboarding: Screen 1", "/onboarding/settings/screen1");
		},

		navigateNext: function() {
			this.transitionOut(function() {
				this.remove();

				//this.$targetEl.parent().removeClass("hovered");

				this.trigger("next");
			});
		},

		onWidgetDropped: function() {
			this.navigateNext();
		},

		onStoreClosed: function() {
			this.navigateNext();
		},

		render: function() {
			// The menu button/icon is always in the same place in a default setup
			this.$el.css({
				top: 33,
				right: 55
			}).html(render("onboarding/settings", {
				intro: true
			})).find(".action-mask").on("mouseover", function(e) {
				this.$el.css("pointer-events", "none");

				var rect = e.currentTarget.getBoundingClientRect();

				$(document.body).on("mousemove.showcase", function(e) {
					if (!(
						e.pageX > rect.left &&
						e.pageX < rect.right &&
						e.pageY > rect.top &&
						e.pageY < rect.bottom
					)) {
						$(document.body).off("mousemove.showcase");

						this.$el.css("pointer-events", "");
					}
				}.bind(this));
			}.bind(this));
		}
	});

	return View;
});
/**
 * The introduction modal
 */
define('onboarding/introduction',["jquery", "backbone", "i18n/i18n", "core/analytics", "core/render"], function($, Backbone, Translate, Track, render) {
	var View = Backbone.View.extend({
		tagName: "div",
		className: "onboarding-flat blue widget-introduction",

		events: {
			"click button.done": function() {
				this.transitionOut(function() {
					this.remove();

					this.trigger("next");
				});
			},

			"click button.skip": function() {
				this.transitionOut(function() {
					this.remove();

					this.trigger("skip");

					this.stopListening();
				});
			},

			"click .terms_checkbox": function() {
				var checked = this.$(".terms_checkbox:checked");
				var buttons = this.$(".tutorial-buttons button");
				if (checked.length > 0) {
					buttons.removeClass("invisible");
				}else{
					buttons.addClass("invisible");
				}
			}

		},

		transitionOut: function(cb) {
			if (!cb) {
				cb = function() {};
			}

			this.el.animate([{
				opacity: 1,
				pointerEvents: "none"
			}, {
				opacity: 0,
				pointerEvents: "none"
			}], {
				duration: 300,
				easing: "cubic-bezier(.4, 0, 1, 1)"
			}).onfinish = cb.bind(this);
		},

		initialize: function() {
			this.render();

			this.$el.appendTo(document.body);

			Track.pageview("Widget onboarding: Screen 1", "/onboarding/widgets/screen1");
		},

		render: function() {
			this.$el.html(render("onboarding/introduction"));
		}
	});

	return View;
});
/**
 * The onboarding modal
 */
define('onboarding/upgrade',[
	"backbone", "browser/api", "core/analytics", "storage/storage", "modals/modals", "core/auth", "storage/syncapi", "core/render", "settings/checkout", "core/uservoice", "modals/alert", "i18n/i18n"
], function(Backbone, Browser, Track, Storage, Modal, Auth, SyncAPI, render, Checkout, UserVoice, Alert, Translate) {
	var View = Backbone.View.extend({
		events: {
			"click button.upgrade": function() {
				Track.FB.logEvent("INITIATED_CHECKOUT", null, { fb_content_type: "pro" });

				Alert({
					confirm: true,
					title: Translate("settings.pro.checkout.signin"),
					contents: [Translate("settings.pro.checkout.signin_desc")],
					buttons: {
						positive: Translate("settings.pro.checkout.signin_btn")
					}
				}, function() {
					Storage.on("done", function(storage) {
						SyncAPI.authorize(storage, false, function() {
							if (Auth.isPro) {
								this.trigger("complete");
								location.reload();
							}
							else {
								new Checkout("pro");
								this.trigger("dismiss");
							}
						}.bind(this));
					}.bind(this));

					return;
				}.bind(this));
			},

			"click header .business a": function(e) {
				e.preventDefault();

				UserVoice("show", { mode: "contact" });
			},

			"click .nav button": "navigate",
		},


		/**
		 * Handles click events on the nav buttons
		 *
		 * @api    private
		 * @param  {Event}  e  A click event
		 */
		navigate: function() {
			if (!this._interactionTracked) {
				// It's important to know how many users don't even click to see the next slide
				Track.event("Onboarding", "Modal", "Interaction");

				this._interactionTracked = true;
			}

			this.modal.hide();

			this.trigger("complete");
		},

		constructor: function() {
			this.modal = new (Modal.extend({
				classes: "onboarding upgrade",

				destroyOnHide: true,

				close: function() {}
			}))();

			this.el = this.modal.el;

			Backbone.View.call(this);
		},

		initialize: function() {
			this.modal.mo.appendTo(document.body);

			this.render();

			this.modal.show();

			// Pages are tracked in addition to events so a funnel can be set up
			Track.pageview("Onboarding Modal: Slide 1", "/onboarding/modal/slide1");
		},

		render: function() {
			this.$el.attr("data-slide", 1);

			this.$el.html(render("onboarding/upgrade", {
				newTab: Browser.app.newTab
			}));
		}
	});

	return View;
});
/**
 * The onboarding guide this is shown once on installation unless a logged in user is synced in
 */
define('onboarding/controller',[
	"lodash", "backbone", "browser/api", "core/analytics", "core/auth", "storage/storage", "onboarding/modal", "onboarding/widgets", "onboarding/settings", "onboarding/introduction", "onboarding/upgrade"
], function(_, Backbone, Browser, Track, Auth, Storage, Modal, WidgetGuide, SettingsGuide, Introduction, UpgradePage) {
	var Controller = function() {
		// The onboarding process is heavily tracked, it's important to know where new users
		// might be giving up or how far they get through the process

		// If we needed to reload because the user was Pro, pick up again at the widget
		// onboarding stage.
		/*if (Browser.storage.firstRun === "resume") {
			return this.showIntroductionGuide();
		}*/

		var isFirstRun = Browser.storage.firstRun === "true";
		if (isFirstRun) {
			//Show instroduction page on first run
			Track.event("Onboarding", "Introduction", "Shown");

			this.introduction = new Introduction();

			this.listenToOnce(this.introduction, "skip", function() {
				this.complete();
			}.bind(this));
			this.listenToOnce(this.introduction, "next", this.showWidgetGuide);

			return true;
		}

		var isAuth = Browser.storage.nextAuth && Browser.storage.nextAuth <= new Date().getTime();
		if (isAuth) {
			if (Auth.isSignedIn) {
				Browser.storage.nextAuth = Number.MAX_VALUE; //Already signed in : never run again
				return; 
			}

			//The Authentication page shown on second run				
			Track.event("Onboarding", "Modal", "Show");

			this.modal = new Modal({isAuth: isAuth});

			this.listenToOnce(this.modal, "close", function(userType) {
				if (userType.indexOf("existing") === 0) {
					this.complete();

					if (userType === "existing_pro") {
						location.reload();
					}
				}

				// If the user is a new user and is Pro (this can happen with businesses and schools),
				// we need to reload the page to handle Pro initialization and then resume the onboarding
				// process
				else if (userType === "new_pro") {
					Browser.storage.firstRun = "resume";

					location.reload();	
				}

				else {
					Browser.storage.nextAuth = new Date().getTime() + 86400000 * 2; //Next run in 2 days
					//this.showIntroductionGuide();
				}
			});
			
			return;
		}
	};

	_.extend(Controller.prototype, Backbone.Events, {
		complete: function(withDelay) {
			delete Browser.storage.firstRun;

			this.trigger("complete");

			Track.event("Onboarding", "Complete");

			Track.FB.logEvent("COMPLETED_TUTORIAL");

			if (!Browser.storage.nextAuth) {
				Browser.storage.nextAuth = new Date().getTime() + (withDelay ? 3000 : 0); //Run onboarding next start to show the SignIn page
			}

		},

		dismiss: function() {
			delete Browser.storage.firstRun;
			
			Track.event("Onboarding", "Dismiss");

			Track.FB.logEvent("DISMISS_TUTORIAL");
		},

		showWidgetGuide: function() {
			Track.event("Onboarding", "Widgets", "Shown");

			this.widgetGuide = new WidgetGuide();

			this.listenToOnce(this.widgetGuide, "skip", this.complete);
			this.listenToOnce(this.widgetGuide, "next", this.showSettingsGuide);
		},

		showSettingsGuide: function() {
			Track.event("Onboarding", "Settings", "Shown");

			this.settingsGuide = new SettingsGuide();

			this.listenToOnce(this.settingsGuide, "skip", this.complete);
			this.listenToOnce(this.settingsGuide, "next", this.showUpgradeScreen);
		},

		showUpgradeScreen: function() {
			Track.event("Onboarding", "Upgrade", "Shown");

			this.upgradePage = new UpgradePage();

			this.listenToOnce(this.upgradePage, "complete", this.complete);
			this.listenToOnce(this.upgradePage, "dismiss", this.dismiss);
		}


	});

	return new Controller();
});
/**
 * Displays a modal after updates
 */
define('notices/updated',[
	"browser/api", "backbone", "core/auth", "modals/modals", "modals/alert", "i18n/i18n", "storage/storage", "storage/syncapi", "core/render"
], function(Browser, Backbone, Auth, Modal, Alert, Translate, Storage, SyncAPI, render) {
	var View = Backbone.View.extend({
		className: "updated",

		events: {
			"click .nav button": "navigate",

			"click .sign-in button.sign-in": function() {
				Alert({
					title: Translate("storage.signin_confirm.title"),
					contents: [Translate("storage.signin_confirm.desc")],
					buttons: {
						negative: Translate("storage.signin_confirm.keep_account"),
						positive: Translate("storage.signin_confirm.keep_local")
					}
				}, function(sendData) {
					Storage.once("done", function(storage) {
						SyncAPI.authorize(storage, sendData, function() {
							this.$(".slide.sign-in .complete").addClass("visible").siblings().removeClass("visible");

							// If the user is Pro, we need to reload so the app initializes properly
							if (Auth.isPro) {
								location.reload();
							}
						}.bind(this));
					}, this);
				}.bind(this));
			}
		},


		/**
		 * Handles click events on the nav buttons
		 *
		 * @api    private
		 * @param  {Event}  e  A click event
		 */
		navigate: function(e) {
			var active = this.$(".slide.active"),
				page;

			if (e.currentTarget.getAttribute("data-direction") === "prev") {
				page = active.prev(".slide");
			}
			else {
				page = active.next(".slide");
			}

			if (page.length) {
				active.removeClass("active");

				page.addClass("active");

				this.$(".nav button.next").toggleClass("finish", !page.next(".slide").length);
			}
			else if (active.attr("data-id") !== "1") {
				this.modal.hide();

				delete Browser.storage.showUpdated;
			}

			var slideID = page.attr("data-id");

			this.$el.attr("data-slide", slideID);
		},

		constructor: function() {
			this.modal = new (Modal.extend({
				classes: "updated",

				destroyOnHide: true,

				close: function() {}
			}))();

			this.el = this.modal.el;

			Backbone.View.call(this);
		},

		initialize: function() {
			this.modal.mo.appendTo(document.body);

			this.$el.attr("data-slide", 1).html(render("updated"));

			this.modal.show();
		}
	});

	return new View();
});
/**
 * Displays a notice to users during the V2 -> V3 upgrade process telling them they need to sign in
 */
define('notices/signin',[
	"jquery", "backbone", "browser/api", "modals/alert", "core/auth", "i18n/i18n", "storage/storage", "storage/syncapi"
], function($, Backbone, Browser, Alert, Auth, Translate, Storage, SyncAPI) {
	var View = Backbone.View.extend({
		tagName: "div",
		className: "snackbar sync-signin",

		events: {
			"click button.dismiss": function() {
				delete Browser.storage.showSignInNotice;

				this.remove();
			},

			"click button.signin": function() {
				Alert({
					title: Translate("storage.signin_confirm.title"),
					contents: [Translate("storage.signin_confirm.desc")],
					buttons: {
						negative: Translate("storage.signin_confirm.keep_account"),
						positive: Translate("storage.signin_confirm.keep_local")
					}
				}, function(sendData) {
					SyncAPI.authorize(this._storage, sendData, function() {
						// If the user is Pro, we need to reload so the app initializes properly
						if (Auth.isPro) {
							location.reload();
						}
					}.bind(this));

					//Needed to stop to show the signin announcements
					Browser.storage.lastUpgradeNotification = new Date().getTime();
				}.bind(this));

				delete Browser.storage.showSignInNotice;

				this.remove();
			}
		},

		initialize: function() {
			Storage.on("done", function(storage) {
				this._storage = storage;

				this.$el.html(
					'<span class="text">' + Translate("storage.signin") + '</span>' +
					'<button type="button" class="material flat dismiss">' + Translate("storage.signin_dismiss") + '</button>' +
					'<button type="button" class="material flat green signin">' + Translate("storage.signin_btn") + '</button>'
				).appendTo(document.body);
			}, this);
		}
	});

	return new View();
});
/**
 * This generates global CSS overrides based on settings and user defined custom CSS
 */
define('core/css',["backbone", "storage/storage", "core/render"], function(Backbone, Storage, render) {
	var Model = Backbone.Model.extend({
			defaults: {
				custom: ""
			},
			init: function() {
				Storage.on("done updated", function(storage) {
					this.set({
						custom: storage.settings.customCSS || ""
					});
				}, this);

				return this;
			}
		}),
		View = Backbone.View.extend({
			tagName: "style",
			className: "customcss",
			initialize: function() {
				this.model = new Model().on("change", this.render, this);

				// This can't be in the same statement since init might be synchronous
				this.model.init();
			},
			render: function() {
				var d = this.model.toJSON();

				this.$el.html(render("css", d));

				return this;
			}
		});

	return View;
});
/**
 * Displays information about the currently displayed background image or video
 */
define('themes/bginfo',[
	"lodash", "backbone", "core/auth", "i18n/i18n", "core/analytics", "modals/alert", "themes/controller", "themes/utils", "core/render"
], function(_, Backbone, Auth, Translate, Track, Alert, Themes, Utils, render) {
	var View = Backbone.View.extend({
		tagName: "section",
		className: "panel",

		attributes: {
			tabindex: -1
		},

		events: {
			"click button.download": function() {
				if (!Auth.isPro) {
					return Alert(Translate("themes.bginfo.pro_only"));
				}

				var a = document.createElement("a");

				a.href = this.data.downloadUrl;

				// Copy the extension
				a.download = this.data.name + a.pathname.slice(a.pathname.lastIndexOf("."), a.pathname.length);

				a.click();
			},

			"click button.source": function() {
				var a = document.createElement("a");

				a.href = this.data.sourceUrl;

				a.click();
			},

			"click button.view": function(e) {
				this.body.prepend(
					'<style id="theme-view-style-elm">' +
						'body > *:not(.bg-video) {' +
							'opacity: 0!important;' +
							'pointer-events: none;' +
							'transition: opacity .3s ease-in-out!important;' +
						'}' +
					'</style>'
				);

				var startX = e.clientX,
					startY = e.clientY;

				// This delays the attaching till after the events have finished bubbling, otherwise mousemove will get called immediately
				requestAnimationFrame(function() {
					this.body.on("mousemove.bgpreview", function(e) {
						if (Math.abs(e.clientX - startX) >= 30 || Math.abs(e.clientY - startY) >= 30) {
							var tStyle = this.body.off("mousemove.bgpreview").children().first().html(
								"body > *:not(.bg-video) {" +
									"transition: opacity .3s ease-in-out!important;" +
								"}"
							);

							setTimeout(function() { tStyle.remove(); }, 300);
						}
					}.bind(this));
				}.bind(this));

				Track.event("Theme Info", "View Background");
			},

			"click button.close": "close",

			"keydown": function(e) {
				if (e.keyCode === 27) {
					this.close();
				}
			}
		},

		close: function() {
			this.body.off("click.bginfo");

			this.animationPlayer.reverse();

			this.animationPlayer.onfinish = this.remove.bind(this);
		},

		initialize: function(options) {
			this.body = options.body;

			if (this.render() === true) {
				return;
			}

			this.listenTo(Themes, "change:theme", this.render);


			var elms = this.$("*").add(this.$el);

			this.body.on("click.bginfo", function(e) {
				if (!elms.is(e.target)) {
					this.close();
				}
			}.bind(this));


			this.animationPlayer = this.el.animate([
				{ transform: "translateY(calc(100% + 10px))" },
				{ transform: "translateY(0)" }
			], {
				duration: 200,
				easing: "cubic-bezier(.4, 0, .2, 1)"
			});

			Track.event("BG Info", "Show");
		},

		render: function() {
			var theme = Themes.theme;

			if (!theme) {
				this.remove();

				return true;
			}

			var preview, downloadUrl;

			// If the theme has multiple images then Utils.getImage might return a random one and
			// not the one that's currently being displayed. Without special logic for each theme
			// type we need to do a reverse lookup for the currently displayed background image.
			//
			// This unfortunately won't handle redirects, but should be OK for almost all cases
			if (theme.images) {
				// Clone so we don't set currentImage on the original
				theme = _.clone(theme);

				theme.currentImage = _.find(Utils.model.get("cached"), {
					image: this.body[0].style.backgroundImage.replace(/.*\s?url\([\'\"]?/, "").replace(/[\'\"]?\).*/, "")
				});

				if (!theme.currentImage) {
					return;
				}

				downloadUrl = Utils.getImage(theme.currentImage);
			}
			else {
				downloadUrl = Utils.getImage(theme);
			}


			if ((theme.oType || theme.type) === "video") {
				var canvas = document.createElement("canvas");

				canvas.width = Themes.video.videoWidth > 800 ? Themes.video.videoWidth / 2 : Themes.video.videoWidth;
				canvas.height = Themes.video.videoHeight > 400 ? Themes.video.videoHeight / 2 : Themes.video.videoHeight;

				var ctx = canvas.getContext("2d");

				ctx.drawImage(Themes.video, 0, 0, canvas.width, canvas.height);

				preview = canvas.toDataURL();
			}
			else {
				preview = downloadUrl;
			}


			this.data = {
				isPro: Auth.isPro,
				preview: preview,
				downloadUrl: downloadUrl
			};


			if (theme.currentImage) {
				if (theme.currentImage.name) {
					this.data.name = theme.currentImage.name;
				}

				if (theme.currentImage.url || (theme.currentImage.source && theme.currentImage.source.url)) {
					this.data.sourceUrl = theme.currentImage.url || (theme.currentImage.source && theme.currentImage.source.url);
				}

				if (theme.currentImage.source) {
					this.data.copyright = theme.currentImage.source.name ? theme.currentImage.source.name : theme.currentImage.source;
				}

				if (theme.currentImage.desc) {
					this.data.desc = theme.currentImage.desc;
				}
			}


			if (!this.data.name) {
				this.data.name = theme.name || Translate("themes.bginfo.unknown");
			}

			if (!this.data.copyright && theme.source && theme.source.name) {
				this.data.copyright = theme.source.name;
			}

			if (!this.data.sourceUrl && theme.source && theme.source.url) {
				this.data.sourceUrl = theme.source.url;
			}


			if (theme.name && theme.id !== 0 && theme.name !== this.data.name && theme.name !== this.data.copyright) {
				this.data.themename = theme.name;
			}


			this.$el.html(render("bginfo", this.data));

			// Focus when we're inserted so hitting Esc immediately works
			requestAnimationFrame(this.$el.focus.bind(this.$el));
		}
	});

	return View;
});
/**
 * The main tooltip handler.  This displays tooltips for any element with a data-tooltip attribute
 */
define('core/tooltips',["jquery", "backbone", "core/analytics", "core/render"], function($, Backbone, Track, render) {
	var View = Backbone.View.extend({
		tagName: "div",
		className: "tooltip",

		events: {
			"mouseenter": function() {
				clearTimeout(this.timeout);

				this.$el.addClass("visible");
			},
			"mouseleave": function() {
				clearTimeout(this.timeout);

				this.$el.removeClass("visible");

				this.timeout = setTimeout(function() {
					this.$el.css({
						top: "",
						left: "",
						maxHeight: ""
					});
				}.bind(this), 300);
			}
		},

		timeout: null,


		/**
		 * Handles the mouse enter event, showing the tooltip
		 *
		 * @api    private
		 * @param  {Event}  e The event
		 */
		mouseEnter: function(e) {
			var elm = $(e.currentTarget),
				offset = elm.offset();

			clearTimeout(this.timeout);

			this.timeout = setTimeout(function() {
				var content = elm.attr("data-tooltip");

				if (!content) {
					return;
				}

				var top = offset.top + elm.outerHeight() + 10,
					maxHeight = false;

				// The RegExp removes extra newlines at the end of tooltips, RegExp should
				// generally not be used with HTML but this is a visual improvement, not functional
				this.$el.html(content.replace(/(<br(?:\s|\n|\r)*(?:\/)?>(?:\s|\n|\r)*)+$/, ""));

				var tHeight = this.$el.outerHeight();

				if ((top + tHeight) > (document.body.scrollTop + window.innerHeight)) {
					top = offset.top - tHeight - 5;

					if (top < 0) {
						maxHeight = tHeight + top;

						top = 0;
					}
				}

				this.$el.css({
					top: Math.round(top),
					maxHeight: maxHeight || "",
					left: Math.round(offset.left)
				}).addClass("visible");

				Track.event("Tooltip", "Show");
			}.bind(this), 500);
		},


		/**
		 * Handles the mouse leave event, hiding the tooltip
		 *
		 * @api    private
		 */
		mouseLeave: function() {
			clearTimeout(this.timeout);

			this.$el.removeClass("visible");

			this.timeout = setTimeout(function() {
				this.$el.css({
					top: "",
					left: "",
					maxHeight: ""
				});
			}.bind(this), 300);
		},

		initialize: function() {
			this.body = $(document.body);

			this.body
				.on("mouseenter", "[data-tooltip]", this.mouseEnter.bind(this))
				.on("mouseleave", "[data-tooltip]", this.mouseLeave.bind(this));

			this.body.append(this.$el);
		},

		render: function() {
			this.$el.html(render("css", this.model.toJSON()));

			return this;
		}
	});

	return View;
});
/**
 * This generates the toolbar and its submodules
 */
define('menu/toolbar',[
	"lodash", "jquery", "backbone", "browser/api", "core/auth", "core/analytics", "storage/storage",
	"storage/defaults", "search/search", "menu/menu", "core/announcements", "core/render"
], function(_, $, Backbone, Browser, Auth, Track, Storage, Defaults, Search, Menu, Announcements, render) {
	var Model = Backbone.Model.extend({
			init: function() {
				Storage.on("done updated", function(storage) {
					var set = _.clone(storage.settings);

					set.links = _.take(set.links, Auth.isPro ? 8 : 3);

					set.name = storage.user.fname || Defaults.user.fname;

					set.profileimage = storage.user.image ? storage.user.image.replace("s128-c", "s72-c") : Defaults.user.image;

					if (set.toolbar === "full") {
						set.toolbar = "button";
						storage.settings = "button";
					}

					Announcements.off("countchange", null, this).on("countchange", function(count) {
						this.set("announcements", count);
					}, this);

					set.announcements = Announcements.count;

					this.set(set);
				}, this);
			}
		}),
		View = Backbone.View.extend({
			tagName: "header",
			className: "toolbar",

			events: {
				"click .apps-toggle": "toggleApps",
				"click .menu-toggle": Menu.toggle.bind(Menu),

				"click .announcements": function() {
					Announcements.show();
				},
				"click .apps a.icon": function(e) {
					e.preventDefault();
				},
				"click a.custom-link": function(e) {
					var href = e.currentTarget.getAttribute("href");

					if (href.indexOf("chrome") === 0) { // chrome:// links can't be opened directly for security reasons, this bypasses that feature.
						e.preventDefault();

						Browser.tabs.getCurrent(function(d) {
							if (e.which === 2 || $("base").attr("target") === "_blank") {
								Browser.tabs.create({
									url: href,
									index: d.index + 1
								});
							}
							else {
								Browser.tabs.update(d.id, {
									url: href
								});
							}
						});

						Track.event("Toolbar", "Link Click", "Chrome");
					}
					else {
						Track.event("Toolbar", "Link Click");
					}
				}
			},


			/**
			 * Shows and hides the apps panel
			 *
			 * @api    private
			 * @param  {Event} e The event
			 */
			toggleApps: function(e) {
				var elm = $(e.currentTarget);

				if (!elm.hasClass("active")) {
					if (!this.appsLoaded) {
						elm.find("img[data-src]").each(function() {
							this.setAttribute("src", this.getAttribute("data-src"));

							this.removeAttribute("data-src");
						});

						this.appsLoaded = true;
					}

					var elms = elm.find("*").add(elm);

					$(document.body).on("click.apps", function(e) {
						if (!elms.is(e.target)) {
							elm.removeClass("active");

							$(document.body).off("click.apps");
						}
					});

					elm.addClass("active");

					Track.event("Toolbar", "Apps Menu", "Open");
				}
				else {
					$(document.body).off("click.apps");

					elm.removeClass("active");

					Track.event("Toolbar", "Apps Menu", "Close");
				}
			},


			initialize: function() {
				this.model = new Model();

				this.Menu = Menu;

				this.Search = new Search();

				var insertTriggered = false;

				// The inserted event is triggered once the toolbar is inserted into the document
				this.on("inserted", function() {
					this.Search.trigger(insertTriggered ? "reinserted" : "inserted");

					if (!insertTriggered) {
						insertTriggered = true;
					}
				});

				// init() needs to be called after the listener is attached to prevent a race condition when storage is already loaded.
				// It also needs to be here instead of attached directly to new Model() otherwise this.model might not be set yet.
				this.model.on("change", this.render, this).init();
			},


			render: function() {
				var toolbar = this.model.get("toolbar") === "full" || this.model.get("toolbar") === "full2" || this.model.get("toolbar") === true;
				this.model.set('isFull', toolbar, {silent:true});

				if (toolbar) {
					this.Menu.$el.detach();
				}

				// The app icons attributes get reset on render
				this.appsLoaded = false;

				this.Search.$el.detach();

				this.$el.html(render("toolbar", this.model.toJSON()));
				this.$el.toggleClass('floating', !toolbar);

				var hiddenSearch = this.model.get("toolbar") === "button_ns";
				this.$el.toggleClass('nosearch', hiddenSearch);

				this.$(".search").replaceWith(this.Search.el);

				this.Search.trigger("reinserted");

				if (toolbar) {
					this.$("nav.menu").replaceWith(this.Menu.el);
				}

				this.Menu.delegateEvents();

				return this;
			}
		});

	return View;
});
/**
 * This generates the toolbar button style
 */
define('menu/button',["backbone", "menu/menu", "core/announcements"], function(Backbone, Menu, Announcements) {
	var View = Backbone.View.extend({
		tagName: "div",
		className: "menu-toggle",

		events: {
			"click .menu-container": Menu.toggle.bind(Menu),

			"click .menu-button, .announcements": function(e) {
				Menu.toggle(e);
			}
		},

		initialize: function() {
			this.render();

			Announcements.on("countchange", this.render, this);
		},

		render: function() {
			Menu.$el.detach();

			this.$el.html('<div class="menu-button"></div>' + (Announcements.count ? '<div class="announcements">' + Announcements.count + '</div>' : "")).append(Menu.el);

			return this;
		}
	});

	return View;
});
/**
 * A View Collection, used by tabs and columns to create collections of models with corresponding views
 */
define('backbone.viewcollection',["lodash", "backbone"], function(_, Backbone) {
	var ViewCollection = Backbone.Collection.extend({
		view: Backbone.View,


		/**
		 * Creates a new view from the specified model
		 *
		 * @api   public
		 * @param {Backbone.Model} model     The model
		 * @param {Boolean}        silent    Whether or not to emit an event
		 * @param {Boolean}        skipSort  Whether or not to skip resorting the views
		 */
		addView: function(model, silent, skipSort) {
			var view = new this.view({
				model: model
			});

			this.views.push(view);

			if (!skipSort) {
				this.sortViews(silent);
			}

			if (!silent) {
				this.trigger("views:add", view, model);
				this.trigger("views:change", this.views, this.models);
			}

			return this;
		},



		/**
		 * Erases and recreates all views from the models
		 *
		 * @api   public
		 */
		resetViews: function() {
			// This function needs to work off of a difference otherwise views will be destroyed
			// erasing event handlers and other jQuery data from their respective elements
			var viewModels = _.pluck(this.views, "model");

			_.each(_.difference(viewModels, this.models), function(e) {
				this.removeView(e, true);
			}, this);

			_.each(_.difference(this.models, viewModels), function(e) {
				this.addView(e, true, true);
			}, this);

			this.sortViews(true);

			this.trigger("views:reset views:change", this.views, this.models);

			return this;
		},



		/**
		 * Sorts the views array to match the models
		 *
		 * @api   public
		 * @param {Boolean}        silent Whether or not to emit an event
		 */
		sortViews: function(silent) {
			// This is used to see if the views actually changed at all
			var oldViews = _.pluck(this.views, "cid").join(" ");

			// Get the model cids as an array.  This can't use this.pluck() since that
			// calls .get() which won't return the cid
			var order = _.pluck(this.models, "cid");

			// Using an object instead of an array makes the sort O(n2) instead of O(n^2)
			order = _.zipObject(order, order.map(function(e, i) {
				// This is +1 so the later order[e.cid] || Infinity doesn't trigger on 0s
				return i + 1;
			}));

			this.views = _.sortBy(this.views, function(e) {
				// If the model isn't present then move it to the end
				return order[e.model.cid] || Infinity;
			});

			if (!silent && oldViews !== _.pluck(this.views, "cid").join(" ")) {
				this.trigger("views:sort views:change", this.views, this.models);
			}

			return this;
		},


		/**
		 * Removes either the specified view or the view for the specified model
		 *
		 * @api   public
		 * @param {String|Backbone.Model|Backbone.View} e      The model, model cid or view
		 * @param {Boolean}                             silent Whether or not to emit an event
		 */
		removeView: function(e, silent) {
			var view;

			if (e instanceof Backbone.View) {
				var i = this.views.indexOf(e);

				if (i !== -1) {
					view = this.views.splice(i, 1)[0];
				}
			}
			else if (e instanceof Backbone.Model) {
				view = _.remove(this.views, {
					model: {
						cid: e.cid
					}
				})[0];
			}
			else if (typeof e === "string") {
				view = _.remove(this.views, {
					model: {
						cid: e
					}
				})[0];
			}

			if (view) {
				view.remove();

				if (!silent) {
					this.trigger("views:remove", view, view.model);
					this.trigger("views:change", this.views, this.models);
				}
			}

			return this;
		},


		// Backbone overrides
		reset: function(models, options) {
			// This is set so the add handler doesn't fire for each model. Since
			// it's synchronous it'll never get seen by anything else
			this.resetting = true;

			Backbone.Collection.prototype.reset.call(this, models, options);

			delete this.resetting;

			this.resetViews();

			return this;
		},

		_reset: function() {
			Backbone.Collection.prototype._reset.call(this);

			if (this.views) {
				_.each(_.clone(this.views), function(e) {
					this.removeView(e, true);
				}, this);
			}
			else {
				this.views = [];
			}
		},

		add: function(models, options) {
			// See above
			this.adding = true;

			Backbone.Collection.prototype.add.call(this, models, options);

			delete this.adding;

			if (!this.resetting && !this.setting) {
				if (!Array.isArray(models)) {
					models = [models];
				}

				_.each(models, function(e) {
					this.addView(e, options.silent);
				}, this);
			}

			return this;
		},

		set: function(models, options) {
			this.setting = true;

			Backbone.Collection.prototype.set.call(this, models, options);

			delete this.setting;

			if (!this.adding && !this.removing && !this.resetting) {
				this.resetViews();
			}

			return this;
		},

		remove: function(models, options) {
			this.removing = true;

			Backbone.Collection.prototype.remove.call(this, models, options);

			delete this.removing;

			if (!this.resetting && !this.setting) {
				if (!Array.isArray(models)) {
					models = [models];
				}

				_.each(models, function(e) {
					this.removeView(e, options.silent);
				}, this);
			}

			return this;
		},

		sort: function(options) {
			Backbone.Collection.prototype.sort.call(this, options);

			if (!this.resetting && !this.setting) {
				this.resetViews();
			}

			return this;
		}
	});

	return ViewCollection;
});
/**
 * The tab model, this creates columns
 */
define('tabs/model',["lodash", "backbone", "backbone.viewcollection", "widgets/registry"], function(_, Backbone, ViewCollection, Registry) {
	var WidgetCollection = ViewCollection.extend({
		view: function(options) {
			if (options && options.model) {
				return Registry.createInstance(options.model);
			}
		},
		model: Registry.InstanceModel
	});

	var Tab = Backbone.Model.extend({
		columns: [],

		initialize: function() {
			var that = this;

			this.columnCollection = WidgetCollection.extend({
				initialize: function() {
					this.on("all", that.onColumnEvent, that);
				}
			});


			this.columns = _.map(this.get("columns"), function(e) {
				return new this.columnCollection(e, {
					validate: true
				});
			}, this);

			this.on("columns:change", this.serializeColumns, this);

			this.on("change:columns", this.updateColumns, this);
		},


		parse: function(data) {
			var defaults = _.result(this, "defaults");

			// If these properties are missing from the new data, they
			// need to be set back to their defaults
			if (typeof data.isGrid === "undefined" && this.has("isGrid")) {
				data.isGrid = defaults.isGrid;

				if (typeof defaults.isGrid === "undefined") {
					this.unset("isGrid");
				}
			}

			if (typeof data.fixed === "undefined" && this.has("fixed")) {
				data.fixed = defaults.fixed;

				if (typeof defaults.fixed === "undefined") {
					this.unset("fixed");
				}
			}

			// The adPlacement property piggybacks on the defaults system, but doesn't actually change
			data.adPlacement = defaults.adPlacement;

			return data;
		},


		toJSON: function() {
			var defaults = _.result(this, "defaults");

			return _.omit(this.attributes, function(e, k) {
				return (k === "isGrid" || k === "fixed") && e === defaults[k];
			});
		},


		/**
		 * Bubbles column events
		 */
		onColumnEvent: function(event) {
			var args = [].slice.call(arguments);

			// Colons actually have no significance in Backbone events, they're
			// just a style. So, we can namespace all bubbled events.
			args[0] = "columns:" + event;

			this.trigger.apply(this, args);
		},


		/**
		 * Serializes the columns collections to JSON, updating the columns attribute
		 *
		 * @param  {Boolean}  [silent]  If the update should be silent
		 */
		serializeColumns: function(silent) {
			this.set("columns", _.invoke(this.columns, "toJSON"), {
				silent: silent === true
			});
		},


		/**
		 * Updates the nested column collections when the column data changes.
		 *
		 * Since there's no way to identify a unique widget, we need to reset
		 * the collections every time a column changes.
		 */
		updateColumns: function() {
			// We use this to destroy any remaining columns in the event of a
			// change in the number of columns
			var tempColumns = this.columns.slice();


			var created = false;

			this.columns = _.map(this.get("columns"), function(e) {
				// Get the old column and data, shifting so we can easily
				// destroy remaining columns later
				var column = tempColumns.shift();

				// Although we have to reset if the data's changed, we can
				// still reuse old columns
				if (column) {
					if (JSON.stringify(column.toJSON()) !== JSON.stringify(e)) {
						column.reset(e);
					}

					return column;
				}

				created = true;

				return new this.columnCollection(e, {
					validate: true
				});
			}, this);


			// Destroy any remaining columns. Since collections don't have a destroy
			// method, we're actually just emptying them, destroying nested
			// widget instances and allowing them to be GC'd
			_.each(tempColumns, function(e) {
				e.off("all", this.onColumnEvent, this);

				e.reset();
			}, this);


			if (tempColumns.length || created) {
				this.trigger("update:columns");
			}
		}
	});

	return Tab;
});
/**
 * The tabs view.  This does the actual rendering of data, creaton of columns and widget insertion.
 */
define('tabs/view',["jquery", "lodash", "backbone", "core/auth", "core/status", "core/analytics", "i18n/i18n"], function($, _, Backbone, Auth, Status, Track, Translate) {
	var GRID_SIZE = 10;

	var view = Backbone.View.extend({
		tagName: "div",
		className: function() {
			return "tab" + (this.model.get("isGrid") ? " grid" : "");
		},

		initialize: function() {
			this.model.on("columns:sort columns:update columns:reset columns:views:change update:columns change:fixed change:isGrid change:adPlacement", function() {
				var options = _.last(arguments);

				if (!(options && options.noRefresh)) {
					this.render();
				}
			}, this);

			this.once("inserted", function() {
				this._inserted = true;
			}, this);

			this.render(true);
		},


		/**
		 * Serializes the widgets and columns into a JSON object, updating the model in the process
		 *
		 * @api    public
		 * @param  {Boolean} [trigger] Whether or not to trigger a sort event for this serialize
		 * @return {Object}  The serialized tab
		 */
		serialize: function(trigger) {
			var columns = [];

			if (this.model.get("isGrid")) {
				var column = [];

				this.$(".widget").each(function() {
					var that = $(this),
						widget = that.data("view");

					var loc = [
						Math.round(that.position().top / GRID_SIZE),
						Math.round(that.position().left / GRID_SIZE),
						Math.round(that.outerWidth() / GRID_SIZE),
						Math.round(that.outerHeight() / GRID_SIZE)
					];

					if (loc[0] < 0) {
						loc[0] = 0;
					}

					if (loc[1] < 0) {
						loc[1] = 0;
					}

					// This is silent so a save isn't triggered prematurely
					widget.model.set("loc", loc, { silent: true });

					column.push(widget);
				});

				columns.push(column);
			}
			else {
				this.$(".widgets-container > .column").each(function() {
					var column = [];

					$(this).children(".widget").each(function() {
						column.push($(this).data("view"));
					});

					columns.push(column);
				});
			}

			_.each(columns, function(column, i) {
				var collection = this.model.columns[i];

				// Only update the collection if the order is different from the columns
				if (_.pluck(collection.views, "cid").join(" ") !== _.pluck(column, "cid").join(" ")) {
					// Remove the old models and views
					collection.remove(
						_(collection.views).difference(column).each(function(e) {
							// If the element is still in the document then it was just moved out
							// of this tab, don't destroy it
							if (!$.contains(document.documentElement, e.el)) {
								// Again, silenced to avoid premature event triggering
								collection.removeView(e, true);
							}
							else {
								// This has to splice so the remove call, which calls removeView,
								// won't destroy the element
								collection.views.splice(collection.views.indexOf(e), 1);
							}
						}).pluck("model").valueOf(),
						{ silent: true }
					);


					// Insert the new ones.  Backbone needs to set up references so these can't be directly inserted
					collection.add(_(column).difference(collection.views).pluck("model").valueOf(), { silent: true });


					// Sort the models to match the views, see lib/backbone.viewcollection for comments
					var cids = _.pluck(_.pluck(column, "model"), "cid"),
						order = _.zipObject(cids, cids.map(function(e, i) {
							return i + 1;
						}));

					collection.models = _.sortBy(collection.models, function(e) {
						return order[e.cid] || Infinity;
					});


					// And then the views to match the new model order
					collection.sortViews(true);
				}
			}, this);

			this.model.serializeColumns(true);


			if (trigger) {
				this.model.trigger("sort", this.model, this.model.columns);

				// Since the render only inserts columns and widgets it's not expensive
				// This is called in requestAnimationFrame so there isn't a visible freeze
				window.requestAnimationFrame(this.render.bind(this));
			}

			return columns;
		},


		/**
		 * Initializes sortable.
		 *
		 * By the time this is called the sortable group has already been initialized, this simply adds
		 * the views columns
		 *
		 * @api    private
		 */
		sortable: function() {
			this.$("> .remove, > .widgets-container.grid, > .widgets-container > .column").sortable({
				group: "columns",
				handle: ".handle",
				itemSelector: "section",
				placeholder: "<section class=\"placeholder\"/>"
			});
		},


		/**
		 * Initializes widget resizing for grid-based tabs
		 *
		 * @api    private
		 */
		resizable: function() {
			var body = $(document.body),
				serialize = this.serialize.bind(this);

			this.$el.off("mousedown").on("mousedown", ".widget > .resize", function(e) {
				var startX = e.pageX,
					startY = e.pageY,
					widget = this.parentNode,
					startWidth = widget.offsetWidth,
					startHeight = widget.offsetHeight,

					grid = widget.parentNode,
					tc = body.children(".tab-container")[0],
					tcHeight = tc.offsetHeight,
					gridMax = tcHeight - 50,
					h;

				_.each(grid.querySelectorAll(".widget"), function(e) {
					h = e.offsetTop + e.offsetHeight;

					if (h >= gridMax) { gridMax = h; }
				});

				body.addClass("resizing").on("mousemove.widgetResize", function(e) {
					e.preventDefault();

					// -1 so it lines up with the insides of the grid squares
					widget.style.width = ((Math.round((startWidth + (e.pageX - startX)) / GRID_SIZE) * GRID_SIZE) - 1) + "px";
					widget.style.height = ((Math.round((startHeight + (e.pageY - startY)) / GRID_SIZE) * GRID_SIZE) - 1) + "px";


					var max = widget.offsetTop + widget.offsetHeight;

					if (gridMax > max) {
						max = gridMax;
					}

					grid.style.height = (max + 50) + "px";
				}).on("mouseup.widgetResize", function() {
					body.removeClass("resizing").off("mousemove.widgetResize mouseup.widgetResize");

					serialize(true);
				});
			});
		},


		/**
		 * Overrides Backbone's remove method
		 *
		 * @api    private
		 * @param  {sortable} [sortable] Whether or not only sortable should be removed
		 */
		remove: function(sortable) {
			// jQuery sortable doesn't have a method for removing containers from
			// groups without destroying the entire group or for accessing them directly.
			//
			// So, we have to get the rootGroup directly from an element's `data` which we
			// can then cleanup.
			var elms = this.$("> .remove, > .widgets-container.grid, > .widgets-container > .column"),
				dta = elms.first().data("sortable");

			if (dta) {
				var rootGroup = dta.rootGroup;

				_.remove(rootGroup.containers, function(e) {
					return elms.filter(e.el).length >= 1;
				});
			}


			if (sortable !== true) {
				Backbone.View.prototype.remove.call(this);
			}
		},


		/**
		 * Constructs a block ad element and appends it to the provided element
		 *
		 * @param   {Boolean}  active       If the tab is currently active
		 * @param   {Element}  el           The element the ad should be appended to
		 * @param   {String}   [placement]  The id of the placement for this ad
		 */
		insertAd: function(active, el, placement) {
			if (Auth.adFree) {
				return;
			}

			placement = placement || this.model.get("adPlacement") || "widget_block";

			var leaderboard = placement === "header_leaderboard" || placement === "footer_leaderboard",
				adId = _.uniqueId("blockAd"),
				ad = document.createElement(leaderboard ? "div" : "section");

			ad.setAttribute("class", "ad-unit" + (leaderboard ? (placement === "header_leaderboard" ? " top" : " bottom") : ""));

			ad.setAttribute("id", adId);

			el.appendChild(ad);


			// We avoid inflating impressions by only displaying the ad once the tab is visible
			// This could be modified to preload the various scripts and only show the ad itself later, but that causes issues with certain ads
			var displayAd = function() {
				var rightNow = new Date().toISOString().slice(0,10).replace(/-/g,"");
				ad.innerHTML = '<button type="button" class="hide-ad"></button>' +
					'<iframe id="adframe" src="https://ichro.me/adframe/' + placement + "?refresh=" + rightNow + '#' + adId + '" style="' + (leaderboard ? "width:728px;height:90px;" : "width:300px;height:250px;") + '" seamless></iframe>';
			};

			this.once("render:complete", function() {
				if (this._inserted && this.$el.hasClass("active")) {
					displayAd();
				}
				else if (this._inserted) {
					this.once("displayed", displayAd);
				}
				else {
					this.once("inserted", function() {
						if (this.$el.hasClass("active")) {
							displayAd();
						}
						else {
							this.once("displayed", displayAd);
						}
					}, this);
				}
			}, this);

			return true;
		},


		render: function(initial) {
			// Remove sortable
			if (initial !== true) {
				this.remove(true);

				// If the sub-views are not detached before $.html() is called,
				// their data will be removed, destroying all event handlers.
				this.$("> .widgets-container > .column > .widget, > .widgets-container.grid > .widget").detach();

				// Call $.html() to remove any data or events related to $.sortable
				this.$el.html("");
			}


			var isGrid = this.model.get("isGrid");

			// Set the grid class
			this.el.classList.toggle("grid", isGrid);

			// We use native methods here for speed
			this.el.innerHTML = '<div class="remove">' + Translate("remove_widget") + '</div>';



			var adColumn = 0,
				adInserted = false,
				adPlacement = this.model.get("adPlacement"),
				insertAd = this.insertAd.bind(this, this.$el.hasClass("active"));

			// If this is a grid-based or empty tab, and the user hasn't chosen to have a header leaderboard,
			// default to a footer one since block-based ones don't work
			if (!Auth.adFree && adPlacement !== "header_leaderboard" && (isGrid || !_.reduce(this.model.columns, function(e, v) { return e + v.length; }, 0))) {
				adPlacement = "footer_leaderboard";
			}

			if (adPlacement === "header_leaderboard" || adPlacement === "footer_leaderboard") {
				insertAd(this.el, adPlacement);

				adInserted = true;
			}

			if (adPlacement === "right_block") {
				adColumn = this.model.columns.length - 1;
			}


			var main = document.createElement("main");

			main.setAttribute("class", "widgets-container" + (this.model.get("fixed") && !isGrid ? " fixed" : "") + (isGrid ? " grid" : ""));


			var models = _.map(this.model.columns, function(collection, columnIndex) {
				var column = main;

				if (!isGrid) {
					column = document.createElement("div");

					column.setAttribute("class", "column");

					main.appendChild(column);
				}

				_.each(collection.views, function(e, i) {
					if (adInserted || isGrid || columnIndex !== adColumn) {
						return column.appendChild(e.el);
					}


					var size = e.model.get("size");

					// Insert the ad before the widget if
					if (
						size !== "tiny" && i !== 0 // This isn't a tiny widget and the previous ones were (if they weren't the ad would already be in)
					) {
						adInserted = insertAd(column, adPlacement);
					}

					column.appendChild(e.el);

					// Insert the ad after the widget if
					if (
						!adInserted &&
						size !== "tiny" || // This isn't a tiny widget
						size === "tiny" && i === 3 // This is the 4th tiny widget in a row
					) {
						adInserted = insertAd(column, adPlacement);
					}
				});

				if (columnIndex === adColumn && !isGrid && !adInserted) {
					adInserted = insertAd(column, adPlacement);
				}

				return collection.models;
			});


			this.el.appendChild(main);


			if (isGrid) {
				var max = this.el.offsetHeight - 50;

				// This is the number of pixels the bottom of the furthest widget is from the top
				var btm = _.max(_.map(_.flatten(models), function(e) {
					var loc = e.get("loc");

					if (loc) {
						return (loc[0] + loc[3]) * GRID_SIZE;
					}

					return 0;
				}));

				if (btm > max) {
					max = btm;
				}

				// The -50 and +50 makes sure that the container is either 50px from the bottom of
				// the last widget or at the bottom of the tab but never past it if it isn't necessary
				main.style.height = (max + 50) + "px";

				this.resizable();
			}


			this.sortable();

			this.trigger("render:complete");

			return this;
		}
	});


	return view;
});
/**
 * The tabs model/controller. This actually creates the tabs and handles things like nav and storage.
 */
define('tabs/collection',["lodash", "jquery", "backbone", "backbone.viewcollection", "tabs/model", "tabs/view"], function(_, $, Backbone, ViewCollection, Model, View) {
	var Tabs = ViewCollection.extend({
		model: Model,
		view: View,

		initialize: function() {
			this.on("views:change", this.navigate, this);


			// The defaults are set by the tabs model since it has access to storage
			this.model = Model.extend({
				defaults: function() {
					return this.defaults;
				}.bind(this)
			});
		},


		/**
		 * Makes a tab active
		 *
		 * @api   private
		 * @param {Backbone.View|Number} tab The tab or tab index to activate
		 */
		setActive: function(tab) {
			if (typeof tab === "number") {
				tab = this.views[tab];
			}

			if (this.indexOf(tab.model) === this.active && tab.$el.hasClass("active")) {
				return;
			}


			tab.$el.addClass("active");

			this.active = this.indexOf(tab.model);

			tab.trigger("displayed");

			$(_(this.views).without(tab).pluck("el").valueOf()).removeClass("active");

			this.trigger("navigate", this.active, tab, tab.model);
		},


		/**
		 * Navigates to a tab
		 *
		 * @api    public
		 * @param  {String|Number} [to] The tab to navigate to, either as an index, next, prev, first or last.
		 * @return {Number}           The index of the tab navigated to
		 */
		navigate: function(to) {
			var i = ((this.active + 1) || this.default || 1) - 1;

			if (typeof to === "number") {
				i = to - 1;
			}
			else if (typeof to === "string") {
				switch (to) {
					case "next":
						i++;
					break;
					case "prev":
						i--;
					break;
					case "first":
						i = 1;
					break;
					case "last":
						i = this.views.length;
					break;
				}
			}

			// This makes numbers larger or smaller than the number of views wrap around
			i %= this.views.length;

			// This takes i = -4 and turns it into (views.length = 6) + (-4) = 2
			if (i < 0) {
				i += this.views.length;
			}

			this.setActive(this.views[i]);

			// This turns i one/id-based
			return i + 1;
		}
	});

	return Tabs;
});
/**
 * The tabs container-model.
 */
define(
	'tabs/tabs',["lodash", "jquery", "backbone", "browser/api", "storage/storage", "storage/defaults", "core/status", "modals/alert", "core/analytics", "tabs/collection", "i18n/i18n", "settings/proxy"],
	function(_, $, Backbone, Browser, Storage, Defaults, Status, Alert, Track, Tabs, Translate, SettingsProxy) {
		var Model = Backbone.Model.extend({
				initialize: function() {
					this.tabs = new Tabs();
				},

				init: function() {
					Storage.on("done updated", function(storage, promise, data) {
						if (!(data && data.tabSort)) {
							var defaults = _.assign({}, Defaults.tab, {
								adPlacement: storage.settings.adPlacement,
								isGrid: storage.settings.layout === "grid",
								fixed: storage.settings.columnWidth === "fixed"
							});


							var oTabs = this.get("tabs") || "";

							this.set({
								tabs: JSON.stringify(_.map(storage.tabs, function(e) {
									return _.omit(e, "columns");
								})),
								default: (storage.settings.defaultTab || 1),
								defaults: defaults
							});

							this.storage = storage;

							this.tabs.defaults = defaults;
							this.tabs.default = (storage.settings.defaultTab || 1);


							if (this.get("tabs") !== oTabs) {
								this.tabs.reset(JSON.parse(JSON.stringify(storage.tabs || [])), {
									parse: true
								});
							}
							else {
								this.tabs.set(JSON.parse(JSON.stringify(storage.tabs || [])), {
									parse: true
								});
							}

							this.tabs.navigate();
						}
					}, this);
				}
			}),
			View = Backbone.View.extend({
				tagName: "div",
				className: "tab-container",
				attributes: {
					tabindex: "-1"
				},

				events: {
					"click .tab-nav button": function(e) {
						this.model.tabs.navigate($(e.currentTarget).attr("data-direction"));
					},
					"keydown": function(e) {
						if (e.which === 37) {
							this.model.tabs.navigate("prev");
						}
						else if (e.which === 39) {
							this.model.tabs.navigate("next");
						}
					},
					"keydown .widgets-container .widget": function(e) {
						if (e.currentTarget.className.indexOf("dragged") === -1) {
							e.stopPropagation();
						}
					},
					"mouseover .tab-nav button": function(e) {
						if ($(document.body).hasClass("dragging")) {
							this.timeout = setTimeout(function() {
								this.model.tabs.navigate($(e.currentTarget).attr("data-direction"));
							}.bind(this), 500);
						}
					},
					"mouseout .tab-nav button": function() {
						clearTimeout(this.timeout);
					},

					"click .ad-unit button.hide-ad": function() {
						Alert({
							contents: [Translate("hide_ad.content")],
							buttons: {
								negative: Translate("hide_ad.upgrade"),
								positive: Translate("hide_ad.hide")
							}
						}, function(hide) {
							if (hide) {
								var elm = document.createElement("style");

								elm.innerHTML = ".ad-unit { display: none; }";

								this.$el.before(elm);
							}
							else {
								SettingsProxy("pro");
							}
						}.bind(this));
					},

					"click .upgrade-to-pro": function(e) {
						var titleVar = $(e.currentTarget).data('title');
						if (titleVar === null) { titleVar = "title-default"; }
						var title = Translate("upgrade_to_pro." + titleVar);

						Alert({
							title: title,
							contents: [Translate("upgrade_to_pro.content-default")],
							buttons: {
							negative: Translate("upgrade_to_pro.upgrade"),
								positive: Translate("upgrade_to_pro.close")
							}
						}, function(close) {
							if (close) {
							}
							else {
								SettingsProxy("pro");
							}
						}.bind(this));
					}
				},

				navigate: function(id) {
					this.model.tabs.navigate(id);
				},

				initialize: function(options, navigate) {
					// Sortable must be initialized before the model tries to create the tabs
					this.sortable();

					$(document).bind("deletewidget", function(e, widgetDiv) {
						var item = $(widgetDiv);

						if (!item.hasClass('widget')) {
							return;
						}

						if (confirm(Translate("widgets.delete_confirm"))) {
							item.remove();

							item.removed = true;

							Track.FB.logEvent("WidgetUninstall", null, { fb_content_id: item.attr("data-name") });

							Track.event("Widgets", "Uninstall", item.attr("data-name"));

							this.serialize(true);
						}
					}.bind(this));

					// Listen for ad unit messages
					window.addEventListener("message", function(e) {
						if (e.origin === "http://localhost:4000" || e.origin === "https://ichro.me" || e.origin === "http://ichro.me") {
							var d = {};

							try {
								d = JSON.parse(e.data);
							}
							catch (err) {}

							if (d && d.hideAd) {
								this.$el.find("#" + d.hideAd).remove();
							}
							else if (d && d.showAdsScreen) {
								SettingsProxy("ads");
							}
							else if (d && d.showProScreen) {
								SettingsProxy("pro");
							}
							else if (d && d.adsizew && d.adsizeh) {
								var adunit = $(".tab-container .tab > .ad-unit");
								adunit.width(d.adsizew);
								adunit.height(d.adsizeh);

								var adframe = $("#adframe");
								adframe.width(d.adsizew);
								adframe.height(d.adsizeh);
							}
						}
					}.bind(this), false);

					this.model = new Model();

					this.on("navigate", navigate);

					this.model.tabs
						.on("views:change", this.render, this)
						.on("sort columns:save change:columns", function() {
							this.model.storage.tabs = this.model.tabs.toJSON();

							this.model.storage.sync({ tabSort: true });
						}, this)
						.on("navigate", function(index, view, model) {
							this.trigger("navigate", index, view, model);
						}, this);

					// init() needs to be called after the listener is attached to prevent a race condition when storage is already loaded.
					// It also needs to be here instead of attached directly to new Model() otherwise this.model might not be set yet.
					this.model.on("change", this.render, this).init();
				},


				/**
				 * Initializes the sortable group, since the sortable plugin only uses settings from the first
				 * call for that group this should be initialized from the main tabs view and the the individual
				 * tab views.
				 *
				 * The group is initialized by creating a sortable instance for a detached element and then removing
				 * the element from the sortable group
				 *
				 * @api    private
				 */
				sortable: function() {
					var elm = $("<div></div>");

					var tcOTop = 0,
						tcHeight = 0,
						onGrid = false,
						grid, gridMax,
						body = $(document.body);

					elm.sortable({
						group: "columns",
						handle: ".handle",
						itemSelector: "section",
						dynamicDimensions: true,
						placeholder: "<section class=\"placeholder\"/>",
						onDragStart: function(item) {
							var ret = item.triggerHandler("sortabledragstart", arguments);

							if (ret) {
								item = ret;
							}
							else {
								var css = {
									height: item[0].offsetHeight,
									width: item[0].offsetWidth,
									minWidth: item[0].offsetWidth,
									maxWidth: item[0].offsetWidth
								};

								item.before('<section id="originalLoc"></section>').css(css).addClass("dragged").appendTo("body > .widgets-container");
							}

							var tc = body.addClass("dragging").children(".tab-container")[0];

							tcOTop = tc.offsetTop;
							tcHeight = tc.offsetHeight;
						},
						onDrag: function(item, position) {
							if (item.context) {
								position.top -= item.context.offsetTop;
								position.left -= item.context.offsetLeft;
							}

							if (onGrid) {
								position.left = 10 * Math.round(position.left / 10); // Rounded to nearest 10
								position.top = 10 * Math.round((position.top - tcOTop) / 10) + tcOTop;

								var max = position.top + item[0].offsetHeight - tcOTop;

								if (gridMax > max) {
									max = gridMax;
								}

								grid[0].style.height = (max + 50) + "px";
							}

							item[0].style.top = position.top + "px";
							item[0].style.left = position.left + "px";
						},
						onBeforeDrop: function(item, placeholder) {
							if (placeholder.parent() && placeholder.parent().is(".remove")) {
								if (item.installing || confirm(Translate("widgets.delete_confirm"))) {
									item.remove();

									item.removed = true;

									if (!item.installing) {
										Track.FB.logEvent("WidgetUninstall", null, { fb_content_id: item.attr("data-name") });

										Track.event("Widgets", "Uninstall", item.attr("data-name"));
									}
								}
								else {
									item.insertBefore("#originalLoc");

									item.reset = true;

									item.isMoved = true;
								}

								return false;
							}

							return true;
						},
						onDrop: function(item, container, _super) {
							var css;

							if (item.isMoved) {
								css = {
									top: item.css("top"),
									left: item.css("left"),
									width: item.css("width"),
									height: item.css("height")
								};
							}
							else {
								css = {
									top: item.position().top - tcOTop,
									left: item.position().left,
									width: Math.round(item.outerWidth() / 10) * 10 - 1,
									height: Math.round(item.outerHeight() / 10) * 10 - 1
								};
							}

							_super(item);


							var view = {};

							if (!item.removed && !item.reset && (view = item.data("view"))) {
								view.onGrid = false;

								if (item.parent().parent().hasClass("grid")) {
									item.css(css);

									view.onGrid = true;
								}

								view.refresh();

								if (item.installing) {
									Track.FB.logEvent("WidgetInstall", null, { widgetId: view.widget.name, size: view.model.get("size") });

									Track.queue("widgets", "install", view.widget.name, view.model.get("size"));

									Track.event("Widgets", "Install", view.widget.name);
								}
							}

							// Trigger a repaint so the tabs height is correct, jQuery oddly seems to be the only thing that gets a flicker-free one.
							body.hide(0, function() {
								body.show();
							});

							$("#originalLoc").remove();

							this.serialize(true);

							Backbone.trigger("widget-dropped");
						}.bind(this),
						afterMove: function(placeholder, container) {
							if (container.el[0].className.indexOf("widgets-container") === -1) {
								onGrid = false;

								placeholder[0].style.width = container.group.item[0].offsetWidth + "px";
								placeholder[0].style.height = container.group.item[0].offsetHeight + "px";

								if (container.group.item.hasClass("tiny")) {
									placeholder.addClass("tiny");
								}
								else {
									placeholder.removeClass("tiny");
								}
							}
							else {
								onGrid = true;

								grid = container.el;

								gridMax = tcHeight - 50;

								var h;

								_.each(grid[0].querySelectorAll(".widget"), function(e) {
									h = e.offsetTop + e.offsetHeight;

									if (h >= gridMax) { gridMax = h; }
								});
							}
						}
					});


					var dta = elm.data("sortable");

					if (dta) {
						if (dta.rootGroup.containers.length === 1) {
							dta.rootGroup.containers = [];
						}
						else {
							_.remove(dta.rootGroup.containers, function(e) {
								return elm.is(e.el);
							});
						}
					}

					return elm;
				},


				/**
				 * Calls serialize on each of the tabs, optionally re-rendering them
				 *
				 * @api    private
				 * @param  {Boolean}  [render]  If the tabs should be re-rendered
				 */
				serialize: function(render) {
					_.invoke(this.model.tabs.views, "serialize");

					// Since the render only inserts columns and widgets it's not expensive
					// This is called in requestAnimationFrame so there isn't a visible freeze
					if (render === true) {
						window.requestAnimationFrame(function() {
							_.invoke(this.model.tabs.views, "render");
						}.bind(this));
					}

					this.model.storage.tabs = this.model.tabs.toJSON();

					this.model.storage.sync({ tabSort: true });
				},

				render: function() {
					// If the tabs are not detached and are still active then when the .html() is called the
					// jQuery data will be removed from all descendants (including columns), destroying sorting.
					$(_.pluck(this.model.tabs.views, "el")).detach();


					this.$el
						.html(
							'<div class="tab-nav">' +
								'<button type="button" class="material fab m-icon prev" data-direction="prev">navigate_before</button>' +
								'<button type="button" class="material fab m-icon next" data-direction="next">navigate_next</button>' +
							'</div>'
						)
						.toggleClass("one-tab", this.model.tabs.length === 1)
						.append(_.pluck(this.model.tabs.views, "el"));

					_.each(this.model.tabs.views, function(e) {
						e.trigger("inserted");
					});

					return this;
				}
			});

		return View;
	}
);
/**
 * The main ProductivityTab view, this initializes everything.
 */
define('core/init',[
	"jquery", "lodash", "browser/api", "backbone", "core/auth", "core/status", "core/analytics", "storage/storage", "core/css",
	"themes/controller", "themes/bginfo", "core/tooltips", "menu/menu", "menu/toolbar", "menu/button", "tabs/tabs", "widgets/store"
], function($, _, Browser, Backbone, Auth, Status, Track, Storage, CSS, Themes, BGInfo, Tooltips, Menu, Toolbar, MenuButton, Tabs, Store) {
	var Model = Backbone.Model.extend({
		init: function() {
			this.on("change:theme", function() {
				Themes.setTheme(this.get("theme"));
			});

			Storage.on("done updated", function(storage) {
				this.set({
					style: storage.settings.style,
					theme: storage.settings.theme,
					toolbar: storage.settings.toolbar,
					editing: storage.settings.editing,
					target: storage.settings.openLinksInNewTab ? "_blank" : "_self"
				});
			}, this);

			return this;
		}
	});

	var iChrome = Backbone.View.extend({
		el: "body",

		Status: Status,

		events: {
			"click .nested-link[data-href]": function(e) {
				// If this was an anchor inside a nested link (like the
				// Twitter widget), then let it pass
				if ($(e.target).is("a")) {
					return;
				}

				e.preventDefault();

				var a = document.createElement("a"),
					elm = $(e.currentTarget);

				a.href = elm.attr("data-href") || "#";

				var target = elm.attr("target");

				if (target) {
					a.target = target;
				}

				a.click();
			},

			"click .bg-info .icon": function(e) {
				e.currentTarget.parentNode.appendChild(new BGInfo({
					body: this.$el
				}).el);
			},

			"click .add-widget-link .icon": function() {
				if (!this.Store) {
					this.Store = new Store();
				}

				// This delays displaying the modal until after the init JS is done so the animation is smooth
				requestAnimationFrame(this.Store.show.bind(this.Store));
			}
		},


		initialize: function() {
			this.model = new Model();

			var loaded = false;

			// This only fires on change otherwise users with the
			// button might see a FOUT (Flash Of Unchosen Toolbar)
			this.model.on("change:toolbar", function() {
				if (!this.Toolbar) {
					this.Toolbar = new Toolbar();
				}

				if (this.model.get("toolbar") === "full2" || this.model.get("toolbar") === "full") {
					if (this.MenuButton) {
						this.MenuButton.$el.detach();
					}
					else {
						Track.event("Toolbar", "Load"); // If a menu button doesn't exist this isn't a setting change
					}

					this.$el.removeClass("floating-toolbar");
				}
				else {
					if (!this.MenuButton) {
						this.MenuButton = new MenuButton();
					}

					if (this.Toolbar) {
						this.Toolbar.$el.detach();
					}
					else {
						Track.event("Menu Button", "Load");
					}

					this.$el.prepend(this.MenuButton.render().el);

					this.$el.addClass("floating-toolbar");
				}

				this.$el.prepend(this.Toolbar.render().el);
				this.Toolbar.trigger("inserted");

				if (!loaded) {
					loaded = true;

					var loader = this.$el.removeClass("unloaded").children(".loading");

					var animationPlayer = loader[0].animate([
						{ opacity: 1 },
						{ opacity: 0 }
					], {
						duration: 100,
						easing: "cubic-bezier(.4, 0, .2, 1)"
					});

					animationPlayer.onfinish = function() {
						loader.remove();
					};
				}
			}, this).on("change:editing", function() {
				this.$el.toggleClass("no-edit", this.model.get("editing") === false);
			}, this).on("change:style", function() {
				this.$el.removeClass(this.model.previous("style"));

				if (Auth.isPro && this.model.get("style") !== "light") {
					this.$el.addClass(this.model.get("style"));
				}
			}, this).on("change:target", function() {
				$("base").attr("target", this.model.get("target"));
			}, this).init();


			this.css = new CSS();

			this.tooltips = new Tooltips();

			var menu = this.Menu = Menu.init(function() {
				tabs.navigate.apply(tabs, arguments);
			});

			var tabs = this.Tabs = new Tabs({
				el: this.$(".tab-container")
			}, function() {
				menu.navigate.apply(menu, arguments);
			});

			//Append custom CSS to body
			this.$el.append(this.css.el);

			if (Auth.isPro) {
				this.$el.addClass("main-pro");
			}

			// requestAnimationFrame ensures this runs after everything is done
			requestAnimationFrame(function() {
				Track.pageDone(this.model.get("toolbar"));
			}.bind(this));
		}
	});


	/**
	 * Background image preloading
	 *
	 * This makes the background image appear with the first render
	 * and makes the first paint happen sooner
	 */
	var themeImg = Browser.storage.themeImg;

	if (themeImg) {
		var loader = new Image();

		loader.src = themeImg;

		loader.onload = function() {
			if (!document.body.style.backgroundImage) {
				document.body.style.backgroundImage = "url(\"" + themeImg + "\")";
			}

			// Force repaint
			document.body.offsetHeight; // jshint ignore:line
		};
	}

	return new iChrome();
});
/**
 * Handles auto-running certain modules without the cost of initializing them when they aren't needed
 */
define('core/autorun',["browser/api"], function(Browser) {
	if (Browser.storage.firstRun === "true" || Browser.storage.firstRun === "resume" || (Browser.storage.nextAuth && Browser.storage.nextAuth <= new Date().getTime())) {
		require(["onboarding/controller"]);
	}

	if (Browser.storage.showUpdated === "true") {
		require(["notices/updated"]);
	}

	if (Browser.storage.showSignInNotice === "true") {
		require(["notices/signin"]);
	}
});
window.pgjs = window.pgjs || {};
window.pgjs.gdpr = window.pgjs.gdpr || {};
window.pgjs.publisher = window.pgjs.publisher || {};
window.pgjs.publisher.name = 'ProductivityTab';
window.pgjs.publisher.privacyPolicy = 'https://productivitytab.co/privacy-policy';
// pgjs.publisher.dataUses = 'user experience customization, analytics';
// pgjs.publisher.logo = 'https://pubguru.com/wp-content/uploads/2017/06/PubGuru-Logo-Final-color-high-res-trans-2000.png';

// use the direct link instead of the CDN temporarily as we continue to add more customizations and
var script = document.createElement("script");
script.async = true;
script.type = "text/javascript";
script.src = 'https://cdn.pubguru.com/pg.js';
var target = document.getElementsByTagName("head")[0];
target.insertBefore(script, target.firstChild);
define("core/pgdg", function(){});

/**
 * Configure requireJS.
 */
require.config({
	baseUrl: "js",
	paths: {
		"w": "../widgets",
		"text": "lib/text",
		"json": "lib/json",
		"hogan": "lib/hogan",
		"oauth": "lib/oauth",
		"lodash": "lib/lodash",
		"moment": "lib/moment",
		"jquery": "lib/jquery",
		"backbone": "lib/backbone",
		"oauth2": "../oauth2/oauth2",
		"fbanalytics": "lib/fbanalytics",
		"widgetTemplate": "widgets/registry/template",
		"jquery.serializejson": "lib/jquery.serializejson",
		"facebooksdk": "https://connect.facebook.net/en_US/sdk",
		"backbone.viewcollection": "lib/backbone.viewcollection",		
		"fullcalendar": "lib/fullcalendar",
		"gcloader": "lib/gcloader",
		"feedlyproxy": "lib/feedlyproxy",
		"cryptoJs": "lib/cryptojs",
	},
	map: {
		"*": {
			"underscore": "lodash" // a Lodash Underscore build is not required for Backbone
		}
	},
	shim: {
		"lib/jquery.sortable": ["jquery"],
		"facebooksdk": {
			exports: "FB"
		}
	}
});


// Make require synchronous. We do this to avoid delays with the two-tiered
// widget system (load the manifest, then the actual code). Without it calls to
// require wait at least 4ms before resolving, even if the module has been
// registered (but not initialized). The difference is difficult to measure but
// this saves approximately 200ms until the first full widget paint.
if (require.s) {
	require.s.contexts._.nextTick = function(fn) {
		return fn();
	};
}


/**
 * Init
 */
require(["core/init", "core/autorun", "core/pgdg"], function(app) {
	window.App = app;
});
define("app", function(){});

